=encoding utf8

=head1 NAME

Locale::CLDR::Locales::Or - Package for language Odia

=cut

package Locale::CLDR::Locales::Or;
# This file auto generated from Data\common\main\or.xml
#	on Fri 17 Jan 12:03:31 pm GMT

use strict;
use warnings;
use version;

our $VERSION = version->declare('v0.46.0');

use v5.12.0;
use mro 'c3';
use utf8;
use feature 'unicode_strings';
use Types::Standard qw( Str Int HashRef ArrayRef CodeRef RegexpRef );
use Moo;

extends('Locale::CLDR::Locales::Root');
has 'display_name_language' => (
	is			=> 'ro',
	isa			=> CodeRef,
	init_arg	=> undef,
	default		=> sub {
		 sub {
			 my %languages = (
				'aa' => 'ଅଫାର୍',
 				'ab' => 'ଆବ୍ଖାଜିଆନ୍',
 				'ace' => 'ଆଚାଇନୀଜ୍',
 				'ach' => 'ଆକୋଲି',
 				'ada' => 'ଆଦାଙ୍ଗେମ୍',
 				'ady' => 'ଅଦ୍ୟଘେ',
 				'ae' => 'ଅବେସ୍ତନ',
 				'af' => 'ଆଫ୍ରିକୀୟ',
 				'afh' => 'ଆଫ୍ରିହିଲି',
 				'agq' => 'ଆଘେମ',
 				'ain' => 'ଆଇନୁ',
 				'ak' => 'ଅକନ୍',
 				'akk' => 'ଆକାଡିଆନ୍',
 				'ale' => 'ଆଲେଇଟୁ',
 				'alt' => 'ଦକ୍ଷିଣ ଆଲ୍ଟାଇ',
 				'am' => 'ଆମହାରକି',
 				'an' => 'ଆର୍ଗୋନୀ',
 				'ang' => 'ପୁରୁଣା ଇଁରାଜୀ',
 				'ann' => 'ଅବୋଲା',
 				'anp' => 'ଅଁଗୀକା',
 				'ar' => 'ଆରବିକ୍',
 				'ar_001' => 'ଆଧୁନିକ ମାନକ ଆରବିକ୍‌',
 				'arc' => 'ଆରାମାଇକ୍',
 				'arn' => 'ମାପୁଚେ',
 				'arp' => 'ଆରାପାହୋ',
 				'ars' => 'ନାଜଦି ଆରବିକ',
 				'arw' => 'ଆରୱକ',
 				'as' => 'ଆସାମୀୟ',
 				'asa' => 'ଆସୁ',
 				'ast' => 'ଆଷ୍ଟୁରିଆନ୍',
 				'atj' => 'ଆଟିକାମେକ୍ୱ',
 				'av' => 'ଆଭାରିକ୍',
 				'awa' => 'ଆୱାଧି',
 				'ay' => 'ଆୟମାରା',
 				'az' => 'ଆଜେରବାଇଜାନି',
 				'az@alt=short' => 'ଆଜେରି',
 				'ba' => 'ବାଶକିର୍',
 				'bal' => 'ବାଲୁଚି',
 				'ban' => 'ବାଲିନୀଜ୍',
 				'bas' => 'ବାସା',
 				'be' => 'ବେଲାରୁଷିଆନ୍',
 				'bej' => 'ବେଜା',
 				'bem' => 'ବେମ୍ବା',
 				'bez' => 'ବେନା',
 				'bg' => 'ବୁଲଗେରିଆନ୍',
 				'bgc' => 'ହରିୟାନଭି',
 				'bho' => 'ଭୋଜପୁରୀ',
 				'bi' => 'ବିସଲାମା',
 				'bik' => 'ବିକୋଲ୍',
 				'bin' => 'ବିନି',
 				'bla' => 'ସିକସିକା',
 				'blo' => 'ବ୍ଲୋ',
 				'bm' => 'ବାମ୍ବାରା',
 				'bn' => 'ବଙ୍ଗଳା',
 				'bo' => 'ତିବ୍ବତୀୟ',
 				'br' => 'ବ୍ରେଟନ୍',
 				'bra' => 'ବ୍ରାଜ୍',
 				'brx' => 'ବୋଡୋ',
 				'bs' => 'ବୋସନିଆନ୍',
 				'bua' => 'ବୁରିଆଟ୍',
 				'bug' => 'ବୁଗୀନୀଜ୍',
 				'byn' => 'ବ୍ଲିନ୍',
 				'ca' => 'କାଟାଲାନ୍',
 				'cad' => 'କାଡୋ',
 				'car' => 'କାରିବ୍',
 				'cay' => 'କାୟୁଗା',
 				'cch' => 'ଆତ୍ସମ୍',
 				'ccp' => 'ଚକମା',
 				'ce' => 'ଚେଚନ୍',
 				'ceb' => 'ସୀବୁଆନୋ',
 				'cgg' => 'ଚିଗା',
 				'ch' => 'ଚାମୋରୋ',
 				'chb' => 'ଚିବ୍ଚା',
 				'chg' => 'ଛଗତାଇ',
 				'chk' => 'ଚୁକୀସେ',
 				'chm' => 'ମାରୀ',
 				'chn' => 'ଚିନୁକ୍ ଜାରଗାଁନ୍',
 				'cho' => 'ଚୋଟୱା',
 				'chp' => 'ଚିପେୱାନ୍',
 				'chr' => 'ଚେରୋକୀ',
 				'chy' => 'ଚେଚେନା',
 				'ckb' => 'କେନ୍ଦ୍ରୀୟ କୁରଡିସ୍',
 				'clc' => 'ଚିଲକୋଟିନ୍',
 				'co' => 'କୋର୍ସିକାନ୍',
 				'cop' => 'କପ୍ଟିକ୍',
 				'cr' => 'କ୍ରୀ',
 				'crg' => 'ମିସିଫ',
 				'crh' => 'କ୍ରୀମିନ୍ ତୁର୍କୀସ୍',
 				'crj' => 'ସାଉଥ୍ ଇଷ୍ଟ କ୍ରି',
 				'crk' => 'ପ୍ଲେନ୍ସ କ୍ରି',
 				'crl' => 'ଉତ୍ତର ପୂର୍ବ କ୍ରୀ',
 				'crm' => 'ମୁସେ କ୍ରୀ',
 				'crr' => 'କାରୋଲିନା ଆଲଗୋନ୍କିଆନ୍',
 				'crs' => 'ସେସେଲୱା କ୍ରେଓଲେ ଫ୍ରେଞ୍ଚ୍',
 				'cs' => 'ଚେକ୍',
 				'csb' => 'କାଶୁବିଆନ୍',
 				'csw' => 'ସ୍ୱାମ୍ପି କ୍ରି',
 				'cu' => 'ଚର୍ଚ୍ଚ ସ୍ଲାଭିକ୍',
 				'cv' => 'ଚୁଭାଶ୍',
 				'cy' => 'ୱେଲ୍ସ',
 				'da' => 'ଡାନିସ୍‌',
 				'dak' => 'ଡାକୋଟା',
 				'dar' => 'ଡାରାଗ୍ୱା',
 				'dav' => 'ତାଇତି',
 				'de' => 'ଜର୍ମାନ',
 				'de_AT' => 'ଅଷ୍ଟ୍ରିଆନ୍ ଜର୍ମାନ',
 				'de_CH' => 'ସ୍ୱିସ୍‌ ହାଇ ଜର୍ମାନ',
 				'del' => 'ଡେଲାୱେର୍',
 				'den' => 'ସ୍ଲେଭ୍',
 				'dgr' => 'ଡୋଗ୍ରିବ୍',
 				'din' => 'ଦିଙ୍କା',
 				'dje' => 'ଜର୍ମା',
 				'doi' => 'ଡୋଗ୍ରୀ',
 				'dsb' => 'ନିମ୍ନ ସର୍ବିଆନ୍‌',
 				'dua' => 'ଡୁଆନା',
 				'dum' => 'ମଧ୍ୟ ପର୍ତ୍ତୁଗାଲୀ',
 				'dv' => 'ଡିଭେହୀ',
 				'dyo' => 'ଜୋଲା-ଫୋନୟି',
 				'dyu' => 'ଡୁଆଲା',
 				'dz' => 'ଦଡଜୋଙ୍ଗଖା',
 				'dzg' => 'ଡାଜାଗା',
 				'ebu' => 'ଏମ୍ଵୁ',
 				'ee' => 'ଇୱେ',
 				'efi' => 'ଏଫିକ୍',
 				'egy' => 'ପ୍ରାଚୀନ୍ ମିଶିରି',
 				'eka' => 'ଏକାଜୁକ୍',
 				'el' => 'ଗ୍ରୀକ୍',
 				'elx' => 'ଏଲାମାଇଟ୍',
 				'en' => 'ଇଂରାଜୀ',
 				'en_AU' => 'ଅଷ୍ଟ୍ରେଲିୟ ଇଂରାଜୀ',
 				'en_CA' => 'କାନାଡିୟ ଇଂରାଜୀ',
 				'en_GB' => 'ବ୍ରିଟିଶ୍‌ ଇଂରାଜୀ',
 				'en_GB@alt=short' => 'ଯୁକ୍ତରାଜ୍ୟ ଇଂରାଜୀ',
 				'en_US' => 'ଆମେରିକୀୟ ଇଂରାଜୀ',
 				'en_US@alt=short' => 'ଯୁକ୍ତରାଷ୍ଟ୍ର ଇଂରାଜୀ',
 				'enm' => 'ମଧ୍ୟ ଇଁରାଜୀ',
 				'eo' => 'ଏସ୍ପାରେଣ୍ଟୋ',
 				'es' => 'ସ୍ପାନିସ୍‌',
 				'es_419' => 'ଲାଟିନ୍‌ ଆମେରିକୀୟ ସ୍ପାନିସ୍‌',
 				'es_ES' => 'ୟୁରୋପୀୟ ସ୍ପାନିସ୍‌',
 				'es_MX' => 'ମେକ୍ସିକାନ ସ୍ପାନିସ୍‌',
 				'et' => 'ଏସ୍ତୋନିଆନ୍',
 				'eu' => 'ବାସ୍କ୍ୱି',
 				'ewo' => 'ଇୱୋଣ୍ଡୋ',
 				'fa' => 'ପର୍ସିଆନ୍',
 				'fa_AF' => 'ଦାରି',
 				'fan' => 'ଫାଙ୍ଗ',
 				'fat' => 'ଫାଣ୍ଟି',
 				'ff' => 'ଫୁଲାହ',
 				'fi' => 'ଫିନ୍ନିସ୍',
 				'fil' => 'ଫିଲିପିନୋ',
 				'fj' => 'ଫିଜି',
 				'fo' => 'ଫାରୋଇଜ୍‌',
 				'fon' => 'ଫନ୍',
 				'fr' => 'ଫରାସୀ',
 				'fr_CA' => 'କାନାଡିୟ ଫ୍ରେଞ୍ଚ',
 				'fr_CH' => 'ସ୍ୱିସ୍ ଫ୍ରେଞ୍ଚ',
 				'frc' => 'କାଜୁନ୍ ଫରାସୀ',
 				'frm' => 'ମଧ୍ୟ ଫ୍ରେଞ୍ଚ',
 				'fro' => 'ପୁରୁଣା ଫ୍ରେଞ୍ଚ',
 				'frr' => 'ଉତ୍ତର ଫ୍ରିସିୟାନ୍',
 				'frs' => 'ପୂର୍ବ ଫ୍ରିସିୟାନ୍',
 				'fur' => 'ଫ୍ରିୟୁଲୀୟାନ୍',
 				'fy' => 'ପାଶ୍ଚାତ୍ୟ ଫ୍ରିସିଆନ୍',
 				'ga' => 'ଆଇରିସ୍‌',
 				'gaa' => 'ଗା',
 				'gay' => 'ଗାୟୋ',
 				'gba' => 'ଗବାୟା',
 				'gd' => 'ସ୍କଟିସ୍ ଗାଏଲିକ୍',
 				'gez' => 'ଗୀଜ୍',
 				'gil' => 'ଜିବ୍ରାଟୀଜ୍',
 				'gl' => 'ଗାଲିସିଆନ୍‌',
 				'gmh' => 'ମିଡିଲ୍ ହାଇ ଜର୍ମାନ୍',
 				'gn' => 'ଗୁଆରାନୀ',
 				'goh' => 'ପୁରୁଣା ହାଇ ଜର୍ମାନ୍',
 				'gon' => 'ଗୋଣ୍ଡି',
 				'gor' => 'ଗୋରୋଣ୍ଟାଲୋ',
 				'got' => 'ଗୋଥିକ୍',
 				'grb' => 'ଗ୍ରେବୋ',
 				'grc' => 'ପ୍ରାଚୀନ୍ ୟୁନାନୀ',
 				'gsw' => 'ସୁଇସ୍ ଜର୍ମାନ୍',
 				'gu' => 'ଗୁଜରାଟୀ',
 				'guz' => 'ଗୁସି',
 				'gv' => 'ମାଁକ୍ସ',
 				'gwi' => 'ଗୱିଚ’ଇନ୍',
 				'ha' => 'ହୌସା',
 				'hai' => 'ହାଇଡା',
 				'haw' => 'ହାୱାଇନ୍',
 				'hax' => 'ସାଉଥ୍ ହାଇଡା',
 				'he' => 'ହିବ୍ରୁ',
 				'hi' => 'ହିନ୍ଦୀ',
 				'hi_Latn@alt=variant' => 'ହିଂଲିସ',
 				'hil' => 'ହିଲିଗୈନନ୍',
 				'hit' => 'ହିତୀତେ',
 				'hmn' => 'ହଁଙ୍ଗ',
 				'ho' => 'ହିରି ମୋଟୁ',
 				'hr' => 'କ୍ରୋଏସୀୟ',
 				'hsb' => 'ଉପର ସର୍ବିଆନ୍',
 				'ht' => 'ହୈତାୟିନ୍',
 				'hu' => 'ହଙ୍ଗେରୀୟ',
 				'hup' => 'ହୁପା',
 				'hur' => 'ହାଲକୋମେଲେମ',
 				'hy' => 'ଆର୍ମେନିଆନ୍',
 				'hz' => 'ହେରେରୋ',
 				'ia' => 'ଇର୍ଣ୍ଟଲିଙ୍ଗୁଆ',
 				'iba' => 'ଇବାନ୍',
 				'ibb' => 'ଇବିବିଓ',
 				'id' => 'ଇଣ୍ଡୋନେସୀୟ',
 				'ie' => 'ଇର୍ଣ୍ଟରଲିଙ୍ଗୁଇ',
 				'ig' => 'ଇଗବୋ',
 				'ii' => 'ସିଚୁଆନ୍ ୟୀ',
 				'ik' => 'ଇନୁପିୟାକ୍',
 				'ikt' => 'ପାଶ୍ଚାତ୍ୟ କାନାଡିୟ ଇନୁକ୍ଟିଟ',
 				'ilo' => 'ଇଲୋକୋ',
 				'inh' => 'ଇଁଙ୍ଗୁଶ୍',
 				'io' => 'ଇଡୋ',
 				'is' => 'ଆଇସଲାଣ୍ଡିକ୍',
 				'it' => 'ଇଟାଲୀୟ',
 				'iu' => 'ଇନୁକଟିଟୁତ୍‌',
 				'ja' => 'ଜାପାନୀ',
 				'jbo' => 'ଲୋଜବାନ୍',
 				'jgo' => 'ନାଗୋମ୍ଵା',
 				'jmc' => 'ମାଚେମେ',
 				'jpr' => 'ଜୁଡେଓ-ପର୍ସିଆନ୍',
 				'jrb' => 'ଜୁଡେଓ-ଆରବୀକ୍',
 				'jv' => 'ଜାଭାନିଜ୍‌',
 				'ka' => 'ଜର୍ଜିଆନ୍‌',
 				'kaa' => 'କାରା-କଲ୍ପକ୍',
 				'kab' => 'କବାଇଲ୍',
 				'kac' => 'କଚିନ୍',
 				'kaj' => 'ଜଜୁ',
 				'kam' => 'କମ୍ବା',
 				'kaw' => 'କାୱି',
 				'kbd' => 'କାବାର୍ଡିଆନ୍',
 				'kcg' => 'ତ୍ୟାପ୍',
 				'kde' => 'ମାକୋଣ୍ଡେ',
 				'kea' => 'କାବୁଭେରଡିଆନୁ',
 				'kfo' => 'କୋରୋ',
 				'kg' => 'କଙ୍ଗୋ',
 				'kgp' => 'କାଇଙ୍ଗାଂ',
 				'kha' => 'ଖାସୀ',
 				'kho' => 'ଖୋତାନୀଜ୍',
 				'khq' => 'କୋୟରା ଚିନି',
 				'ki' => 'କୀକୁୟୁ',
 				'kj' => 'କ୍ୱାନ୍ୟାମ୍',
 				'kk' => 'କାଜାଖ୍‌',
 				'kkj' => 'କାକୋ',
 				'kl' => 'କାଲାଲିସୁଟ୍',
 				'kln' => 'କାଲେନଜିନ୍',
 				'km' => 'ଖାମେର୍',
 				'kmb' => 'କିମ୍ବୁଣ୍ଡୁ',
 				'kn' => 'କନ୍ନଡ',
 				'ko' => 'କୋରିଆନ୍',
 				'kok' => 'କୋଙ୍କଣି',
 				'kos' => 'କୋସରୈନ୍',
 				'kpe' => 'କୈପେଲେ',
 				'kr' => 'କନୁରୀ',
 				'krc' => 'କରାଚୟ-ବଲ୍କାର',
 				'krl' => 'କାରେଲିୟାନ୍',
 				'kru' => 'କୁରୁଖ',
 				'ks' => 'କାଶ୍ମିରୀ',
 				'ksb' => 'ଶାମବାଲା',
 				'ksf' => 'ବାଫଲା',
 				'ksh' => 'କୋଲୋବନିୟ',
 				'ku' => 'କୁର୍ଦ୍ଦିଶ୍',
 				'kum' => 'କୁମୀକ୍',
 				'kut' => 'କୁତେନାଉ',
 				'kv' => 'କୋମି',
 				'kw' => 'କୋର୍ନିସ୍',
 				'kwk' => 'କ୍ଵାକୱାଲା',
 				'kxv' => 'କୁୱି',
 				'ky' => 'କୀରଗୀଜ୍',
 				'la' => 'ଲାଟିନ୍',
 				'lad' => 'ଲାଦିନୋ',
 				'lag' => 'ଲାନଗି',
 				'lah' => 'ଲାହାଣ୍ଡା',
 				'lam' => 'ଲାମ୍ବା',
 				'lb' => 'ଲକ୍ସେମବର୍ଗିସ୍',
 				'lez' => 'ଲେଜଗିୟାନ୍',
 				'lg' => 'ଗନ୍ଦା',
 				'li' => 'ଲିମ୍ବୁର୍ଗିସ୍',
 				'lij' => 'ଲିଗୁରିଆନ୍‌',
 				'lil' => 'ଲିଲ୍ଲୁଏଟ',
 				'lkt' => 'ଲାକୋଟା',
 				'lmo' => 'ଲୋମ୍ବାର୍ଡ୍‌',
 				'ln' => 'ଲିଙ୍ଗାଲା',
 				'lo' => 'ଲାଓ',
 				'lol' => 'ମଙ୍ଗୋ',
 				'lou' => 'ଲୌସିଆନା କ୍ରେଓଲେ',
 				'loz' => 'ଲୋଜି',
 				'lrc' => 'ଉତ୍ତର ଲୁରି',
 				'lsm' => 'ସାମିଆ',
 				'lt' => 'ଲିଥୁଆନିଆନ୍',
 				'lu' => 'ଲ୍ୟୁବା-କାଟାଙ୍ଗା',
 				'lua' => 'ଲୁବା-ଲୁଲୁଆ',
 				'lui' => 'ଲୁଇସେନୋ',
 				'lun' => 'ଲୁଣ୍ଡା',
 				'luo' => 'ଲୁଓ',
 				'lus' => 'ମିଜୋ',
 				'luy' => 'ଲୁୟିଆ',
 				'lv' => 'ଲାଟଭିଆନ୍',
 				'mad' => 'ମାଦୁରୀସ୍',
 				'mag' => 'ମାଗାହୀ',
 				'mai' => 'ମୈଥିଳୀ',
 				'mak' => 'ମକାସର୍',
 				'man' => 'ମାଣ୍ଡିଙ୍ଗୋ',
 				'mas' => 'ମାସାଇ',
 				'mdf' => 'ମୋକ୍ଷ',
 				'mdr' => 'ମନ୍ଦାର',
 				'men' => 'ମେନଡେ',
 				'mer' => 'ମେରୁ',
 				'mfe' => 'ମୋରିସୟେନ୍',
 				'mg' => 'ମାଲାଗାସୀ',
 				'mga' => 'ମଧ୍ୟ ଇରିଶ୍',
 				'mgh' => 'ମଖୁୱା-ମେଟ୍ଟା',
 				'mgo' => 'ମେଟା',
 				'mh' => 'ମାର୍ଶାଲୀଜ୍',
 				'mi' => 'ମାଓରୀ',
 				'mic' => 'ମିକମୌକ୍',
 				'min' => 'ମିନାଙ୍ଗାବାଉ',
 				'mk' => 'ମାସେଡୋନିଆନ୍',
 				'ml' => 'ମାଲାୟଲମ୍',
 				'mn' => 'ମଙ୍ଗୋଲୀୟ',
 				'mnc' => 'ମାଞ୍ଚୁ',
 				'mni' => 'ମଣିପୁରୀ',
 				'moe' => 'ଇନ୍ନୁ-ଏମୁନ',
 				'moh' => 'ମୋହୌକ',
 				'mos' => 'ମୋସି',
 				'mr' => 'ମରାଠୀ',
 				'ms' => 'ମାଲୟ',
 				'mt' => 'ମାଲଟୀଜ୍',
 				'mua' => 'ମୁନଡାଂ',
 				'mul' => 'ବିବିଧ ଭାଷା',
 				'mus' => 'କ୍ରୀକ୍',
 				'mwl' => 'ମିରାଣ୍ଡିଜ୍',
 				'mwr' => 'ମାରୱାରୀ',
 				'my' => 'ବର୍ମୀଜ୍',
 				'myv' => 'ଏର୍ଜୟା',
 				'mzn' => 'ମାଜାନଡେରାନି',
 				'na' => 'ନାଉରୁ',
 				'nap' => 'ନୀପୋଲିଟାନ୍',
 				'naq' => 'ନାମା',
 				'nb' => 'ନରୱେଜିଆନ୍ ବୋକମଲ୍',
 				'nd' => 'ଉତ୍ତର ନେଡବେଲେ',
 				'nds' => 'ଲୋ ଜର୍ମାନ୍',
 				'ne' => 'ନେପାଳୀ',
 				'new' => 'ନେୱାରୀ',
 				'ng' => 'ଡୋଙ୍ଗା',
 				'nia' => 'ନୀୟାସ୍',
 				'niu' => 'ନିୟୁଆନ୍',
 				'nl' => 'ଡଚ୍',
 				'nl_BE' => 'ଫ୍ଲେମିଶ୍',
 				'nmg' => 'କୱାସିଓ',
 				'nn' => 'ନରୱେଜିଆନ୍ ନିନର୍ସ୍କ୍‌',
 				'nnh' => 'ନାଗିମବୋନ୍',
 				'no' => 'ନରୱେଜିଆନ୍',
 				'nog' => 'ନୋଗାଇ',
 				'non' => 'ପୁରୁଣା ନର୍ସ',
 				'nqo' => 'ଏନକୋ',
 				'nr' => 'ଦକ୍ଷିଣ ନେଡବେଲେ',
 				'nso' => 'ଉତ୍ତରୀ ସୋଥୋ',
 				'nus' => 'ନୁଏର',
 				'nv' => 'ନାଭାଜୋ',
 				'nwc' => 'ପାରମ୍ପରିକ ନେୱାରୀ',
 				'ny' => 'ନିୟାଞ୍ଜ',
 				'nym' => 'ନ୍ୟାମୱେଜୀ',
 				'nyn' => 'ନ୍ୟାନକୋଲ୍',
 				'nyo' => 'ନ୍ୟାରୋ',
 				'nzi' => 'ଞ୍ଜିମା',
 				'oc' => 'ଓସିଟାନ୍',
 				'oj' => 'ଓଜିୱା',
 				'ojb' => 'ଉତ୍ତର-ପଶ୍ଚିମ ଓଜିବ୍ଵା',
 				'ojc' => 'କେନ୍ଦ୍ରୀୟ ଓଜିବ୍ଵା',
 				'ojs' => 'ଓଜି-କ୍ରି',
 				'ojw' => 'ପାଶ୍ଚାତ୍ୟ ଓଜିବ୍ଵା',
 				'oka' => 'ଓକାନାଗାନ୍',
 				'om' => 'ଓରୋମୋ',
 				'or' => 'ଓଡ଼ିଆ',
 				'os' => 'ଓସେଟିକ୍',
 				'osa' => 'ୱୌସେଜ୍',
 				'ota' => 'ଓଟ୍ଟୋମନ୍ ତୁର୍କିସ୍',
 				'pa' => 'ପଞ୍ଜାବୀ',
 				'pag' => 'ପାଙ୍ଗାସିନିଆନ୍',
 				'pal' => 'ପାହ୍ଲାଭି',
 				'pam' => 'ପାମ୍ପାଙ୍ଗା',
 				'pap' => 'ପାପିଆମେଣ୍ଟୋ',
 				'pau' => 'ପାଲାଉଆନ୍',
 				'pcm' => 'ନାଇଜେରୀୟ ପିଡଗିନ୍',
 				'peo' => 'ପୁରୁଣା ପର୍ସିଆନ୍',
 				'phn' => 'ଫୋନେସିଆନ୍',
 				'pi' => 'ପାଲି',
 				'pis' => 'ପିଜିନ୍',
 				'pl' => 'ପୋଲିଶ୍',
 				'pon' => 'ପୋହପିଏନ୍',
 				'pqm' => 'ମାଲିସୀଟ-ପାସମକୁଅଡ୍ଡି',
 				'prg' => 'ପ୍ରୁସିୟ',
 				'pro' => 'ପୁରୁଣା ପ୍ରେଭେନେସିଆଲ୍',
 				'ps' => 'ପାସ୍ତୋ',
 				'pt' => 'ପର୍ତ୍ତୁଗୀଜ୍‌',
 				'pt_BR' => 'ବ୍ରାଜିଲିଆନ୍ ପର୍ତ୍ତୁଗୀଜ୍',
 				'pt_PT' => 'ୟୁରୋପୀୟ ପର୍ତ୍ତୁଗୀଜ୍‌',
 				'qu' => 'କ୍ୱେଚୁଆ',
 				'quc' => 'କିଚେ',
 				'raj' => 'ରାଜସ୍ଥାନୀ',
 				'rap' => 'ରାପାନୁଇ',
 				'rar' => 'ରାରୋତୋଙ୍ଗନ୍',
 				'rhg' => 'ରୋହିଙ୍ଗ୍ୟା',
 				'rm' => 'ରୋମାନଶ୍‌',
 				'rn' => 'ରୁଣ୍ଡି',
 				'ro' => 'ରୋମାନିଆନ୍',
 				'ro_MD' => 'ମୋଲଡୋଭିଆନ୍',
 				'rof' => 'ରୋମ୍ବୋ',
 				'rom' => 'ରୋମାନି',
 				'ru' => 'ରୁଷିୟ',
 				'rup' => 'ଆରୋମାନିଆନ୍',
 				'rw' => 'କିନ୍ୟାରୱାଣ୍ଡା',
 				'rwk' => 'ଆରଡବ୍ୟୁଏ',
 				'sa' => 'ସଂସ୍କୃତ',
 				'sad' => 'ସଣ୍ଡାୱେ',
 				'sah' => 'ୟାକୂଟ୍‌',
 				'sam' => 'ସାମୌରିଟନ୍ ଆରମାଇକ୍',
 				'saq' => 'ସମବୁରୁ',
 				'sas' => 'ସାସାକ୍',
 				'sat' => 'ସାନ୍ତାଳି',
 				'sba' => 'ନଗାମବେ',
 				'sbp' => 'ସାନଗୁ',
 				'sc' => 'ସାର୍ଡିନିଆନ୍‌',
 				'scn' => 'ସିଶିଲିଆନ୍',
 				'sco' => 'ସ୍କଟସ୍',
 				'sd' => 'ସିନ୍ଧୀ',
 				'se' => 'ଉତ୍ତର ସାମି',
 				'seh' => 'ସେନା',
 				'sel' => 'ସେଲ୍କପ୍',
 				'ses' => 'କୋୟରା ସେନ୍ନି',
 				'sg' => 'ସାଙ୍ଗୋ',
 				'sga' => 'ପୁରୁଣା ଇରିଶ୍',
 				'sh' => 'ସର୍ବୋ-କ୍ରୋଆଟିଆନ୍',
 				'shi' => 'ତାଚେଲହିଟ୍',
 				'shn' => 'ଶାନ୍',
 				'si' => 'ସିଂହଳ',
 				'sid' => 'ସିଦାମୋ',
 				'sk' => 'ସ୍ଲୋଭାକ୍',
 				'sl' => 'ସ୍ଲୋଭେନିଆନ୍',
 				'slh' => 'ସାଉଥ୍ ଲୁଶୋସିଟେଡ୍',
 				'sm' => 'ସାମୋଆନ୍',
 				'sma' => 'ଦକ୍ଷିଣ ସାମି',
 				'smj' => 'ଲୁଲେ ସାମି',
 				'smn' => 'ଇନାରୀ ସାମି',
 				'sms' => 'ସ୍କୋଲ୍ଟ ସାମି',
 				'sn' => 'ଶୋନା',
 				'snk' => 'ସୋନିଙ୍କେ',
 				'so' => 'ସୋମାଲିଆ',
 				'sog' => 'ସୋଗଡିଏନ୍',
 				'sq' => 'ଆଲବାନିଆନ୍',
 				'sr' => 'ସର୍ବିୟ',
 				'srn' => 'ଶାରାନା ଟୋଙ୍ଗୋ',
 				'srr' => 'ଶେରେର୍',
 				'ss' => 'ସ୍ଵାତି',
 				'ssy' => 'ସହୋ',
 				'st' => 'ସେସୋଥୋ',
 				'str' => 'ଷ୍ଟ୍ରାଇଟ୍ ସାଲିଶ୍',
 				'su' => 'ସୁଦାନୀଜ୍',
 				'suk' => 'ସୁକୁମା',
 				'sus' => 'ଶୁଶୁ',
 				'sux' => 'ସୁମେରିଆନ୍',
 				'sv' => 'ସ୍ୱେଡିସ୍',
 				'sw' => 'ସ୍ୱାହିଲି',
 				'sw_CD' => 'କଙ୍ଗୋ ସ୍ୱାହିଲି',
 				'swb' => 'କୋମୋରିୟ',
 				'syc' => 'କ୍ଲାସିକାଲ୍ ସିରିକ୍',
 				'syr' => 'ସିରିଆକ୍‌',
 				'szl' => 'ସାଇଲେସିଆନ୍‌',
 				'ta' => 'ତାମିଲ୍',
 				'tce' => 'ସାଉଥ୍ ଟଚୋନ୍',
 				'te' => 'ତେଲୁଗୁ',
 				'tem' => 'ତିମନେ',
 				'teo' => 'ତେସା',
 				'ter' => 'ତେରେନୋ',
 				'tet' => 'ତେତୁମ୍',
 				'tg' => 'ତାଜିକ୍',
 				'tgx' => 'ତାଗିଶ',
 				'th' => 'ଥାଇ',
 				'tht' => 'ତହଲତାନ୍',
 				'ti' => 'ଟାଇଗ୍ରିନିଆ',
 				'tig' => 'ଟାଇଗ୍ରେ',
 				'tiv' => 'ତୀଭ୍',
 				'tk' => 'ତୁର୍କମେନ୍',
 				'tkl' => 'ଟୋକେଲାଉ',
 				'tl' => 'ଟାଗାଲଗ୍',
 				'tlh' => 'କ୍ଲିଙ୍ଗନ୍',
 				'tli' => 'ତ୍ଲିଙ୍ଗିଟ୍',
 				'tmh' => 'ତାମାଶେକ୍',
 				'tn' => 'ସୱାନା',
 				'to' => 'ଟୋଙ୍ଗା',
 				'tog' => 'ନ୍ୟାସା ଟୋଙ୍ଗୋ',
 				'tok' => 'ଟୋକି ପୋନା',
 				'tpi' => 'ଟୋକ୍ ପିସିନ୍',
 				'tr' => 'ତୁର୍କିସ୍',
 				'trv' => 'ତାରୋକୋ',
 				'ts' => 'ସୋଙ୍ଗା',
 				'tsi' => 'ତିସିମିସିଆନ୍',
 				'tt' => 'ତାତାର୍',
 				'ttm' => 'ଉତ୍ତର ଟୁଚୋନ୍',
 				'tum' => 'ଟୁମ୍ବୁକା',
 				'tvl' => 'ତୁଭାଲୁ',
 				'tw' => 'ତ୍ୱି',
 				'twq' => 'ତାସାୱାକ୍',
 				'ty' => 'ତାହିତିଆନ୍',
 				'tyv' => 'ତୁଭିନିଆନ୍',
 				'tzm' => 'କେନ୍ଦ୍ରୀୟ ଆଟଲାସ୍ ଟାମାଜିଘାଟ୍',
 				'udm' => 'ଉଦମୂର୍ତ୍ତ',
 				'ug' => 'ୟୁଘୁର୍',
 				'uga' => 'ୟୁଗୋରଟିକ୍',
 				'uk' => 'ୟୁକ୍ରେନିଆନ୍',
 				'umb' => 'ଉମ୍ବୁଣ୍ଡୁ',
 				'und' => 'ଅଜଣା ଭାଷା',
 				'ur' => 'ଉର୍ଦ୍ଦୁ',
 				'uz' => 'ଉଜବେକ୍',
 				'vai' => 'ଭାଇ',
 				've' => 'ଭେଣ୍ଡା',
 				'vec' => 'ଭନିଶନ୍‌',
 				'vi' => 'ଭିଏତନାମିଜ୍',
 				'vmw' => 'ମାଖୁୱା',
 				'vo' => 'ବୋଲାପୁକ',
 				'vot' => 'ଭୋଟିକ୍',
 				'vun' => 'ଭୁନଜୋ',
 				'wa' => 'ୱାଲୁନ୍',
 				'wae' => 'ୱାଲସେର୍',
 				'wal' => 'ୱାଲମୋ',
 				'war' => 'ୱାରୈ',
 				'was' => 'ୱାସୋ',
 				'wo' => 'ୱୋଲଫ୍',
 				'wuu' => 'ୱୁ ଚାଇନିଜ',
 				'xal' => 'କାଲ୍ମୀକ୍',
 				'xh' => 'ଖୋସା',
 				'xnr' => 'କାଙ୍ଗ୍ରି',
 				'xog' => 'ସୋଗା',
 				'yao' => 'ୟାଓ',
 				'yap' => 'ୟାପୀସ୍',
 				'yav' => 'ୟାଂବେନ୍',
 				'ybb' => 'ୟେମବା',
 				'yi' => 'ୟିଡିସ୍',
 				'yo' => 'ୟୋରୁବା',
 				'yrl' => 'ନିଙ୍ଗାଟୁ',
 				'yue' => 'କାଣ୍ଟୋନିଜ୍‌',
 				'yue@alt=menu' => 'ଚାଇନିଜ୍‌, କାଣ୍ଟୋନିଜ୍‌',
 				'za' => 'ଜୁଆଙ୍ଗ୍‌',
 				'zap' => 'ଜାପୋଟେକ୍',
 				'zbl' => 'ବ୍ଲିସିମ୍ବଲସ୍',
 				'zen' => 'ଜେନାଗା',
 				'zgh' => 'ମାନାଙ୍କ ମରୋକିୟ ତାମାଜିଘାଟ୍',
 				'zh' => 'ଚାଇନିଜ୍‌',
 				'zh@alt=menu' => 'ଚାଇନିଜ୍, ମାଣ୍ଡାରିନ୍',
 				'zh_Hans' => 'ସରଳୀକୃତ ଚାଇନିଜ',
 				'zh_Hans@alt=long' => 'ସରଳୀକୃତ ମାଣ୍ଡାରିନ୍ ଚାଇନିଜ୍',
 				'zh_Hant' => 'ପାରମ୍ପରିକ ଚାଇନିଜ୍‌',
 				'zh_Hant@alt=long' => 'ପାରମ୍ପରିକ ମାଣ୍ଡାରିନ୍ ଚାଇନିଜ୍',
 				'zu' => 'ଜୁଲୁ',
 				'zun' => 'ଜୁନୀ',
 				'zxx' => 'କୌଣସି ଲିଙ୍ଗୁଇଷ୍ଟ ସାମଗ୍ରୀ ନାହିଁ',
 				'zza' => 'ଜାଜା',

			);
			if (@_) {
				return $languages{$_[0]};
			}
			return \%languages;
		}
	},
);

has 'display_name_script' => (
	is			=> 'ro',
	isa			=> CodeRef,
	init_arg	=> undef,
	default		=> sub {
		sub {
			my %scripts = (
			'Adlm' => 'ଆଡଲମ୍',
 			'Arab' => 'ଆରବିକ୍',
 			'Aran' => 'ନାଷ୍ଟାଲିକ୍‌',
 			'Armi' => 'ଇମ୍ପେରିଆଲ୍ ଆରମିକ୍',
 			'Armn' => 'ଆର୍ମେନୀୟ',
 			'Avst' => 'ଆବେସ୍ଥାନ୍',
 			'Bali' => 'ବାଲିନୀଜ୍',
 			'Batk' => 'ବାଟାକ୍',
 			'Beng' => 'ବଙ୍ଗାଳୀ',
 			'Blis' => 'ବ୍ଲିସିମ୍ବଲସ୍',
 			'Bopo' => 'ବୋପୋମୋଫୋ',
 			'Brah' => 'ବ୍ରାହ୍ମୀ',
 			'Brai' => 'ବ୍ରେଲ୍',
 			'Bugi' => 'ବୁଗାନୀଜ୍',
 			'Buhd' => 'ବୁହିଦ୍',
 			'Cakm' => 'ଚକମା',
 			'Cans' => 'ୟୁନିଫାଏଡ୍ କାନାଡିଆନ୍ ଆବ୍ରୋଜିନାଲ୍ ସିଲାବିକସ୍',
 			'Cari' => 'କୈରନ୍',
 			'Cham' => 'ଛମ୍',
 			'Cher' => 'ଚିରୁକୀ',
 			'Cirt' => 'ସିର୍ଥ',
 			'Copt' => 'କପଟିକ୍',
 			'Cprt' => 'ସିପ୍ରଅଟ୍',
 			'Cyrl' => 'ସିରିଲିକ୍',
 			'Cyrs' => 'ଓଲ୍ଡ ଚର୍ଚ୍ଚ ସାଲଭୋନିକ୍ ସିରିଲିକ୍',
 			'Deva' => 'ଦେବନାଗରୀ',
 			'Dsrt' => 'ଡେସର୍ଟ',
 			'Egyd' => 'ଇଜିପ୍ଟିଆନ୍ ଡେମୋଟିକ୍',
 			'Egyh' => 'ଇଜିପ୍ଟିଆନ୍ ହାଇଅରଟିକ୍',
 			'Egyp' => 'ଇଜିପ୍ଟିଆନ୍ ହାଅରଗ୍ଲିପସ୍',
 			'Ethi' => 'ଇଥିଓପିକ୍‌',
 			'Geok' => 'ଜର୍ଜିଆନ୍ ଖୁଟସୁରୀ',
 			'Geor' => 'ଜର୍ଜିୟ',
 			'Glag' => 'ଗ୍ଲାଗ୍ଲୋଟିକ୍',
 			'Goth' => 'ଗୋଥିକ୍',
 			'Grek' => 'ଗ୍ରୀକ୍',
 			'Gujr' => 'ଗୁଜରାଟୀ',
 			'Guru' => 'ଗୁରମୁଖୀ',
 			'Hanb' => 'ବୋପୋମୋଫୋ ସହିତ ହାନ୍‌',
 			'Hang' => 'ହାଙ୍ଗୁଲ୍',
 			'Hani' => 'ହାନ୍',
 			'Hano' => 'ହାନୁନ୍',
 			'Hans' => 'ସରଳୀକୃତ',
 			'Hans@alt=stand-alone' => 'ସରଳୀକୃତ ହାନ୍‌',
 			'Hant' => 'ପାରମ୍ପରିକ',
 			'Hant@alt=stand-alone' => 'ପାରମ୍ପରିକ ହାନ୍‌',
 			'Hebr' => 'ହିବୃ',
 			'Hira' => 'ହିରାଗାନା',
 			'Hmng' => 'ପାହୋ ହୋଙ୍ଗ',
 			'Hrkt' => 'ଜାପାନୀ ସିଲାବରିଜ୍‌',
 			'Hung' => 'ପୁରୁଣା ହଙ୍ଗେରିଆନ୍',
 			'Inds' => 'ସିନ୍ଧୁ',
 			'Ital' => 'ପୁରୁଣା ଇଟାଲୀ',
 			'Jamo' => 'ଜାମୋ',
 			'Java' => 'ଜାଭାନୀଜ୍',
 			'Jpan' => 'ଜାପାନୀଜ୍',
 			'Kali' => 'କାୟାହା ଲୀ',
 			'Kana' => 'କାତାକାନା',
 			'Khar' => 'ଖାରୋସ୍ଥି',
 			'Khmr' => 'ଖମେର୍',
 			'Knda' => 'କନ୍ନଡ଼',
 			'Kore' => 'କୋରିଆନ୍',
 			'Kthi' => 'କୈଥି',
 			'Lana' => 'ଲାନା',
 			'Laoo' => 'ଲାଓ',
 			'Latf' => 'ଫ୍ରାକଥୁର୍ ଲାଟିନ୍',
 			'Latg' => 'ଗାଏଲିକ୍ ଲାଟିନ୍',
 			'Latn' => 'ଲାଟିନ୍',
 			'Lepc' => 'ଲେପଚା',
 			'Limb' => 'ଲିମ୍ବୁ',
 			'Lina' => 'ଲିନିୟର୍',
 			'Linb' => 'ଲିନିୟର୍ ବି',
 			'Lyci' => 'ଲିଶିୟନ୍',
 			'Lydi' => 'ଲିଡିୟନ୍',
 			'Mand' => 'ମାନଡେନ୍',
 			'Mani' => 'ମନଶୀନ୍',
 			'Maya' => 'ମୟାନ୍ ହାୟରଲଜିକସ୍',
 			'Mero' => 'ମେରୋଇଟିକ୍',
 			'Mlym' => 'ମାଲାୟାଲମ୍',
 			'Mong' => 'ମଙ୍ଗୋଲିଆନ୍',
 			'Moon' => 'ଚନ୍ଦ୍ର',
 			'Mtei' => 'ମାଏତି ମାୟେକ୍',
 			'Mymr' => 'ମ୍ୟାନମାର୍',
 			'Nkoo' => 'ଏନ୍ କୋ',
 			'Ogam' => 'ଓଘାମା',
 			'Olck' => 'ଅଲ୍ ଚିକି',
 			'Orkh' => 'ଓରୋଖନ୍',
 			'Orya' => 'ଓଡ଼ିଆ',
 			'Osma' => 'ଓସୋମାନିୟା',
 			'Perm' => 'ଓଲ୍ଡ ପରମିକ୍',
 			'Phag' => 'ଫାଗସ୍-ପା',
 			'Phli' => 'ଇନସ୍କ୍ରୀପସାନଲ୍ ପାହାଲାୱୀ',
 			'Phlp' => 'ସ୍ଲାଟର୍ ପାହାଲାୱୀ',
 			'Phlv' => 'ବୁକ୍ ପାହାଲାୱୀ',
 			'Phnx' => 'ଫେନୋସିଆନ୍',
 			'Plrd' => 'ପୋଲାର୍ଡ ଫୋନେଟିକ୍',
 			'Prti' => 'ଇନସ୍କ୍ରୀପସାନଲ୍ ପାର୍ଥିଆନ୍',
 			'Rjng' => 'ରେଜାଙ୍ଗ',
 			'Rohg' => 'ହାନିଫି',
 			'Roro' => 'ରୋଙ୍ଗୋରୋଙ୍ଗୋ',
 			'Runr' => 'ରନିକ୍',
 			'Samr' => 'ସମୌରିଟନ୍',
 			'Sara' => 'ସାରାତି',
 			'Saur' => 'ସୌରାଷ୍ଟ୍ର',
 			'Sgnw' => 'ସାଙ୍କେତିକ ଲିଖ',
 			'Shaw' => 'ସାବିୟାନ୍',
 			'Sinh' => 'ସିଂହଳ',
 			'Sund' => 'ସୁଦାନିଜ୍',
 			'Sylo' => 'ସୀଲିତୋ ନଗରୀ',
 			'Syrc' => 'ସିରିୟାକ୍',
 			'Syre' => 'ଏଷ୍ଟ୍ରାଙ୍ଗେଲୋ ସିରିକ୍',
 			'Syrj' => 'ୱେଷ୍ଟର୍ନ ସିରିକ୍',
 			'Syrn' => 'ଇଷ୍ଟର୍ନ ସିରିକ୍',
 			'Tagb' => 'ତଗବାନ୍ୱା',
 			'Tale' => 'ତାଇ ଲେ',
 			'Talu' => 'ନୂତନ ତାଇ ଲୁଏ',
 			'Taml' => 'ତାମିଲ୍',
 			'Tavt' => 'ତାଇ ଭିଏତ୍',
 			'Telu' => 'ତେଲୁଗୁ',
 			'Teng' => 'ତେଙ୍ଗୱାର୍',
 			'Tfng' => 'ଟିଫିନାଘ୍‌',
 			'Tglg' => 'ଟାଗାଲୋଗ୍',
 			'Thaa' => 'ଥାନା',
 			'Thai' => 'ଥାଇ',
 			'Tibt' => 'ତିବେତାନ୍',
 			'Ugar' => 'ୟୁଗାରିଟିକ୍',
 			'Vaii' => 'ୱାଇ',
 			'Visp' => 'ଭିଜିବଲ୍ ସ୍ପିଚ୍',
 			'Xpeo' => 'ପୁରୁଣା ଫରାସୀ',
 			'Xsux' => 'ସୁମେରୋ-ଆକ୍କାଡିଆନ୍ ସୁନିଫର୍ମ',
 			'Yiii' => 'ୟୀ',
 			'Zinh' => 'ବଂଶଗତ',
 			'Zmth' => 'ଗାଣିତିକ ନୋଟେସନ୍',
 			'Zsye' => 'ଇମୋଜି',
 			'Zsym' => 'ସଙ୍କେତଗୁଡ଼ିକ',
 			'Zxxx' => 'ଅଲିଖିତ',
 			'Zyyy' => 'ସାଧାରଣ',
 			'Zzzz' => 'ଅଜଣା ଲିପି',

			);
			if ( @_ ) {
				return $scripts{$_[0]};
			}
			return \%scripts;
		}
	}
);

has 'display_name_region' => (
	is			=> 'ro',
	isa			=> HashRef[Str],
	init_arg	=> undef,
	default		=> sub {
		{
			'001' => 'ବିଶ୍ୱ',
 			'002' => 'ଆଫ୍ରିକା',
 			'003' => 'ଉତ୍ତର ଆମେରିକା',
 			'005' => 'ଦକ୍ଷିଣ ଆମେରିକା',
 			'009' => 'ଓସିନିଆ',
 			'011' => 'ପଶ୍ଚିମ ଆଫ୍ରିକା',
 			'013' => 'ମଧ୍ୟ ଆମେରିକା',
 			'014' => 'ପୂର୍ବ ଆଫ୍ରିକା',
 			'015' => 'ଉତ୍ତର ଆଫ୍ରିକା',
 			'017' => 'ମଧ୍ୟ ଆଫ୍ରିକା',
 			'018' => 'ଦକ୍ଷିଣସ୍ଥ ଆଫ୍ରିକା',
 			'019' => 'ଆମେରିକା',
 			'021' => 'ଉତ୍ତରସ୍ଥ ଆମେରିକା',
 			'029' => 'କାରିବିଆନ୍',
 			'030' => 'ପୂର୍ବ ଏସିଆ',
 			'034' => 'ଦକ୍ଷିଣ ଏସିଆ',
 			'035' => 'ଦକ୍ଷିଣପୂର୍ବ ଏସିଆ',
 			'039' => 'ଦକ୍ଷିଣ ୟୁରୋପ୍',
 			'053' => 'ଅଷ୍ଟ୍ରେଲେସିଆ',
 			'054' => 'ମେଲାନେସିଆ',
 			'057' => 'ମାଇକ୍ରୋନେସିଆନ୍ ଅଞ୍ଚଳ',
 			'061' => 'ପଲିନେସିଆ',
 			'142' => 'ଏସିଆ',
 			'143' => 'ମଧ୍ୟ ଏସିଆ',
 			'145' => 'ପଶ୍ଚିମ ଏସିଆ',
 			'150' => 'ୟୁରୋପ୍',
 			'151' => 'ପୂର୍ବ ୟୁରୋପ୍',
 			'154' => 'ଉତ୍ତର ୟୁରୋପ୍',
 			'155' => 'ପଶ୍ଚିମ ୟୁରୋପ୍',
 			'202' => 'ଉପ-ସାହାରା ଆଫ୍ରିକା',
 			'419' => 'ଲାଟିନ୍‌ ଆମେରିକା',
 			'AC' => 'ଆସେନସିଅନ୍‌ ଦ୍ୱୀପ',
 			'AD' => 'ଆଣ୍ଡୋରା',
 			'AE' => 'ସଂଯୁକ୍ତ ଆରବ ଏମିରେଟସ୍',
 			'AF' => 'ଆଫଗାନିସ୍ତାନ୍',
 			'AG' => 'ଆଣ୍ଟିଗୁଆ ଏବଂ ବାରବୁଦା',
 			'AI' => 'ଆଙ୍ଗୁଇଲ୍ଲା',
 			'AL' => 'ଆଲବାନିଆ',
 			'AM' => 'ଆର୍ମେନିଆ',
 			'AO' => 'ଆଙ୍ଗୋଲା',
 			'AQ' => 'ଆଣ୍ଟାର୍କାଟିକା',
 			'AR' => 'ଆର୍ଜେଣ୍ଟିନା',
 			'AS' => 'ଆମେରିକାନ୍ ସାମୋଆ',
 			'AT' => 'ଅଷ୍ଟ୍ରିଆ',
 			'AU' => 'ଅଷ୍ଟ୍ରେଲିଆ',
 			'AW' => 'ଆରୁବା',
 			'AX' => 'ଅଲାଣ୍ଡ ଦ୍ଵୀପପୁଞ୍ଜ',
 			'AZ' => 'ଆଜେରବାଇଜାନ୍',
 			'BA' => 'ବୋସନିଆ ଏବଂ ହର୍ଜଗୋଭିନା',
 			'BB' => 'ବାରବାଡୋସ୍',
 			'BD' => 'ବାଂଲାଦେଶ',
 			'BE' => 'ବେଲଜିୟମ୍',
 			'BF' => 'ବୁର୍କିନା ଫାସୋ',
 			'BG' => 'ବୁଲଗେରିଆ',
 			'BH' => 'ବାହାରିନ୍',
 			'BI' => 'ବୁରୁଣ୍ଡି',
 			'BJ' => 'ବେନିନ୍',
 			'BL' => 'ସେଣ୍ଟ ବାର୍ଥେଲେମି',
 			'BM' => 'ବର୍ମୁଡା',
 			'BN' => 'ବ୍ରୁନେଇ',
 			'BO' => 'ବୋଲିଭିଆ',
 			'BQ' => 'କାରବିୟନ୍‌ ନେଦରଲ୍ୟାଣ୍ଡ',
 			'BR' => 'ବ୍ରାଜିଲ୍',
 			'BS' => 'ବାହାମାସ୍',
 			'BT' => 'ଭୁଟାନ',
 			'BV' => 'ବୌଭେଟ୍‌ ଦ୍ୱୀପ',
 			'BW' => 'ବୋଟସ୍ୱାନା',
 			'BY' => 'ବେଲାରୁଷ୍',
 			'BZ' => 'ବେଲିଜ୍',
 			'CA' => 'କାନାଡା',
 			'CC' => 'କୋକୋସ୍ (କୀଲିଂ) ଦ୍ଵୀପପୁଞ୍ଜ',
 			'CD' => 'କଙ୍ଗୋ (ଡିଆରସି)',
 			'CF' => 'ମଧ୍ୟ ଆଫ୍ରିକୀୟ ସାଧାରଣତନ୍ତ୍ର',
 			'CG' => 'କଙ୍ଗୋ-ବ୍ରାଜିଭିଲ୍ଲେ',
 			'CG@alt=variant' => 'କଙ୍ଗୋ (ସାଧାରଣତନ୍ତ୍ର)',
 			'CH' => 'ସ୍ୱିଜରଲ୍ୟାଣ୍ଡ',
 			'CI' => 'କୋତ୍ ଡି ଭ୍ଵାର୍',
 			'CI@alt=variant' => 'ଆଇଭରୀ କୋଷ୍ଟ',
 			'CK' => 'କୁକ୍‌ ଦ୍ୱୀପପୁଞ୍ଜ',
 			'CL' => 'ଚିଲି',
 			'CM' => 'କାମେରୁନ୍',
 			'CN' => 'ଚୀନ୍‌',
 			'CO' => 'କଲମ୍ବିଆ',
 			'CP' => 'କ୍ଲିପରଟନ୍‌ ଦ୍ୱୀପ',
 			'CR' => 'କୋଷ୍ଟା ରିକା',
 			'CU' => 'କ‍୍ୟୁବା',
 			'CV' => 'କେପ୍ ଭର୍ଦେ',
 			'CW' => 'କୁରାକାଓ',
 			'CX' => 'ଖ୍ରୀଷ୍ଟମାସ ଦ୍ୱୀପ',
 			'CY' => 'ସାଇପ୍ରସ୍',
 			'CZ' => 'ଚେଚିଆ',
 			'CZ@alt=variant' => 'ଚେକ୍‌ ସାଧାରଣତନ୍ତ୍ର',
 			'DE' => 'ଜର୍ମାନୀ',
 			'DG' => 'ଡିଏଗୋ ଗାର୍ସିଆ',
 			'DJ' => 'ଜିବୋଟି',
 			'DK' => 'ଡେନମାର୍କ',
 			'DM' => 'ଡୋମିନିକା',
 			'DO' => 'ଡୋମିନିକାନ୍‌ ସାଧାରଣତନ୍ତ୍ର',
 			'DZ' => 'ଆଲଜେରିଆ',
 			'EA' => 'ସିଉଟା ଏବଂ ମେଲିଲା',
 			'EC' => 'ଇକ୍ୱେଡର୍‌',
 			'EE' => 'ଏସ୍ତୋନିଆ',
 			'EG' => 'ଇଜିପ୍ଟ',
 			'EH' => 'ପଶ୍ଚିମ ସାହାରା',
 			'ER' => 'ଇରିଟ୍ରିୟା',
 			'ES' => 'ସ୍ପେନ୍',
 			'ET' => 'ଇଥିଓପିଆ',
 			'EU' => 'ୟୁରୋପୀୟ ସଂଘ',
 			'EZ' => 'ୟୁରୋକ୍ଷେତ୍ର',
 			'FI' => 'ଫିନଲ୍ୟାଣ୍ଡ',
 			'FJ' => 'ଫିଜି',
 			'FK' => 'ଫକ୍‌ଲ୍ୟାଣ୍ଡ ଦ୍ଵୀପପୁଞ୍ଜ',
 			'FK@alt=variant' => 'ଫକ୍‌ଲ୍ୟାଣ୍ଡ ଦ୍ଵୀପପୁଞ୍ଜ (ଇସଲାସ୍‌ ମାଲଭିନାସ୍‌)',
 			'FM' => 'ମାଇକ୍ରୋନେସିଆ',
 			'FO' => 'ଫାରୋଇ ଦ୍ୱୀପପୁଞ୍ଜ',
 			'FR' => 'ଫ୍ରାନ୍ସ',
 			'GA' => 'ଗାବୋନ୍',
 			'GB' => 'ଯୁକ୍ତରାଜ୍ୟ',
 			'GB@alt=short' => 'ୟୁକେ',
 			'GD' => 'ଗ୍ରେନାଡା',
 			'GE' => 'ଜର୍ଜିଆ',
 			'GF' => 'ଫ୍ରେଞ୍ଚ ଗୁଇନା',
 			'GG' => 'ଗୁଏରନେସି',
 			'GH' => 'ଘାନା',
 			'GI' => 'ଜିବ୍ରାଲ୍ଟର୍',
 			'GL' => 'ଗ୍ରୀନଲ୍ୟାଣ୍ଡ',
 			'GM' => 'ଗାମ୍ବିଆ',
 			'GN' => 'ଗୁଇନିଆ',
 			'GP' => 'ଗୁଆଡେଲୋପ୍',
 			'GQ' => 'ଇକ୍ବାଟୋରିଆଲ୍ ଗୁଇନିଆ',
 			'GR' => 'ଗ୍ରୀସ୍',
 			'GS' => 'ଦକ୍ଷିଣ ଜର୍ଜିଆ ଏବଂ ଦକ୍ଷିଣ ସାଣ୍ଡୱିଚ୍ ଦ୍ୱୀପପୁଞ୍ଜ',
 			'GT' => 'ଗୁଏତମାଲା',
 			'GU' => 'ଗୁଆମ୍',
 			'GW' => 'ଗୁଇନିଆ-ବିସାଉ',
 			'GY' => 'ଗୁଇନା',
 			'HK' => 'ହଂ କଂ ଏସଏଆର୍‌ ଚାଇନା',
 			'HK@alt=short' => 'ହଂ କଂ',
 			'HM' => 'ହାର୍ଡ୍‌ ଏବଂ ମ୍ୟାକଡୋନାଲ୍ଡ ଦ୍ୱୀପପୁଞ୍ଜ',
 			'HN' => 'ହୋଣ୍ଡୁରାସ୍‌',
 			'HR' => 'କ୍ରୋଏସିଆ',
 			'HT' => 'ହାଇତି',
 			'HU' => 'ହଙ୍ଗେରୀ',
 			'IC' => 'କେନେରୀ ଦ୍ୱୀପପୁଞ୍ଜ',
 			'ID' => 'ଇଣ୍ଡୋନେସିଆ',
 			'IE' => 'ଆୟରଲ୍ୟାଣ୍ଡ',
 			'IL' => 'ଇସ୍ରାଏଲ୍',
 			'IM' => 'ଆଇଲ୍‌ ଅଫ୍‌ ମ୍ୟାନ୍‌',
 			'IN' => 'ଭାରତ',
 			'IO' => 'ବ୍ରିଟିଶ୍‌ ଭାରତୀୟ ମହାସାଗର କ୍ଷେତ୍ର',
 			'IO@alt=chagos' => 'ଚାଗୋସ୍ ଆର୍କିପେଲାଗୋ',
 			'IQ' => 'ଇରାକ୍',
 			'IR' => 'ଇରାନ',
 			'IS' => 'ଆଇସଲ୍ୟାଣ୍ଡ',
 			'IT' => 'ଇଟାଲୀ',
 			'JE' => 'ଜର୍ସି',
 			'JM' => 'ଜାମାଇକା',
 			'JO' => 'ଜୋର୍ଡାନ୍',
 			'JP' => 'ଜାପାନ',
 			'KE' => 'କେନିୟା',
 			'KG' => 'କିର୍ଗିଜିସ୍ତାନ',
 			'KH' => 'କାମ୍ବୋଡିଆ',
 			'KI' => 'କିରିବାଟି',
 			'KM' => 'କୋମୋରସ୍',
 			'KN' => 'ସେଣ୍ଟ କିଟସ୍‌ ଏବଂ ନେଭିସ୍‌',
 			'KP' => 'ଉତ୍ତର କୋରିଆ',
 			'KR' => 'ଦକ୍ଷିଣ କୋରିଆ',
 			'KW' => 'କୁଏତ୍',
 			'KY' => 'କେମ୍ୟାନ୍‌ ଦ୍ୱୀପପୁଞ୍ଜ',
 			'KZ' => 'କାଜାଖସ୍ତାନ୍‌',
 			'LA' => 'ଲାଓସ୍',
 			'LB' => 'ଲେବାନନ୍',
 			'LC' => 'ସେଣ୍ଟ ଲୁସିଆ',
 			'LI' => 'ଲିକ୍ଟନ୍‌ଷ୍ଟାଇନ୍‌',
 			'LK' => 'ଶ୍ରୀଲଙ୍କା',
 			'LR' => 'ଲାଇବେରିଆ',
 			'LS' => 'ଲେସୋଥୋ',
 			'LT' => 'ଲିଥୁଆନିଆ',
 			'LU' => 'ଲକ୍ସେମବର୍ଗ',
 			'LV' => 'ଲାଟଭିଆ',
 			'LY' => 'ଲିବ୍ୟା',
 			'MA' => 'ମୋରୋକ୍କୋ',
 			'MC' => 'ମୋନାକୋ',
 			'MD' => 'ମୋଲଡୋଭା',
 			'ME' => 'ମଣ୍ଟେନିଗ୍ରୋ',
 			'MF' => 'ସେଣ୍ଟ ମାର୍ଟିନ୍',
 			'MG' => 'ମାଡାଗାସ୍କର୍',
 			'MH' => 'ମାର୍ଶାଲ୍ ଦ୍ୱୀପପୁଞ୍ଜ',
 			'MK' => 'ଉତ୍ତର ମାସେଡୋନିଆ',
 			'ML' => 'ମାଲି',
 			'MM' => 'ମିଆଁମାର',
 			'MN' => 'ମଙ୍ଗୋଲିଆ',
 			'MO' => 'ମାକାଉ ଏସଏଆର୍‌ ଚାଇନା',
 			'MO@alt=short' => 'ମାକାଉ',
 			'MP' => 'ଉତ୍ତର ମାରିଆନା ଦ୍ୱୀପପୁଞ୍ଜ',
 			'MQ' => 'ମାର୍ଟିନିକ୍ୟୁ',
 			'MR' => 'ମୌରିଟାନିଆ',
 			'MS' => 'ମଣ୍ଟେସେରାଟ୍',
 			'MT' => 'ମାଲ୍ଟା',
 			'MU' => 'ମରିସସ',
 			'MV' => 'ମାଲଦିଭସ୍‌',
 			'MW' => 'ମାଲୱି',
 			'MX' => 'ମେକ୍ସିକୋ',
 			'MY' => 'ମାଲେସିଆ',
 			'MZ' => 'ମୋଜାମ୍ବିକ୍‌',
 			'NA' => 'ନାମିବିଆ',
 			'NC' => 'ନୂତନ କାଲେଡୋନିଆ',
 			'NE' => 'ନାଇଜର',
 			'NF' => 'ନର୍ଫକ୍ ଦ୍ଵୀପ',
 			'NG' => 'ନାଇଜେରିଆ',
 			'NI' => 'ନିକାରାଗୁଆ',
 			'NL' => 'ନେଦରଲ୍ୟାଣ୍ଡ',
 			'NO' => 'ନରୱେ',
 			'NP' => 'ନେପାଳ',
 			'NR' => 'ନାଉରୁ',
 			'NU' => 'ନିଉ',
 			'NZ' => 'ନ୍ୟୁଜିଲାଣ୍ଡ',
 			'NZ@alt=variant' => 'ଆଓଟେରୋଆ ନ୍ୟୁଜିଲାଣ୍ଡ',
 			'OM' => 'ଓମାନ୍',
 			'PA' => 'ପାନାମା',
 			'PE' => 'ପେରୁ',
 			'PF' => 'ଫ୍ରେଞ୍ଚ ପଲିନେସିଆ',
 			'PG' => 'ପପୁଆ ନ୍ୟୁ ଗିନି',
 			'PH' => 'ଫିଲିପାଇନସ୍',
 			'PK' => 'ପାକିସ୍ତାନ',
 			'PL' => 'ପୋଲାଣ୍ଡ',
 			'PM' => 'ସେଣ୍ଟ ପିଏରେ ଏବଂ ମିକ୍ୱେଲନ୍‌',
 			'PN' => 'ପିଟକାଇରିନ୍‌ ଦ୍ୱୀପପୁଞ୍ଜ',
 			'PR' => 'ପୁଏର୍ତ୍ତୋ ରିକୋ',
 			'PS' => 'ପାଲେଷ୍ଟେନିୟ ଭୂଭାଗ',
 			'PS@alt=short' => 'ପାଲେଷ୍ଟାଇନ୍',
 			'PT' => 'ପର୍ତ୍ତୁଗାଲ୍',
 			'PW' => 'ପାଲାଉ',
 			'PY' => 'ପାରାଗୁଏ',
 			'QA' => 'କତାର୍',
 			'QO' => 'ସୀମାନ୍ତବର୍ତ୍ତୀ ଓସିନିଆ',
 			'RE' => 'ରିୟୁନିଅନ୍',
 			'RO' => 'ରୋମାନିଆ',
 			'RS' => 'ସର୍ବିଆ',
 			'RU' => 'ରୁଷିଆ',
 			'RW' => 'ରାୱାଣ୍ଡା',
 			'SA' => 'ସାଉଦି ଆରବିଆ',
 			'SB' => 'ସୋଲୋମନ୍‌ ଦ୍ୱୀପପୁଞ୍ଜ',
 			'SC' => 'ସେଚେଲସ୍',
 			'SD' => 'ସୁଦାନ',
 			'SE' => 'ସ୍ୱିଡେନ୍‌',
 			'SG' => 'ସିଙ୍ଗାପୁର୍',
 			'SH' => 'ସେଣ୍ଟ ହେଲେନା',
 			'SI' => 'ସ୍ଲୋଭେନିଆ',
 			'SJ' => 'ସାଲବାର୍ଡ ଏବଂ ଜାନ୍‌ ମାୟେନ୍‌',
 			'SK' => 'ସ୍ଲୋଭାକିଆ',
 			'SL' => 'ସିଏରା ଲିଓନ',
 			'SM' => 'ସାନ୍ ମାରିନୋ',
 			'SN' => 'ସେନେଗାଲ୍',
 			'SO' => 'ସୋମାଲିଆ',
 			'SR' => 'ସୁରିନାମ',
 			'SS' => 'ଦକ୍ଷିଣ ସୁଦାନ',
 			'ST' => 'ସାଓ ଟୋମେ ଏବଂ ପ୍ରିନସିପି',
 			'SV' => 'ଏଲ୍ ସାଲଭାଡୋର୍',
 			'SX' => 'ସିଣ୍ଟ ମାର୍ଟୀନ୍‌',
 			'SY' => 'ସିରିଆ',
 			'SZ' => 'ଇସ୍ୱାତିନୀ',
 			'SZ@alt=variant' => 'ସ୍ୱାଜିଲ୍ୟାଣ୍ଡ',
 			'TA' => 'ଟ୍ରାଇଷ୍ଟନ୍‌ ଦା କୁନ୍‌ଚା',
 			'TC' => 'ତୁର୍କସ୍‌ ଏବଂ କାଇକୋସ୍‌ ଦ୍ୱୀପପୁଞ୍ଜ',
 			'TD' => 'ଚାଦ୍',
 			'TF' => 'ଫରାସୀ ଦକ୍ଷିଣ କ୍ଷେତ୍ର',
 			'TG' => 'ଟୋଗୋ',
 			'TH' => 'ଥାଇଲ୍ୟାଣ୍ଡ',
 			'TJ' => 'ତାଜିକିସ୍ଥାନ୍',
 			'TK' => 'ଟୋକେଲାଉ',
 			'TL' => 'ତିମୋର୍-ଲେଷ୍ଟେ',
 			'TL@alt=variant' => 'ପୂର୍ବ ତିମୋର୍‌',
 			'TM' => 'ତୁର୍କମେନିସ୍ତାନ',
 			'TN' => 'ଟ୍ୟୁନିସିଆ',
 			'TO' => 'ଟୋଙ୍ଗା',
 			'TR' => 'ତୁର୍କୀ',
 			'TT' => 'ତ୍ରିନିଦାଦ୍ ଏବଂ ଟୋବାଗୋ',
 			'TV' => 'ତୁଭାଲୁ',
 			'TW' => 'ତାଇୱାନ',
 			'TZ' => 'ତାଞ୍ଜାନିଆ',
 			'UA' => 'ୟୁକ୍ରେନ୍',
 			'UG' => 'ଉଗାଣ୍ଡା',
 			'UM' => 'ଯୁକ୍ତରାଷ୍ଟ୍ର ଆଉଟ୍‌ଲାଇଙ୍ଗ ଦ୍ଵୀପପୁଞ୍ଜ',
 			'UN' => 'ଜାତିସଂଘ',
 			'US' => 'ଯୁକ୍ତ ରାଷ୍ଟ୍ର',
 			'US@alt=short' => 'ଯୁକ୍ତରାଷ୍ଟ୍ର',
 			'UY' => 'ଉରୁଗୁଏ',
 			'UZ' => 'ଉଜବେକିସ୍ତାନ',
 			'VA' => 'ଭାଟିକାନ୍ ସିଟି',
 			'VC' => 'ସେଣ୍ଟ ଭିନସେଣ୍ଟ ଏବଂ ଗ୍ରେନାଡାଇନ୍ସ',
 			'VE' => 'ଭେନେଜୁଏଲା',
 			'VG' => 'ବ୍ରିଟିଶ୍‌ ଭର୍ଜିନ୍ ଦ୍ୱୀପପୁଞ୍ଜ',
 			'VI' => 'ଯୁକ୍ତରାଷ୍ଟ୍ର ଭର୍ଜିନ୍ ଦ୍ଵୀପପୁଞ୍ଜ',
 			'VN' => 'ଭିଏତନାମ୍',
 			'VU' => 'ଭାନୁଆତୁ',
 			'WF' => 'ୱାଲିସ୍ ଏବଂ ଫୁତୁନା',
 			'WS' => 'ସାମୋଆ',
 			'XA' => 'ସିୟୁଡୋ-ଏସେଣ୍ଟ',
 			'XB' => 'ସିୟୁଡୋ-ବିଡି',
 			'XK' => 'କୋସୋଭୋ',
 			'YE' => 'ୟେମେନ୍',
 			'YT' => 'ମାୟୋଟେ',
 			'ZA' => 'ଦକ୍ଷିଣ ଆଫ୍ରିକା',
 			'ZM' => 'ଜାମ୍ବିଆ',
 			'ZW' => 'ଜିମ୍ବାୱେ',
 			'ZZ' => 'ଅଜଣା ଅଞ୍ଚଳ',

		}
	},
);

has 'display_name_variant' => (
	is			=> 'ro',
	isa			=> HashRef[Str],
	init_arg	=> undef,
	default		=> sub {
		{
			'1901' => 'ପାରମ୍ପରିକ ଜର୍ମାନ ବର୍ଣ୍ଣପ୍ରକରଣ',
 			'1996' => '1996ର ଜର୍ମାନ ବର୍ଣ୍ଣପ୍ରକରଣ',
 			'1694ACAD' => 'ଆଦ୍ୟ ଆଧୁନିକ ଫରାସୀ',
 			'1959ACAD' => 'ଏକାଡେମିକ',
 			'ALUKU' => 'ଆଲୁକୁ ଉପଭାଷା',
 			'UNIFON' => 'ୟୁନିଫନ୍ ଫନେଟିକ୍ ଆଲଫାବେଟ୍',
 			'VAIDIKA' => 'ବୈଦିକ',
 			'VALENCIA' => 'ଭେଲେନସିଆନ୍',

		}
	},
);

has 'display_name_key' => (
	is			=> 'ro',
	isa			=> HashRef[Str],
	init_arg	=> undef,
	default		=> sub {
		{
			'calendar' => 'କ୍ୟାଲେଣ୍ଡର୍',
 			'cf' => 'ମୁଦ୍ରା ଫର୍ମାଟ୍‌',
 			'collation' => 'ସର୍ଟ୍‌ କ୍ରମ',
 			'currency' => 'ମୁଦ୍ରା',
 			'hc' => 'ଘଣ୍ଟା ଚକ୍ର (12 ବନାମ 24)',
 			'lb' => 'ଲାଇନ୍‌ ବ୍ରେକ୍‌ ଷ୍ଟାଇଲ୍‌',
 			'ms' => 'ମାପ ପଦ୍ଧତି',
 			'numbers' => 'ସଂଖ୍ୟା',

		}
	},
);

has 'display_name_type' => (
	is			=> 'ro',
	isa			=> HashRef[HashRef[Str]],
	init_arg	=> undef,
	default		=> sub {
		{
			'calendar' => {
 				'buddhist' => q{ବୌଦ୍ଧ କ୍ୟାଲେଣ୍ଡର୍‌},
 				'chinese' => q{ଚାଇନିଜ୍‌ କ୍ୟାଲେଣ୍ଡର୍‌},
 				'coptic' => q{କପ୍ଟିକ୍ କ୍ୟାଲେଣ୍ଡର୍‌},
 				'dangi' => q{ଦାଙ୍ଗି କ୍ୟାଲେଣ୍ଡର୍‌},
 				'ethiopic' => q{ଇଥିଓପିକ୍‌ କ୍ୟାଲେଣ୍ଡର୍‌},
 				'ethiopic-amete-alem' => q{ଏଥିଓପିକ୍-ଆମେଟ୍-ଆଲେମ୍},
 				'gregorian' => q{ଗ୍ରେଗୋରିୟ କ୍ୟାଲେଣ୍ଡର୍},
 				'hebrew' => q{ହିବୃ କ୍ୟାଲେଣ୍ଡର୍‌},
 				'indian' => q{ଭାରତୀୟ ରାଷ୍ଟ୍ରୀୟ କ୍ୟାଲେଣ୍ଡର୍‌},
 				'islamic' => q{ହିଜ୍ରି କ୍ୟାଲେଣ୍ଡର},
 				'islamic-civil' => q{ହିଜ୍ରି କ୍ୟାଲେଣ୍ଡର (ଟାବୁଲାର୍, ନାଗରିକ ଯୁଗ)},
 				'islamic-umalqura' => q{ହିଜ୍ରି କ୍ୟାଲେଣ୍ଡର (ଉମ୍ ଅଲ୍-କୁରା)},
 				'iso8601' => q{ISO-8601 କ୍ୟାଲେଣ୍ଡର୍‌},
 				'japanese' => q{ଜାପାନିଜ୍‌ କ୍ୟାଲେଣ୍ଡର୍‌},
 				'persian' => q{ପର୍ସିଆନ୍‌ କ୍ୟାଲେଣ୍ଡର୍‌},
 				'roc' => q{ମିଙ୍ଗୋଓ କ୍ୟାଲେଣ୍ଡର୍‌},
 			},
 			'cf' => {
 				'account' => q{ଏକାଉଣ୍ଟିଂ ମୁଦ୍ରା ଫର୍ମାଟ୍‌},
 				'standard' => q{ମାନାଙ୍କ ମୁଦ୍ରା ଫର୍ମାଟ୍‌},
 			},
 			'collation' => {
 				'ducet' => q{ଡିଫଲ୍ଟ ୟୁନିକୋଡ୍‌ ସର୍ଟ୍‌ କ୍ରମ},
 				'search' => q{ସାଧାରଣ ଉଦ୍ଦେଶ୍ୟ-ବିଶିଷ୍ଟ ସନ୍ଧାନ},
 				'standard' => q{ଷ୍ଟାଣ୍ଡାର୍ଡ୍‌ ସର୍ଟ୍‌ କ୍ରମ},
 			},
 			'hc' => {
 				'h11' => q{12 ଘଣ୍ଟିଆ ପଦ୍ଧତି (0–11)},
 				'h12' => q{12 ଘଣ୍ଟିଆ ପଦ୍ଧତି (1–12)},
 				'h23' => q{24 ଘଣ୍ଟିଆ ପଦ୍ଧତି (0–23)},
 				'h24' => q{24 ଘଣ୍ଟିଆ ପଦ୍ଧତି (1–24)},
 			},
 			'lb' => {
 				'loose' => q{କୋହଳ ଲାଇନ୍‌ ବ୍ରେକ୍‌ ଷ୍ଟାଇଲ୍‌},
 				'normal' => q{ସାଧାରଣ ଲାଇନ୍‌ ବ୍ରେକ୍‌ ଷ୍ଟାଇଲ୍‌},
 				'strict' => q{କଠୋର ଧାଡ଼ି ବିରତି ଶୈଳୀ},
 			},
 			'ms' => {
 				'metric' => q{ମେଟ୍ରିକ୍‌ ପଦ୍ଧତି},
 				'uksystem' => q{ଇମ୍ପେରିଆଲ୍‌ ମାପ ପଦ୍ଧତି},
 				'ussystem' => q{ୟୁଏସ୍‌ ମାପ ପଦ୍ଧତି},
 			},
 			'numbers' => {
 				'arab' => q{ଆରବିକ୍‌-ଇଣ୍ଡିକ୍‌ ଅଙ୍କଗୁଡ଼ିକ},
 				'arabext' => q{ପରିବର୍ଦ୍ଧିତ ଆରବିକ୍‌-ଇଣ୍ଡିକ୍‌ ଅଙ୍କଗୁଡ଼ିକ},
 				'armn' => q{ଆର୍ମେନିୟ ସଂଖ୍ୟାଗୁଡ଼ିକ},
 				'armnlow' => q{ଆର୍ମେନିୟ ଛୋଟ ଅକ୍ଷର ସଂଖ୍ୟାଗୁଡ଼ିକ},
 				'beng' => q{ବଙ୍ଗଳା ଅଙ୍କଗୁଡ଼ିକ},
 				'cakm' => q{ଚକମା ଅଙ୍କଗୁଡ଼ିକ},
 				'deva' => q{ଦେବନାଗରୀ ଅଙ୍କଗୁଡ଼ିକ},
 				'ethi' => q{ଇଥିଓପିକ୍‌ ସଂଖ୍ୟାଗୁଡ଼ିକ},
 				'fullwide' => q{ପୂର୍ଣ୍ଣ-ପ୍ରସ୍ଥ ଅଙ୍କଗୁଡ଼ିକ},
 				'geor' => q{ଜର୍ଜିଆନ୍‌ ସଂଖ୍ୟାଗୁଡ଼ିକ},
 				'grek' => q{ଗ୍ରୀକ୍‌ ସଂଖ୍ୟାଗୁଡ଼ିକ},
 				'greklow' => q{ଗ୍ରୀକ୍‌ ଛୋଟ ଅକ୍ଷର ସଂଖ୍ୟାଗୁଡ଼ିକ},
 				'gujr' => q{ଗୁଜରାଟୀ ଅଙ୍କଗୁଡ଼ିକ},
 				'guru' => q{ଗୁରମୁଖୀ ଅଙ୍କଗୁଡ଼ିକ},
 				'hanidec' => q{ଚାଇନିଜ୍‌ ଦଶମିକ ସଂଖ୍ୟା},
 				'hans' => q{ସରଳୀକୃତ ଚିନି ସଂଖ୍ୟାଗୁଡ଼ିକ},
 				'hansfin' => q{ସରଳୀକୃତ ଚିନି ଆର୍ଥିକ ସଂଖ୍ୟାଗୁଡ଼ିକ},
 				'hant' => q{ପାରମ୍ପରିକ ଚିନି ସଂଖ୍ୟାଗୁଡ଼ିକ},
 				'hantfin' => q{ପାରମ୍ପରିକ ଚିନି ଆର୍ଥିକ ସଂଖ୍ୟାଗୁଡ଼ିକ},
 				'hebr' => q{ହିବୃ ସଂଖ୍ୟାଗୁଡ଼ିକ},
 				'java' => q{ଜାଭାନିଜ ଅଙ୍କଗୁଡ଼ିକ},
 				'jpan' => q{ଜାପାନୀ ସଂଖ୍ୟାଗୁଡ଼ିକ},
 				'jpanfin' => q{ଜାପାନୀ ଆର୍ଥିକ ସଂଖ୍ୟାଗୁଡ଼ିକ},
 				'khmr' => q{ଖିମର୍‌ ଅଙ୍କଗୁଡ଼ିକ},
 				'knda' => q{କନ୍ନଡ଼ ଅଙ୍କଗୁଡ଼ିକ},
 				'laoo' => q{ଲାଓ ଅଙ୍କଗୁଡ଼ିକ},
 				'latn' => q{ପାଶ୍ଚାତ୍ୟ ଅଙ୍କଗୁଡ଼ିକ},
 				'mlym' => q{ମଲୟାଲମ୍ ଅଙ୍କଗୁଡ଼ିକ},
 				'mong' => q{ମଙ୍ଗୋଲୀୟ ଡିଜିଟ୍},
 				'mtei' => q{ମିତେଇ ମାୟେକ ଅଙ୍କଗୁଡ଼ିକ},
 				'mymr' => q{ମିଆଁମାର୍‌ ଅଙ୍କଗୁଡ଼ିକ},
 				'olck' => q{ଓଲ୍ ଚିକି ଅଙ୍କଗୁଡ଼ିକ},
 				'orya' => q{ଓଡ଼ିଆ ଅଙ୍କଗୁଡ଼ିକ},
 				'roman' => q{ରୋମାନ୍‌ ସଂଖ୍ୟାଗୁଡ଼ିକ},
 				'romanlow' => q{ରୋମାନ୍‌ ଛୋଟ ଅକ୍ଷର ସଂଖ୍ୟାଗୁଡ଼ିକ},
 				'taml' => q{ପାରମ୍ପରିକ ତାମିଲ୍ ସଂଖ୍ୟାଗୁଡ଼ିକ},
 				'tamldec' => q{ତାମିଲ୍ ଅଙ୍କଗୁଡ଼ିକ},
 				'telu' => q{ତେଲୁଗୁ ଅଙ୍କଗୁଡ଼ିକ},
 				'thai' => q{ଥାଇ ଅଙ୍କଗୁଡ଼ିକ},
 				'tibt' => q{ତିବତୀ ଅଙ୍କଗୁଡ଼ିକ},
 				'vaii' => q{ଭାଇ ଅଙ୍କଗୁଡ଼ିକ},
 			},

		}
	},
);

has 'display_name_measurement_system' => (
	is			=> 'ro',
	isa			=> HashRef[Str],
	init_arg	=> undef,
	default		=> sub {
		{
			'metric' => q{ମେଟ୍ରିକ୍‌},
 			'UK' => q{ୟୁକେ},
 			'US' => q{ୟୁଏସ୍‌},

		}
	},
);

has 'display_name_code_patterns' => (
	is			=> 'ro',
	isa			=> HashRef[Str],
	init_arg	=> undef,
	default		=> sub {
		{
			'language' => 'ଭାଷା: {0}',
 			'script' => 'ଲିପି: {0}',
 			'region' => 'ଅଞ୍ଚଳ: {0}',

		}
	},
);

has 'characters' => (
	is			=> 'ro',
	isa			=> HashRef,
	init_arg	=> undef,
	default		=> $^V ge v5.18.0
	? eval <<'EOT'
	sub {
		no warnings 'experimental::regex_sets';
		return {
			auxiliary => qr{[‌‍]},
			index => ['ଅ', 'ଆ', 'ଇ', 'ଈ', 'ଉ', 'ଊ', 'ଋ', 'ଏ', 'ଐ', 'ଓ', 'ଔ', 'କ', 'ଖ', 'ଗ', 'ଘ', 'ଙ', 'ଚ', 'ଛ', 'ଜ', 'ଝ', 'ଞ', 'ଟ', 'ଠ', 'ଡ', 'ଢ', 'ଣ', 'ତ', 'ଥ', 'ଦ', 'ଧ', 'ନ', 'ପ', 'ଫ', 'ବ', 'ଭ', 'ମ', 'ଯ', 'ର', 'ଲ', 'ଳ', 'ଶ', 'ଷ', 'ସ', 'ହ', '{କ୍ଷ}'],
			main => qr{[଼ ଅ ଆ ଇ ଈ ଉ ଊ ଋ ଏ ଐ ଓ ଔ ଁ ଂ ଃ କ ଖ ଗ ଘ ଙ ଚ ଛ ଜ ଝ ଞ ଟ ଠ ଡ{ଡ଼} ଢ{ଢ଼} ଣ ତ ଥ ଦ ଧ ନ ପ ଫ ବ ଭ ମ ଯୟ ର ଲ ଳ ଵ ୱ ଶ ଷ ସ ହ {କ୍ଷ} ା ି ୀ ୁ ୂ ୃ େ ୈ ୋ ୌ ୍]},
			numbers => qr{[\- ‑ , . % ‰ + 0୦ 1୧ 2୨ 3୩ 4୪ 5୫ 6୬ 7୭ 8୮ 9୯]},
			punctuation => qr{[\- ‐‑ – — , ; \: ! ? . … '‘’ "“” ( ) \[ \] § @ * / \& # † ‡ ′ ″]},
		};
	},
EOT
: sub {
		return { index => ['ଅ', 'ଆ', 'ଇ', 'ଈ', 'ଉ', 'ଊ', 'ଋ', 'ଏ', 'ଐ', 'ଓ', 'ଔ', 'କ', 'ଖ', 'ଗ', 'ଘ', 'ଙ', 'ଚ', 'ଛ', 'ଜ', 'ଝ', 'ଞ', 'ଟ', 'ଠ', 'ଡ', 'ଢ', 'ଣ', 'ତ', 'ଥ', 'ଦ', 'ଧ', 'ନ', 'ପ', 'ଫ', 'ବ', 'ଭ', 'ମ', 'ଯ', 'ର', 'ଲ', 'ଳ', 'ଶ', 'ଷ', 'ସ', 'ହ', '{କ୍ଷ}'], };
},
);


has 'units' => (
	is			=> 'ro',
	isa			=> HashRef[HashRef[HashRef[Str]]],
	init_arg	=> undef,
	default		=> sub { {
				'long' => {
					# Long Unit Identifier
					'' => {
						'name' => q(ପ୍ରଧାନ ଦିଶା),
					},
					# Core Unit Identifier
					'' => {
						'name' => q(ପ୍ରଧାନ ଦିଶା),
					},
					# Long Unit Identifier
					'1024p2' => {
						'1' => q(mebi{0}),
					},
					# Core Unit Identifier
					'1024p2' => {
						'1' => q(mebi{0}),
					},
					# Long Unit Identifier
					'1024p4' => {
						'1' => q(tebi{0}),
					},
					# Core Unit Identifier
					'1024p4' => {
						'1' => q(tebi{0}),
					},
					# Long Unit Identifier
					'1024p5' => {
						'1' => q(pebi{0}),
					},
					# Core Unit Identifier
					'1024p5' => {
						'1' => q(pebi{0}),
					},
					# Long Unit Identifier
					'1024p6' => {
						'1' => q(exbi{0}),
					},
					# Core Unit Identifier
					'1024p6' => {
						'1' => q(exbi{0}),
					},
					# Long Unit Identifier
					'1024p7' => {
						'1' => q(zebi{0}),
					},
					# Core Unit Identifier
					'1024p7' => {
						'1' => q(zebi{0}),
					},
					# Long Unit Identifier
					'1024p8' => {
						'1' => q(yobi{0}),
					},
					# Core Unit Identifier
					'1024p8' => {
						'1' => q(yobi{0}),
					},
					# Long Unit Identifier
					'10p-1' => {
						'1' => q(ଡେସି{0}),
					},
					# Core Unit Identifier
					'1' => {
						'1' => q(ଡେସି{0}),
					},
					# Long Unit Identifier
					'10p-12' => {
						'1' => q(ପିକୋ{0}),
					},
					# Core Unit Identifier
					'12' => {
						'1' => q(ପିକୋ{0}),
					},
					# Long Unit Identifier
					'10p-15' => {
						'1' => q(ଫିମଟୋ{0}),
					},
					# Core Unit Identifier
					'15' => {
						'1' => q(ଫିମଟୋ{0}),
					},
					# Long Unit Identifier
					'10p-18' => {
						'1' => q(ଅଟୋ{0}),
					},
					# Core Unit Identifier
					'18' => {
						'1' => q(ଅଟୋ{0}),
					},
					# Long Unit Identifier
					'10p-2' => {
						'1' => q(ସେଣ୍ଟି{0}),
					},
					# Core Unit Identifier
					'2' => {
						'1' => q(ସେଣ୍ଟି{0}),
					},
					# Long Unit Identifier
					'10p-21' => {
						'1' => q(ଜିପୋଟ{0}),
					},
					# Core Unit Identifier
					'21' => {
						'1' => q(ଜିପୋଟ{0}),
					},
					# Long Unit Identifier
					'10p-24' => {
						'1' => q(ୟୋକଟ{0}),
					},
					# Core Unit Identifier
					'24' => {
						'1' => q(ୟୋକଟ{0}),
					},
					# Long Unit Identifier
					'10p-3' => {
						'1' => q(ମିଲି{0}),
					},
					# Core Unit Identifier
					'3' => {
						'1' => q(ମିଲି{0}),
					},
					# Long Unit Identifier
					'10p-6' => {
						'1' => q(ମାଇକ୍ରୋ{0}),
					},
					# Core Unit Identifier
					'6' => {
						'1' => q(ମାଇକ୍ରୋ{0}),
					},
					# Long Unit Identifier
					'10p-9' => {
						'1' => q(ନାନୋ{0}),
					},
					# Core Unit Identifier
					'9' => {
						'1' => q(ନାନୋ{0}),
					},
					# Long Unit Identifier
					'10p1' => {
						'1' => q(ଡେକା{0}),
					},
					# Core Unit Identifier
					'10p1' => {
						'1' => q(ଡେକା{0}),
					},
					# Long Unit Identifier
					'10p12' => {
						'1' => q(ଟେରା{0}),
					},
					# Core Unit Identifier
					'10p12' => {
						'1' => q(ଟେରା{0}),
					},
					# Long Unit Identifier
					'10p15' => {
						'1' => q(ପିଟା{0}),
					},
					# Core Unit Identifier
					'10p15' => {
						'1' => q(ପିଟା{0}),
					},
					# Long Unit Identifier
					'10p18' => {
						'1' => q(ଏକ୍ସା{0}),
					},
					# Core Unit Identifier
					'10p18' => {
						'1' => q(ଏକ୍ସା{0}),
					},
					# Long Unit Identifier
					'10p2' => {
						'1' => q(ହେକ୍ଟା{0}),
					},
					# Core Unit Identifier
					'10p2' => {
						'1' => q(ହେକ୍ଟା{0}),
					},
					# Long Unit Identifier
					'10p21' => {
						'1' => q(ଜିଟା{0}),
					},
					# Core Unit Identifier
					'10p21' => {
						'1' => q(ଜିଟା{0}),
					},
					# Long Unit Identifier
					'10p24' => {
						'1' => q(ୟୋଟା{0}),
					},
					# Core Unit Identifier
					'10p24' => {
						'1' => q(ୟୋଟା{0}),
					},
					# Long Unit Identifier
					'10p3' => {
						'1' => q(କିଲୋ{0}),
					},
					# Core Unit Identifier
					'10p3' => {
						'1' => q(କିଲୋ{0}),
					},
					# Long Unit Identifier
					'10p6' => {
						'1' => q(ମେଗା{0}),
					},
					# Core Unit Identifier
					'10p6' => {
						'1' => q(ମେଗା{0}),
					},
					# Long Unit Identifier
					'10p9' => {
						'1' => q(ଗିଗା{0}),
					},
					# Core Unit Identifier
					'10p9' => {
						'1' => q(ଗିଗା{0}),
					},
					# Long Unit Identifier
					'acceleration-g-force' => {
						'name' => q(ଜି-ଫୋର୍ସ୍),
						'one' => q({0} ଜି-ଫୋର୍ସ୍),
						'other' => q({0} ଜି-ଫୋର୍ସ୍),
					},
					# Core Unit Identifier
					'g-force' => {
						'name' => q(ଜି-ଫୋର୍ସ୍),
						'one' => q({0} ଜି-ଫୋର୍ସ୍),
						'other' => q({0} ଜି-ଫୋର୍ସ୍),
					},
					# Long Unit Identifier
					'acceleration-meter-per-square-second' => {
						'name' => q(ମିଟର୍ ପ୍ରତି ସେକେଣ୍ଡ୍ ବର୍ଗ),
						'one' => q({0} ମିଟର୍ ପ୍ରତି ସେକେଣ୍ଡ୍ ବର୍ଗ),
						'other' => q({0} ମିଟର୍ ପ୍ରତି ସେକେଣ୍ଡ୍ ବର୍ଗ),
					},
					# Core Unit Identifier
					'meter-per-square-second' => {
						'name' => q(ମିଟର୍ ପ୍ରତି ସେକେଣ୍ଡ୍ ବର୍ଗ),
						'one' => q({0} ମିଟର୍ ପ୍ରତି ସେକେଣ୍ଡ୍ ବର୍ଗ),
						'other' => q({0} ମିଟର୍ ପ୍ରତି ସେକେଣ୍ଡ୍ ବର୍ଗ),
					},
					# Long Unit Identifier
					'angle-arc-minute' => {
						'name' => q(ଆର୍କମିନିଟ୍),
						'one' => q({0}′),
						'other' => q({0} ଆର୍କମିନିଟ୍),
					},
					# Core Unit Identifier
					'arc-minute' => {
						'name' => q(ଆର୍କମିନିଟ୍),
						'one' => q({0}′),
						'other' => q({0} ଆର୍କମିନିଟ୍),
					},
					# Long Unit Identifier
					'angle-arc-second' => {
						'name' => q(ଆର୍କସେକେଣ୍ଡ୍),
						'one' => q({0} ଆର୍କସେକେଣ୍ଡ୍),
						'other' => q({0} ଆର୍କସେକେଣ୍ଡ୍),
					},
					# Core Unit Identifier
					'arc-second' => {
						'name' => q(ଆର୍କସେକେଣ୍ଡ୍),
						'one' => q({0} ଆର୍କସେକେଣ୍ଡ୍),
						'other' => q({0} ଆର୍କସେକେଣ୍ଡ୍),
					},
					# Long Unit Identifier
					'angle-degree' => {
						'one' => q({0} ଡିଗ୍ରୀ),
						'other' => q({0} ଡିଗ୍ରୀ),
					},
					# Core Unit Identifier
					'degree' => {
						'one' => q({0} ଡିଗ୍ରୀ),
						'other' => q({0} ଡିଗ୍ରୀ),
					},
					# Long Unit Identifier
					'angle-radian' => {
						'one' => q({0} ରେଡିଆନ୍),
						'other' => q({0} ରେଡିଆନ୍),
					},
					# Core Unit Identifier
					'radian' => {
						'one' => q({0} ରେଡିଆନ୍),
						'other' => q({0} ରେଡିଆନ୍),
					},
					# Long Unit Identifier
					'angle-revolution' => {
						'name' => q(ପରିକ୍ରମଣ),
						'one' => q({0} ପରିକ୍ରମଣ),
						'other' => q({0} ପରିକ୍ରମଣ),
					},
					# Core Unit Identifier
					'revolution' => {
						'name' => q(ପରିକ୍ରମଣ),
						'one' => q({0} ପରିକ୍ରମଣ),
						'other' => q({0} ପରିକ୍ରମଣ),
					},
					# Long Unit Identifier
					'area-hectare' => {
						'one' => q({0} ହେକ୍ଟର୍),
						'other' => q({0} ହେକ୍ଟର୍),
					},
					# Core Unit Identifier
					'hectare' => {
						'one' => q({0} ହେକ୍ଟର୍),
						'other' => q({0} ହେକ୍ଟର୍),
					},
					# Long Unit Identifier
					'area-square-centimeter' => {
						'name' => q(ବର୍ଗ ସେଣ୍ଟିମିଟର୍),
						'one' => q({0} ବର୍ଗ ସେଣ୍ଟିମିଟର୍),
						'other' => q({0} ବର୍ଗ ସେଣ୍ଟିମିଟର୍),
						'per' => q({0} ପ୍ରତି ବର୍ଗ ସେଣ୍ଟିମିଟର୍),
					},
					# Core Unit Identifier
					'square-centimeter' => {
						'name' => q(ବର୍ଗ ସେଣ୍ଟିମିଟର୍),
						'one' => q({0} ବର୍ଗ ସେଣ୍ଟିମିଟର୍),
						'other' => q({0} ବର୍ଗ ସେଣ୍ଟିମିଟର୍),
						'per' => q({0} ପ୍ରତି ବର୍ଗ ସେଣ୍ଟିମିଟର୍),
					},
					# Long Unit Identifier
					'area-square-foot' => {
						'one' => q({0} ବର୍ଗ ଫୁଟ୍),
						'other' => q({0} ବର୍ଗ ଫିଟ୍),
					},
					# Core Unit Identifier
					'square-foot' => {
						'one' => q({0} ବର୍ଗ ଫୁଟ୍),
						'other' => q({0} ବର୍ଗ ଫିଟ୍),
					},
					# Long Unit Identifier
					'area-square-inch' => {
						'name' => q(ବର୍ଗ ଇଞ୍ଚ),
						'one' => q({0} ବର୍ଗ ଇଞ୍ଚ),
						'other' => q({0} ବର୍ଗ ଇଞ୍ଚ),
						'per' => q({0} ପ୍ରତି ବର୍ଗ ଇଞ୍ଚ),
					},
					# Core Unit Identifier
					'square-inch' => {
						'name' => q(ବର୍ଗ ଇଞ୍ଚ),
						'one' => q({0} ବର୍ଗ ଇଞ୍ଚ),
						'other' => q({0} ବର୍ଗ ଇଞ୍ଚ),
						'per' => q({0} ପ୍ରତି ବର୍ଗ ଇଞ୍ଚ),
					},
					# Long Unit Identifier
					'area-square-kilometer' => {
						'name' => q(ବର୍ଗ କିଲୋମିଟର୍),
						'one' => q({0} ବର୍ଗ କିଲୋମିଟର୍),
						'other' => q({0} ବର୍ଗ କିଲୋମିଟର୍),
						'per' => q({0} ପ୍ରତି ବର୍ଗ କିଲୋମିଟର୍),
					},
					# Core Unit Identifier
					'square-kilometer' => {
						'name' => q(ବର୍ଗ କିଲୋମିଟର୍),
						'one' => q({0} ବର୍ଗ କିଲୋମିଟର୍),
						'other' => q({0} ବର୍ଗ କିଲୋମିଟର୍),
						'per' => q({0} ପ୍ରତି ବର୍ଗ କିଲୋମିଟର୍),
					},
					# Long Unit Identifier
					'area-square-meter' => {
						'name' => q(ବର୍ଗ ମିଟର୍),
						'one' => q({0} ବର୍ଗ ମିଟର୍),
						'other' => q({0} ବର୍ଗ ମିଟର୍),
						'per' => q({0} ପ୍ରତି ବର୍ଗ ମିଟର୍),
					},
					# Core Unit Identifier
					'square-meter' => {
						'name' => q(ବର୍ଗ ମିଟର୍),
						'one' => q({0} ବର୍ଗ ମିଟର୍),
						'other' => q({0} ବର୍ଗ ମିଟର୍),
						'per' => q({0} ପ୍ରତି ବର୍ଗ ମିଟର୍),
					},
					# Long Unit Identifier
					'area-square-mile' => {
						'per' => q({0} ପ୍ରତି ବର୍ଗ ମାଇଲ୍),
					},
					# Core Unit Identifier
					'square-mile' => {
						'per' => q({0} ପ୍ରତି ବର୍ଗ ମାଇଲ୍),
					},
					# Long Unit Identifier
					'area-square-yard' => {
						'name' => q(ବର୍ଗ ଗଜ),
						'one' => q({0} ବର୍ଗ ଗଜ),
						'other' => q({0} ବର୍ଗ ଗଜ),
					},
					# Core Unit Identifier
					'square-yard' => {
						'name' => q(ବର୍ଗ ଗଜ),
						'one' => q({0} ବର୍ଗ ଗଜ),
						'other' => q({0} ବର୍ଗ ଗଜ),
					},
					# Long Unit Identifier
					'concentr-item' => {
						'name' => q(ଆଇଟମ୍‌ଗୁଡିକ),
						'one' => q({0} ଆଇଟମ୍),
						'other' => q({0} ଆଇଟମ୍‌ଗୁଡିକ),
					},
					# Core Unit Identifier
					'item' => {
						'name' => q(ଆଇଟମ୍‌ଗୁଡିକ),
						'one' => q({0} ଆଇଟମ୍),
						'other' => q({0} ଆଇଟମ୍‌ଗୁଡିକ),
					},
					# Long Unit Identifier
					'concentr-karat' => {
						'one' => q({0} କ୍ୟାରେଟ୍),
						'other' => q({0} କ୍ୟାରେଟ୍),
					},
					# Core Unit Identifier
					'karat' => {
						'one' => q({0} କ୍ୟାରେଟ୍),
						'other' => q({0} କ୍ୟାରେଟ୍),
					},
					# Long Unit Identifier
					'concentr-milligram-ofglucose-per-deciliter' => {
						'name' => q(ମିଲିଗ୍ରାମ୍ ପ୍ରତି ଡେସିଲିଟର୍),
						'one' => q({0} ମିଲିଗ୍ରାମ୍ ପ୍ରତି ଡେସିଲିଟର୍),
						'other' => q({0} ମିଲିଗ୍ରାମ୍ ପ୍ରତି ଡେସିଲିଟର୍),
					},
					# Core Unit Identifier
					'milligram-ofglucose-per-deciliter' => {
						'name' => q(ମିଲିଗ୍ରାମ୍ ପ୍ରତି ଡେସିଲିଟର୍),
						'one' => q({0} ମିଲିଗ୍ରାମ୍ ପ୍ରତି ଡେସିଲିଟର୍),
						'other' => q({0} ମିଲିଗ୍ରାମ୍ ପ୍ରତି ଡେସିଲିଟର୍),
					},
					# Long Unit Identifier
					'concentr-millimole-per-liter' => {
						'name' => q(ମିଲିମୋଲ୍ ପ୍ରତି ଲିଟର୍),
						'one' => q({0} ମିଲିମୋଲ୍ ପ୍ରତି ଲିଟର୍),
						'other' => q({0} ମିଲିମୋଲ୍ ପ୍ରତି ଲିଟର୍),
					},
					# Core Unit Identifier
					'millimole-per-liter' => {
						'name' => q(ମିଲିମୋଲ୍ ପ୍ରତି ଲିଟର୍),
						'one' => q({0} ମିଲିମୋଲ୍ ପ୍ରତି ଲିଟର୍),
						'other' => q({0} ମିଲିମୋଲ୍ ପ୍ରତି ଲିଟର୍),
					},
					# Long Unit Identifier
					'concentr-mole' => {
						'name' => q(ମୋଲସ),
						'one' => q({0} ମୋଲ),
						'other' => q({0} ମୋଲସ),
					},
					# Core Unit Identifier
					'mole' => {
						'name' => q(ମୋଲସ),
						'one' => q({0} ମୋଲ),
						'other' => q({0} ମୋଲସ),
					},
					# Long Unit Identifier
					'concentr-percent' => {
						'one' => q({0} ଶତକଡ଼ା),
						'other' => q({0} ଶତକଡ଼ା),
					},
					# Core Unit Identifier
					'percent' => {
						'one' => q({0} ଶତକଡ଼ା),
						'other' => q({0} ଶତକଡ଼ା),
					},
					# Long Unit Identifier
					'concentr-permille' => {
						'one' => q({0} ପରମିଲ),
						'other' => q({0} ପରମିଲ),
					},
					# Core Unit Identifier
					'permille' => {
						'one' => q({0} ପରମିଲ),
						'other' => q({0} ପରମିଲ),
					},
					# Long Unit Identifier
					'concentr-permillion' => {
						'name' => q(ଅଂଶ ପ୍ରତି ନିୟୁତ),
						'one' => q({0} ଅଂଶ ପ୍ରତି ନିୟୁତ),
						'other' => q({0} ଅଂଶ ପ୍ରତି ନିୟୁତ),
					},
					# Core Unit Identifier
					'permillion' => {
						'name' => q(ଅଂଶ ପ୍ରତି ନିୟୁତ),
						'one' => q({0} ଅଂଶ ପ୍ରତି ନିୟୁତ),
						'other' => q({0} ଅଂଶ ପ୍ରତି ନିୟୁତ),
					},
					# Long Unit Identifier
					'concentr-permyriad' => {
						'one' => q({0} ପରମାଇରିଆଡ),
						'other' => q({0} ପରମାଇରିଆଡ),
					},
					# Core Unit Identifier
					'permyriad' => {
						'one' => q({0} ପରମାଇରିଆଡ),
						'other' => q({0} ପରମାଇରିଆଡ),
					},
					# Long Unit Identifier
					'concentr-portion-per-1e9' => {
						'name' => q(ବିଲିୟନ ପ୍ରତି ଅଂଶଗୁଡିକ),
						'one' => q({0} ପାର୍ଟ୍ସ ପ୍ରତି ବିଲିୟନ୍),
						'other' => q({0} ପାର୍ଟ୍ସ ପ୍ରତି ବିଲିୟନ୍),
					},
					# Core Unit Identifier
					'portion-per-1e9' => {
						'name' => q(ବିଲିୟନ ପ୍ରତି ଅଂଶଗୁଡିକ),
						'one' => q({0} ପାର୍ଟ୍ସ ପ୍ରତି ବିଲିୟନ୍),
						'other' => q({0} ପାର୍ଟ୍ସ ପ୍ରତି ବିଲିୟନ୍),
					},
					# Long Unit Identifier
					'consumption-liter-per-100-kilometer' => {
						'name' => q(100 କିଲୋମିଟର୍ ପ୍ରତି ଲିଟର୍),
						'one' => q(100 କିଲୋମିଟର୍ ପ୍ରତି {0} ଲିଟର୍),
						'other' => q(100 କିଲୋମିଟର୍ ପ୍ରତି {0} ଲିଟର୍),
					},
					# Core Unit Identifier
					'liter-per-100-kilometer' => {
						'name' => q(100 କିଲୋମିଟର୍ ପ୍ରତି ଲିଟର୍),
						'one' => q(100 କିଲୋମିଟର୍ ପ୍ରତି {0} ଲିଟର୍),
						'other' => q(100 କିଲୋମିଟର୍ ପ୍ରତି {0} ଲିଟର୍),
					},
					# Long Unit Identifier
					'consumption-liter-per-kilometer' => {
						'name' => q(ଲିଟର୍ ପ୍ରତି କିଲୋମିଟର୍),
						'one' => q({0} ଲିଟର୍ ପ୍ରତି କିଲୋମିଟର୍),
						'other' => q({0} ଲିଟର୍ ପ୍ରତି କିଲୋମିଟର୍),
					},
					# Core Unit Identifier
					'liter-per-kilometer' => {
						'name' => q(ଲିଟର୍ ପ୍ରତି କିଲୋମିଟର୍),
						'one' => q({0} ଲିଟର୍ ପ୍ରତି କିଲୋମିଟର୍),
						'other' => q({0} ଲିଟର୍ ପ୍ରତି କିଲୋମିଟର୍),
					},
					# Long Unit Identifier
					'consumption-mile-per-gallon' => {
						'name' => q(ମାଇଲ୍ ପ୍ରତି ଗ୍ୟାଲନ୍),
						'one' => q({0} ମାଇଲ୍ ପ୍ରତି ଗ୍ୟାଲନ୍),
						'other' => q({0} ମାଇଲ୍ ପ୍ରତି ଗ୍ୟାଲନ୍),
					},
					# Core Unit Identifier
					'mile-per-gallon' => {
						'name' => q(ମାଇଲ୍ ପ୍ରତି ଗ୍ୟାଲନ୍),
						'one' => q({0} ମାଇଲ୍ ପ୍ରତି ଗ୍ୟାଲନ୍),
						'other' => q({0} ମାଇଲ୍ ପ୍ରତି ଗ୍ୟାଲନ୍),
					},
					# Long Unit Identifier
					'consumption-mile-per-gallon-imperial' => {
						'name' => q(ମାଇଲ୍ ପ୍ରତି ଇମ୍ପେରିଆଲ୍ ଗ୍ୟାଲନ୍),
						'one' => q({0} ମାଇଲ୍ ପ୍ରତି ଇମ୍ପେରିଆଲ୍ ଗ୍ୟାଲନ୍),
						'other' => q({0} ମାଇଲ୍ ପ୍ରତି ଇମ୍ପେରିଆଲ୍ ଗ୍ୟାଲନ୍),
					},
					# Core Unit Identifier
					'mile-per-gallon-imperial' => {
						'name' => q(ମାଇଲ୍ ପ୍ରତି ଇମ୍ପେରିଆଲ୍ ଗ୍ୟାଲନ୍),
						'one' => q({0} ମାଇଲ୍ ପ୍ରତି ଇମ୍ପେରିଆଲ୍ ଗ୍ୟାଲନ୍),
						'other' => q({0} ମାଇଲ୍ ପ୍ରତି ଇମ୍ପେରିଆଲ୍ ଗ୍ୟାଲନ୍),
					},
					# Long Unit Identifier
					'coordinate' => {
						'east' => q({0} ପୂର୍ବ),
						'north' => q({0} ଉତ୍ତର),
						'south' => q({0} ଦକ୍ଷିଣ),
						'west' => q({0} ପଶ୍ଚିମ),
					},
					# Core Unit Identifier
					'coordinate' => {
						'east' => q({0} ପୂର୍ବ),
						'north' => q({0} ଉତ୍ତର),
						'south' => q({0} ଦକ୍ଷିଣ),
						'west' => q({0} ପଶ୍ଚିମ),
					},
					# Long Unit Identifier
					'digital-gigabit' => {
						'name' => q(ଗିଗାବିଟ୍),
						'one' => q({0} ଗିଗାବିଟ୍),
						'other' => q({0} ଗିଗାବିଟ୍),
					},
					# Core Unit Identifier
					'gigabit' => {
						'name' => q(ଗିଗାବିଟ୍),
						'one' => q({0} ଗିଗାବିଟ୍),
						'other' => q({0} ଗିଗାବିଟ୍),
					},
					# Long Unit Identifier
					'digital-gigabyte' => {
						'name' => q(ଗିଗାବାଇଟ୍),
						'one' => q({0} ଗିଗାବାଇଟ୍),
						'other' => q({0} ଗିଗାବାଇଟ୍),
					},
					# Core Unit Identifier
					'gigabyte' => {
						'name' => q(ଗିଗାବାଇଟ୍),
						'one' => q({0} ଗିଗାବାଇଟ୍),
						'other' => q({0} ଗିଗାବାଇଟ୍),
					},
					# Long Unit Identifier
					'digital-kilobit' => {
						'name' => q(କିଲୋବିଟ୍),
						'one' => q({0} କିଲୋବିଟ୍),
						'other' => q({0} କିଲୋବିଟ୍),
					},
					# Core Unit Identifier
					'kilobit' => {
						'name' => q(କିଲୋବିଟ୍),
						'one' => q({0} କିଲୋବିଟ୍),
						'other' => q({0} କିଲୋବିଟ୍),
					},
					# Long Unit Identifier
					'digital-kilobyte' => {
						'name' => q(କିଲୋବାଇଟ୍),
						'one' => q({0} କିଲୋବାଇଟ୍),
						'other' => q({0} କିଲୋବାଇଟ୍),
					},
					# Core Unit Identifier
					'kilobyte' => {
						'name' => q(କିଲୋବାଇଟ୍),
						'one' => q({0} କିଲୋବାଇଟ୍),
						'other' => q({0} କିଲୋବାଇଟ୍),
					},
					# Long Unit Identifier
					'digital-megabit' => {
						'name' => q(ମେଗାବିଟ୍),
						'one' => q({0} ମେଗାବିଟ୍),
						'other' => q({0} ମେଗାବିଟ୍),
					},
					# Core Unit Identifier
					'megabit' => {
						'name' => q(ମେଗାବିଟ୍),
						'one' => q({0} ମେଗାବିଟ୍),
						'other' => q({0} ମେଗାବିଟ୍),
					},
					# Long Unit Identifier
					'digital-megabyte' => {
						'name' => q(ମେଗାବାଇଟ୍),
						'one' => q({0} ମେଗାବାଇଟ୍),
						'other' => q({0} ମେଗାବାଇଟ୍),
					},
					# Core Unit Identifier
					'megabyte' => {
						'name' => q(ମେଗାବାଇଟ୍),
						'one' => q({0} ମେଗାବାଇଟ୍),
						'other' => q({0} ମେଗାବାଇଟ୍),
					},
					# Long Unit Identifier
					'digital-petabyte' => {
						'name' => q(ପେଟାବାଇଟ୍‌),
					},
					# Core Unit Identifier
					'petabyte' => {
						'name' => q(ପେଟାବାଇଟ୍‌),
					},
					# Long Unit Identifier
					'digital-terabit' => {
						'name' => q(ଟେରାବିଟ୍),
						'one' => q({0} ଟେରାବିଟ୍),
						'other' => q({0} ଟେରାବିଟ୍),
					},
					# Core Unit Identifier
					'terabit' => {
						'name' => q(ଟେରାବିଟ୍),
						'one' => q({0} ଟେରାବିଟ୍),
						'other' => q({0} ଟେରାବିଟ୍),
					},
					# Long Unit Identifier
					'digital-terabyte' => {
						'name' => q(ଟେରାବାଇଟ୍),
						'one' => q({0} ଟେରାବାଇଟ୍),
						'other' => q({0} ଟେରାବାଇଟ୍),
					},
					# Core Unit Identifier
					'terabyte' => {
						'name' => q(ଟେରାବାଇଟ୍),
						'one' => q({0} ଟେରାବାଇଟ୍),
						'other' => q({0} ଟେରାବାଇଟ୍),
					},
					# Long Unit Identifier
					'duration-century' => {
						'name' => q(ଶତାବ୍ଦୀ),
						'one' => q({0} ଶତାବ୍ଦୀ),
						'other' => q({0} ଶତାବ୍ଦୀ),
					},
					# Core Unit Identifier
					'century' => {
						'name' => q(ଶତାବ୍ଦୀ),
						'one' => q({0} ଶତାବ୍ଦୀ),
						'other' => q({0} ଶତାବ୍ଦୀ),
					},
					# Long Unit Identifier
					'duration-day' => {
						'per' => q(ଦିନକୁ {0}),
					},
					# Core Unit Identifier
					'day' => {
						'per' => q(ଦିନକୁ {0}),
					},
					# Long Unit Identifier
					'duration-decade' => {
						'one' => q({0} ଦଶନ୍ଧି),
						'other' => q({0} ଦଶନ୍ଧି),
					},
					# Core Unit Identifier
					'decade' => {
						'one' => q({0} ଦଶନ୍ଧି),
						'other' => q({0} ଦଶନ୍ଧି),
					},
					# Long Unit Identifier
					'duration-hour' => {
						'per' => q(ଘଣ୍ଟା ପ୍ରତି {0}),
					},
					# Core Unit Identifier
					'hour' => {
						'per' => q(ଘଣ୍ଟା ପ୍ରତି {0}),
					},
					# Long Unit Identifier
					'duration-microsecond' => {
						'name' => q(ମାଇକ୍ରୋସେକେଣ୍ଡ),
						'one' => q({0} ମାଇକ୍ରୋସେକେଣ୍ଡ),
						'other' => q({0} ମାଇକ୍ରୋସେକେଣ୍ଡ),
					},
					# Core Unit Identifier
					'microsecond' => {
						'name' => q(ମାଇକ୍ରୋସେକେଣ୍ଡ),
						'one' => q({0} ମାଇକ୍ରୋସେକେଣ୍ଡ),
						'other' => q({0} ମାଇକ୍ରୋସେକେଣ୍ଡ),
					},
					# Long Unit Identifier
					'duration-millisecond' => {
						'one' => q({0} ମିଲିସେକେଣ୍ଡ),
						'other' => q({0} ମିଲିସେକେଣ୍ଡ),
					},
					# Core Unit Identifier
					'millisecond' => {
						'one' => q({0} ମିଲିସେକେଣ୍ଡ),
						'other' => q({0} ମିଲିସେକେଣ୍ଡ),
					},
					# Long Unit Identifier
					'duration-minute' => {
						'one' => q({0} ମିନିଟ୍‌),
						'other' => q({0} ମିନିଟ୍),
						'per' => q(ମିନିଟ୍‌ ପ୍ରତି {0}),
					},
					# Core Unit Identifier
					'minute' => {
						'one' => q({0} ମିନିଟ୍‌),
						'other' => q({0} ମିନିଟ୍),
						'per' => q(ମିନିଟ୍‌ ପ୍ରତି {0}),
					},
					# Long Unit Identifier
					'duration-month' => {
						'per' => q(ମାସକୁ {0}),
					},
					# Core Unit Identifier
					'month' => {
						'per' => q(ମାସକୁ {0}),
					},
					# Long Unit Identifier
					'duration-nanosecond' => {
						'name' => q(ନାନୋସେକେଣ୍ଡ),
						'one' => q({0} ନାନୋସେକେଣ୍ଡ),
						'other' => q({0} ନାନୋସେକେଣ୍ଡ),
					},
					# Core Unit Identifier
					'nanosecond' => {
						'name' => q(ନାନୋସେକେଣ୍ଡ),
						'one' => q({0} ନାନୋସେକେଣ୍ଡ),
						'other' => q({0} ନାନୋସେକେଣ୍ଡ),
					},
					# Long Unit Identifier
					'duration-night' => {
						'name' => q(ରାତି),
						'one' => q({0} ରାତି),
						'other' => q({0} ରାତି),
						'per' => q({0} ପ୍ରତି ରାତି),
					},
					# Core Unit Identifier
					'night' => {
						'name' => q(ରାତି),
						'one' => q({0} ରାତି),
						'other' => q({0} ରାତି),
						'per' => q({0} ପ୍ରତି ରାତି),
					},
					# Long Unit Identifier
					'duration-quarter' => {
						'one' => q({0} କ୍ୱାର୍ଟର୍),
						'other' => q({0} କ୍ୱାର୍ଟର୍ସ),
					},
					# Core Unit Identifier
					'quarter' => {
						'one' => q({0} କ୍ୱାର୍ଟର୍),
						'other' => q({0} କ୍ୱାର୍ଟର୍ସ),
					},
					# Long Unit Identifier
					'duration-second' => {
						'per' => q({0} ପ୍ରତି ସେକେଣ୍ଡ),
					},
					# Core Unit Identifier
					'second' => {
						'per' => q({0} ପ୍ରତି ସେକେଣ୍ଡ),
					},
					# Long Unit Identifier
					'duration-week' => {
						'per' => q(ସପ୍ତାହକୁ {0}),
					},
					# Core Unit Identifier
					'week' => {
						'per' => q(ସପ୍ତାହକୁ {0}),
					},
					# Long Unit Identifier
					'duration-year' => {
						'per' => q({0} ପ୍ରତି ବର୍ଷ),
					},
					# Core Unit Identifier
					'year' => {
						'per' => q({0} ପ୍ରତି ବର୍ଷ),
					},
					# Long Unit Identifier
					'electric-ampere' => {
						'name' => q(ଆମ୍ପିୟର୍),
						'one' => q({0} ଆମ୍ପିୟର୍),
						'other' => q({0} ଆମ୍ପିୟର୍),
					},
					# Core Unit Identifier
					'ampere' => {
						'name' => q(ଆମ୍ପିୟର୍),
						'one' => q({0} ଆମ୍ପିୟର୍),
						'other' => q({0} ଆମ୍ପିୟର୍),
					},
					# Long Unit Identifier
					'electric-milliampere' => {
						'name' => q(ମିଲିଆମ୍ପିୟର୍),
						'one' => q({0} ମିଲିଆମ୍ପିୟର୍),
						'other' => q({0} ମିଲିଆମ୍ପିୟର୍),
					},
					# Core Unit Identifier
					'milliampere' => {
						'name' => q(ମିଲିଆମ୍ପିୟର୍),
						'one' => q({0} ମିଲିଆମ୍ପିୟର୍),
						'other' => q({0} ମିଲିଆମ୍ପିୟର୍),
					},
					# Long Unit Identifier
					'electric-ohm' => {
						'one' => q({0} ଓହମ୍),
						'other' => q({0} ଓହମ୍),
					},
					# Core Unit Identifier
					'ohm' => {
						'one' => q({0} ଓହମ୍),
						'other' => q({0} ଓହମ୍),
					},
					# Long Unit Identifier
					'electric-volt' => {
						'one' => q({0} ଭୋଲ୍ଟ୍),
						'other' => q({0} ଭୋଲ୍ଟ୍),
					},
					# Core Unit Identifier
					'volt' => {
						'one' => q({0} ଭୋଲ୍ଟ୍),
						'other' => q({0} ଭୋଲ୍ଟ୍),
					},
					# Long Unit Identifier
					'energy-british-thermal-unit' => {
						'name' => q(ବ୍ରିଟିଶ ଥର୍ମାଲ ଏକକ),
						'one' => q({0} ବ୍ରିଟିଶ ଥର୍ମାଲ ଏକକ),
						'other' => q({0} ବ୍ରିଟିଶ ଥର୍ମାଲ ଏକକ),
					},
					# Core Unit Identifier
					'british-thermal-unit' => {
						'name' => q(ବ୍ରିଟିଶ ଥର୍ମାଲ ଏକକ),
						'one' => q({0} ବ୍ରିଟିଶ ଥର୍ମାଲ ଏକକ),
						'other' => q({0} ବ୍ରିଟିଶ ଥର୍ମାଲ ଏକକ),
					},
					# Long Unit Identifier
					'energy-calorie' => {
						'name' => q(କ୍ୟାଲୋରୀ),
						'one' => q({0} କ୍ୟାଲୋରୀ),
						'other' => q({0} କ୍ୟାଲୋରୀ),
					},
					# Core Unit Identifier
					'calorie' => {
						'name' => q(କ୍ୟାଲୋରୀ),
						'one' => q({0} କ୍ୟାଲୋରୀ),
						'other' => q({0} କ୍ୟାଲୋରୀ),
					},
					# Long Unit Identifier
					'energy-electronvolt' => {
						'one' => q({0} ଇଲେକ୍ଟ୍ରୋନ୍‌ ଭୋଲ୍ଟ),
						'other' => q({0} ଇଲେକ୍ଟ୍ରୋନ୍‌ ଭୋଲ୍ଟ),
					},
					# Core Unit Identifier
					'electronvolt' => {
						'one' => q({0} ଇଲେକ୍ଟ୍ରୋନ୍‌ ଭୋଲ୍ଟ),
						'other' => q({0} ଇଲେକ୍ଟ୍ରୋନ୍‌ ଭୋଲ୍ଟ),
					},
					# Long Unit Identifier
					'energy-foodcalorie' => {
						'name' => q(କ୍ୟାଲୋରୀ),
						'one' => q({0} କ୍ୟାଲୋରୀ),
						'other' => q({0} କ୍ୟାଲୋରୀ),
					},
					# Core Unit Identifier
					'foodcalorie' => {
						'name' => q(କ୍ୟାଲୋରୀ),
						'one' => q({0} କ୍ୟାଲୋରୀ),
						'other' => q({0} କ୍ୟାଲୋରୀ),
					},
					# Long Unit Identifier
					'energy-joule' => {
						'one' => q({0} ଜୁଲ୍),
						'other' => q({0} ଜୁଲ୍),
					},
					# Core Unit Identifier
					'joule' => {
						'one' => q({0} ଜୁଲ୍),
						'other' => q({0} ଜୁଲ୍),
					},
					# Long Unit Identifier
					'energy-kilocalorie' => {
						'name' => q(କିଲୋକ୍ୟାଲୋରୀ),
						'one' => q({0} କିଲୋକ୍ୟାଲୋରୀ),
						'other' => q({0} କିଲୋକ୍ୟାଲୋରୀ),
					},
					# Core Unit Identifier
					'kilocalorie' => {
						'name' => q(କିଲୋକ୍ୟାଲୋରୀ),
						'one' => q({0} କିଲୋକ୍ୟାଲୋରୀ),
						'other' => q({0} କିଲୋକ୍ୟାଲୋରୀ),
					},
					# Long Unit Identifier
					'energy-kilojoule' => {
						'one' => q({0} କିଲୋଜୁଲ୍),
						'other' => q({0} କିଲୋଜୁଲ୍),
					},
					# Core Unit Identifier
					'kilojoule' => {
						'one' => q({0} କିଲୋଜୁଲ୍),
						'other' => q({0} କିଲୋଜୁଲ୍),
					},
					# Long Unit Identifier
					'energy-kilowatt-hour' => {
						'name' => q(କିଲୋୱାଟ୍-ଘଣ୍ଟା),
						'one' => q({0} କିଲୋୱାଟ୍-ଘଣ୍ଟା),
						'other' => q({0} କିଲୋୱାଟ୍-ଘଣ୍ଟା),
					},
					# Core Unit Identifier
					'kilowatt-hour' => {
						'name' => q(କିଲୋୱାଟ୍-ଘଣ୍ଟା),
						'one' => q({0} କିଲୋୱାଟ୍-ଘଣ୍ଟା),
						'other' => q({0} କିଲୋୱାଟ୍-ଘଣ୍ଟା),
					},
					# Long Unit Identifier
					'force-kilowatt-hour-per-100-kilometer' => {
						'name' => q(100 କିଲୋମିଟର୍‌ ପ୍ରତି କିଲୋୱାଟ୍‌-ଘଣ୍ଟା),
						'one' => q({0} 100 କିଲୋମିଟର୍‌ ପ୍ରତି କିଲୋୱାଟ୍‌-ଘଣ୍ଟା),
						'other' => q({0} 100 କିଲୋମିଟର୍‌ ପ୍ରତି କିଲୋୱାଟ୍‌-ଘଣ୍ଟା),
					},
					# Core Unit Identifier
					'kilowatt-hour-per-100-kilometer' => {
						'name' => q(100 କିଲୋମିଟର୍‌ ପ୍ରତି କିଲୋୱାଟ୍‌-ଘଣ୍ଟା),
						'one' => q({0} 100 କିଲୋମିଟର୍‌ ପ୍ରତି କିଲୋୱାଟ୍‌-ଘଣ୍ଟା),
						'other' => q({0} 100 କିଲୋମିଟର୍‌ ପ୍ରତି କିଲୋୱାଟ୍‌-ଘଣ୍ଟା),
					},
					# Long Unit Identifier
					'force-newton' => {
						'name' => q(ନ୍ୟୁଟନ୍ସ),
						'one' => q({0} ନ୍ୟୁଟନ),
						'other' => q({0} ନ୍ୟୁଟନ୍ସ),
					},
					# Core Unit Identifier
					'newton' => {
						'name' => q(ନ୍ୟୁଟନ୍ସ),
						'one' => q({0} ନ୍ୟୁଟନ),
						'other' => q({0} ନ୍ୟୁଟନ୍ସ),
					},
					# Long Unit Identifier
					'force-pound-force' => {
						'name' => q(ପାଉଣ୍ଡସ ଅଫ ଫୋର୍ସ),
						'one' => q({0} ପାଉଣ୍ଡସ ଅଫ ଫୋର୍ସ),
						'other' => q({0} ପାଉଣ୍ଡସ ଅଫ ଫୋର୍ସ),
					},
					# Core Unit Identifier
					'pound-force' => {
						'name' => q(ପାଉଣ୍ଡସ ଅଫ ଫୋର୍ସ),
						'one' => q({0} ପାଉଣ୍ଡସ ଅଫ ଫୋର୍ସ),
						'other' => q({0} ପାଉଣ୍ଡସ ଅଫ ଫୋର୍ସ),
					},
					# Long Unit Identifier
					'frequency-gigahertz' => {
						'name' => q(ଗିଗାହର୍ଜ୍),
						'one' => q({0} ଗିଗାହର୍ଜ୍),
						'other' => q({0} ଗିଗାହର୍ଜ୍),
					},
					# Core Unit Identifier
					'gigahertz' => {
						'name' => q(ଗିଗାହର୍ଜ୍),
						'one' => q({0} ଗିଗାହର୍ଜ୍),
						'other' => q({0} ଗିଗାହର୍ଜ୍),
					},
					# Long Unit Identifier
					'frequency-hertz' => {
						'name' => q(ହର୍ଜ୍),
						'one' => q({0} ହର୍ଜ୍),
						'other' => q({0} ହର୍ଜ୍),
					},
					# Core Unit Identifier
					'hertz' => {
						'name' => q(ହର୍ଜ୍),
						'one' => q({0} ହର୍ଜ୍),
						'other' => q({0} ହର୍ଜ୍),
					},
					# Long Unit Identifier
					'frequency-kilohertz' => {
						'name' => q(କିଲୋହର୍ଜ୍),
						'one' => q({0} କିଲୋହର୍ଜ୍),
						'other' => q({0} କିଲୋହର୍ଜ୍),
					},
					# Core Unit Identifier
					'kilohertz' => {
						'name' => q(କିଲୋହର୍ଜ୍),
						'one' => q({0} କିଲୋହର୍ଜ୍),
						'other' => q({0} କିଲୋହର୍ଜ୍),
					},
					# Long Unit Identifier
					'frequency-megahertz' => {
						'name' => q(ମେଗାହର୍ଜ୍),
						'one' => q({0} ମେଗାହର୍ଜ୍),
						'other' => q({0} ମେଗାହର୍ଜ୍),
					},
					# Core Unit Identifier
					'megahertz' => {
						'name' => q(ମେଗାହର୍ଜ୍),
						'one' => q({0} ମେଗାହର୍ଜ୍),
						'other' => q({0} ମେଗାହର୍ଜ୍),
					},
					# Long Unit Identifier
					'graphics-dot' => {
						'one' => q({0} ବିନ୍ଦୁ),
						'other' => q({0} ବି),
					},
					# Core Unit Identifier
					'dot' => {
						'one' => q({0} ବିନ୍ଦୁ),
						'other' => q({0} ବି),
					},
					# Long Unit Identifier
					'graphics-dot-per-centimeter' => {
						'name' => q(ବିନ୍ଦୁ ପ୍ରତି ସେଣ୍ଟିମିଟର),
						'one' => q({0} ବିନ୍ଦୁ ପ୍ରତି ସେଣ୍ଟିମିଟର),
						'other' => q({0} ବିନ୍ଦୁ ପ୍ରତି ସେଣ୍ଟିମିଟର),
					},
					# Core Unit Identifier
					'dot-per-centimeter' => {
						'name' => q(ବିନ୍ଦୁ ପ୍ରତି ସେଣ୍ଟିମିଟର),
						'one' => q({0} ବିନ୍ଦୁ ପ୍ରତି ସେଣ୍ଟିମିଟର),
						'other' => q({0} ବିନ୍ଦୁ ପ୍ରତି ସେଣ୍ଟିମିଟର),
					},
					# Long Unit Identifier
					'graphics-dot-per-inch' => {
						'name' => q(ପ୍ରତି ଇଞ୍ଚରେ ବିନ୍ଦୁ),
						'one' => q({0} ପ୍ରତି ଇଞ୍ଚରେ ବିନ୍ଦୁ),
						'other' => q({0} ପ୍ରତି ଇଞ୍ଚରେ ବିନ୍ଦୁ),
					},
					# Core Unit Identifier
					'dot-per-inch' => {
						'name' => q(ପ୍ରତି ଇଞ୍ଚରେ ବିନ୍ଦୁ),
						'one' => q({0} ପ୍ରତି ଇଞ୍ଚରେ ବିନ୍ଦୁ),
						'other' => q({0} ପ୍ରତି ଇଞ୍ଚରେ ବିନ୍ଦୁ),
					},
					# Long Unit Identifier
					'graphics-em' => {
						'name' => q(ଟାଇପୋଗ୍ରାଫିକ୍ ems),
					},
					# Core Unit Identifier
					'em' => {
						'name' => q(ଟାଇପୋଗ୍ରାଫିକ୍ ems),
					},
					# Long Unit Identifier
					'graphics-megapixel' => {
						'name' => q(ମେଗାପିକ୍ସେଲ),
						'one' => q({0} ମେଗାପିକ୍ସେଲ),
						'other' => q({0} ମେଗାପିକ୍ସେଲ୍ସ),
					},
					# Core Unit Identifier
					'megapixel' => {
						'name' => q(ମେଗାପିକ୍ସେଲ),
						'one' => q({0} ମେଗାପିକ୍ସେଲ),
						'other' => q({0} ମେଗାପିକ୍ସେଲ୍ସ),
					},
					# Long Unit Identifier
					'graphics-pixel' => {
						'name' => q(ପିକ୍ସେଲ),
						'one' => q({0} ପିକ୍ସେଲ),
						'other' => q({0} ପିକ୍ସେଲ୍ସ),
					},
					# Core Unit Identifier
					'pixel' => {
						'name' => q(ପିକ୍ସେଲ),
						'one' => q({0} ପିକ୍ସେଲ),
						'other' => q({0} ପିକ୍ସେଲ୍ସ),
					},
					# Long Unit Identifier
					'graphics-pixel-per-centimeter' => {
						'name' => q(ପିକ୍ସେଲ ପ୍ରତି ସେଣ୍ଟିମିଟର),
						'one' => q({0} ପିକ୍ସେଲ ପ୍ରତି ସେଣ୍ଟିମିଟର),
						'other' => q({0} ପିକ୍ସେଲ ପ୍ରତି ସେଣ୍ଟିମିଟର),
					},
					# Core Unit Identifier
					'pixel-per-centimeter' => {
						'name' => q(ପିକ୍ସେଲ ପ୍ରତି ସେଣ୍ଟିମିଟର),
						'one' => q({0} ପିକ୍ସେଲ ପ୍ରତି ସେଣ୍ଟିମିଟର),
						'other' => q({0} ପିକ୍ସେଲ ପ୍ରତି ସେଣ୍ଟିମିଟର),
					},
					# Long Unit Identifier
					'graphics-pixel-per-inch' => {
						'name' => q(ପ୍ରତି ଇଞ୍ଚରେ ପିକ୍ସେଲ),
						'one' => q({0} ପ୍ରତି ଇଞ୍ଚରେ ପିକ୍ସେଲ),
						'other' => q({0} ପ୍ରତି ଇଞ୍ଚରେ ପିକ୍ସେଲ),
					},
					# Core Unit Identifier
					'pixel-per-inch' => {
						'name' => q(ପ୍ରତି ଇଞ୍ଚରେ ପିକ୍ସେଲ),
						'one' => q({0} ପ୍ରତି ଇଞ୍ଚରେ ପିକ୍ସେଲ),
						'other' => q({0} ପ୍ରତି ଇଞ୍ଚରେ ପିକ୍ସେଲ),
					},
					# Long Unit Identifier
					'length-astronomical-unit' => {
						'name' => q(ଖଗୋଲୀୟ ଏକକ),
						'one' => q({0} ଖଗୋଲୀୟ ଏକକ),
						'other' => q({0} ଖଗୋଲୀୟ ଏକକ),
					},
					# Core Unit Identifier
					'astronomical-unit' => {
						'name' => q(ଖଗୋଲୀୟ ଏକକ),
						'one' => q({0} ଖଗୋଲୀୟ ଏକକ),
						'other' => q({0} ଖଗୋଲୀୟ ଏକକ),
					},
					# Long Unit Identifier
					'length-centimeter' => {
						'name' => q(ସେଣ୍ଟିମିଟର୍),
						'one' => q({0} ସେଣ୍ଟିମିଟର୍),
						'other' => q({0} ସେଣ୍ଟିମିଟର୍),
						'per' => q({0} ପ୍ରତି ସେଣ୍ଟିମିଟର୍),
					},
					# Core Unit Identifier
					'centimeter' => {
						'name' => q(ସେଣ୍ଟିମିଟର୍),
						'one' => q({0} ସେଣ୍ଟିମିଟର୍),
						'other' => q({0} ସେଣ୍ଟିମିଟର୍),
						'per' => q({0} ପ୍ରତି ସେଣ୍ଟିମିଟର୍),
					},
					# Long Unit Identifier
					'length-decimeter' => {
						'name' => q(ଡେସିମିଟର୍),
						'one' => q({0} ଡେସିମିଟର୍),
						'other' => q({0} ଡେସିମିଟର୍),
					},
					# Core Unit Identifier
					'decimeter' => {
						'name' => q(ଡେସିମିଟର୍),
						'one' => q({0} ଡେସିମିଟର୍),
						'other' => q({0} ଡେସିମିଟର୍),
					},
					# Long Unit Identifier
					'length-earth-radius' => {
						'name' => q(ପୃଥିବୀ ବ୍ୟାସାର୍ଦ୍ଧ),
						'one' => q({0} ପୃଥିବୀ ବ୍ୟାସାର୍ଦ୍ଧ),
						'other' => q({0} ପୃଥିବୀ ବ୍ୟାସାର୍ଦ୍ଧ),
					},
					# Core Unit Identifier
					'earth-radius' => {
						'name' => q(ପୃଥିବୀ ବ୍ୟାସାର୍ଦ୍ଧ),
						'one' => q({0} ପୃଥିବୀ ବ୍ୟାସାର୍ଦ୍ଧ),
						'other' => q({0} ପୃଥିବୀ ବ୍ୟାସାର୍ଦ୍ଧ),
					},
					# Long Unit Identifier
					'length-fathom' => {
						'name' => q(ଫାଟୋମସ୍),
						'one' => q({0} ଫାଟୋମ),
						'other' => q({0} ଫାଟୋମସ୍),
					},
					# Core Unit Identifier
					'fathom' => {
						'name' => q(ଫାଟୋମସ୍),
						'one' => q({0} ଫାଟୋମ),
						'other' => q({0} ଫାଟୋମସ୍),
					},
					# Long Unit Identifier
					'length-foot' => {
						'one' => q({0} ଫୁଟ୍),
						'other' => q({0} ଫିଟ୍),
						'per' => q({0} ପ୍ରତି ଫୁଟ୍),
					},
					# Core Unit Identifier
					'foot' => {
						'one' => q({0} ଫୁଟ୍),
						'other' => q({0} ଫିଟ୍),
						'per' => q({0} ପ୍ରତି ଫୁଟ୍),
					},
					# Long Unit Identifier
					'length-furlong' => {
						'one' => q({0} ଫର୍ଲଙ୍ଗ୍),
						'other' => q({0} ଫର୍ଲଙ୍ଗସ୍),
					},
					# Core Unit Identifier
					'furlong' => {
						'one' => q({0} ଫର୍ଲଙ୍ଗ୍),
						'other' => q({0} ଫର୍ଲଙ୍ଗସ୍),
					},
					# Long Unit Identifier
					'length-inch' => {
						'per' => q({0} ପ୍ରତି ଇଞ୍ଚ୍),
					},
					# Core Unit Identifier
					'inch' => {
						'per' => q({0} ପ୍ରତି ଇଞ୍ଚ୍),
					},
					# Long Unit Identifier
					'length-kilometer' => {
						'name' => q(କିଲୋମିଟର୍),
						'one' => q({0} କିଲୋମିଟର୍),
						'other' => q({0} କିଲୋମିଟର୍),
						'per' => q({0} ପ୍ରତି କିଲୋମିଟର୍),
					},
					# Core Unit Identifier
					'kilometer' => {
						'name' => q(କିଲୋମିଟର୍),
						'one' => q({0} କିଲୋମିଟର୍),
						'other' => q({0} କିଲୋମିଟର୍),
						'per' => q({0} ପ୍ରତି କିଲୋମିଟର୍),
					},
					# Long Unit Identifier
					'length-light-year' => {
						'one' => q({0} ଆଲୋକ ବର୍ଷ),
						'other' => q({0} ଆଲୋକ ବର୍ଷ),
					},
					# Core Unit Identifier
					'light-year' => {
						'one' => q({0} ଆଲୋକ ବର୍ଷ),
						'other' => q({0} ଆଲୋକ ବର୍ଷ),
					},
					# Long Unit Identifier
					'length-meter' => {
						'name' => q(ମିଟର୍),
						'one' => q({0} ମିଟର୍),
						'other' => q({0} ମିଟର୍),
						'per' => q({0} ପ୍ରତି ମିଟର୍),
					},
					# Core Unit Identifier
					'meter' => {
						'name' => q(ମିଟର୍),
						'one' => q({0} ମିଟର୍),
						'other' => q({0} ମିଟର୍),
						'per' => q({0} ପ୍ରତି ମିଟର୍),
					},
					# Long Unit Identifier
					'length-micrometer' => {
						'name' => q(ମାଇକ୍ରୋମିଟର୍),
						'one' => q({0} ମାଇକ୍ରୋମିଟର୍),
						'other' => q({0} ମାଇକ୍ରୋମିଟର୍),
					},
					# Core Unit Identifier
					'micrometer' => {
						'name' => q(ମାଇକ୍ରୋମିଟର୍),
						'one' => q({0} ମାଇକ୍ରୋମିଟର୍),
						'other' => q({0} ମାଇକ୍ରୋମିଟର୍),
					},
					# Long Unit Identifier
					'length-mile' => {
						'one' => q({0} ମାଇଲ୍),
						'other' => q({0} ମାଇଲ୍),
					},
					# Core Unit Identifier
					'mile' => {
						'one' => q({0} ମାଇଲ୍),
						'other' => q({0} ମାଇଲ୍),
					},
					# Long Unit Identifier
					'length-mile-scandinavian' => {
						'name' => q(ମାଇଲ୍-ସ୍କାନଡିନାଭିୟ),
						'one' => q({0} ମାଇଲ୍-ସ୍କାନଡିନାଭିୟ),
						'other' => q({0} ମାଇଲ୍-ସ୍କାନଡିନାଭିୟ),
					},
					# Core Unit Identifier
					'mile-scandinavian' => {
						'name' => q(ମାଇଲ୍-ସ୍କାନଡିନାଭିୟ),
						'one' => q({0} ମାଇଲ୍-ସ୍କାନଡିନାଭିୟ),
						'other' => q({0} ମାଇଲ୍-ସ୍କାନଡିନାଭିୟ),
					},
					# Long Unit Identifier
					'length-millimeter' => {
						'name' => q(ମିଲିମିଟର୍),
						'one' => q({0} ମିଲିମିଟର୍),
						'other' => q({0} ମିଲିମିଟର୍),
					},
					# Core Unit Identifier
					'millimeter' => {
						'name' => q(ମିଲିମିଟର୍),
						'one' => q({0} ମିଲିମିଟର୍),
						'other' => q({0} ମିଲିମିଟର୍),
					},
					# Long Unit Identifier
					'length-nanometer' => {
						'name' => q(ନାନୋମିଟର୍),
						'one' => q({0} ନାନୋମିଟର୍),
						'other' => q({0} ନାନୋମିଟର୍),
					},
					# Core Unit Identifier
					'nanometer' => {
						'name' => q(ନାନୋମିଟର୍),
						'one' => q({0} ନାନୋମିଟର୍),
						'other' => q({0} ନାନୋମିଟର୍),
					},
					# Long Unit Identifier
					'length-nautical-mile' => {
						'name' => q(ନଟିକାଲ୍ ମାଇଲ୍),
						'one' => q({0} ନଟିକାଲ୍ ମାଇଲ୍),
						'other' => q({0} ନଟିକାଲ୍ ମାଇଲ୍),
					},
					# Core Unit Identifier
					'nautical-mile' => {
						'name' => q(ନଟିକାଲ୍ ମାଇଲ୍),
						'one' => q({0} ନଟିକାଲ୍ ମାଇଲ୍),
						'other' => q({0} ନଟିକାଲ୍ ମାଇଲ୍),
					},
					# Long Unit Identifier
					'length-parsec' => {
						'one' => q({0} ପାରସେକ୍),
						'other' => q({0} ପାରସେକ୍),
					},
					# Core Unit Identifier
					'parsec' => {
						'one' => q({0} ପାରସେକ୍),
						'other' => q({0} ପାରସେକ୍),
					},
					# Long Unit Identifier
					'length-picometer' => {
						'name' => q(ପିକୋମିଟର୍),
						'one' => q({0} ପିକୋମିଟର୍),
						'other' => q({0} ପିକୋମିଟର୍),
					},
					# Core Unit Identifier
					'picometer' => {
						'name' => q(ପିକୋମିଟର୍),
						'one' => q({0} ପିକୋମିଟର୍),
						'other' => q({0} ପିକୋମିଟର୍),
					},
					# Long Unit Identifier
					'length-point' => {
						'one' => q({0} ପଏଣ୍ଟ୍),
						'other' => q({0} ପଏଣ୍ଟ୍),
					},
					# Core Unit Identifier
					'point' => {
						'one' => q({0} ପଏଣ୍ଟ୍),
						'other' => q({0} ପଏଣ୍ଟ୍),
					},
					# Long Unit Identifier
					'length-solar-radius' => {
						'name' => q(ସୋଲାର ବ୍ୟାସାର୍ଦ୍ଧ),
						'one' => q({0} ସୋଲାର ବ୍ୟାସାର୍ଦ୍ଧ),
						'other' => q({0} ସୋଲାର ବ୍ୟାସାର୍ଦ୍ଧ),
					},
					# Core Unit Identifier
					'solar-radius' => {
						'name' => q(ସୋଲାର ବ୍ୟାସାର୍ଦ୍ଧ),
						'one' => q({0} ସୋଲାର ବ୍ୟାସାର୍ଦ୍ଧ),
						'other' => q({0} ସୋଲାର ବ୍ୟାସାର୍ଦ୍ଧ),
					},
					# Long Unit Identifier
					'light-candela' => {
						'name' => q(candela),
						'one' => q({0} candela),
						'other' => q({0} candela),
					},
					# Core Unit Identifier
					'candela' => {
						'name' => q(candela),
						'one' => q({0} candela),
						'other' => q({0} candela),
					},
					# Long Unit Identifier
					'light-solar-luminosity' => {
						'one' => q({0} ସୋଲର ଲ୍ୟୁମିନୋସିଟି),
						'other' => q({0} ସୋଲର ଲ୍ୟୁମିନୋସିଟିସ),
					},
					# Core Unit Identifier
					'solar-luminosity' => {
						'one' => q({0} ସୋଲର ଲ୍ୟୁମିନୋସିଟି),
						'other' => q({0} ସୋଲର ଲ୍ୟୁମିନୋସିଟିସ),
					},
					# Long Unit Identifier
					'mass-carat' => {
						'one' => q({0} କ୍ୟାରେଟ୍),
						'other' => q({0} କ୍ୟାରେଟ୍),
					},
					# Core Unit Identifier
					'carat' => {
						'one' => q({0} କ୍ୟାରେଟ୍),
						'other' => q({0} କ୍ୟାରେଟ୍),
					},
					# Long Unit Identifier
					'mass-dalton' => {
						'one' => q({0} ଡାଲ୍ଟନ),
						'other' => q({0} ଡାଲ୍ଟନ),
					},
					# Core Unit Identifier
					'dalton' => {
						'one' => q({0} ଡାଲ୍ଟନ),
						'other' => q({0} ଡାଲ୍ଟନ),
					},
					# Long Unit Identifier
					'mass-earth-mass' => {
						'one' => q({0} ଅର୍ଥ ମାସ),
						'other' => q({0} ଅର୍ଥ ମାସେସ),
					},
					# Core Unit Identifier
					'earth-mass' => {
						'one' => q({0} ଅର୍ଥ ମାସ),
						'other' => q({0} ଅର୍ଥ ମାସେସ),
					},
					# Long Unit Identifier
					'mass-gram' => {
						'one' => q({0} ଗ୍ରାମ୍),
						'other' => q({0} ଗ୍ରାମ୍),
						'per' => q({0} ପ୍ରତି ଗ୍ରାମ୍),
					},
					# Core Unit Identifier
					'gram' => {
						'one' => q({0} ଗ୍ରାମ୍),
						'other' => q({0} ଗ୍ରାମ୍),
						'per' => q({0} ପ୍ରତି ଗ୍ରାମ୍),
					},
					# Long Unit Identifier
					'mass-kilogram' => {
						'name' => q(କିଲୋଗ୍ରାମ୍),
						'one' => q({0} କିଲୋଗ୍ରାମ୍),
						'other' => q({0} କିଲୋଗ୍ରାମ୍),
						'per' => q({0} ପ୍ରତି କିଲୋଗ୍ରାମ୍),
					},
					# Core Unit Identifier
					'kilogram' => {
						'name' => q(କିଲୋଗ୍ରାମ୍),
						'one' => q({0} କିଲୋଗ୍ରାମ୍),
						'other' => q({0} କିଲୋଗ୍ରାମ୍),
						'per' => q({0} ପ୍ରତି କିଲୋଗ୍ରାମ୍),
					},
					# Long Unit Identifier
					'mass-microgram' => {
						'name' => q(ମାଇକ୍ରୋଗ୍ରାମ୍),
						'one' => q({0} ମାଇକ୍ରୋଗ୍ରାମ୍),
						'other' => q({0} ମାଇକ୍ରୋଗ୍ରାମ୍),
					},
					# Core Unit Identifier
					'microgram' => {
						'name' => q(ମାଇକ୍ରୋଗ୍ରାମ୍),
						'one' => q({0} ମାଇକ୍ରୋଗ୍ରାମ୍),
						'other' => q({0} ମାଇକ୍ରୋଗ୍ରାମ୍),
					},
					# Long Unit Identifier
					'mass-milligram' => {
						'name' => q(ମିଲିଗ୍ରାମ୍),
						'one' => q({0} ମିଲିଗ୍ରାମ୍),
						'other' => q({0} ମିଲିଗ୍ରାମ୍),
					},
					# Core Unit Identifier
					'milligram' => {
						'name' => q(ମିଲିଗ୍ରାମ୍),
						'one' => q({0} ମିଲିଗ୍ରାମ୍),
						'other' => q({0} ମିଲିଗ୍ରାମ୍),
					},
					# Long Unit Identifier
					'mass-ounce' => {
						'name' => q(ଆଉନ୍ସ),
						'one' => q({0} ଆଉନ୍ସ),
						'other' => q({0} ଆଉନ୍ସ),
						'per' => q({0} ପ୍ରତି ଆଉନ୍ସ),
					},
					# Core Unit Identifier
					'ounce' => {
						'name' => q(ଆଉନ୍ସ),
						'one' => q({0} ଆଉନ୍ସ),
						'other' => q({0} ଆଉନ୍ସ),
						'per' => q({0} ପ୍ରତି ଆଉନ୍ସ),
					},
					# Long Unit Identifier
					'mass-ounce-troy' => {
						'name' => q(ଟ୍ରୋୟ ଆଉନ୍ସ),
						'one' => q({0} ଟ୍ରୋୟ ଆଉନ୍ସ),
						'other' => q({0} ଟ୍ରୋୟ ଆଉନ୍ସ),
					},
					# Core Unit Identifier
					'ounce-troy' => {
						'name' => q(ଟ୍ରୋୟ ଆଉନ୍ସ),
						'one' => q({0} ଟ୍ରୋୟ ଆଉନ୍ସ),
						'other' => q({0} ଟ୍ରୋୟ ଆଉନ୍ସ),
					},
					# Long Unit Identifier
					'mass-pound' => {
						'per' => q({0} ପ୍ରତି ପାଉଣ୍ଡ୍),
					},
					# Core Unit Identifier
					'pound' => {
						'per' => q({0} ପ୍ରତି ପାଉଣ୍ଡ୍),
					},
					# Long Unit Identifier
					'mass-solar-mass' => {
						'one' => q({0} ସୋଲର ମାସ),
						'other' => q({0} ସୋଲର ମାସେସ),
					},
					# Core Unit Identifier
					'solar-mass' => {
						'one' => q({0} ସୋଲର ମାସ),
						'other' => q({0} ସୋଲର ମାସେସ),
					},
					# Long Unit Identifier
					'mass-stone' => {
						'one' => q({0} ଷ୍ଟୋନ୍),
						'other' => q({0} ଷ୍ଟୋନସ୍),
					},
					# Core Unit Identifier
					'stone' => {
						'one' => q({0} ଷ୍ଟୋନ୍),
						'other' => q({0} ଷ୍ଟୋନସ୍),
					},
					# Long Unit Identifier
					'mass-ton' => {
						'name' => q(ଟନ୍),
					},
					# Core Unit Identifier
					'ton' => {
						'name' => q(ଟନ୍),
					},
					# Long Unit Identifier
					'mass-tonne' => {
						'name' => q(ମେଟ୍ରିକ୍ ଟନ୍),
						'one' => q({0} ମେଟ୍ରିକ୍ ଟନ୍),
						'other' => q({0} ମେଟ୍ରିକ୍ ଟନ୍),
					},
					# Core Unit Identifier
					'tonne' => {
						'name' => q(ମେଟ୍ରିକ୍ ଟନ୍),
						'one' => q({0} ମେଟ୍ରିକ୍ ଟନ୍),
						'other' => q({0} ମେଟ୍ରିକ୍ ଟନ୍),
					},
					# Long Unit Identifier
					'per' => {
						'1' => q({1} ପ୍ରତି {0}),
					},
					# Core Unit Identifier
					'per' => {
						'1' => q({1} ପ୍ରତି {0}),
					},
					# Long Unit Identifier
					'power-gigawatt' => {
						'name' => q(ଗିଗାୱାଟ୍),
						'one' => q({0} ଗିଗାୱାଟ୍),
						'other' => q({0} ଗିଗାୱାଟ୍),
					},
					# Core Unit Identifier
					'gigawatt' => {
						'name' => q(ଗିଗାୱାଟ୍),
						'one' => q({0} ଗିଗାୱାଟ୍),
						'other' => q({0} ଗିଗାୱାଟ୍),
					},
					# Long Unit Identifier
					'power-horsepower' => {
						'name' => q(ହର୍ସପାୱାର୍),
						'one' => q({0} ହର୍ସପାୱାର୍),
						'other' => q({0} ହର୍ସପାୱାର୍),
					},
					# Core Unit Identifier
					'horsepower' => {
						'name' => q(ହର୍ସପାୱାର୍),
						'one' => q({0} ହର୍ସପାୱାର୍),
						'other' => q({0} ହର୍ସପାୱାର୍),
					},
					# Long Unit Identifier
					'power-kilowatt' => {
						'name' => q(କିଲୋୱାଟ୍),
						'one' => q({0} କିଲୋୱାଟ୍),
						'other' => q({0} କିଲୋୱାଟ୍),
					},
					# Core Unit Identifier
					'kilowatt' => {
						'name' => q(କିଲୋୱାଟ୍),
						'one' => q({0} କିଲୋୱାଟ୍),
						'other' => q({0} କିଲୋୱାଟ୍),
					},
					# Long Unit Identifier
					'power-megawatt' => {
						'name' => q(ମେଗାୱାଟ୍),
						'one' => q({0} ମେଗାୱାଟ୍),
						'other' => q({0} ମେଗାୱାଟ୍),
					},
					# Core Unit Identifier
					'megawatt' => {
						'name' => q(ମେଗାୱାଟ୍),
						'one' => q({0} ମେଗାୱାଟ୍),
						'other' => q({0} ମେଗାୱାଟ୍),
					},
					# Long Unit Identifier
					'power-milliwatt' => {
						'name' => q(ମିଲିୱାଟ୍),
						'one' => q({0} ମିଲିୱାଟ୍),
						'other' => q({0} ମିଲିୱାଟ୍),
					},
					# Core Unit Identifier
					'milliwatt' => {
						'name' => q(ମିଲିୱାଟ୍),
						'one' => q({0} ମିଲିୱାଟ୍),
						'other' => q({0} ମିଲିୱାଟ୍),
					},
					# Long Unit Identifier
					'power-watt' => {
						'one' => q({0} ୱାଟ୍),
						'other' => q({0} ୱାଟ୍),
					},
					# Core Unit Identifier
					'watt' => {
						'one' => q({0} ୱାଟ୍),
						'other' => q({0} ୱାଟ୍),
					},
					# Long Unit Identifier
					'power2' => {
						'1' => q(ସ୍କୋୟାର୍ {0}),
						'one' => q(ସ୍କୋୟାର୍{0}),
						'other' => q(ସ୍କୋ{0}),
					},
					# Core Unit Identifier
					'power2' => {
						'1' => q(ସ୍କୋୟାର୍ {0}),
						'one' => q(ସ୍କୋୟାର୍{0}),
						'other' => q(ସ୍କୋ{0}),
					},
					# Long Unit Identifier
					'power3' => {
						'1' => q(କ୍ୟୁବି {0}),
						'one' => q(କ୍ୟୁବିକ୍ {0}),
						'other' => q(କ୍ୟୁ {0}),
					},
					# Core Unit Identifier
					'power3' => {
						'1' => q(କ୍ୟୁବି {0}),
						'one' => q(କ୍ୟୁବିକ୍ {0}),
						'other' => q(କ୍ୟୁ {0}),
					},
					# Long Unit Identifier
					'pressure-atmosphere' => {
						'name' => q(ଆଟମୋସ୍ପିଅର),
						'one' => q({0} ଆଟମୋସ୍ପିଅର),
						'other' => q({0} ଆଟମୋସ୍ପିଅର),
					},
					# Core Unit Identifier
					'atmosphere' => {
						'name' => q(ଆଟମୋସ୍ପିଅର),
						'one' => q({0} ଆଟମୋସ୍ପିଅର),
						'other' => q({0} ଆଟମୋସ୍ପିଅର),
					},
					# Long Unit Identifier
					'pressure-hectopascal' => {
						'name' => q(ହେକ୍ଟୋପାସ୍କେଲ୍),
						'one' => q({0} ହେକ୍ଟୋପାସ୍କେଲ୍),
						'other' => q({0} ହେକ୍ଟୋପାସ୍କେଲ୍),
					},
					# Core Unit Identifier
					'hectopascal' => {
						'name' => q(ହେକ୍ଟୋପାସ୍କେଲ୍),
						'one' => q({0} ହେକ୍ଟୋପାସ୍କେଲ୍),
						'other' => q({0} ହେକ୍ଟୋପାସ୍କେଲ୍),
					},
					# Long Unit Identifier
					'pressure-inch-ofhg' => {
						'name' => q(ପାରାର ଇଞ୍ଜି),
						'one' => q(ପାରାର {0} ଇଞ୍ଜି),
						'other' => q(ପାରାର {0} ଇଞ୍ଜି),
					},
					# Core Unit Identifier
					'inch-ofhg' => {
						'name' => q(ପାରାର ଇଞ୍ଜି),
						'one' => q(ପାରାର {0} ଇଞ୍ଜି),
						'other' => q(ପାରାର {0} ଇଞ୍ଜି),
					},
					# Long Unit Identifier
					'pressure-kilopascal' => {
						'name' => q(କିଲୋପାସକଲ),
						'one' => q({0} କିଲୋପାସକଲ),
						'other' => q({0} କିଲୋପାସକଲ),
					},
					# Core Unit Identifier
					'kilopascal' => {
						'name' => q(କିଲୋପାସକଲ),
						'one' => q({0} କିଲୋପାସକଲ),
						'other' => q({0} କିଲୋପାସକଲ),
					},
					# Long Unit Identifier
					'pressure-megapascal' => {
						'name' => q(ମେଗାପାସକଲ),
						'one' => q({0} ମେଗାପାସକଲ),
						'other' => q({0} ମେଗାପାସକଲ),
					},
					# Core Unit Identifier
					'megapascal' => {
						'name' => q(ମେଗାପାସକଲ),
						'one' => q({0} ମେଗାପାସକଲ),
						'other' => q({0} ମେଗାପାସକଲ),
					},
					# Long Unit Identifier
					'pressure-millibar' => {
						'name' => q(ମିଲିବାର୍),
						'one' => q({0} ମିଲିବାର୍),
						'other' => q({0} ମିଲିବାର୍),
					},
					# Core Unit Identifier
					'millibar' => {
						'name' => q(ମିଲିବାର୍),
						'one' => q({0} ମିଲିବାର୍),
						'other' => q({0} ମିଲିବାର୍),
					},
					# Long Unit Identifier
					'pressure-millimeter-ofhg' => {
						'name' => q(ପାରାର ମିଲିମିଟର୍),
						'one' => q(ପାରାର {0} ମିଲିମିଟର୍),
						'other' => q(ପାରାର {0} ମିଲିମିଟର୍),
					},
					# Core Unit Identifier
					'millimeter-ofhg' => {
						'name' => q(ପାରାର ମିଲିମିଟର୍),
						'one' => q(ପାରାର {0} ମିଲିମିଟର୍),
						'other' => q(ପାରାର {0} ମିଲିମିଟର୍),
					},
					# Long Unit Identifier
					'pressure-pound-force-per-square-inch' => {
						'name' => q(ପାଉଣ୍ଡ୍ ପ୍ରତି ବର୍ଗ ଇଞ୍ଚ),
						'one' => q(ପ୍ରତି ବର୍ଗ ଇଞ୍ଚ {0} ପାଉଣ୍ଡ୍),
						'other' => q(ପ୍ରତି ବର୍ଗ ଇଞ୍ଚ {0} ପାଉଣ୍ଡ୍),
					},
					# Core Unit Identifier
					'pound-force-per-square-inch' => {
						'name' => q(ପାଉଣ୍ଡ୍ ପ୍ରତି ବର୍ଗ ଇଞ୍ଚ),
						'one' => q(ପ୍ରତି ବର୍ଗ ଇଞ୍ଚ {0} ପାଉଣ୍ଡ୍),
						'other' => q(ପ୍ରତି ବର୍ଗ ଇଞ୍ଚ {0} ପାଉଣ୍ଡ୍),
					},
					# Long Unit Identifier
					'speed-kilometer-per-hour' => {
						'name' => q(କିଲୋମିଟର୍ ପ୍ରତି ଘଣ୍ଟା),
						'one' => q({0} କିଲୋମିଟର୍ ପ୍ରତି ଘଣ୍ଟା),
						'other' => q({0} କିଲୋମିଟର୍ ପ୍ରତି ଘଣ୍ଟା),
					},
					# Core Unit Identifier
					'kilometer-per-hour' => {
						'name' => q(କିଲୋମିଟର୍ ପ୍ରତି ଘଣ୍ଟା),
						'one' => q({0} କିଲୋମିଟର୍ ପ୍ରତି ଘଣ୍ଟା),
						'other' => q({0} କିଲୋମିଟର୍ ପ୍ରତି ଘଣ୍ଟା),
					},
					# Long Unit Identifier
					'speed-light-speed' => {
						'name' => q(ଆଲୋକ),
						'one' => q({0} ଆଲୋକ),
						'other' => q({0} ଆଲୋକ),
					},
					# Core Unit Identifier
					'light-speed' => {
						'name' => q(ଆଲୋକ),
						'one' => q({0} ଆଲୋକ),
						'other' => q({0} ଆଲୋକ),
					},
					# Long Unit Identifier
					'speed-meter-per-second' => {
						'name' => q(ମିଟର୍ ପ୍ରତି ସେକେଣ୍ଡ୍),
						'one' => q({0} ମିଟର୍ ପ୍ରତି ସେକେଣ୍ଡ୍),
						'other' => q({0} ମିଟର୍ ପ୍ରତି ସେକେଣ୍ଡ୍),
					},
					# Core Unit Identifier
					'meter-per-second' => {
						'name' => q(ମିଟର୍ ପ୍ରତି ସେକେଣ୍ଡ୍),
						'one' => q({0} ମିଟର୍ ପ୍ରତି ସେକେଣ୍ଡ୍),
						'other' => q({0} ମିଟର୍ ପ୍ରତି ସେକେଣ୍ଡ୍),
					},
					# Long Unit Identifier
					'speed-mile-per-hour' => {
						'name' => q(ମାଇଲ୍ ପ୍ରତି ଘଣ୍ଟା),
						'one' => q({0} ମାଇଲ୍ ପ୍ରତି ଘଣ୍ଟା),
						'other' => q({0} ମାଇଲ୍ ପ୍ରତି ଘଣ୍ଟା),
					},
					# Core Unit Identifier
					'mile-per-hour' => {
						'name' => q(ମାଇଲ୍ ପ୍ରତି ଘଣ୍ଟା),
						'one' => q({0} ମାଇଲ୍ ପ୍ରତି ଘଣ୍ଟା),
						'other' => q({0} ମାଇଲ୍ ପ୍ରତି ଘଣ୍ଟା),
					},
					# Long Unit Identifier
					'temperature-celsius' => {
						'name' => q(ଡିଗ୍ରୀ ସେଲସିୟସ୍),
						'one' => q({0} ଡିଗ୍ରୀ ସେଲସିୟସ୍),
						'other' => q({0} ଡିଗ୍ରୀ ସେଲସିୟସ୍),
					},
					# Core Unit Identifier
					'celsius' => {
						'name' => q(ଡିଗ୍ରୀ ସେଲସିୟସ୍),
						'one' => q({0} ଡିଗ୍ରୀ ସେଲସିୟସ୍),
						'other' => q({0} ଡିଗ୍ରୀ ସେଲସିୟସ୍),
					},
					# Long Unit Identifier
					'temperature-fahrenheit' => {
						'name' => q(ଡିଗ୍ରୀ ଫାରେନହାଇଟ୍),
						'one' => q({0} ଡିଗ୍ରୀ ଫାରେନହାଇଟ୍),
						'other' => q({0} ଡିଗ୍ରୀ ଫାରେନହାଇଟ୍),
					},
					# Core Unit Identifier
					'fahrenheit' => {
						'name' => q(ଡିଗ୍ରୀ ଫାରେନହାଇଟ୍),
						'one' => q({0} ଡିଗ୍ରୀ ଫାରେନହାଇଟ୍),
						'other' => q({0} ଡିଗ୍ରୀ ଫାରେନହାଇଟ୍),
					},
					# Long Unit Identifier
					'temperature-kelvin' => {
						'name' => q(କେଲଭିନ୍),
						'one' => q({0} କେଲଭିନ୍),
						'other' => q({0} କେଲଭିନ୍),
					},
					# Core Unit Identifier
					'kelvin' => {
						'name' => q(କେଲଭିନ୍),
						'one' => q({0} କେଲଭିନ୍),
						'other' => q({0} କେଲଭିନ୍),
					},
					# Long Unit Identifier
					'torque-newton-meter' => {
						'name' => q(ନ୍ୟୁଟନ-ମିଟର୍ସ),
						'one' => q({0} ନ୍ୟୁଟନ-ମିଟର),
						'other' => q({0} ନ୍ୟୁଟନ-ମିଟର୍ସ),
					},
					# Core Unit Identifier
					'newton-meter' => {
						'name' => q(ନ୍ୟୁଟନ-ମିଟର୍ସ),
						'one' => q({0} ନ୍ୟୁଟନ-ମିଟର),
						'other' => q({0} ନ୍ୟୁଟନ-ମିଟର୍ସ),
					},
					# Long Unit Identifier
					'torque-pound-force-foot' => {
						'name' => q(ପାଉଣ୍ଡ-ଫିଟ),
						'one' => q({0} ପାଉଣ୍ଡ୍-ଫୋର୍ସ୍‌-ଫୁଟ୍‌),
						'other' => q({0} ପାଉଣ୍ଡ-ଫିଟ),
					},
					# Core Unit Identifier
					'pound-force-foot' => {
						'name' => q(ପାଉଣ୍ଡ-ଫିଟ),
						'one' => q({0} ପାଉଣ୍ଡ୍-ଫୋର୍ସ୍‌-ଫୁଟ୍‌),
						'other' => q({0} ପାଉଣ୍ଡ-ଫିଟ),
					},
					# Long Unit Identifier
					'volume-acre-foot' => {
						'name' => q(ଏକର-ଫିଟ୍),
						'one' => q({0} ଏକର-ଫୁଟ),
						'other' => q({0} ଏକର-ଫିଟ୍),
					},
					# Core Unit Identifier
					'acre-foot' => {
						'name' => q(ଏକର-ଫିଟ୍),
						'one' => q({0} ଏକର-ଫୁଟ),
						'other' => q({0} ଏକର-ଫିଟ୍),
					},
					# Long Unit Identifier
					'volume-barrel' => {
						'one' => q({0} ବାରେଲ),
						'other' => q({0} ବାରେଲ),
					},
					# Core Unit Identifier
					'barrel' => {
						'one' => q({0} ବାରେଲ),
						'other' => q({0} ବାରେଲ),
					},
					# Long Unit Identifier
					'volume-centiliter' => {
						'name' => q(ସେଣ୍ଟିଲିଟର୍),
						'one' => q({0} ସେଣ୍ଟିଲିଟର୍),
						'other' => q({0} ସେଣ୍ଟିଲିଟର୍),
					},
					# Core Unit Identifier
					'centiliter' => {
						'name' => q(ସେଣ୍ଟିଲିଟର୍),
						'one' => q({0} ସେଣ୍ଟିଲିଟର୍),
						'other' => q({0} ସେଣ୍ଟିଲିଟର୍),
					},
					# Long Unit Identifier
					'volume-cubic-centimeter' => {
						'name' => q(କ୍ୟୁବିକ୍ ସେଣ୍ଟିମିଟର୍),
						'one' => q({0} କ୍ୟୁବିକ୍ ସେଣ୍ଟିମିଟର୍),
						'other' => q({0} କ୍ୟୁବିକ୍ ସେଣ୍ଟିମିଟର୍),
						'per' => q({0} ପ୍ରତି କ୍ୟୁବିକ୍ ସେଣ୍ଟିମିଟର୍),
					},
					# Core Unit Identifier
					'cubic-centimeter' => {
						'name' => q(କ୍ୟୁବିକ୍ ସେଣ୍ଟିମିଟର୍),
						'one' => q({0} କ୍ୟୁବିକ୍ ସେଣ୍ଟିମିଟର୍),
						'other' => q({0} କ୍ୟୁବିକ୍ ସେଣ୍ଟିମିଟର୍),
						'per' => q({0} ପ୍ରତି କ୍ୟୁବିକ୍ ସେଣ୍ଟିମିଟର୍),
					},
					# Long Unit Identifier
					'volume-cubic-foot' => {
						'name' => q(କ୍ୟୁବିକ୍ ଫିଟ୍),
						'one' => q({0} କ୍ୟୁବିକ୍ ଫୁଟ୍),
						'other' => q({0} କ୍ୟୁବିକ୍ ଫିଟ୍),
					},
					# Core Unit Identifier
					'cubic-foot' => {
						'name' => q(କ୍ୟୁବିକ୍ ଫିଟ୍),
						'one' => q({0} କ୍ୟୁବିକ୍ ଫୁଟ୍),
						'other' => q({0} କ୍ୟୁବିକ୍ ଫିଟ୍),
					},
					# Long Unit Identifier
					'volume-cubic-inch' => {
						'name' => q(କ୍ୟୁବିକ୍ ଇଞ୍ଚ୍),
						'one' => q({0} କ୍ୟୁବିକ୍ ଇଞ୍ଚ୍),
						'other' => q({0} କ୍ୟୁବିକ୍ ଇଞ୍ଚ୍),
					},
					# Core Unit Identifier
					'cubic-inch' => {
						'name' => q(କ୍ୟୁବିକ୍ ଇଞ୍ଚ୍),
						'one' => q({0} କ୍ୟୁବିକ୍ ଇଞ୍ଚ୍),
						'other' => q({0} କ୍ୟୁବିକ୍ ଇଞ୍ଚ୍),
					},
					# Long Unit Identifier
					'volume-cubic-kilometer' => {
						'name' => q(କ୍ୟୁବିକ୍ କିଲୋମିଟର୍),
						'one' => q({0} କ୍ୟୁବିକ୍ କିଲୋମିଟର୍),
						'other' => q({0} କ୍ୟୁବିକ୍ କିଲୋମିଟର୍),
					},
					# Core Unit Identifier
					'cubic-kilometer' => {
						'name' => q(କ୍ୟୁବିକ୍ କିଲୋମିଟର୍),
						'one' => q({0} କ୍ୟୁବିକ୍ କିଲୋମିଟର୍),
						'other' => q({0} କ୍ୟୁବିକ୍ କିଲୋମିଟର୍),
					},
					# Long Unit Identifier
					'volume-cubic-meter' => {
						'name' => q(କ୍ୟୁବିକ୍ ମିଟର୍),
						'one' => q({0} କ୍ୟୁବିକ୍ ମିଟର୍),
						'other' => q({0} କ୍ୟୁବିକ୍ ମିଟର୍),
						'per' => q({0} ପ୍ରତି କ୍ୟୁବିକ୍ ମିଟର୍),
					},
					# Core Unit Identifier
					'cubic-meter' => {
						'name' => q(କ୍ୟୁବିକ୍ ମିଟର୍),
						'one' => q({0} କ୍ୟୁବିକ୍ ମିଟର୍),
						'other' => q({0} କ୍ୟୁବିକ୍ ମିଟର୍),
						'per' => q({0} ପ୍ରତି କ୍ୟୁବିକ୍ ମିଟର୍),
					},
					# Long Unit Identifier
					'volume-cubic-mile' => {
						'name' => q(କ୍ୟୁବିକ୍ ମାଇଲ୍),
						'one' => q({0} କ୍ୟୁବିକ୍ ମାଇଲ୍),
						'other' => q({0} କ୍ୟୁବିକ୍ ମାଇଲ୍),
					},
					# Core Unit Identifier
					'cubic-mile' => {
						'name' => q(କ୍ୟୁବିକ୍ ମାଇଲ୍),
						'one' => q({0} କ୍ୟୁବିକ୍ ମାଇଲ୍),
						'other' => q({0} କ୍ୟୁବିକ୍ ମାଇଲ୍),
					},
					# Long Unit Identifier
					'volume-cubic-yard' => {
						'name' => q(କ୍ୟୁବିକ୍ ୟାର୍ଡ୍),
						'one' => q({0} କ୍ୟୁବିକ୍ ୟାର୍ଡ୍),
						'other' => q({0} କ୍ୟୁବିକ୍ ୟାର୍ଡ୍),
					},
					# Core Unit Identifier
					'cubic-yard' => {
						'name' => q(କ୍ୟୁବିକ୍ ୟାର୍ଡ୍),
						'one' => q({0} କ୍ୟୁବିକ୍ ୟାର୍ଡ୍),
						'other' => q({0} କ୍ୟୁବିକ୍ ୟାର୍ଡ୍),
					},
					# Long Unit Identifier
					'volume-cup' => {
						'one' => q({0} କପ୍),
						'other' => q({0} କପ୍),
					},
					# Core Unit Identifier
					'cup' => {
						'one' => q({0} କପ୍),
						'other' => q({0} କପ୍),
					},
					# Long Unit Identifier
					'volume-cup-metric' => {
						'name' => q(ମେଟ୍ରିକ୍ କପ୍),
						'one' => q({0} ମେଟ୍ରିକ୍ କପ୍),
						'other' => q({0} ମେଟ୍ରିକ୍ କପ୍),
					},
					# Core Unit Identifier
					'cup-metric' => {
						'name' => q(ମେଟ୍ରିକ୍ କପ୍),
						'one' => q({0} ମେଟ୍ରିକ୍ କପ୍),
						'other' => q({0} ମେଟ୍ରିକ୍ କପ୍),
					},
					# Long Unit Identifier
					'volume-deciliter' => {
						'name' => q(ଡେସିଲିଟର୍),
						'one' => q({0} ଡେସିଲିଟର୍),
						'other' => q({0} ଡେସିଲିଟର୍),
					},
					# Core Unit Identifier
					'deciliter' => {
						'name' => q(ଡେସିଲିଟର୍),
						'one' => q({0} ଡେସିଲିଟର୍),
						'other' => q({0} ଡେସିଲିଟର୍),
					},
					# Long Unit Identifier
					'volume-dessert-spoon' => {
						'name' => q(ଡିଜଟ୍ ସ୍ପୁନ୍),
						'one' => q({0} ଡିଜଟ୍ ସ୍ପୁନ୍),
						'other' => q({0} ଡିଜଟ୍ ସ୍ପୁନ୍),
					},
					# Core Unit Identifier
					'dessert-spoon' => {
						'name' => q(ଡିଜଟ୍ ସ୍ପୁନ୍),
						'one' => q({0} ଡିଜଟ୍ ସ୍ପୁନ୍),
						'other' => q({0} ଡିଜଟ୍ ସ୍ପୁନ୍),
					},
					# Long Unit Identifier
					'volume-fluid-ounce' => {
						'name' => q(ଫ୍ଲୁଇଡ୍ ଆଉନ୍ସ),
						'one' => q({0} ଫ୍ଲୁଇଡ୍ ଆଉନ୍ସ),
						'other' => q({0} ଫ୍ଲୁଇଡ୍ ଆଉନ୍ସ),
					},
					# Core Unit Identifier
					'fluid-ounce' => {
						'name' => q(ଫ୍ଲୁଇଡ୍ ଆଉନ୍ସ),
						'one' => q({0} ଫ୍ଲୁଇଡ୍ ଆଉନ୍ସ),
						'other' => q({0} ଫ୍ଲୁଇଡ୍ ଆଉନ୍ସ),
					},
					# Long Unit Identifier
					'volume-fluid-ounce-imperial' => {
						'name' => q(ଇମ୍ପେରିଅଲ ତରଳ ଆଉନ୍ସ),
						'one' => q({0} ଇମ୍ପ. ତରଳ ଆଉନ୍ସ),
						'other' => q({0} ଇମ୍ପ. ତରଳ ଆଉନ୍ସ),
					},
					# Core Unit Identifier
					'fluid-ounce-imperial' => {
						'name' => q(ଇମ୍ପେରିଅଲ ତରଳ ଆଉନ୍ସ),
						'one' => q({0} ଇମ୍ପ. ତରଳ ଆଉନ୍ସ),
						'other' => q({0} ଇମ୍ପ. ତରଳ ଆଉନ୍ସ),
					},
					# Long Unit Identifier
					'volume-gallon' => {
						'name' => q(ଗ୍ୟାଲନ୍),
						'one' => q({0} ଗ୍ୟାଲନ୍),
						'other' => q({0} ଗ୍ୟାଲନ୍),
						'per' => q({0} ପ୍ରତି ଗ୍ୟାଲନ୍),
					},
					# Core Unit Identifier
					'gallon' => {
						'name' => q(ଗ୍ୟାଲନ୍),
						'one' => q({0} ଗ୍ୟାଲନ୍),
						'other' => q({0} ଗ୍ୟାଲନ୍),
						'per' => q({0} ପ୍ରତି ଗ୍ୟାଲନ୍),
					},
					# Long Unit Identifier
					'volume-gallon-imperial' => {
						'name' => q(ଇମ୍ପେରିଆଲ୍ ଗ୍ୟାଲନ୍),
						'one' => q({0} ଇମ୍ପେରିଆଲ୍ ଗ୍ୟାଲନ୍),
						'other' => q({0} ଇମ୍ପେରିଆଲ୍ ଗ୍ୟାଲନ୍),
						'per' => q({0} ପ୍ରତି ଇମ୍ପେରିଆଲ୍ ଗ୍ୟାଲନ୍),
					},
					# Core Unit Identifier
					'gallon-imperial' => {
						'name' => q(ଇମ୍ପେରିଆଲ୍ ଗ୍ୟାଲନ୍),
						'one' => q({0} ଇମ୍ପେରିଆଲ୍ ଗ୍ୟାଲନ୍),
						'other' => q({0} ଇମ୍ପେରିଆଲ୍ ଗ୍ୟାଲନ୍),
						'per' => q({0} ପ୍ରତି ଇମ୍ପେରିଆଲ୍ ଗ୍ୟାଲନ୍),
					},
					# Long Unit Identifier
					'volume-hectoliter' => {
						'name' => q(ହେକ୍ଟୋଲିଟର୍),
						'one' => q({0} ହେକ୍ଟୋଲିଟର୍),
						'other' => q({0} ହେକ୍ଟୋଲିଟର୍),
					},
					# Core Unit Identifier
					'hectoliter' => {
						'name' => q(ହେକ୍ଟୋଲିଟର୍),
						'one' => q({0} ହେକ୍ଟୋଲିଟର୍),
						'other' => q({0} ହେକ୍ଟୋଲିଟର୍),
					},
					# Long Unit Identifier
					'volume-liter' => {
						'one' => q({0} ଲିଟର୍),
						'other' => q({0} ଲିଟର୍),
						'per' => q({0} ପ୍ରତି ଲିଟର୍),
					},
					# Core Unit Identifier
					'liter' => {
						'one' => q({0} ଲିଟର୍),
						'other' => q({0} ଲିଟର୍),
						'per' => q({0} ପ୍ରତି ଲିଟର୍),
					},
					# Long Unit Identifier
					'volume-megaliter' => {
						'name' => q(ମେଗାଲିଟର୍),
						'one' => q({0} ମେଗାଲିଟର୍),
						'other' => q({0} ମେଗାଲିଟର୍),
					},
					# Core Unit Identifier
					'megaliter' => {
						'name' => q(ମେଗାଲିଟର୍),
						'one' => q({0} ମେଗାଲିଟର୍),
						'other' => q({0} ମେଗାଲିଟର୍),
					},
					# Long Unit Identifier
					'volume-milliliter' => {
						'name' => q(ମିଲିଲିଟର୍),
						'one' => q({0} ମିଲିଲିଟର୍),
						'other' => q({0} ମିଲିଲିଟର୍),
					},
					# Core Unit Identifier
					'milliliter' => {
						'name' => q(ମିଲିଲିଟର୍),
						'one' => q({0} ମିଲିଲିଟର୍),
						'other' => q({0} ମିଲିଲିଟର୍),
					},
					# Long Unit Identifier
					'volume-pint-metric' => {
						'name' => q(ମେଟ୍ରିକ୍ ପାଇଣ୍ଟ୍),
						'one' => q({0} ମେଟ୍ରିକ୍ ପାଇଣ୍ଟ୍),
						'other' => q({0} ମେଟ୍ରିକ୍ ପାଇଣ୍ଟ୍),
					},
					# Core Unit Identifier
					'pint-metric' => {
						'name' => q(ମେଟ୍ରିକ୍ ପାଇଣ୍ଟ୍),
						'one' => q({0} ମେଟ୍ରିକ୍ ପାଇଣ୍ଟ୍),
						'other' => q({0} ମେଟ୍ରିକ୍ ପାଇଣ୍ଟ୍),
					},
				},
				'narrow' => {
					# Long Unit Identifier
					'10p-1' => {
						'1' => q(ଡେସି{0}),
					},
					# Core Unit Identifier
					'1' => {
						'1' => q(ଡେସି{0}),
					},
					# Long Unit Identifier
					'10p-12' => {
						'1' => q(ପି{0}),
					},
					# Core Unit Identifier
					'12' => {
						'1' => q(ପି{0}),
					},
					# Long Unit Identifier
					'10p-15' => {
						'1' => q(ଫି{0}),
					},
					# Core Unit Identifier
					'15' => {
						'1' => q(ଫି{0}),
					},
					# Long Unit Identifier
					'10p-18' => {
						'1' => q(ଅ{0}),
					},
					# Core Unit Identifier
					'18' => {
						'1' => q(ଅ{0}),
					},
					# Long Unit Identifier
					'10p-2' => {
						'1' => q(ସେ{0}),
					},
					# Core Unit Identifier
					'2' => {
						'1' => q(ସେ{0}),
					},
					# Long Unit Identifier
					'10p-21' => {
						'1' => q(ଜି{0}),
					},
					# Core Unit Identifier
					'21' => {
						'1' => q(ଜି{0}),
					},
					# Long Unit Identifier
					'10p-24' => {
						'1' => q(ୟୋ{0}),
					},
					# Core Unit Identifier
					'24' => {
						'1' => q(ୟୋ{0}),
					},
					# Long Unit Identifier
					'10p-3' => {
						'1' => q(ମି{0}),
					},
					# Core Unit Identifier
					'3' => {
						'1' => q(ମି{0}),
					},
					# Long Unit Identifier
					'10p-9' => {
						'1' => q(ନେ{0}),
					},
					# Core Unit Identifier
					'9' => {
						'1' => q(ନେ{0}),
					},
					# Long Unit Identifier
					'10p1' => {
						'1' => q(ଡେ{0}),
					},
					# Core Unit Identifier
					'10p1' => {
						'1' => q(ଡେ{0}),
					},
					# Long Unit Identifier
					'10p12' => {
						'1' => q(ଟେ{0}),
					},
					# Core Unit Identifier
					'10p12' => {
						'1' => q(ଟେ{0}),
					},
					# Long Unit Identifier
					'10p15' => {
						'1' => q(ପି{0}),
					},
					# Core Unit Identifier
					'10p15' => {
						'1' => q(ପି{0}),
					},
					# Long Unit Identifier
					'10p18' => {
						'1' => q(ଏ{0}),
					},
					# Core Unit Identifier
					'10p18' => {
						'1' => q(ଏ{0}),
					},
					# Long Unit Identifier
					'10p2' => {
						'1' => q(ହେ{0}),
					},
					# Core Unit Identifier
					'10p2' => {
						'1' => q(ହେ{0}),
					},
					# Long Unit Identifier
					'10p21' => {
						'1' => q(ଜି{0}),
					},
					# Core Unit Identifier
					'10p21' => {
						'1' => q(ଜି{0}),
					},
					# Long Unit Identifier
					'10p24' => {
						'1' => q(ୟୋ{0}),
					},
					# Core Unit Identifier
					'10p24' => {
						'1' => q(ୟୋ{0}),
					},
					# Long Unit Identifier
					'10p3' => {
						'1' => q(କି{0}),
					},
					# Core Unit Identifier
					'10p3' => {
						'1' => q(କି{0}),
					},
					# Long Unit Identifier
					'10p6' => {
						'1' => q(ମେ{0}),
					},
					# Core Unit Identifier
					'10p6' => {
						'1' => q(ମେ{0}),
					},
					# Long Unit Identifier
					'10p9' => {
						'1' => q(ଗି{0}),
					},
					# Core Unit Identifier
					'10p9' => {
						'1' => q(ଗି{0}),
					},
					# Long Unit Identifier
					'acceleration-g-force' => {
						'name' => q(ଜି-ଫୋର୍ସ୍),
						'one' => q({0}ମା. ବଳ),
						'other' => q({0}ମା. ବଳ),
					},
					# Core Unit Identifier
					'g-force' => {
						'name' => q(ଜି-ଫୋର୍ସ୍),
						'one' => q({0}ମା. ବଳ),
						'other' => q({0}ମା. ବଳ),
					},
					# Long Unit Identifier
					'angle-arc-minute' => {
						'name' => q(ଆର୍କ-ମିନିଟ୍),
						'one' => q({0} ଆର୍କମି),
						'other' => q({0}′),
					},
					# Core Unit Identifier
					'arc-minute' => {
						'name' => q(ଆର୍କ-ମିନିଟ୍),
						'one' => q({0} ଆର୍କମି),
						'other' => q({0}′),
					},
					# Long Unit Identifier
					'angle-radian' => {
						'one' => q({0} ରେଡିଆନ୍),
						'other' => q({0} ରେଡିଆନ୍),
					},
					# Core Unit Identifier
					'radian' => {
						'one' => q({0} ରେଡିଆନ୍),
						'other' => q({0} ରେଡିଆନ୍),
					},
					# Long Unit Identifier
					'angle-revolution' => {
						'name' => q(ଘୂର୍ଣନ),
						'one' => q({0} ଘୂର୍ଣନ),
						'other' => q({0} ଘୂର୍ଣନ),
					},
					# Core Unit Identifier
					'revolution' => {
						'name' => q(ଘୂର୍ଣନ),
						'one' => q({0} ଘୂର୍ଣନ),
						'other' => q({0} ଘୂର୍ଣନ),
					},
					# Long Unit Identifier
					'area-dunam' => {
						'name' => q(ଡୋନମ୍),
						'one' => q({0} ଡୋନମ୍),
						'other' => q({0} ଡୋନମ୍),
					},
					# Core Unit Identifier
					'dunam' => {
						'name' => q(ଡୋନମ୍),
						'one' => q({0} ଡୋନମ୍),
						'other' => q({0} ଡୋନମ୍),
					},
					# Long Unit Identifier
					'area-square-centimeter' => {
						'name' => q(ବର୍ଗସେମି),
						'one' => q({0} /ବର୍ଗସେମି),
						'other' => q({0} /ବର୍ଗସେମି),
						'per' => q({0} /ବର୍ଗସେମି),
					},
					# Core Unit Identifier
					'square-centimeter' => {
						'name' => q(ବର୍ଗସେମି),
						'one' => q({0} /ବର୍ଗସେମି),
						'other' => q({0} /ବର୍ଗସେମି),
						'per' => q({0} /ବର୍ଗସେମି),
					},
					# Long Unit Identifier
					'area-square-inch' => {
						'name' => q(ବର୍ଗଇଞ୍ଚ),
						'one' => q({0} /ବର୍ଗଇଞ୍ଚ),
						'other' => q({0} /ବର୍ଗଇଞ୍ଚ),
						'per' => q({0} /ବର୍ଗଇଞ୍ଚ),
					},
					# Core Unit Identifier
					'square-inch' => {
						'name' => q(ବର୍ଗଇଞ୍ଚ),
						'one' => q({0} /ବର୍ଗଇଞ୍ଚ),
						'other' => q({0} /ବର୍ଗଇଞ୍ଚ),
						'per' => q({0} /ବର୍ଗଇଞ୍ଚ),
					},
					# Long Unit Identifier
					'area-square-kilometer' => {
						'name' => q(ବର୍ଗକିମି),
						'per' => q({0}/ବର୍ଗକିମି),
					},
					# Core Unit Identifier
					'square-kilometer' => {
						'name' => q(ବର୍ଗକିମି),
						'per' => q({0}/ବର୍ଗକିମି),
					},
					# Long Unit Identifier
					'area-square-meter' => {
						'name' => q(ବର୍ଗମି),
						'one' => q({0} ବର୍ଗମି),
						'other' => q({0} ବର୍ଗମି),
					},
					# Core Unit Identifier
					'square-meter' => {
						'name' => q(ବର୍ଗମି),
						'one' => q({0} ବର୍ଗମି),
						'other' => q({0} ବର୍ଗମି),
					},
					# Long Unit Identifier
					'area-square-mile' => {
						'one' => q({0}ବର୍ଗମାଇଲ୍),
						'other' => q({0}ବର୍ଗମାଇଲ୍),
						'per' => q({0}/ବର୍ଗମାଇଲ୍),
					},
					# Core Unit Identifier
					'square-mile' => {
						'one' => q({0}ବର୍ଗମାଇଲ୍),
						'other' => q({0}ବର୍ଗମାଇଲ୍),
						'per' => q({0}/ବର୍ଗମାଇଲ୍),
					},
					# Long Unit Identifier
					'area-square-yard' => {
						'name' => q(ବର୍ଗଗଜ),
						'one' => q({0} ବର୍ଗଗଜ),
						'other' => q({0} ବର୍ଗଗଜ),
					},
					# Core Unit Identifier
					'square-yard' => {
						'name' => q(ବର୍ଗଗଜ),
						'one' => q({0} ବର୍ଗଗଜ),
						'other' => q({0} ବର୍ଗଗଜ),
					},
					# Long Unit Identifier
					'concentr-item' => {
						'one' => q({0}ଆଇଟମ୍),
						'other' => q({0}ଆଇଟମ୍),
					},
					# Core Unit Identifier
					'item' => {
						'one' => q({0}ଆଇଟମ୍),
						'other' => q({0}ଆଇଟମ୍),
					},
					# Long Unit Identifier
					'concentr-karat' => {
						'one' => q({0}kt),
						'other' => q({0}kt),
					},
					# Core Unit Identifier
					'karat' => {
						'one' => q({0}kt),
						'other' => q({0}kt),
					},
					# Long Unit Identifier
					'concentr-milligram-ofglucose-per-deciliter' => {
						'name' => q(ମି.ଗ୍ରା./ଡେ.ଲି.),
						'one' => q({0} ମି.ଗ୍ରା./ଡେ.ଲି.),
						'other' => q({0} ମି.ଗ୍ରା./ଡେ.ଲି.),
					},
					# Core Unit Identifier
					'milligram-ofglucose-per-deciliter' => {
						'name' => q(ମି.ଗ୍ରା./ଡେ.ଲି.),
						'one' => q({0} ମି.ଗ୍ରା./ଡେ.ଲି.),
						'other' => q({0} ମି.ଗ୍ରା./ଡେ.ଲି.),
					},
					# Long Unit Identifier
					'concentr-millimole-per-liter' => {
						'name' => q(ମିଲିମୋଲ୍/ଲି),
						'one' => q({0}ମିଲିମୋଲ୍/ଲି),
						'other' => q({0}ମିଲିମୋଲ୍/ଲି),
					},
					# Core Unit Identifier
					'millimole-per-liter' => {
						'name' => q(ମିଲିମୋଲ୍/ଲି),
						'one' => q({0}ମିଲିମୋଲ୍/ଲି),
						'other' => q({0}ମିଲିମୋଲ୍/ଲି),
					},
					# Long Unit Identifier
					'concentr-mole' => {
						'one' => q({0}ମୋଲ),
						'other' => q({0}ମୋଲ),
					},
					# Core Unit Identifier
					'mole' => {
						'one' => q({0}ମୋଲ),
						'other' => q({0}ମୋଲ),
					},
					# Long Unit Identifier
					'concentr-percent' => {
						'name' => q(%),
					},
					# Core Unit Identifier
					'percent' => {
						'name' => q(%),
					},
					# Long Unit Identifier
					'concentr-permille' => {
						'name' => q(‰),
					},
					# Core Unit Identifier
					'permille' => {
						'name' => q(‰),
					},
					# Long Unit Identifier
					'concentr-permillion' => {
						'name' => q(ପିପିଏମ୍),
						'one' => q({0}ପିପିଏମ୍),
						'other' => q({0}ପିପିଏମ୍),
					},
					# Core Unit Identifier
					'permillion' => {
						'name' => q(ପିପିଏମ୍),
						'one' => q({0}ପିପିଏମ୍),
						'other' => q({0}ପିପିଏମ୍),
					},
					# Long Unit Identifier
					'concentr-permyriad' => {
						'name' => q(‱),
					},
					# Core Unit Identifier
					'permyriad' => {
						'name' => q(‱),
					},
					# Long Unit Identifier
					'concentr-portion-per-1e9' => {
						'one' => q({0}ppb),
						'other' => q({0}ppb),
					},
					# Core Unit Identifier
					'portion-per-1e9' => {
						'one' => q({0}ppb),
						'other' => q({0}ppb),
					},
					# Long Unit Identifier
					'consumption-liter-per-100-kilometer' => {
						'name' => q(ଲି/100କିମି),
						'one' => q({0}ଲି/100 କିମି),
						'other' => q({0}ଲି/100 କିମି),
					},
					# Core Unit Identifier
					'liter-per-100-kilometer' => {
						'name' => q(ଲି/100କିମି),
						'one' => q({0}ଲି/100 କିମି),
						'other' => q({0}ଲି/100 କିମି),
					},
					# Long Unit Identifier
					'consumption-mile-per-gallon' => {
						'name' => q(ମାଇଲ୍/ଗେଲନ୍),
					},
					# Core Unit Identifier
					'mile-per-gallon' => {
						'name' => q(ମାଇଲ୍/ଗେଲନ୍),
					},
					# Long Unit Identifier
					'consumption-mile-per-gallon-imperial' => {
						'name' => q(mpg UK),
						'one' => q({0}m/gUK),
						'other' => q({0}m/gUK),
					},
					# Core Unit Identifier
					'mile-per-gallon-imperial' => {
						'name' => q(mpg UK),
						'one' => q({0}m/gUK),
						'other' => q({0}m/gUK),
					},
					# Long Unit Identifier
					'coordinate' => {
						'north' => q({0}ଉ),
					},
					# Core Unit Identifier
					'coordinate' => {
						'north' => q({0}ଉ),
					},
					# Long Unit Identifier
					'duration-century' => {
						'one' => q({0} ଶତକ),
						'other' => q({0} ଶତକ),
					},
					# Core Unit Identifier
					'century' => {
						'one' => q({0} ଶତକ),
						'other' => q({0} ଶତକ),
					},
					# Long Unit Identifier
					'duration-day' => {
						'one' => q({0}ଦିନ),
						'other' => q({0}ଦିନ),
					},
					# Core Unit Identifier
					'day' => {
						'one' => q({0}ଦିନ),
						'other' => q({0}ଦିନ),
					},
					# Long Unit Identifier
					'duration-decade' => {
						'name' => q(ଦଶନ୍ଧି),
						'one' => q({0} ଦଶନ୍ଧି),
						'other' => q({0} ଦଶନ୍ଧି),
					},
					# Core Unit Identifier
					'decade' => {
						'name' => q(ଦଶନ୍ଧି),
						'one' => q({0} ଦଶନ୍ଧି),
						'other' => q({0} ଦଶନ୍ଧି),
					},
					# Long Unit Identifier
					'duration-hour' => {
						'one' => q({0}ଘଣ୍ଟା),
						'other' => q({0}ଘଣ୍ଟା),
						'per' => q({0}/ଘ.),
					},
					# Core Unit Identifier
					'hour' => {
						'one' => q({0}ଘଣ୍ଟା),
						'other' => q({0}ଘଣ୍ଟା),
						'per' => q({0}/ଘ.),
					},
					# Long Unit Identifier
					'duration-millisecond' => {
						'one' => q({0}ms),
						'other' => q({0} ms),
					},
					# Core Unit Identifier
					'millisecond' => {
						'one' => q({0}ms),
						'other' => q({0} ms),
					},
					# Long Unit Identifier
					'duration-minute' => {
						'one' => q({0}ମିନିଟ୍‌),
						'other' => q({0}ମିନିଟ୍‌),
						'per' => q({0}/ମି),
					},
					# Core Unit Identifier
					'minute' => {
						'one' => q({0}ମିନିଟ୍‌),
						'other' => q({0}ମିନିଟ୍‌),
						'per' => q({0}/ମି),
					},
					# Long Unit Identifier
					'duration-month' => {
						'one' => q({0}ମାସ),
						'other' => q({0}ମାସ),
					},
					# Core Unit Identifier
					'month' => {
						'one' => q({0}ମାସ),
						'other' => q({0}ମାସ),
					},
					# Long Unit Identifier
					'duration-night' => {
						'name' => q(ରାତି),
						'one' => q({0} ରାତି),
						'other' => q({0} ରାତି),
						'per' => q({0}/ରାତି),
					},
					# Core Unit Identifier
					'night' => {
						'name' => q(ରାତି),
						'one' => q({0} ରାତି),
						'other' => q({0} ରାତି),
						'per' => q({0}/ରାତି),
					},
					# Long Unit Identifier
					'duration-second' => {
						'one' => q({0}ସେକ୍),
						'other' => q({0}ସେକ୍),
						'per' => q({0}/ସେ),
					},
					# Core Unit Identifier
					'second' => {
						'one' => q({0}ସେକ୍),
						'other' => q({0}ସେକ୍),
						'per' => q({0}/ସେ),
					},
					# Long Unit Identifier
					'duration-week' => {
						'one' => q({0}ସପ୍),
						'other' => q({0} ସପ୍),
					},
					# Core Unit Identifier
					'week' => {
						'one' => q({0}ସପ୍),
						'other' => q({0} ସପ୍),
					},
					# Long Unit Identifier
					'duration-year' => {
						'name' => q(yr),
						'one' => q({0}ବର୍ଷ),
						'other' => q({0}ବର୍ଷ),
					},
					# Core Unit Identifier
					'year' => {
						'name' => q(yr),
						'one' => q({0}ବର୍ଷ),
						'other' => q({0}ବର୍ଷ),
					},
					# Long Unit Identifier
					'electric-ampere' => {
						'name' => q(ଏମ୍ପି.),
					},
					# Core Unit Identifier
					'ampere' => {
						'name' => q(ଏମ୍ପି.),
					},
					# Long Unit Identifier
					'electric-ohm' => {
						'name' => q(ଓମ୍),
					},
					# Core Unit Identifier
					'ohm' => {
						'name' => q(ଓମ୍),
					},
					# Long Unit Identifier
					'energy-british-thermal-unit' => {
						'name' => q(BTU),
					},
					# Core Unit Identifier
					'british-thermal-unit' => {
						'name' => q(BTU),
					},
					# Long Unit Identifier
					'energy-kilowatt-hour' => {
						'one' => q({0}kWh),
						'other' => q({0} କିୱାଘ),
					},
					# Core Unit Identifier
					'kilowatt-hour' => {
						'one' => q({0}kWh),
						'other' => q({0} କିୱାଘ),
					},
					# Long Unit Identifier
					'energy-therm-us' => {
						'name' => q(ୟୁଏସ୍ଥର୍ମ),
						'one' => q({0} ୟୁଏସ୍ଥର୍ମ),
						'other' => q({0} ୟୁଏସ୍ଥର୍ମ),
					},
					# Core Unit Identifier
					'therm-us' => {
						'name' => q(ୟୁଏସ୍ଥର୍ମ),
						'one' => q({0} ୟୁଏସ୍ଥର୍ମ),
						'other' => q({0} ୟୁଏସ୍ଥର୍ମ),
					},
					# Long Unit Identifier
					'force-newton' => {
						'name' => q(ନ୍ୟୁ.),
						'one' => q({0} ନ୍ୟୁ.),
						'other' => q({0} ନ୍ୟୁ.),
					},
					# Core Unit Identifier
					'newton' => {
						'name' => q(ନ୍ୟୁ.),
						'one' => q({0} ନ୍ୟୁ.),
						'other' => q({0} ନ୍ୟୁ.),
					},
					# Long Unit Identifier
					'graphics-dot' => {
						'name' => q(ବିନ୍ଦୁ),
					},
					# Core Unit Identifier
					'dot' => {
						'name' => q(ବିନ୍ଦୁ),
					},
					# Long Unit Identifier
					'graphics-dot-per-centimeter' => {
						'name' => q(ବିନ୍ଦୁ ପ୍ରତି ସେଣ୍ଟିମିଟର),
						'one' => q({0}dpcm),
						'other' => q({0}dpcm),
					},
					# Core Unit Identifier
					'dot-per-centimeter' => {
						'name' => q(ବିନ୍ଦୁ ପ୍ରତି ସେଣ୍ଟିମିଟର),
						'one' => q({0}dpcm),
						'other' => q({0}dpcm),
					},
					# Long Unit Identifier
					'graphics-dot-per-inch' => {
						'one' => q({0}dpi),
						'other' => q({0}dpi),
					},
					# Core Unit Identifier
					'dot-per-inch' => {
						'one' => q({0}dpi),
						'other' => q({0}dpi),
					},
					# Long Unit Identifier
					'length-astronomical-unit' => {
						'name' => q(ଖଗୋ. ଇକା.),
						'one' => q({0}au),
						'other' => q({0}au),
					},
					# Core Unit Identifier
					'astronomical-unit' => {
						'name' => q(ଖଗୋ. ଇକା.),
						'one' => q({0}au),
						'other' => q({0}au),
					},
					# Long Unit Identifier
					'length-centimeter' => {
						'one' => q({0} ସେମି),
						'other' => q({0}ସେମି),
						'per' => q({0}/ସେ.ମି.),
					},
					# Core Unit Identifier
					'centimeter' => {
						'one' => q({0} ସେମି),
						'other' => q({0}ସେମି),
						'per' => q({0}/ସେ.ମି.),
					},
					# Long Unit Identifier
					'length-decimeter' => {
						'name' => q(ଡେ. ମି.),
						'one' => q({0} ଡେ. ମି.),
						'other' => q({0} ଡେ. ମି.),
					},
					# Core Unit Identifier
					'decimeter' => {
						'name' => q(ଡେ. ମି.),
						'one' => q({0} ଡେ. ମି.),
						'other' => q({0} ଡେ. ମି.),
					},
					# Long Unit Identifier
					'length-earth-radius' => {
						'one' => q({0} R⊕),
						'other' => q({0}R⊕),
					},
					# Core Unit Identifier
					'earth-radius' => {
						'one' => q({0} R⊕),
						'other' => q({0}R⊕),
					},
					# Long Unit Identifier
					'length-fathom' => {
						'name' => q(ଫେଦମ୍),
						'one' => q({0}fth),
						'other' => q({0} fth),
					},
					# Core Unit Identifier
					'fathom' => {
						'name' => q(ଫେଦମ୍),
						'one' => q({0}fth),
						'other' => q({0} fth),
					},
					# Long Unit Identifier
					'length-furlong' => {
						'name' => q(ଫର୍ଲଙ୍ଗ୍),
						'one' => q({0} ଫର୍ଲଙ୍ଗ୍),
						'other' => q({0} ଫର୍ଲଙ୍ଗ୍),
					},
					# Core Unit Identifier
					'furlong' => {
						'name' => q(ଫର୍ଲଙ୍ଗ୍),
						'one' => q({0} ଫର୍ଲଙ୍ଗ୍),
						'other' => q({0} ଫର୍ଲଙ୍ଗ୍),
					},
					# Long Unit Identifier
					'length-micrometer' => {
						'name' => q(μm),
						'one' => q({0}μm),
						'other' => q({0}μm),
					},
					# Core Unit Identifier
					'micrometer' => {
						'name' => q(μm),
						'one' => q({0}μm),
						'other' => q({0}μm),
					},
					# Long Unit Identifier
					'length-mile' => {
						'one' => q({0}ମାଇଲ),
						'other' => q({0}ମାଇଲ),
					},
					# Core Unit Identifier
					'mile' => {
						'one' => q({0}ମାଇଲ),
						'other' => q({0}ମାଇଲ),
					},
					# Long Unit Identifier
					'length-mile-scandinavian' => {
						'name' => q(smi),
						'one' => q({0}smi),
						'other' => q({0}smi),
					},
					# Core Unit Identifier
					'mile-scandinavian' => {
						'name' => q(smi),
						'one' => q({0}smi),
						'other' => q({0}smi),
					},
					# Long Unit Identifier
					'length-millimeter' => {
						'one' => q({0}ମିମି),
						'other' => q({0}ମିମି),
					},
					# Core Unit Identifier
					'millimeter' => {
						'one' => q({0}ମିମି),
						'other' => q({0}ମିମି),
					},
					# Long Unit Identifier
					'length-nanometer' => {
						'name' => q(nm),
						'one' => q({0}nm),
						'other' => q({0}nm),
					},
					# Core Unit Identifier
					'nanometer' => {
						'name' => q(nm),
						'one' => q({0}nm),
						'other' => q({0}nm),
					},
					# Long Unit Identifier
					'length-nautical-mile' => {
						'name' => q(nmi),
						'one' => q({0}nmi),
						'other' => q({0}nmi),
					},
					# Core Unit Identifier
					'nautical-mile' => {
						'name' => q(nmi),
						'one' => q({0}nmi),
						'other' => q({0}nmi),
					},
					# Long Unit Identifier
					'length-parsec' => {
						'name' => q(ପାର୍ସେ),
					},
					# Core Unit Identifier
					'parsec' => {
						'name' => q(ପାର୍ସେ),
					},
					# Long Unit Identifier
					'length-picometer' => {
						'name' => q(pm),
						'one' => q({0}ପି.ମି.),
						'other' => q({0}ପି.ମି.),
					},
					# Core Unit Identifier
					'picometer' => {
						'name' => q(pm),
						'one' => q({0}ପି.ମି.),
						'other' => q({0}ପି.ମି.),
					},
					# Long Unit Identifier
					'length-solar-radius' => {
						'name' => q(R☉),
					},
					# Core Unit Identifier
					'solar-radius' => {
						'name' => q(R☉),
					},
					# Long Unit Identifier
					'length-yard' => {
						'name' => q(ଗଜ),
						'one' => q({0}ଗଜ),
						'other' => q({0}ଗଜ),
					},
					# Core Unit Identifier
					'yard' => {
						'name' => q(ଗଜ),
						'one' => q({0}ଗଜ),
						'other' => q({0}ଗଜ),
					},
					# Long Unit Identifier
					'mass-dalton' => {
						'name' => q(ଡାଲଟନ୍),
						'one' => q({0} ଡାଲଟନ୍),
						'other' => q({0} ଡାଲଟନ୍),
					},
					# Core Unit Identifier
					'dalton' => {
						'name' => q(ଡାଲଟନ୍),
						'one' => q({0} ଡାଲଟନ୍),
						'other' => q({0} ଡାଲଟନ୍),
					},
					# Long Unit Identifier
					'mass-earth-mass' => {
						'name' => q(ଅର୍ଥ ମାସ୍),
					},
					# Core Unit Identifier
					'earth-mass' => {
						'name' => q(ଅର୍ଥ ମାସ୍),
					},
					# Long Unit Identifier
					'mass-gram' => {
						'one' => q({0}ଗ୍ରା),
						'other' => q({0}ଗ୍ରା),
						'per' => q({0}/ଗ୍ରା.),
					},
					# Core Unit Identifier
					'gram' => {
						'one' => q({0}ଗ୍ରା),
						'other' => q({0}ଗ୍ରା),
						'per' => q({0}/ଗ୍ରା.),
					},
					# Long Unit Identifier
					'mass-kilogram' => {
						'one' => q({0}କିଗ୍ରା),
						'other' => q({0}କିଗ୍ରା),
						'per' => q({0}/କି. ଗ୍ରା.),
					},
					# Core Unit Identifier
					'kilogram' => {
						'one' => q({0}କିଗ୍ରା),
						'other' => q({0}କିଗ୍ରା),
						'per' => q({0}/କି. ଗ୍ରା.),
					},
					# Long Unit Identifier
					'mass-microgram' => {
						'one' => q({0} μg),
						'other' => q({0} ମା. ଗ୍ରା.),
					},
					# Core Unit Identifier
					'microgram' => {
						'one' => q({0} μg),
						'other' => q({0} ମା. ଗ୍ରା.),
					},
					# Long Unit Identifier
					'mass-milligram' => {
						'name' => q(ମି. ଗ୍ରା.),
						'one' => q({0} ମି. ଗ୍ରା.),
						'other' => q({0} ମି. ଗ୍ରା.),
					},
					# Core Unit Identifier
					'milligram' => {
						'name' => q(ମି. ଗ୍ରା.),
						'one' => q({0} ମି. ଗ୍ରା.),
						'other' => q({0} ମି. ଗ୍ରା.),
					},
					# Long Unit Identifier
					'mass-ounce' => {
						'name' => q(ଅନ୍ସ),
						'one' => q({0}ଅ.),
						'other' => q({0}ଅ.),
						'per' => q({0}/ଅନ୍ସ),
					},
					# Core Unit Identifier
					'ounce' => {
						'name' => q(ଅନ୍ସ),
						'one' => q({0}ଅ.),
						'other' => q({0}ଅ.),
						'per' => q({0}/ଅନ୍ସ),
					},
					# Long Unit Identifier
					'mass-ounce-troy' => {
						'name' => q(ଅନ୍ସ-ଟ୍ରାଇ),
						'one' => q({0} ଅନ୍ସ-ଟ୍ରାଇ),
						'other' => q({0} ଅନ୍ସ-ଟ୍ରାଇ),
					},
					# Core Unit Identifier
					'ounce-troy' => {
						'name' => q(ଅନ୍ସ-ଟ୍ରାଇ),
						'one' => q({0} ଅନ୍ସ-ଟ୍ରାଇ),
						'other' => q({0} ଅନ୍ସ-ଟ୍ରାଇ),
					},
					# Long Unit Identifier
					'mass-ton' => {
						'name' => q(ଟନ୍),
					},
					# Core Unit Identifier
					'ton' => {
						'name' => q(ଟନ୍),
					},
					# Long Unit Identifier
					'mass-tonne' => {
						'name' => q(ମେଟ୍ରିକଟନ),
						'one' => q({0} ମେଟ୍ରିକଟନ),
						'other' => q({0} ମେଟ୍ରିକଟନ),
					},
					# Core Unit Identifier
					'tonne' => {
						'name' => q(ମେଟ୍ରିକଟନ),
						'one' => q({0} ମେଟ୍ରିକଟନ),
						'other' => q({0} ମେଟ୍ରିକଟନ),
					},
					# Long Unit Identifier
					'power-horsepower' => {
						'name' => q(ଏଚ୍ପୀ),
						'one' => q({0}ଏଚ୍ପୀ),
						'other' => q({0}ଏଚ୍ପୀ),
					},
					# Core Unit Identifier
					'horsepower' => {
						'name' => q(ଏଚ୍ପୀ),
						'one' => q({0}ଏଚ୍ପୀ),
						'other' => q({0}ଏଚ୍ପୀ),
					},
					# Long Unit Identifier
					'pressure-kilopascal' => {
						'name' => q(କି.ପା.),
						'one' => q({0} କି.ପା.),
						'other' => q({0} କି.ପା.),
					},
					# Core Unit Identifier
					'kilopascal' => {
						'name' => q(କି.ପା.),
						'one' => q({0} କି.ପା.),
						'other' => q({0} କି.ପା.),
					},
					# Long Unit Identifier
					'pressure-megapascal' => {
						'name' => q(ମେ.ପା.),
						'one' => q({0} ମେ.ପା.),
						'other' => q({0} ମେ.ପା.),
					},
					# Core Unit Identifier
					'megapascal' => {
						'name' => q(ମେ.ପା.),
						'one' => q({0} ମେ.ପା.),
						'other' => q({0} ମେ.ପା.),
					},
					# Long Unit Identifier
					'pressure-pascal' => {
						'name' => q(ପା.),
						'one' => q({0} ପା.),
						'other' => q({0} ପା.),
					},
					# Core Unit Identifier
					'pascal' => {
						'name' => q(ପା.),
						'one' => q({0} ପା.),
						'other' => q({0} ପା.),
					},
					# Long Unit Identifier
					'speed-beaufort' => {
						'one' => q(B{0}),
						'other' => q(B{0}),
					},
					# Core Unit Identifier
					'beaufort' => {
						'one' => q(B{0}),
						'other' => q(B{0}),
					},
					# Long Unit Identifier
					'speed-kilometer-per-hour' => {
						'name' => q(କିମି/ଘ),
						'one' => q({0}କେପିଏଚ୍),
						'other' => q({0}କେପିଏଚ୍),
					},
					# Core Unit Identifier
					'kilometer-per-hour' => {
						'name' => q(କିମି/ଘ),
						'one' => q({0}କେପିଏଚ୍),
						'other' => q({0}କେପିଏଚ୍),
					},
					# Long Unit Identifier
					'speed-knot' => {
						'name' => q(ଗଣ୍ଠି),
					},
					# Core Unit Identifier
					'knot' => {
						'name' => q(ଗଣ୍ଠି),
					},
					# Long Unit Identifier
					'speed-light-speed' => {
						'name' => q(ଆଲୋକ),
						'one' => q({0} ଆଲୋକ),
						'other' => q({0} ଆଲୋକ),
					},
					# Core Unit Identifier
					'light-speed' => {
						'name' => q(ଆଲୋକ),
						'one' => q({0} ଆଲୋକ),
						'other' => q({0} ଆଲୋକ),
					},
					# Long Unit Identifier
					'speed-meter-per-second' => {
						'name' => q(ମିଟର/ସେ),
					},
					# Core Unit Identifier
					'meter-per-second' => {
						'name' => q(ମିଟର/ସେ),
					},
					# Long Unit Identifier
					'temperature-celsius' => {
						'name' => q(°ସେ),
					},
					# Core Unit Identifier
					'celsius' => {
						'name' => q(°ସେ),
					},
					# Long Unit Identifier
					'temperature-fahrenheit' => {
						'name' => q(ଡିଗ୍ରୀଫାରେନ୍ହାଇଟ୍),
					},
					# Core Unit Identifier
					'fahrenheit' => {
						'name' => q(ଡିଗ୍ରୀଫାରେନ୍ହାଇଟ୍),
					},
					# Long Unit Identifier
					'torque-newton-meter' => {
						'name' => q(ନ୍ୟୁ.ମି.),
						'one' => q({0} ନ୍ୟୁ.ମି.),
						'other' => q({0} ନ୍ୟୁ.ମି.),
					},
					# Core Unit Identifier
					'newton-meter' => {
						'name' => q(ନ୍ୟୁ.ମି.),
						'one' => q({0} ନ୍ୟୁ.ମି.),
						'other' => q({0} ନ୍ୟୁ.ମି.),
					},
					# Long Unit Identifier
					'volume-acre-foot' => {
						'name' => q(ଏକରଫୁଟ),
						'one' => q({0} ଏକରଫୁଟ),
						'other' => q({0} ଏକରଫୁଟ),
					},
					# Core Unit Identifier
					'acre-foot' => {
						'name' => q(ଏକରଫୁଟ),
						'one' => q({0} ଏକରଫୁଟ),
						'other' => q({0} ଏକରଫୁଟ),
					},
					# Long Unit Identifier
					'volume-barrel' => {
						'name' => q(ବ୍ୟାରେଲ୍),
						'one' => q({0} ବ୍ୟାରେଲ୍),
						'other' => q({0} ବ୍ୟାରେଲ୍),
					},
					# Core Unit Identifier
					'barrel' => {
						'name' => q(ବ୍ୟାରେଲ୍),
						'one' => q({0} ବ୍ୟାରେଲ୍),
						'other' => q({0} ବ୍ୟାରେଲ୍),
					},
					# Long Unit Identifier
					'volume-centiliter' => {
						'name' => q(ସେ. ଲି.),
						'one' => q({0} ସେ. ଲି.),
						'other' => q({0} ସେ. ଲି.),
					},
					# Core Unit Identifier
					'centiliter' => {
						'name' => q(ସେ. ଲି.),
						'one' => q({0} ସେ. ଲି.),
						'other' => q({0} ସେ. ଲି.),
					},
					# Long Unit Identifier
					'volume-cubic-centimeter' => {
						'one' => q({0}/ଘନସେମି),
						'other' => q({0}/ଘନସେମି),
					},
					# Core Unit Identifier
					'cubic-centimeter' => {
						'one' => q({0}/ଘନସେମି),
						'other' => q({0}/ଘନସେମି),
					},
					# Long Unit Identifier
					'volume-cubic-foot' => {
						'name' => q(ft³),
						'one' => q({0}ft³),
						'other' => q({0}ft³),
					},
					# Core Unit Identifier
					'cubic-foot' => {
						'name' => q(ft³),
						'one' => q({0}ft³),
						'other' => q({0}ft³),
					},
					# Long Unit Identifier
					'volume-cubic-inch' => {
						'name' => q(ଘନଇଞ୍ଚ),
						'one' => q({0} ଘନଇଞ୍ଚ),
						'other' => q({0} ଘନଇଞ୍ଚ),
					},
					# Core Unit Identifier
					'cubic-inch' => {
						'name' => q(ଘନଇଞ୍ଚ),
						'one' => q({0} ଘନଇଞ୍ଚ),
						'other' => q({0} ଘନଇଞ୍ଚ),
					},
					# Long Unit Identifier
					'volume-cubic-kilometer' => {
						'one' => q({0}ଘନକି.ମି.),
						'other' => q({0}ଘନକି.ମି.),
					},
					# Core Unit Identifier
					'cubic-kilometer' => {
						'one' => q({0}ଘନକି.ମି.),
						'other' => q({0}ଘନକି.ମି.),
					},
					# Long Unit Identifier
					'volume-cubic-meter' => {
						'one' => q({0}/ ଘନମି),
						'other' => q({0}/ ଘନମି),
					},
					# Core Unit Identifier
					'cubic-meter' => {
						'one' => q({0}/ ଘନମି),
						'other' => q({0}/ ଘନମି),
					},
					# Long Unit Identifier
					'volume-cubic-mile' => {
						'name' => q(ଘନମାଇଲ୍),
						'one' => q({0}ଘନମାଇଲ୍),
						'other' => q({0}ଘନମାଇଲ୍),
					},
					# Core Unit Identifier
					'cubic-mile' => {
						'name' => q(ଘନମାଇଲ୍),
						'one' => q({0}ଘନମାଇଲ୍),
						'other' => q({0}ଘନମାଇଲ୍),
					},
					# Long Unit Identifier
					'volume-cubic-yard' => {
						'name' => q(yd³),
						'one' => q({0}yd³),
						'other' => q({0}yd³),
					},
					# Core Unit Identifier
					'cubic-yard' => {
						'name' => q(yd³),
						'one' => q({0}yd³),
						'other' => q({0}yd³),
					},
					# Long Unit Identifier
					'volume-cup' => {
						'one' => q({0} କପ),
						'other' => q({0} କପ),
					},
					# Core Unit Identifier
					'cup' => {
						'one' => q({0} କପ),
						'other' => q({0} କପ),
					},
					# Long Unit Identifier
					'volume-cup-metric' => {
						'name' => q(mcup),
						'one' => q({0}mc),
						'other' => q({0}mc),
					},
					# Core Unit Identifier
					'cup-metric' => {
						'name' => q(mcup),
						'one' => q({0}mc),
						'other' => q({0}mc),
					},
					# Long Unit Identifier
					'volume-deciliter' => {
						'name' => q(ଡେ. ଲି.),
						'one' => q({0} ଡେ. ଲି.),
						'other' => q({0} ଡେ. ଲି.),
					},
					# Core Unit Identifier
					'deciliter' => {
						'name' => q(ଡେ. ଲି.),
						'one' => q({0} ଡେ. ଲି.),
						'other' => q({0} ଡେ. ଲି.),
					},
					# Long Unit Identifier
					'volume-dessert-spoon' => {
						'name' => q(dsp),
						'one' => q({0}dsp),
						'other' => q({0}dsp),
					},
					# Core Unit Identifier
					'dessert-spoon' => {
						'name' => q(dsp),
						'one' => q({0}dsp),
						'other' => q({0}dsp),
					},
					# Long Unit Identifier
					'volume-dessert-spoon-imperial' => {
						'name' => q(dsp Imp),
						'one' => q({0}dsp-Imp),
						'other' => q({0}dsp-Imp),
					},
					# Core Unit Identifier
					'dessert-spoon-imperial' => {
						'name' => q(dsp Imp),
						'one' => q({0}dsp-Imp),
						'other' => q({0}dsp-Imp),
					},
					# Long Unit Identifier
					'volume-dram' => {
						'name' => q(fl.dr.),
						'one' => q({0}fl.dr.),
						'other' => q({0}fl.dr.),
					},
					# Core Unit Identifier
					'dram' => {
						'name' => q(fl.dr.),
						'one' => q({0}fl.dr.),
						'other' => q({0}fl.dr.),
					},
					# Long Unit Identifier
					'volume-drop' => {
						'name' => q(dr),
						'one' => q({0}dr),
						'other' => q({0}dr),
					},
					# Core Unit Identifier
					'drop' => {
						'name' => q(dr),
						'one' => q({0}dr),
						'other' => q({0}dr),
					},
					# Long Unit Identifier
					'volume-fluid-ounce' => {
						'name' => q(fl oz),
					},
					# Core Unit Identifier
					'fluid-ounce' => {
						'name' => q(fl oz),
					},
					# Long Unit Identifier
					'volume-gallon' => {
						'name' => q(ଗେଲନ୍),
						'one' => q({0} ଗେ),
						'other' => q({0} ଗେ),
						'per' => q({0}/ ଗେ),
					},
					# Core Unit Identifier
					'gallon' => {
						'name' => q(ଗେଲନ୍),
						'one' => q({0} ଗେ),
						'other' => q({0} ଗେ),
						'per' => q({0}/ ଗେ),
					},
					# Long Unit Identifier
					'volume-gallon-imperial' => {
						'name' => q(ଇମ୍ପିଗେଲନ୍),
						'one' => q({0} ଇମ୍ପିଗେଲନ୍),
						'other' => q({0} ଇମ୍ପିଗେଲନ୍),
						'per' => q({0}/ ଇମ୍ପିଗେଲନ୍),
					},
					# Core Unit Identifier
					'gallon-imperial' => {
						'name' => q(ଇମ୍ପିଗେଲନ୍),
						'one' => q({0} ଇମ୍ପିଗେଲନ୍),
						'other' => q({0} ଇମ୍ପିଗେଲନ୍),
						'per' => q({0}/ ଇମ୍ପିଗେଲନ୍),
					},
					# Long Unit Identifier
					'volume-hectoliter' => {
						'one' => q({0}hL),
						'other' => q({0} ହେଲି),
					},
					# Core Unit Identifier
					'hectoliter' => {
						'one' => q({0}hL),
						'other' => q({0} ହେଲି),
					},
					# Long Unit Identifier
					'volume-liter' => {
						'one' => q({0}ଲି),
						'other' => q({0}ଲି),
					},
					# Core Unit Identifier
					'liter' => {
						'one' => q({0}ଲି),
						'other' => q({0}ଲି),
					},
					# Long Unit Identifier
					'volume-megaliter' => {
						'name' => q(ML),
						'one' => q({0}ML),
						'other' => q({0}ML),
					},
					# Core Unit Identifier
					'megaliter' => {
						'name' => q(ML),
						'one' => q({0}ML),
						'other' => q({0}ML),
					},
					# Long Unit Identifier
					'volume-milliliter' => {
						'name' => q(ମି. ଲି.),
						'one' => q({0} ମି. ଲି.),
						'other' => q({0} ମି. ଲି.),
					},
					# Core Unit Identifier
					'milliliter' => {
						'name' => q(ମି. ଲି.),
						'one' => q({0} ମି. ଲି.),
						'other' => q({0} ମି. ଲି.),
					},
					# Long Unit Identifier
					'volume-pinch' => {
						'name' => q(ଚିମୁଟ),
						'one' => q({0} ଚିମୁଟ),
						'other' => q({0} ଚିମୁଟ),
					},
					# Core Unit Identifier
					'pinch' => {
						'name' => q(ଚିମୁଟ),
						'one' => q({0} ଚିମୁଟ),
						'other' => q({0} ଚିମୁଟ),
					},
					# Long Unit Identifier
					'volume-pint-metric' => {
						'name' => q(pt),
						'one' => q({0}mpt),
						'other' => q({0}mpt),
					},
					# Core Unit Identifier
					'pint-metric' => {
						'name' => q(pt),
						'one' => q({0}mpt),
						'other' => q({0}mpt),
					},
					# Long Unit Identifier
					'volume-teaspoon' => {
						'name' => q(tsp),
						'one' => q({0}tsp),
						'other' => q({0}tsp),
					},
					# Core Unit Identifier
					'teaspoon' => {
						'name' => q(tsp),
						'one' => q({0}tsp),
						'other' => q({0}tsp),
					},
				},
				'short' => {
					# Long Unit Identifier
					'' => {
						'name' => q(ଦିଗ),
					},
					# Core Unit Identifier
					'' => {
						'name' => q(ଦିଗ),
					},
					# Long Unit Identifier
					'10p-1' => {
						'1' => q(ଡେ{0}),
					},
					# Core Unit Identifier
					'1' => {
						'1' => q(ଡେ{0}),
					},
					# Long Unit Identifier
					'10p-12' => {
						'1' => q(ପିକ{0}),
					},
					# Core Unit Identifier
					'12' => {
						'1' => q(ପିକ{0}),
					},
					# Long Unit Identifier
					'10p-15' => {
						'1' => q(ଫି.{0}),
					},
					# Core Unit Identifier
					'15' => {
						'1' => q(ଫି.{0}),
					},
					# Long Unit Identifier
					'10p-18' => {
						'1' => q(ଅ.{0}),
					},
					# Core Unit Identifier
					'18' => {
						'1' => q(ଅ.{0}),
					},
					# Long Unit Identifier
					'10p-2' => {
						'1' => q(ସେ.{0}),
					},
					# Core Unit Identifier
					'2' => {
						'1' => q(ସେ.{0}),
					},
					# Long Unit Identifier
					'10p-21' => {
						'1' => q(ଜିପ{0}),
					},
					# Core Unit Identifier
					'21' => {
						'1' => q(ଜିପ{0}),
					},
					# Long Unit Identifier
					'10p-24' => {
						'1' => q(ୟୋକ{0}),
					},
					# Core Unit Identifier
					'24' => {
						'1' => q(ୟୋକ{0}),
					},
					# Long Unit Identifier
					'10p-3' => {
						'1' => q(ମି.{0}),
					},
					# Core Unit Identifier
					'3' => {
						'1' => q(ମି.{0}),
					},
					# Long Unit Identifier
					'10p-9' => {
						'1' => q(ନେ.{0}),
					},
					# Core Unit Identifier
					'9' => {
						'1' => q(ନେ.{0}),
					},
					# Long Unit Identifier
					'10p1' => {
						'1' => q(ଡେକ{0}),
					},
					# Core Unit Identifier
					'10p1' => {
						'1' => q(ଡେକ{0}),
					},
					# Long Unit Identifier
					'10p12' => {
						'1' => q(ଟେ.{0}),
					},
					# Core Unit Identifier
					'10p12' => {
						'1' => q(ଟେ.{0}),
					},
					# Long Unit Identifier
					'10p15' => {
						'1' => q(ପି.{0}),
					},
					# Core Unit Identifier
					'10p15' => {
						'1' => q(ପି.{0}),
					},
					# Long Unit Identifier
					'10p18' => {
						'1' => q(ଏ.{0}),
					},
					# Core Unit Identifier
					'10p18' => {
						'1' => q(ଏ.{0}),
					},
					# Long Unit Identifier
					'10p2' => {
						'1' => q(ହେ.{0}),
					},
					# Core Unit Identifier
					'10p2' => {
						'1' => q(ହେ.{0}),
					},
					# Long Unit Identifier
					'10p21' => {
						'1' => q(ଜି.{0}),
					},
					# Core Unit Identifier
					'10p21' => {
						'1' => q(ଜି.{0}),
					},
					# Long Unit Identifier
					'10p24' => {
						'1' => q(ୟୋ.{0}),
					},
					# Core Unit Identifier
					'10p24' => {
						'1' => q(ୟୋ.{0}),
					},
					# Long Unit Identifier
					'10p3' => {
						'1' => q(କି.{0}),
					},
					# Core Unit Identifier
					'10p3' => {
						'1' => q(କି.{0}),
					},
					# Long Unit Identifier
					'10p6' => {
						'1' => q(ମେ.{0}),
					},
					# Core Unit Identifier
					'10p6' => {
						'1' => q(ମେ.{0}),
					},
					# Long Unit Identifier
					'10p9' => {
						'1' => q(ଗି.{0}),
					},
					# Core Unit Identifier
					'10p9' => {
						'1' => q(ଗି.{0}),
					},
					# Long Unit Identifier
					'acceleration-g-force' => {
						'one' => q({0} ଜି),
						'other' => q({0} ଜି),
					},
					# Core Unit Identifier
					'g-force' => {
						'one' => q({0} ଜି),
						'other' => q({0} ଜି),
					},
					# Long Unit Identifier
					'acceleration-meter-per-square-second' => {
						'name' => q(ମିଟର୍/ସେ²),
						'one' => q({0} ମି/ସେ²),
						'other' => q({0} ମି/ସେ²),
					},
					# Core Unit Identifier
					'meter-per-square-second' => {
						'name' => q(ମିଟର୍/ସେ²),
						'one' => q({0} ମି/ସେ²),
						'other' => q({0} ମି/ସେ²),
					},
					# Long Unit Identifier
					'angle-arc-minute' => {
						'name' => q(ଆର୍କମି),
						'one' => q({0} ଆର୍କମି),
						'other' => q({0} ଆର୍କମି),
					},
					# Core Unit Identifier
					'arc-minute' => {
						'name' => q(ଆର୍କମି),
						'one' => q({0} ଆର୍କମି),
						'other' => q({0} ଆର୍କମି),
					},
					# Long Unit Identifier
					'angle-arc-second' => {
						'name' => q(ଆର୍କସେ),
						'one' => q({0} ଆର୍କସେ),
						'other' => q({0} ଆର୍କସେ),
					},
					# Core Unit Identifier
					'arc-second' => {
						'name' => q(ଆର୍କସେ),
						'one' => q({0} ଆର୍କସେ),
						'other' => q({0} ଆର୍କସେ),
					},
					# Long Unit Identifier
					'angle-degree' => {
						'name' => q(ଡିଗ୍ରୀ),
						'one' => q({0} ଡି),
						'other' => q({0} ଡି),
					},
					# Core Unit Identifier
					'degree' => {
						'name' => q(ଡିଗ୍ରୀ),
						'one' => q({0} ଡି),
						'other' => q({0} ଡି),
					},
					# Long Unit Identifier
					'angle-radian' => {
						'name' => q(ରେଡିଆନ୍),
						'one' => q({0} ରେଡି),
						'other' => q({0} ରେଡି),
					},
					# Core Unit Identifier
					'radian' => {
						'name' => q(ରେଡିଆନ୍),
						'one' => q({0} ରେଡି),
						'other' => q({0} ରେଡି),
					},
					# Long Unit Identifier
					'angle-revolution' => {
						'name' => q(ପରିକ୍ର),
						'one' => q({0} ପରିକ୍ର),
						'other' => q({0} ପରିକ୍ର),
					},
					# Core Unit Identifier
					'revolution' => {
						'name' => q(ପରିକ୍ର),
						'one' => q({0} ପରିକ୍ର),
						'other' => q({0} ପରିକ୍ର),
					},
					# Long Unit Identifier
					'area-acre' => {
						'name' => q(ଏକର),
						'one' => q({0} ଏକର),
						'other' => q({0} ଏକର),
					},
					# Core Unit Identifier
					'acre' => {
						'name' => q(ଏକର),
						'one' => q({0} ଏକର),
						'other' => q({0} ଏକର),
					},
					# Long Unit Identifier
					'area-dunam' => {
						'name' => q(ଡୁନାମ),
						'one' => q({0} ଡୁନାମ),
						'other' => q({0} ଡୁନାମ),
					},
					# Core Unit Identifier
					'dunam' => {
						'name' => q(ଡୁନାମ),
						'one' => q({0} ଡୁନାମ),
						'other' => q({0} ଡୁନାମ),
					},
					# Long Unit Identifier
					'area-hectare' => {
						'name' => q(ହେକ୍ଟର୍),
						'one' => q({0} ହେ),
						'other' => q({0} ହେ),
					},
					# Core Unit Identifier
					'hectare' => {
						'name' => q(ହେକ୍ଟର୍),
						'one' => q({0} ହେ),
						'other' => q({0} ହେ),
					},
					# Long Unit Identifier
					'area-square-centimeter' => {
						'name' => q(ସେମି²),
						'one' => q({0} ସେମି²),
						'other' => q({0} ସେମି²),
						'per' => q({0}/ସେମି²),
					},
					# Core Unit Identifier
					'square-centimeter' => {
						'name' => q(ସେମି²),
						'one' => q({0} ସେମି²),
						'other' => q({0} ସେମି²),
						'per' => q({0}/ସେମି²),
					},
					# Long Unit Identifier
					'area-square-foot' => {
						'name' => q(ବର୍ଗ ଫିଟ୍),
						'one' => q({0} ବର୍ଗ ଫିଟ୍),
						'other' => q({0} ବର୍ଗ ଫିଟ୍),
					},
					# Core Unit Identifier
					'square-foot' => {
						'name' => q(ବର୍ଗ ଫିଟ୍),
						'one' => q({0} ବର୍ଗ ଫିଟ୍),
						'other' => q({0} ବର୍ଗ ଫିଟ୍),
					},
					# Long Unit Identifier
					'area-square-inch' => {
						'name' => q(ଇଞ୍ଚ²),
						'one' => q({0} ଇଞ୍ଚ²),
						'other' => q({0} ଇଞ୍ଚ²),
						'per' => q({0}/ଇଞ୍ଚ²),
					},
					# Core Unit Identifier
					'square-inch' => {
						'name' => q(ଇଞ୍ଚ²),
						'one' => q({0} ଇଞ୍ଚ²),
						'other' => q({0} ଇଞ୍ଚ²),
						'per' => q({0}/ଇଞ୍ଚ²),
					},
					# Long Unit Identifier
					'area-square-kilometer' => {
						'name' => q(କିମି²),
						'one' => q({0} କିମି²),
						'other' => q({0} କିମି²),
						'per' => q({0}/କିମି²),
					},
					# Core Unit Identifier
					'square-kilometer' => {
						'name' => q(କିମି²),
						'one' => q({0} କିମି²),
						'other' => q({0} କିମି²),
						'per' => q({0}/କିମି²),
					},
					# Long Unit Identifier
					'area-square-meter' => {
						'name' => q(ମିଟର୍²),
						'one' => q({0} ମି²),
						'other' => q({0} ମି²),
						'per' => q({0}/ମି²),
					},
					# Core Unit Identifier
					'square-meter' => {
						'name' => q(ମିଟର୍²),
						'one' => q({0} ମି²),
						'other' => q({0} ମି²),
						'per' => q({0}/ମି²),
					},
					# Long Unit Identifier
					'area-square-mile' => {
						'name' => q(ବର୍ଗ ମାଇଲ୍),
						'one' => q({0} ବର୍ଗ ମାଇଲ୍),
						'other' => q({0} ବର୍ଗ ମାଇଲ୍),
						'per' => q({0}/ମାଇଲ୍²),
					},
					# Core Unit Identifier
					'square-mile' => {
						'name' => q(ବର୍ଗ ମାଇଲ୍),
						'one' => q({0} ବର୍ଗ ମାଇଲ୍),
						'other' => q({0} ବର୍ଗ ମାଇଲ୍),
						'per' => q({0}/ମାଇଲ୍²),
					},
					# Long Unit Identifier
					'area-square-yard' => {
						'name' => q(ୟାର୍ଡ୍²),
						'one' => q({0} ୟାର୍ଡ୍²),
						'other' => q({0} ୟାର୍ଡ୍²),
					},
					# Core Unit Identifier
					'square-yard' => {
						'name' => q(ୟାର୍ଡ୍²),
						'one' => q({0} ୟାର୍ଡ୍²),
						'other' => q({0} ୟାର୍ଡ୍²),
					},
					# Long Unit Identifier
					'concentr-item' => {
						'name' => q(ଆଇଟମ୍),
						'one' => q({0} ଆଇଟମ୍),
						'other' => q({0} ଆଇଟମ୍),
					},
					# Core Unit Identifier
					'item' => {
						'name' => q(ଆଇଟମ୍),
						'one' => q({0} ଆଇଟମ୍),
						'other' => q({0} ଆଇଟମ୍),
					},
					# Long Unit Identifier
					'concentr-karat' => {
						'name' => q(କ୍ୟାରେଟ୍),
					},
					# Core Unit Identifier
					'karat' => {
						'name' => q(କ୍ୟାରେଟ୍),
					},
					# Long Unit Identifier
					'concentr-milligram-ofglucose-per-deciliter' => {
						'name' => q(ମିଗ୍ରା/ଡେଲି),
						'one' => q({0} ମିଗ୍ରା/ଡେଲି),
						'other' => q({0} ମିଗ୍ରା/ଡେଲି),
					},
					# Core Unit Identifier
					'milligram-ofglucose-per-deciliter' => {
						'name' => q(ମିଗ୍ରା/ଡେଲି),
						'one' => q({0} ମିଗ୍ରା/ଡେଲି),
						'other' => q({0} ମିଗ୍ରା/ଡେଲି),
					},
					# Long Unit Identifier
					'concentr-millimole-per-liter' => {
						'name' => q(ମିଲିମୋଲ୍/ଲିଟର୍),
						'one' => q({0} ମିଲିମୋଲ୍/ଲି),
						'other' => q({0} ମିଲିମୋଲ୍/ଲି),
					},
					# Core Unit Identifier
					'millimole-per-liter' => {
						'name' => q(ମିଲିମୋଲ୍/ଲିଟର୍),
						'one' => q({0} ମିଲିମୋଲ୍/ଲି),
						'other' => q({0} ମିଲିମୋଲ୍/ଲି),
					},
					# Long Unit Identifier
					'concentr-mole' => {
						'name' => q(ମୋଲ),
						'one' => q(ମୋଲ),
						'other' => q({0} ମୋଲ),
					},
					# Core Unit Identifier
					'mole' => {
						'name' => q(ମୋଲ),
						'one' => q(ମୋଲ),
						'other' => q({0} ମୋଲ),
					},
					# Long Unit Identifier
					'concentr-percent' => {
						'name' => q(ଶତକଡ଼ା),
					},
					# Core Unit Identifier
					'percent' => {
						'name' => q(ଶତକଡ଼ା),
					},
					# Long Unit Identifier
					'concentr-permille' => {
						'name' => q(ପରମିଲ),
					},
					# Core Unit Identifier
					'permille' => {
						'name' => q(ପରମିଲ),
					},
					# Long Unit Identifier
					'concentr-permillion' => {
						'name' => q(ଅଂଶ/ନିୟୁତ),
						'one' => q({0} ପିପିଏମ୍),
						'other' => q({0} ପିପିଏମ୍),
					},
					# Core Unit Identifier
					'permillion' => {
						'name' => q(ଅଂଶ/ନିୟୁତ),
						'one' => q({0} ପିପିଏମ୍),
						'other' => q({0} ପିପିଏମ୍),
					},
					# Long Unit Identifier
					'concentr-permyriad' => {
						'name' => q(ପରମାଇରିଆଡ),
					},
					# Core Unit Identifier
					'permyriad' => {
						'name' => q(ପରମାଇରିଆଡ),
					},
					# Long Unit Identifier
					'concentr-portion-per-1e9' => {
						'name' => q(ପାର୍ଟ୍ସ/ବିଲିୟନ୍),
					},
					# Core Unit Identifier
					'portion-per-1e9' => {
						'name' => q(ପାର୍ଟ୍ସ/ବିଲିୟନ୍),
					},
					# Long Unit Identifier
					'consumption-liter-per-100-kilometer' => {
						'name' => q(ଲି/100 କିମି),
						'one' => q({0} ଲି/100 କିମି),
						'other' => q({0} ଲି/100 କିମି),
					},
					# Core Unit Identifier
					'liter-per-100-kilometer' => {
						'name' => q(ଲି/100 କିମି),
						'one' => q({0} ଲି/100 କିମି),
						'other' => q({0} ଲି/100 କିମି),
					},
					# Long Unit Identifier
					'consumption-liter-per-kilometer' => {
						'name' => q(ଲିଟର୍/କିମି),
						'one' => q({0} ଲି/କିମି),
						'other' => q({0} ଲି/କିମି),
					},
					# Core Unit Identifier
					'liter-per-kilometer' => {
						'name' => q(ଲିଟର୍/କିମି),
						'one' => q({0} ଲି/କିମି),
						'other' => q({0} ଲି/କିମି),
					},
					# Long Unit Identifier
					'consumption-mile-per-gallon' => {
						'name' => q(ମାଇଲ୍/ଗ୍ୟା),
						'one' => q({0} ଏମପିଜି),
						'other' => q({0} ଏମପିଜି),
					},
					# Core Unit Identifier
					'mile-per-gallon' => {
						'name' => q(ମାଇଲ୍/ଗ୍ୟା),
						'one' => q({0} ଏମପିଜି),
						'other' => q({0} ଏମପିଜି),
					},
					# Long Unit Identifier
					'consumption-mile-per-gallon-imperial' => {
						'name' => q(ମାଇଲ୍/ଇମ୍ପେ. ଗ୍ୟା),
						'one' => q({0} ଏମପିଜି ଇମ୍ପେ.),
						'other' => q({0} ଏମପିଜି ଇମ୍ପେ.),
					},
					# Core Unit Identifier
					'mile-per-gallon-imperial' => {
						'name' => q(ମାଇଲ୍/ଇମ୍ପେ. ଗ୍ୟା),
						'one' => q({0} ଏମପିଜି ଇମ୍ପେ.),
						'other' => q({0} ଏମପିଜି ଇମ୍ପେ.),
					},
					# Long Unit Identifier
					'coordinate' => {
						'east' => q({0} ପୂ),
						'north' => q({0} ଉ),
						'south' => q({0} ଦ),
						'west' => q({0} ପ),
					},
					# Core Unit Identifier
					'coordinate' => {
						'east' => q({0} ପୂ),
						'north' => q({0} ଉ),
						'south' => q({0} ଦ),
						'west' => q({0} ପ),
					},
					# Long Unit Identifier
					'digital-bit' => {
						'name' => q(ବିଟ୍),
						'one' => q({0} ବିଟ୍),
						'other' => q({0} ବିଟ୍),
					},
					# Core Unit Identifier
					'bit' => {
						'name' => q(ବିଟ୍),
						'one' => q({0} ବିଟ୍),
						'other' => q({0} ବିଟ୍),
					},
					# Long Unit Identifier
					'digital-byte' => {
						'name' => q(ବାଇଟ୍),
						'one' => q({0} ବାଇଟ୍),
						'other' => q({0} ବାଇଟ୍),
					},
					# Core Unit Identifier
					'byte' => {
						'name' => q(ବାଇଟ୍),
						'one' => q({0} ବାଇଟ୍),
						'other' => q({0} ବାଇଟ୍),
					},
					# Long Unit Identifier
					'digital-gigabit' => {
						'name' => q(ଜିବିଟ୍),
					},
					# Core Unit Identifier
					'gigabit' => {
						'name' => q(ଜିବିଟ୍),
					},
					# Long Unit Identifier
					'digital-gigabyte' => {
						'name' => q(ଜିବାଇଟ୍),
					},
					# Core Unit Identifier
					'gigabyte' => {
						'name' => q(ଜିବାଇଟ୍),
					},
					# Long Unit Identifier
					'digital-kilobit' => {
						'name' => q(କେବିଟ୍),
					},
					# Core Unit Identifier
					'kilobit' => {
						'name' => q(କେବିଟ୍),
					},
					# Long Unit Identifier
					'digital-kilobyte' => {
						'name' => q(କେବାଇଟ୍),
					},
					# Core Unit Identifier
					'kilobyte' => {
						'name' => q(କେବାଇଟ୍),
					},
					# Long Unit Identifier
					'digital-megabit' => {
						'name' => q(ମେବିଟ୍),
					},
					# Core Unit Identifier
					'megabit' => {
						'name' => q(ମେବିଟ୍),
					},
					# Long Unit Identifier
					'digital-megabyte' => {
						'name' => q(ମେବାଇଟ୍),
					},
					# Core Unit Identifier
					'megabyte' => {
						'name' => q(ମେବାଇଟ୍),
					},
					# Long Unit Identifier
					'digital-petabyte' => {
						'name' => q(PByte),
					},
					# Core Unit Identifier
					'petabyte' => {
						'name' => q(PByte),
					},
					# Long Unit Identifier
					'digital-terabit' => {
						'name' => q(ଟିବିଟ୍),
					},
					# Core Unit Identifier
					'terabit' => {
						'name' => q(ଟିବିଟ୍),
					},
					# Long Unit Identifier
					'digital-terabyte' => {
						'name' => q(ଟିବାଇଟ୍),
					},
					# Core Unit Identifier
					'terabyte' => {
						'name' => q(ଟିବାଇଟ୍),
					},
					# Long Unit Identifier
					'duration-day' => {
						'name' => q(ଦିନ),
						'one' => q({0} ଦିନ),
						'other' => q({0} ଦିନ),
						'per' => q({0}/ଦିନ),
					},
					# Core Unit Identifier
					'day' => {
						'name' => q(ଦିନ),
						'one' => q({0} ଦିନ),
						'other' => q({0} ଦିନ),
						'per' => q({0}/ଦିନ),
					},
					# Long Unit Identifier
					'duration-decade' => {
						'one' => q({0} ଦଶନ୍ଧି),
						'other' => q({0} ଦଶନ୍ଧି),
					},
					# Core Unit Identifier
					'decade' => {
						'one' => q({0} ଦଶନ୍ଧି),
						'other' => q({0} ଦଶନ୍ଧି),
					},
					# Long Unit Identifier
					'duration-hour' => {
						'name' => q(ଘଣ୍ଟା),
						'one' => q({0} ଘଣ୍ଟା),
						'other' => q({0} ଘଣ୍ଟା),
						'per' => q({0}/ଘଣ୍ଟା),
					},
					# Core Unit Identifier
					'hour' => {
						'name' => q(ଘଣ୍ଟା),
						'one' => q({0} ଘଣ୍ଟା),
						'other' => q({0} ଘଣ୍ଟା),
						'per' => q({0}/ଘଣ୍ଟା),
					},
					# Long Unit Identifier
					'duration-microsecond' => {
						'name' => q(μସେକେଣ୍ଡ),
					},
					# Core Unit Identifier
					'microsecond' => {
						'name' => q(μସେକେଣ୍ଡ),
					},
					# Long Unit Identifier
					'duration-millisecond' => {
						'name' => q(ମିଲିସେକେଣ୍ଡ),
					},
					# Core Unit Identifier
					'millisecond' => {
						'name' => q(ମିଲିସେକେଣ୍ଡ),
					},
					# Long Unit Identifier
					'duration-minute' => {
						'name' => q(ମିନିଟ୍‌),
						'one' => q({0} ମିନିଟ୍‌),
						'other' => q({0} ମିନିଟ୍‌),
						'per' => q({0}/ମିନିଟ୍‌),
					},
					# Core Unit Identifier
					'minute' => {
						'name' => q(ମିନିଟ୍‌),
						'one' => q({0} ମିନିଟ୍‌),
						'other' => q({0} ମିନିଟ୍‌),
						'per' => q({0}/ମିନିଟ୍‌),
					},
					# Long Unit Identifier
					'duration-month' => {
						'name' => q(ମାସ),
						'one' => q({0} ମାସ),
						'other' => q({0} ମାସ),
						'per' => q({0}/ମାସ),
					},
					# Core Unit Identifier
					'month' => {
						'name' => q(ମାସ),
						'one' => q({0} ମାସ),
						'other' => q({0} ମାସ),
						'per' => q({0}/ମାସ),
					},
					# Long Unit Identifier
					'duration-night' => {
						'name' => q(ରାତି),
						'one' => q({0} ରାତି),
						'other' => q({0} ରାତି),
						'per' => q({0}/ରାତି),
					},
					# Core Unit Identifier
					'night' => {
						'name' => q(ରାତି),
						'one' => q({0} ରାତି),
						'other' => q({0} ରାତି),
						'per' => q({0}/ରାତି),
					},
					# Long Unit Identifier
					'duration-quarter' => {
						'name' => q(କ୍ୱାର୍ଟର୍ସ),
						'one' => q({0} କ୍ୱାର୍ଟର୍ସ),
						'other' => q({0} କ୍ୱାର୍ଟର୍ସ),
						'per' => q({0}/କ୍ୱାର୍ଟର୍ସ),
					},
					# Core Unit Identifier
					'quarter' => {
						'name' => q(କ୍ୱାର୍ଟର୍ସ),
						'one' => q({0} କ୍ୱାର୍ଟର୍ସ),
						'other' => q({0} କ୍ୱାର୍ଟର୍ସ),
						'per' => q({0}/କ୍ୱାର୍ଟର୍ସ),
					},
					# Long Unit Identifier
					'duration-second' => {
						'name' => q(ସେକେଣ୍ଡ),
						'one' => q({0} ସେକେଣ୍ଡ),
						'other' => q({0} ସେକେଣ୍ଡ),
						'per' => q({0}/ସେକେଣ୍ଡ),
					},
					# Core Unit Identifier
					'second' => {
						'name' => q(ସେକେଣ୍ଡ),
						'one' => q({0} ସେକେଣ୍ଡ),
						'other' => q({0} ସେକେଣ୍ଡ),
						'per' => q({0}/ସେକେଣ୍ଡ),
					},
					# Long Unit Identifier
					'duration-week' => {
						'name' => q(ସପ୍ତାହ),
						'one' => q({0} ସପ୍ତାହ),
						'other' => q({0} ସପ୍ତାହ),
						'per' => q({0}/ସପ୍ତାହ),
					},
					# Core Unit Identifier
					'week' => {
						'name' => q(ସପ୍ତାହ),
						'one' => q({0} ସପ୍ତାହ),
						'other' => q({0} ସପ୍ତାହ),
						'per' => q({0}/ସପ୍ତାହ),
					},
					# Long Unit Identifier
					'duration-year' => {
						'name' => q(ବର୍ଷ),
						'one' => q({0} ବର୍ଷ),
						'other' => q({0} ବର୍ଷ),
						'per' => q({0}/ବର୍ଷ),
					},
					# Core Unit Identifier
					'year' => {
						'name' => q(ବର୍ଷ),
						'one' => q({0} ବର୍ଷ),
						'other' => q({0} ବର୍ଷ),
						'per' => q({0}/ବର୍ଷ),
					},
					# Long Unit Identifier
					'electric-ampere' => {
						'name' => q(ଆମ୍ପପ୍),
						'one' => q({0} ଏ),
						'other' => q({0} ଏ),
					},
					# Core Unit Identifier
					'ampere' => {
						'name' => q(ଆମ୍ପପ୍),
						'one' => q({0} ଏ),
						'other' => q({0} ଏ),
					},
					# Long Unit Identifier
					'electric-milliampere' => {
						'name' => q(ମିଲିଆମ୍ପ୍),
						'one' => q({0} ମିଆ),
						'other' => q({0} ମିଆ),
					},
					# Core Unit Identifier
					'milliampere' => {
						'name' => q(ମିଲିଆମ୍ପ୍),
						'one' => q({0} ମିଆ),
						'other' => q({0} ମିଆ),
					},
					# Long Unit Identifier
					'electric-ohm' => {
						'name' => q(ଓହମ୍),
					},
					# Core Unit Identifier
					'ohm' => {
						'name' => q(ଓହମ୍),
					},
					# Long Unit Identifier
					'electric-volt' => {
						'name' => q(ଭୋଲ୍ଟ୍),
						'one' => q({0} ଭୋ),
						'other' => q({0} ଭୋ),
					},
					# Core Unit Identifier
					'volt' => {
						'name' => q(ଭୋଲ୍ଟ୍),
						'one' => q({0} ଭୋ),
						'other' => q({0} ଭୋ),
					},
					# Long Unit Identifier
					'energy-calorie' => {
						'name' => q(କ୍ୟାଲ୍),
						'one' => q({0} କ୍ୟାଲ୍),
						'other' => q({0} କ୍ୟାଲ୍),
					},
					# Core Unit Identifier
					'calorie' => {
						'name' => q(କ୍ୟାଲ୍),
						'one' => q({0} କ୍ୟାଲ୍),
						'other' => q({0} କ୍ୟାଲ୍),
					},
					# Long Unit Identifier
					'energy-electronvolt' => {
						'name' => q(ଇଲେକ୍ଟ୍ରୋନ୍‌ ଭୋଲ୍ଟ),
					},
					# Core Unit Identifier
					'electronvolt' => {
						'name' => q(ଇଲେକ୍ଟ୍ରୋନ୍‌ ଭୋଲ୍ଟ),
					},
					# Long Unit Identifier
					'energy-foodcalorie' => {
						'name' => q(କ୍ୟାଲ୍),
						'one' => q({0} କ୍ୟାଲ୍),
						'other' => q({0} କ୍ୟାଲ୍),
					},
					# Core Unit Identifier
					'foodcalorie' => {
						'name' => q(କ୍ୟାଲ୍),
						'one' => q({0} କ୍ୟାଲ୍),
						'other' => q({0} କ୍ୟାଲ୍),
					},
					# Long Unit Identifier
					'energy-joule' => {
						'name' => q(ଜୁଲ୍),
						'one' => q({0} ଜୁ),
						'other' => q({0} ଜୁ),
					},
					# Core Unit Identifier
					'joule' => {
						'name' => q(ଜୁଲ୍),
						'one' => q({0} ଜୁ),
						'other' => q({0} ଜୁ),
					},
					# Long Unit Identifier
					'energy-kilocalorie' => {
						'name' => q(କିଲୋକ୍ୟାଲ୍),
						'one' => q({0} କିଲୋକ୍ୟାଲ୍),
						'other' => q({0} କିଲୋକ୍ୟାଲ୍),
					},
					# Core Unit Identifier
					'kilocalorie' => {
						'name' => q(କିଲୋକ୍ୟାଲ୍),
						'one' => q({0} କିଲୋକ୍ୟାଲ୍),
						'other' => q({0} କିଲୋକ୍ୟାଲ୍),
					},
					# Long Unit Identifier
					'energy-kilojoule' => {
						'name' => q(କିଲୋଜୁଲ୍),
						'one' => q({0} କିଜୁ),
						'other' => q({0} କିଜୁ),
					},
					# Core Unit Identifier
					'kilojoule' => {
						'name' => q(କିଲୋଜୁଲ୍),
						'one' => q({0} କିଜୁ),
						'other' => q({0} କିଜୁ),
					},
					# Long Unit Identifier
					'energy-kilowatt-hour' => {
						'name' => q(କିୱା-ଘଣ୍ଟା),
						'one' => q({0} କିୱାଘ),
						'other' => q({0} କିୱାଘ),
					},
					# Core Unit Identifier
					'kilowatt-hour' => {
						'name' => q(କିୱା-ଘଣ୍ଟା),
						'one' => q({0} କିୱାଘ),
						'other' => q({0} କିୱାଘ),
					},
					# Long Unit Identifier
					'energy-therm-us' => {
						'name' => q(ୟୁଏସ୍‌ ଥର୍ମ),
						'one' => q({0} ୟୁଏସ୍‌ ଥର୍ମ),
						'other' => q({0} ୟୁଏସ୍‌ ଥର୍ମ),
					},
					# Core Unit Identifier
					'therm-us' => {
						'name' => q(ୟୁଏସ୍‌ ଥର୍ମ),
						'one' => q({0} ୟୁଏସ୍‌ ଥର୍ମ),
						'other' => q({0} ୟୁଏସ୍‌ ଥର୍ମ),
					},
					# Long Unit Identifier
					'force-newton' => {
						'name' => q(ନ୍ୟୁଟନ),
					},
					# Core Unit Identifier
					'newton' => {
						'name' => q(ନ୍ୟୁଟନ),
					},
					# Long Unit Identifier
					'force-pound-force' => {
						'name' => q(ପାଉଣ୍ଡ-ଫୋର୍ସ),
					},
					# Core Unit Identifier
					'pound-force' => {
						'name' => q(ପାଉଣ୍ଡ-ଫୋର୍ସ),
					},
					# Long Unit Identifier
					'graphics-dot' => {
						'name' => q(ବି.),
						'one' => q({0} ବିନ୍ଦୁ),
						'other' => q({0} ବିନ୍ଦୁ),
					},
					# Core Unit Identifier
					'dot' => {
						'name' => q(ବି.),
						'one' => q({0} ବିନ୍ଦୁ),
						'other' => q({0} ବିନ୍ଦୁ),
					},
					# Long Unit Identifier
					'graphics-dot-per-centimeter' => {
						'name' => q(dpcm),
						'one' => q({0} dpcm),
						'other' => q({0} dpcm),
					},
					# Core Unit Identifier
					'dot-per-centimeter' => {
						'name' => q(dpcm),
						'one' => q({0} dpcm),
						'other' => q({0} dpcm),
					},
					# Long Unit Identifier
					'graphics-dot-per-inch' => {
						'name' => q(dpi),
						'one' => q({0} dpi),
						'other' => q({0} dpi),
					},
					# Core Unit Identifier
					'dot-per-inch' => {
						'name' => q(dpi),
						'one' => q({0} dpi),
						'other' => q({0} dpi),
					},
					# Long Unit Identifier
					'length-astronomical-unit' => {
						'name' => q(ଆୟୁ),
						'one' => q({0} au),
						'other' => q({0} au),
					},
					# Core Unit Identifier
					'astronomical-unit' => {
						'name' => q(ଆୟୁ),
						'one' => q({0} au),
						'other' => q({0} au),
					},
					# Long Unit Identifier
					'length-centimeter' => {
						'name' => q(ସେମି),
						'one' => q({0} ସେମି),
						'other' => q({0} ସେମି),
						'per' => q({0}/ସେମି),
					},
					# Core Unit Identifier
					'centimeter' => {
						'name' => q(ସେମି),
						'one' => q({0} ସେମି),
						'other' => q({0} ସେମି),
						'per' => q({0}/ସେମି),
					},
					# Long Unit Identifier
					'length-decimeter' => {
						'name' => q(ଡେମି),
						'one' => q({0} ଡେମି),
						'other' => q({0} ଡେମି),
					},
					# Core Unit Identifier
					'decimeter' => {
						'name' => q(ଡେମି),
						'one' => q({0} ଡେମି),
						'other' => q({0} ଡେମି),
					},
					# Long Unit Identifier
					'length-fathom' => {
						'one' => q({0} ଫାଟୋମ),
						'other' => q({0} fth),
					},
					# Core Unit Identifier
					'fathom' => {
						'one' => q({0} ଫାଟୋମ),
						'other' => q({0} fth),
					},
					# Long Unit Identifier
					'length-foot' => {
						'name' => q(ଫିଟ୍),
						'one' => q({0} ଫିଟ୍),
						'other' => q({0} ଫିଟ୍),
						'per' => q({0}/ଫିଟ୍),
					},
					# Core Unit Identifier
					'foot' => {
						'name' => q(ଫିଟ୍),
						'one' => q({0} ଫିଟ୍),
						'other' => q({0} ଫିଟ୍),
						'per' => q({0}/ଫିଟ୍),
					},
					# Long Unit Identifier
					'length-furlong' => {
						'name' => q(ଫର୍ଲଙ୍ଗସ୍),
						'one' => q({0} ଫର୍ଲଙ୍ଗ୍),
						'other' => q({0} fur),
					},
					# Core Unit Identifier
					'furlong' => {
						'name' => q(ଫର୍ଲଙ୍ଗସ୍),
						'one' => q({0} ଫର୍ଲଙ୍ଗ୍),
						'other' => q({0} fur),
					},
					# Long Unit Identifier
					'length-inch' => {
						'name' => q(ଇଞ୍ଚ୍),
						'one' => q({0} ଇଞ୍ଚ୍),
						'other' => q({0} ଇଞ୍ଚ୍),
						'per' => q({0}/ଇଞ୍ଚ୍),
					},
					# Core Unit Identifier
					'inch' => {
						'name' => q(ଇଞ୍ଚ୍),
						'one' => q({0} ଇଞ୍ଚ୍),
						'other' => q({0} ଇଞ୍ଚ୍),
						'per' => q({0}/ଇଞ୍ଚ୍),
					},
					# Long Unit Identifier
					'length-kilometer' => {
						'name' => q(କିମି),
						'one' => q({0} କିମି),
						'other' => q({0} କିମି),
						'per' => q({0}/କିମି),
					},
					# Core Unit Identifier
					'kilometer' => {
						'name' => q(କିମି),
						'one' => q({0} କିମି),
						'other' => q({0} କିମି),
						'per' => q({0}/କିମି),
					},
					# Long Unit Identifier
					'length-light-year' => {
						'name' => q(ଆଲୋକ ବର୍ଷ),
						'one' => q({0} ଆବ),
						'other' => q({0} ଆବ),
					},
					# Core Unit Identifier
					'light-year' => {
						'name' => q(ଆଲୋକ ବର୍ଷ),
						'one' => q({0} ଆବ),
						'other' => q({0} ଆବ),
					},
					# Long Unit Identifier
					'length-meter' => {
						'name' => q(ମି),
						'one' => q({0} ମି),
						'other' => q({0} ମି),
						'per' => q({0}/ମି),
					},
					# Core Unit Identifier
					'meter' => {
						'name' => q(ମି),
						'one' => q({0} ମି),
						'other' => q({0} ମି),
						'per' => q({0}/ମି),
					},
					# Long Unit Identifier
					'length-micrometer' => {
						'name' => q(μମିଟର୍),
						'one' => q({0} μମି),
						'other' => q({0} μମି),
					},
					# Core Unit Identifier
					'micrometer' => {
						'name' => q(μମିଟର୍),
						'one' => q({0} μମି),
						'other' => q({0} μମି),
					},
					# Long Unit Identifier
					'length-mile' => {
						'name' => q(ମାଇଲ୍),
						'one' => q({0} ମା),
						'other' => q({0} ମା),
					},
					# Core Unit Identifier
					'mile' => {
						'name' => q(ମାଇଲ୍),
						'one' => q({0} ମା),
						'other' => q({0} ମା),
					},
					# Long Unit Identifier
					'length-mile-scandinavian' => {
						'name' => q(ସମି),
						'one' => q({0} ସମି),
						'other' => q({0} ସମି),
					},
					# Core Unit Identifier
					'mile-scandinavian' => {
						'name' => q(ସମି),
						'one' => q({0} ସମି),
						'other' => q({0} ସମି),
					},
					# Long Unit Identifier
					'length-millimeter' => {
						'name' => q(ମିମି),
						'one' => q({0} ମିମି),
						'other' => q({0} ମିମି),
					},
					# Core Unit Identifier
					'millimeter' => {
						'name' => q(ମିମି),
						'one' => q({0} ମିମି),
						'other' => q({0} ମିମି),
					},
					# Long Unit Identifier
					'length-nanometer' => {
						'name' => q(ନାମି),
						'one' => q({0} ନାମି),
						'other' => q({0} ନାମି),
					},
					# Core Unit Identifier
					'nanometer' => {
						'name' => q(ନାମି),
						'one' => q({0} ନାମି),
						'other' => q({0} ନାମି),
					},
					# Long Unit Identifier
					'length-nautical-mile' => {
						'name' => q(ନୌମି),
						'one' => q({0} nmi),
						'other' => q({0} nmi),
					},
					# Core Unit Identifier
					'nautical-mile' => {
						'name' => q(ନୌମି),
						'one' => q({0} nmi),
						'other' => q({0} nmi),
					},
					# Long Unit Identifier
					'length-parsec' => {
						'name' => q(ପାରସେକ୍),
						'one' => q({0} ପିସି),
						'other' => q({0} ପିସି),
					},
					# Core Unit Identifier
					'parsec' => {
						'name' => q(ପାରସେକ୍),
						'one' => q({0} ପିସି),
						'other' => q({0} ପିସି),
					},
					# Long Unit Identifier
					'length-picometer' => {
						'name' => q(ପିମି),
						'one' => q({0} ପିମି),
						'other' => q({0} ପିମି),
					},
					# Core Unit Identifier
					'picometer' => {
						'name' => q(ପିମି),
						'one' => q({0} ପିମି),
						'other' => q({0} ପିମି),
					},
					# Long Unit Identifier
					'length-point' => {
						'name' => q(ପଏଣ୍ଟ୍),
						'one' => q({0} ପ),
						'other' => q({0} ପ),
					},
					# Core Unit Identifier
					'point' => {
						'name' => q(ପଏଣ୍ଟ୍),
						'one' => q({0} ପ),
						'other' => q({0} ପ),
					},
					# Long Unit Identifier
					'length-solar-radius' => {
						'name' => q(ସୋଲାର ବ୍ୟାସାର୍ଦ୍ଧ),
					},
					# Core Unit Identifier
					'solar-radius' => {
						'name' => q(ସୋଲାର ବ୍ୟାସାର୍ଦ୍ଧ),
					},
					# Long Unit Identifier
					'length-yard' => {
						'name' => q(ୟାର୍ଡ୍),
						'one' => q({0} ୟାର୍ଡ୍),
						'other' => q({0} ୟାର୍ଡ୍),
					},
					# Core Unit Identifier
					'yard' => {
						'name' => q(ୟାର୍ଡ୍),
						'one' => q({0} ୟାର୍ଡ୍),
						'other' => q({0} ୟାର୍ଡ୍),
					},
					# Long Unit Identifier
					'light-lux' => {
						'name' => q(ଲକ୍ସ),
						'one' => q({0} ଲକ୍ସ),
						'other' => q({0} ଲକ୍ସ),
					},
					# Core Unit Identifier
					'lux' => {
						'name' => q(ଲକ୍ସ),
						'one' => q({0} ଲକ୍ସ),
						'other' => q({0} ଲକ୍ସ),
					},
					# Long Unit Identifier
					'light-solar-luminosity' => {
						'name' => q(ସୋଲର ଲ୍ୟୁମିନୋସିଟିସ),
					},
					# Core Unit Identifier
					'solar-luminosity' => {
						'name' => q(ସୋଲର ଲ୍ୟୁମିନୋସିଟିସ),
					},
					# Long Unit Identifier
					'mass-carat' => {
						'name' => q(କ୍ୟାରେଟ୍),
						'one' => q({0} ସିଡି),
						'other' => q({0} ସିଡି),
					},
					# Core Unit Identifier
					'carat' => {
						'name' => q(କ୍ୟାରେଟ୍),
						'one' => q({0} ସିଡି),
						'other' => q({0} ସିଡି),
					},
					# Long Unit Identifier
					'mass-dalton' => {
						'name' => q(ଡାଲ୍ଟନ),
						'one' => q({0} ଡିଏ),
						'other' => q({0} ଡିଏ),
					},
					# Core Unit Identifier
					'dalton' => {
						'name' => q(ଡାଲ୍ଟନ),
						'one' => q({0} ଡିଏ),
						'other' => q({0} ଡିଏ),
					},
					# Long Unit Identifier
					'mass-earth-mass' => {
						'name' => q(ଅର୍ଥ ମାସେସ),
					},
					# Core Unit Identifier
					'earth-mass' => {
						'name' => q(ଅର୍ଥ ମାସେସ),
					},
					# Long Unit Identifier
					'mass-grain' => {
						'name' => q(ଗ୍ରେନ୍),
						'one' => q({0} ଗ୍ରେନ୍),
						'other' => q({0} ଗ୍ରେନ୍),
					},
					# Core Unit Identifier
					'grain' => {
						'name' => q(ଗ୍ରେନ୍),
						'one' => q({0} ଗ୍ରେନ୍),
						'other' => q({0} ଗ୍ରେନ୍),
					},
					# Long Unit Identifier
					'mass-gram' => {
						'name' => q(ଗ୍ରାମ୍),
						'one' => q({0} ଗ୍ରା),
						'other' => q({0} ଗ୍ରା),
						'per' => q({0}/ଗ୍ରା),
					},
					# Core Unit Identifier
					'gram' => {
						'name' => q(ଗ୍ରାମ୍),
						'one' => q({0} ଗ୍ରା),
						'other' => q({0} ଗ୍ରା),
						'per' => q({0}/ଗ୍ରା),
					},
					# Long Unit Identifier
					'mass-kilogram' => {
						'name' => q(କିଗ୍ରା),
						'one' => q({0} କିଗ୍ରା),
						'other' => q({0} କିଗ୍ରା),
						'per' => q({0}/କିଗ୍ରା),
					},
					# Core Unit Identifier
					'kilogram' => {
						'name' => q(କିଗ୍ରା),
						'one' => q({0} କିଗ୍ରା),
						'other' => q({0} କିଗ୍ରା),
						'per' => q({0}/କିଗ୍ରା),
					},
					# Long Unit Identifier
					'mass-milligram' => {
						'name' => q(ମିଗ୍ରା),
						'one' => q({0} ମିଗ୍ରା),
						'other' => q({0} ମିଗ୍ରା),
					},
					# Core Unit Identifier
					'milligram' => {
						'name' => q(ମିଗ୍ରା),
						'one' => q({0} ମିଗ୍ରା),
						'other' => q({0} ମିଗ୍ରା),
					},
					# Long Unit Identifier
					'mass-ounce' => {
						'name' => q(ଓଜ୍),
						'one' => q({0} ଓଜ୍),
						'other' => q({0} ଓଜ୍),
						'per' => q({0}/ଓଜ୍),
					},
					# Core Unit Identifier
					'ounce' => {
						'name' => q(ଓଜ୍),
						'one' => q({0} ଓଜ୍),
						'other' => q({0} ଓଜ୍),
						'per' => q({0}/ଓଜ୍),
					},
					# Long Unit Identifier
					'mass-ounce-troy' => {
						'name' => q(ଓଜ୍ ଟ୍ରୋୟ),
						'one' => q({0} ଓଜ୍ ଟ୍ରୋ),
						'other' => q({0} ଓଜ୍ ଟ୍ରୋ),
					},
					# Core Unit Identifier
					'ounce-troy' => {
						'name' => q(ଓଜ୍ ଟ୍ରୋୟ),
						'one' => q({0} ଓଜ୍ ଟ୍ରୋ),
						'other' => q({0} ଓଜ୍ ଟ୍ରୋ),
					},
					# Long Unit Identifier
					'mass-pound' => {
						'name' => q(ପାଉଣ୍ଡ୍),
						'one' => q({0} ପାଉଣ୍ଡ୍),
						'other' => q({0} ପାଉଣ୍ଡ୍),
						'per' => q({0}/ପାଉଣ୍ଡ୍),
					},
					# Core Unit Identifier
					'pound' => {
						'name' => q(ପାଉଣ୍ଡ୍),
						'one' => q({0} ପାଉଣ୍ଡ୍),
						'other' => q({0} ପାଉଣ୍ଡ୍),
						'per' => q({0}/ପାଉଣ୍ଡ୍),
					},
					# Long Unit Identifier
					'mass-solar-mass' => {
						'name' => q(ସୋଲର ମାସେସ),
					},
					# Core Unit Identifier
					'solar-mass' => {
						'name' => q(ସୋଲର ମାସେସ),
					},
					# Long Unit Identifier
					'mass-stone' => {
						'name' => q(ଷ୍ଟୋନସ୍),
						'one' => q({0} ଷ୍ଟ.),
						'other' => q({0} ଷ୍ଟ.),
					},
					# Core Unit Identifier
					'stone' => {
						'name' => q(ଷ୍ଟୋନସ୍),
						'one' => q({0} ଷ୍ଟ.),
						'other' => q({0} ଷ୍ଟ.),
					},
					# Long Unit Identifier
					'mass-ton' => {
						'one' => q({0} ଟନ୍),
						'other' => q({0} ଟନ୍),
					},
					# Core Unit Identifier
					'ton' => {
						'one' => q({0} ଟନ୍),
						'other' => q({0} ଟନ୍),
					},
					# Long Unit Identifier
					'mass-tonne' => {
						'name' => q(ଟ),
						'one' => q({0} ଟ),
						'other' => q({0} ଟ),
					},
					# Core Unit Identifier
					'tonne' => {
						'name' => q(ଟ),
						'one' => q({0} ଟ),
						'other' => q({0} ଟ),
					},
					# Long Unit Identifier
					'power-gigawatt' => {
						'name' => q(ଗିୱା),
						'one' => q({0} ଗିୱା),
						'other' => q({0} ଗିୱା),
					},
					# Core Unit Identifier
					'gigawatt' => {
						'name' => q(ଗିୱା),
						'one' => q({0} ଗିୱା),
						'other' => q({0} ଗିୱା),
					},
					# Long Unit Identifier
					'power-horsepower' => {
						'name' => q(ଏଚପି),
						'one' => q({0} ଏଚପି),
						'other' => q({0} ଏଚପି),
					},
					# Core Unit Identifier
					'horsepower' => {
						'name' => q(ଏଚପି),
						'one' => q({0} ଏଚପି),
						'other' => q({0} ଏଚପି),
					},
					# Long Unit Identifier
					'power-kilowatt' => {
						'name' => q(କିୱା),
						'one' => q({0} କିୱା),
						'other' => q({0} କିୱା),
					},
					# Core Unit Identifier
					'kilowatt' => {
						'name' => q(କିୱା),
						'one' => q({0} କିୱା),
						'other' => q({0} କିୱା),
					},
					# Long Unit Identifier
					'power-megawatt' => {
						'name' => q(ମେୱା),
						'one' => q({0} ମେୱା),
						'other' => q({0} ମେୱା),
					},
					# Core Unit Identifier
					'megawatt' => {
						'name' => q(ମେୱା),
						'one' => q({0} ମେୱା),
						'other' => q({0} ମେୱା),
					},
					# Long Unit Identifier
					'power-milliwatt' => {
						'name' => q(ମିୱା),
						'one' => q({0} ମିୱା),
						'other' => q({0} ମିୱା),
					},
					# Core Unit Identifier
					'milliwatt' => {
						'name' => q(ମିୱା),
						'one' => q({0} ମିୱା),
						'other' => q({0} ମିୱା),
					},
					# Long Unit Identifier
					'power-watt' => {
						'name' => q(ୱାଟ୍),
						'one' => q({0} ୱା),
						'other' => q({0} ୱା),
					},
					# Core Unit Identifier
					'watt' => {
						'name' => q(ୱାଟ୍),
						'one' => q({0} ୱା),
						'other' => q({0} ୱା),
					},
					# Long Unit Identifier
					'pressure-bar' => {
						'name' => q(ବାର୍‌),
						'one' => q({0} ବାର୍‌),
						'other' => q({0} ବାର୍‌),
					},
					# Core Unit Identifier
					'bar' => {
						'name' => q(ବାର୍‌),
						'one' => q({0} ବାର୍‌),
						'other' => q({0} ବାର୍‌),
					},
					# Long Unit Identifier
					'pressure-millimeter-ofhg' => {
						'name' => q(mmHg),
						'one' => q({0} mmHg),
						'other' => q({0} mmHg),
					},
					# Core Unit Identifier
					'millimeter-ofhg' => {
						'name' => q(mmHg),
						'one' => q({0} mmHg),
						'other' => q({0} mmHg),
					},
					# Long Unit Identifier
					'pressure-pascal' => {
						'name' => q(ପା),
						'one' => q({0} ପା),
						'other' => q({0} ପା),
					},
					# Core Unit Identifier
					'pascal' => {
						'name' => q(ପା),
						'one' => q({0} ପା),
						'other' => q({0} ପା),
					},
					# Long Unit Identifier
					'speed-kilometer-per-hour' => {
						'name' => q(କିମି/ଘଣ୍ଟା),
						'one' => q({0} କେପିଏଚ୍),
						'other' => q({0} କେପିଏଚ୍),
					},
					# Core Unit Identifier
					'kilometer-per-hour' => {
						'name' => q(କିମି/ଘଣ୍ଟା),
						'one' => q({0} କେପିଏଚ୍),
						'other' => q({0} କେପିଏଚ୍),
					},
					# Long Unit Identifier
					'speed-knot' => {
						'name' => q(ନଟ୍),
						'one' => q({0} ନଟ୍),
						'other' => q({0} ନଟ୍),
					},
					# Core Unit Identifier
					'knot' => {
						'name' => q(ନଟ୍),
						'one' => q({0} ନଟ୍),
						'other' => q({0} ନଟ୍),
					},
					# Long Unit Identifier
					'speed-light-speed' => {
						'name' => q(ଆଲୋକ),
						'one' => q({0} ଆଲୋକ),
						'other' => q({0} ଆଲୋକ),
					},
					# Core Unit Identifier
					'light-speed' => {
						'name' => q(ଆଲୋକ),
						'one' => q({0} ଆଲୋକ),
						'other' => q({0} ଆଲୋକ),
					},
					# Long Unit Identifier
					'speed-meter-per-second' => {
						'name' => q(ମିଟର୍/ସେ),
						'one' => q({0} ମି/ସେ),
						'other' => q({0} ମି/ସେ),
					},
					# Core Unit Identifier
					'meter-per-second' => {
						'name' => q(ମିଟର୍/ସେ),
						'one' => q({0} ମି/ସେ),
						'other' => q({0} ମି/ସେ),
					},
					# Long Unit Identifier
					'speed-mile-per-hour' => {
						'name' => q(ମାଇଲ୍/ଘଣ୍ଟା),
						'one' => q({0} ଏମପିଏଚ୍),
						'other' => q({0} ଏମପିଏଚ୍),
					},
					# Core Unit Identifier
					'mile-per-hour' => {
						'name' => q(ମାଇଲ୍/ଘଣ୍ଟା),
						'one' => q({0} ଏମପିଏଚ୍),
						'other' => q({0} ଏମପିଏଚ୍),
					},
					# Long Unit Identifier
					'temperature-celsius' => {
						'name' => q(ଡି. ସେ),
						'one' => q({0}°ସେ),
						'other' => q({0}°ସେ),
					},
					# Core Unit Identifier
					'celsius' => {
						'name' => q(ଡି. ସେ),
						'one' => q({0}°ସେ),
						'other' => q({0}°ସେ),
					},
					# Long Unit Identifier
					'temperature-fahrenheit' => {
						'name' => q(ଡି. ଫା),
						'one' => q({0}°ଫା),
						'other' => q({0}°ଫା),
					},
					# Core Unit Identifier
					'fahrenheit' => {
						'name' => q(ଡି. ଫା),
						'one' => q({0}°ଫା),
						'other' => q({0}°ଫା),
					},
					# Long Unit Identifier
					'temperature-kelvin' => {
						'name' => q(କେ),
					},
					# Core Unit Identifier
					'kelvin' => {
						'name' => q(କେ),
					},
					# Long Unit Identifier
					'volume-acre-foot' => {
						'name' => q(ଏକର ଫିଟ୍),
						'one' => q({0} ଏକର-ଫିଟ୍),
						'other' => q({0} ଏକର-ଫିଟ୍),
					},
					# Core Unit Identifier
					'acre-foot' => {
						'name' => q(ଏକର ଫିଟ୍),
						'one' => q({0} ଏକର-ଫିଟ୍),
						'other' => q({0} ଏକର-ଫିଟ୍),
					},
					# Long Unit Identifier
					'volume-barrel' => {
						'name' => q(ବାରେଲ),
					},
					# Core Unit Identifier
					'barrel' => {
						'name' => q(ବାରେଲ),
					},
					# Long Unit Identifier
					'volume-centiliter' => {
						'name' => q(ସେଲି),
						'one' => q({0} ସେଲି),
						'other' => q({0} ସେଲି),
					},
					# Core Unit Identifier
					'centiliter' => {
						'name' => q(ସେଲି),
						'one' => q({0} ସେଲି),
						'other' => q({0} ସେଲି),
					},
					# Long Unit Identifier
					'volume-cubic-centimeter' => {
						'name' => q(ସେମି³),
						'one' => q({0} ସେମି³),
						'other' => q({0} ସେମି³),
						'per' => q({0}/ସେମି³),
					},
					# Core Unit Identifier
					'cubic-centimeter' => {
						'name' => q(ସେମି³),
						'one' => q({0} ସେମି³),
						'other' => q({0} ସେମି³),
						'per' => q({0}/ସେମି³),
					},
					# Long Unit Identifier
					'volume-cubic-foot' => {
						'name' => q(ଫିଟ୍³),
						'one' => q({0} ଫିଟ୍³),
						'other' => q({0} ଫିଟ୍³),
					},
					# Core Unit Identifier
					'cubic-foot' => {
						'name' => q(ଫିଟ୍³),
						'one' => q({0} ଫିଟ୍³),
						'other' => q({0} ଫିଟ୍³),
					},
					# Long Unit Identifier
					'volume-cubic-inch' => {
						'name' => q(ଇଞ୍ଚ୍³),
						'one' => q({0} ଇଞ୍ଚ୍³),
						'other' => q({0} ଇଞ୍ଚ୍³),
					},
					# Core Unit Identifier
					'cubic-inch' => {
						'name' => q(ଇଞ୍ଚ୍³),
						'one' => q({0} ଇଞ୍ଚ୍³),
						'other' => q({0} ଇଞ୍ଚ୍³),
					},
					# Long Unit Identifier
					'volume-cubic-kilometer' => {
						'name' => q(କିମି³),
						'one' => q({0} କିମି³),
						'other' => q({0} କିମି³),
					},
					# Core Unit Identifier
					'cubic-kilometer' => {
						'name' => q(କିମି³),
						'one' => q({0} କିମି³),
						'other' => q({0} କିମି³),
					},
					# Long Unit Identifier
					'volume-cubic-meter' => {
						'name' => q(ମି³),
						'one' => q({0} ମି³),
						'other' => q({0} ମି³),
						'per' => q({0}/ମି³),
					},
					# Core Unit Identifier
					'cubic-meter' => {
						'name' => q(ମି³),
						'one' => q({0} ମି³),
						'other' => q({0} ମି³),
						'per' => q({0}/ମି³),
					},
					# Long Unit Identifier
					'volume-cubic-mile' => {
						'name' => q(ମା³),
						'one' => q({0} ମା³),
						'other' => q({0} ମା³),
					},
					# Core Unit Identifier
					'cubic-mile' => {
						'name' => q(ମା³),
						'one' => q({0} ମା³),
						'other' => q({0} ମା³),
					},
					# Long Unit Identifier
					'volume-cubic-yard' => {
						'name' => q(ୟାର୍ଡ୍³),
						'one' => q({0} yd³),
						'other' => q({0} yd³),
					},
					# Core Unit Identifier
					'cubic-yard' => {
						'name' => q(ୟାର୍ଡ୍³),
						'one' => q({0} yd³),
						'other' => q({0} yd³),
					},
					# Long Unit Identifier
					'volume-cup' => {
						'name' => q(କପ୍),
						'one' => q({0} କ),
						'other' => q({0} କ),
					},
					# Core Unit Identifier
					'cup' => {
						'name' => q(କପ୍),
						'one' => q({0} କ),
						'other' => q({0} କ),
					},
					# Long Unit Identifier
					'volume-cup-metric' => {
						'one' => q({0} ମେକ),
						'other' => q({0} ମେକ),
					},
					# Core Unit Identifier
					'cup-metric' => {
						'one' => q({0} ମେକ),
						'other' => q({0} ମେକ),
					},
					# Long Unit Identifier
					'volume-deciliter' => {
						'name' => q(ଡେଲି),
						'one' => q({0} ଡେଲି),
						'other' => q({0} ଡେଲି),
					},
					# Core Unit Identifier
					'deciliter' => {
						'name' => q(ଡେଲି),
						'one' => q({0} ଡେଲି),
						'other' => q({0} ଡେଲି),
					},
					# Long Unit Identifier
					'volume-dessert-spoon-imperial' => {
						'one' => q({0} dsp-Imp.),
						'other' => q({0} dsp-Imp.),
					},
					# Core Unit Identifier
					'dessert-spoon-imperial' => {
						'one' => q({0} dsp-Imp.),
						'other' => q({0} dsp-Imp.),
					},
					# Long Unit Identifier
					'volume-fluid-ounce' => {
						'name' => q(ଫ୍ଲୁ ଓଜ୍),
						'one' => q({0} ଫ୍ଲୁ ଓଜ୍),
						'other' => q({0} ଫ୍ଲୁ ଓଜ୍),
					},
					# Core Unit Identifier
					'fluid-ounce' => {
						'name' => q(ଫ୍ଲୁ ଓଜ୍),
						'one' => q({0} ଫ୍ଲୁ ଓଜ୍),
						'other' => q({0} ଫ୍ଲୁ ଓଜ୍),
					},
					# Long Unit Identifier
					'volume-fluid-ounce-imperial' => {
						'name' => q(ଇମ୍ପ. ଏଫଏଲ ଓଜେ),
					},
					# Core Unit Identifier
					'fluid-ounce-imperial' => {
						'name' => q(ଇମ୍ପ. ଏଫଏଲ ଓଜେ),
					},
					# Long Unit Identifier
					'volume-gallon' => {
						'name' => q(ଗ୍ୟାଲ୍),
						'one' => q({0} ଗ୍ୟାଲ୍),
						'other' => q({0} ଗ୍ୟାଲ୍),
						'per' => q({0}/ଗ୍ୟାଲ୍ ଯୁକ୍ତରାଷ୍ଟ୍ର),
					},
					# Core Unit Identifier
					'gallon' => {
						'name' => q(ଗ୍ୟାଲ୍),
						'one' => q({0} ଗ୍ୟାଲ୍),
						'other' => q({0} ଗ୍ୟାଲ୍),
						'per' => q({0}/ଗ୍ୟାଲ୍ ଯୁକ୍ତରାଷ୍ଟ୍ର),
					},
					# Long Unit Identifier
					'volume-gallon-imperial' => {
						'name' => q(ଇମ୍ପେ. ଗ୍ୟା),
						'one' => q({0} ଇମ୍ପେ. ଗ୍ୟା),
						'other' => q({0} ଇମ୍ପେ. ଗ୍ୟା),
						'per' => q({0}/ଇମ୍ପେ. ଗ୍ୟା),
					},
					# Core Unit Identifier
					'gallon-imperial' => {
						'name' => q(ଇମ୍ପେ. ଗ୍ୟା),
						'one' => q({0} ଇମ୍ପେ. ଗ୍ୟା),
						'other' => q({0} ଇମ୍ପେ. ଗ୍ୟା),
						'per' => q({0}/ଇମ୍ପେ. ଗ୍ୟା),
					},
					# Long Unit Identifier
					'volume-hectoliter' => {
						'name' => q(ହେଲି),
						'one' => q({0} ହେଲି),
						'other' => q({0} ହେଲି),
					},
					# Core Unit Identifier
					'hectoliter' => {
						'name' => q(ହେଲି),
						'one' => q({0} ହେଲି),
						'other' => q({0} ହେଲି),
					},
					# Long Unit Identifier
					'volume-liter' => {
						'name' => q(ଲିଟର୍),
						'one' => q({0} ଲି),
						'other' => q({0} ଲି),
						'per' => q({0}/ଲି),
					},
					# Core Unit Identifier
					'liter' => {
						'name' => q(ଲିଟର୍),
						'one' => q({0} ଲି),
						'other' => q({0} ଲି),
						'per' => q({0}/ଲି),
					},
					# Long Unit Identifier
					'volume-megaliter' => {
						'name' => q(ଏମଏଲ୍),
						'one' => q({0} ଏମଏଲ୍),
						'other' => q({0} ଏମଏଲ୍),
					},
					# Core Unit Identifier
					'megaliter' => {
						'name' => q(ଏମଏଲ୍),
						'one' => q({0} ଏମଏଲ୍),
						'other' => q({0} ଏମଏଲ୍),
					},
					# Long Unit Identifier
					'volume-milliliter' => {
						'name' => q(ମିଲି),
						'one' => q({0} ମିଲି),
						'other' => q({0} ମିଲି),
					},
					# Core Unit Identifier
					'milliliter' => {
						'name' => q(ମିଲି),
						'one' => q({0} ମିଲି),
						'other' => q({0} ମିଲି),
					},
					# Long Unit Identifier
					'volume-pint' => {
						'name' => q(ପାଇଣ୍ଟ୍),
						'one' => q({0} ପାଇଣ୍ଟ୍),
						'other' => q({0} ପାଇଣ୍ଟ୍),
					},
					# Core Unit Identifier
					'pint' => {
						'name' => q(ପାଇଣ୍ଟ୍),
						'one' => q({0} ପାଇଣ୍ଟ୍),
						'other' => q({0} ପାଇଣ୍ଟ୍),
					},
					# Long Unit Identifier
					'volume-pint-metric' => {
						'name' => q(ମେପା),
						'one' => q({0} mpt),
						'other' => q({0} mpt),
					},
					# Core Unit Identifier
					'pint-metric' => {
						'name' => q(ମେପା),
						'one' => q({0} mpt),
						'other' => q({0} mpt),
					},
					# Long Unit Identifier
					'volume-quart' => {
						'name' => q(କ୍ଵାର୍ଟ୍),
						'one' => q({0} କ୍ଵାର୍ଟ୍),
						'other' => q({0} କ୍ଵାର୍ଟ୍),
					},
					# Core Unit Identifier
					'quart' => {
						'name' => q(କ୍ଵାର୍ଟ୍),
						'one' => q({0} କ୍ଵାର୍ଟ୍),
						'other' => q({0} କ୍ଵାର୍ଟ୍),
					},
					# Long Unit Identifier
					'volume-tablespoon' => {
						'name' => q(ଖାଇବା ଚାମଚ),
						'one' => q({0} ଖାଇବା ଚାମଚ),
						'other' => q({0} ଖାଇବା ଚାମଚ),
					},
					# Core Unit Identifier
					'tablespoon' => {
						'name' => q(ଖାଇବା ଚାମଚ),
						'one' => q({0} ଖାଇବା ଚାମଚ),
						'other' => q({0} ଖାଇବା ଚାମଚ),
					},
					# Long Unit Identifier
					'volume-teaspoon' => {
						'name' => q(ଛୋଟ ଚାମଚ),
						'one' => q({0} tsp),
						'other' => q({0} tsp),
					},
					# Core Unit Identifier
					'teaspoon' => {
						'name' => q(ଛୋଟ ଚାମଚ),
						'one' => q({0} tsp),
						'other' => q({0} tsp),
					},
				},
			} }
);

has 'yesstr' => (
	is			=> 'ro',
	isa			=> RegexpRef,
	init_arg	=> undef,
	default		=> sub { qr'^(?i:ହଁ|yes|y)$' }
);

has 'nostr' => (
	is			=> 'ro',
	isa			=> RegexpRef,
	init_arg	=> undef,
	default		=> sub { qr'^(?i:ନା|no|n)$' }
);

has 'listPatterns' => (
	is			=> 'ro',
	isa			=> HashRef,
	init_arg	=> undef,
	default		=> sub { {
				end => q({0}, ଓ {1}),
				2 => q({0} ଓ {1}),
		} }
);

has native_numbering_system => (
	is			=> 'ro',
	isa			=> Str,
	init_arg	=> undef,
	default		=> 'orya',
);

has 'number_formats' => (
	is			=> 'ro',
	isa			=> HashRef,
	init_arg	=> undef,
	default		=> sub { {
		decimalFormat => {
			'default' => {
				'1000' => {
					'one' => '0ହ',
					'other' => '0ହ',
				},
				'10000' => {
					'one' => '00ହ',
					'other' => '00ହ',
				},
				'100000' => {
					'one' => '000ହ',
					'other' => '000ହ',
				},
				'1000000' => {
					'one' => '0ନି',
					'other' => '0ନି',
				},
				'10000000' => {
					'one' => '00ନି',
					'other' => '00ନି',
				},
				'100000000' => {
					'one' => '000ନି',
					'other' => '000ନି',
				},
				'1000000000' => {
					'one' => '0ବି',
					'other' => '0ବି',
				},
				'10000000000' => {
					'one' => '00ବି',
					'other' => '00ବି',
				},
				'100000000000' => {
					'one' => '000ବି',
					'other' => '000ବି',
				},
				'1000000000000' => {
					'one' => '0ଟ୍ରି',
					'other' => '0ଟ୍ରି',
				},
				'10000000000000' => {
					'one' => '00ଟ୍ରି',
					'other' => '00ଟ୍ରି',
				},
				'100000000000000' => {
					'one' => '000ଟ୍ରି',
					'other' => '000ଟ୍ରି',
				},
				'standard' => {
					'default' => '#,##,##0.###',
				},
			},
			'long' => {
				'1000' => {
					'one' => '0 ହଜାର',
					'other' => '0 ହଜାର',
				},
				'10000' => {
					'one' => '00 ହଜାର',
					'other' => '00 ହଜାର',
				},
				'100000' => {
					'one' => '000 ହଜାର',
					'other' => '000 ହଜାର',
				},
				'1000000' => {
					'one' => '0 ନିୟୁତ',
					'other' => '0 ନିୟୁତ',
				},
				'10000000' => {
					'one' => '00 ନିୟୁତ',
					'other' => '00 ନିୟୁତ',
				},
				'100000000' => {
					'one' => '000 ନିୟୁତ',
					'other' => '000 ନିୟୁତ',
				},
				'1000000000' => {
					'one' => '0 ଶହକୋଟି',
					'other' => '0 ଶହକୋଟି',
				},
				'10000000000' => {
					'one' => '00 ଶହକୋଟି',
					'other' => '00 ଶହକୋଟି',
				},
				'100000000000' => {
					'one' => '000 ଶହକୋଟି',
					'other' => '000 ଶହକୋଟି',
				},
				'1000000000000' => {
					'one' => '0 ଲକ୍ଷକୋଟି',
					'other' => '0 ଲକ୍ଷକୋଟି',
				},
				'10000000000000' => {
					'one' => '00 ଲକ୍ଷକୋଟି',
					'other' => '00 ଲକ୍ଷକୋଟି',
				},
				'100000000000000' => {
					'one' => '000 ଲକ୍ଷକୋଟି',
					'other' => '000 ଲକ୍ଷକୋଟି',
				},
			},
			'short' => {
				'1000' => {
					'one' => '0ହ',
					'other' => '0ହ',
				},
				'10000' => {
					'one' => '00ହ',
					'other' => '00ହ',
				},
				'100000' => {
					'one' => '000ହ',
					'other' => '000ହ',
				},
				'1000000' => {
					'one' => '0ନି',
					'other' => '0ନି',
				},
				'10000000' => {
					'one' => '00ନି',
					'other' => '00ନି',
				},
				'100000000' => {
					'one' => '000ନି',
					'other' => '000ନି',
				},
				'1000000000' => {
					'one' => '0ବି',
					'other' => '0ବି',
				},
				'10000000000' => {
					'one' => '00ବି',
					'other' => '00ବି',
				},
				'100000000000' => {
					'one' => '000ବି',
					'other' => '000ବି',
				},
				'1000000000000' => {
					'one' => '0ଟ୍ରି',
					'other' => '0ଟ୍ରି',
				},
				'10000000000000' => {
					'one' => '00ଟ୍ରି',
					'other' => '00ଟ୍ରି',
				},
				'100000000000000' => {
					'one' => '000ଟ୍ରି',
					'other' => '000ଟ୍ରି',
				},
			},
		},
} },
);

has 'number_currency_formats' => (
	is			=> 'ro',
	isa			=> HashRef,
	init_arg	=> undef,
	default		=> sub { {
		'latn' => {
			'pattern' => {
				'default' => {
					'accounting' => {
						'negative' => '(¤#,##0.00)',
						'positive' => '¤#,##0.00',
					},
					'standard' => {
						'positive' => '¤#,##0.00',
					},
				},
			},
		},
} },
);

has 'currencies' => (
	is			=> 'ro',
	isa			=> HashRef,
	init_arg	=> undef,
	default		=> sub { {
		'AED' => {
			display_name => {
				'currency' => q(ଯୁକ୍ତ ଆରବ ଏମିରେଟସ୍ ଦିରହାମ୍),
				'one' => q(UAE ଦିରହାମ୍),
				'other' => q(UAE ଦିରହାମ୍),
			},
		},
		'AFN' => {
			display_name => {
				'currency' => q(ଆଫଗାନ ଆଫଗାନି),
			},
		},
		'ALL' => {
			display_name => {
				'currency' => q(ଆଲବାନିୟ ଲେକ୍),
			},
		},
		'AMD' => {
			display_name => {
				'currency' => q(ଅର୍ମେନୀୟ ଡ୍ରାମ୍),
			},
		},
		'ANG' => {
			display_name => {
				'currency' => q(ନେଦରଲ୍ୟାଣ୍ଡ୍ ଆଣ୍ଟିଲିୟ ଗିଲଡର୍),
			},
		},
		'AOA' => {
			display_name => {
				'currency' => q(ଅଙ୍ଗୋଲୀୟ କୱାନଜା),
			},
		},
		'ARS' => {
			display_name => {
				'currency' => q(ଆର୍ଜେଣ୍ଟାଇନ୍‍ ପେସୋ),
			},
		},
		'AUD' => {
			display_name => {
				'currency' => q(ଅଷ୍ଟ୍ରେଲିୟ ଡଲାର୍),
			},
		},
		'AWG' => {
			display_name => {
				'currency' => q(ଆରୁବୀୟ ଫ୍ଲୋରିନ୍),
			},
		},
		'AZN' => {
			display_name => {
				'currency' => q(ଆଜେରବାଇଜାନି ମନତ୍),
			},
		},
		'BAM' => {
			display_name => {
				'currency' => q(ବୋସନିଆ-ହର୍ଜଗୋଭିନା କନଭର୍ଟିବଲ୍ ମାର୍କ୍),
			},
		},
		'BBD' => {
			display_name => {
				'currency' => q(ବାର୍ବାଡୀୟ ଡଲାର୍),
			},
		},
		'BDT' => {
			display_name => {
				'currency' => q(ବଙ୍ଗଳାଦେଶୀ ଟାକା),
			},
		},
		'BGN' => {
			display_name => {
				'currency' => q(ବୁଲଗେରୀୟ ଲେଭ୍),
			},
		},
		'BHD' => {
			display_name => {
				'currency' => q(ବାଃରେନି ଦିନାର୍),
			},
		},
		'BIF' => {
			display_name => {
				'currency' => q(ବୁରୁଣ୍ଡିୟ ଫ୍ରାଙ୍କ୍),
			},
		},
		'BMD' => {
			display_name => {
				'currency' => q(ବର୍ମ୍ୟୁଡା ଡଲାର୍),
			},
		},
		'BND' => {
			display_name => {
				'currency' => q(ବ୍ରୁନେଇ ଡଲାର୍),
			},
		},
		'BOB' => {
			display_name => {
				'currency' => q(ବୋଲିଭୀୟ ବୋଲିଭିଆନୋ),
			},
		},
		'BRL' => {
			display_name => {
				'currency' => q(ବ୍ରାଜିଲୀୟ ରିଏଲ୍),
			},
		},
		'BSD' => {
			display_name => {
				'currency' => q(ବାହାମୀୟ ଡଲାର୍),
			},
		},
		'BTN' => {
			display_name => {
				'currency' => q(ଭୁଟାନୀ ଗଲଟ୍ରୁମ୍),
			},
		},
		'BWP' => {
			display_name => {
				'currency' => q(ବୋତ୍ସୱାନା ପୁଲା),
			},
		},
		'BYN' => {
			symbol => 'р.',
			display_name => {
				'currency' => q(ବେଲାରୁସି ରୁବଲ୍),
			},
		},
		'BZD' => {
			display_name => {
				'currency' => q(ବେଲିଜ୍ ଡଲାର୍),
			},
		},
		'CAD' => {
			display_name => {
				'currency' => q(କାନେଡିୟ ଡଲାର୍),
			},
		},
		'CDF' => {
			display_name => {
				'currency' => q(କଙ୍ଗୋଲିଜ୍ ଫ୍ରାଙ୍କ୍),
			},
		},
		'CHF' => {
			display_name => {
				'currency' => q(ସୁଇସ୍ ଫ୍ରାଙ୍କ୍),
			},
		},
		'CLP' => {
			display_name => {
				'currency' => q(ଚିଲି ପେସୋ),
			},
		},
		'CNH' => {
			display_name => {
				'currency' => q(ଚିନୀ ୟୁଆନ୍ \(ଅଫସୋର୍\)),
				'one' => q(ଚିନୀ ୟୁଆନ୍ \(ଉପକୂଳବର୍ତ୍ତୀ\)),
				'other' => q(ଚିନୀ ୟୁଆନ୍ \(ଅଫସୋର୍\)),
			},
		},
		'CNY' => {
			display_name => {
				'currency' => q(ଚିନୀ ୟୁଆନ୍),
			},
		},
		'COP' => {
			display_name => {
				'currency' => q(କଲୋମ୍ବୀୟ ପେସୋ),
			},
		},
		'CRC' => {
			display_name => {
				'currency' => q(କୋଷ୍ଟା ରିକୀୟ କୋଲୋନ୍),
			},
		},
		'CUC' => {
			display_name => {
				'currency' => q(କ୍ୟୁବାନ୍ କନଭର୍ଟିବଲ୍ ପେସୋ),
			},
		},
		'CUP' => {
			display_name => {
				'currency' => q(କ୍ୟୁବାନ୍ ପେସୋ),
			},
		},
		'CVE' => {
			display_name => {
				'currency' => q(କେପ୍ ଭେର୍ଦେୟ ଏସ୍କୁଡୋ),
			},
		},
		'CZK' => {
			display_name => {
				'currency' => q(ଚେକ୍ କୋରୁନା),
			},
		},
		'DJF' => {
			display_name => {
				'currency' => q(ଜିବୌଟିୟ ଫ୍ରାଙ୍କ୍),
			},
		},
		'DKK' => {
			display_name => {
				'currency' => q(ଡାନିସ୍ କ୍ରୋନ୍),
			},
		},
		'DOP' => {
			display_name => {
				'currency' => q(ଡୋମିନିକୀୟ ପେସୋ),
			},
		},
		'DZD' => {
			display_name => {
				'currency' => q(ଆଲଜେରୀୟ ଦିନାର୍),
			},
		},
		'EGP' => {
			display_name => {
				'currency' => q(ଇଜିପ୍ଟିୟ ପାଉଣ୍ଡ୍),
			},
		},
		'ERN' => {
			display_name => {
				'currency' => q(ଏରିଟ୍ରେୟ ନାକଫା),
			},
		},
		'ETB' => {
			display_name => {
				'currency' => q(ଇଥିଓପିୟ ବିର୍),
			},
		},
		'EUR' => {
			display_name => {
				'currency' => q(ୟୁରୋ),
			},
		},
		'FJD' => {
			display_name => {
				'currency' => q(ଫିଜି ଡଲାର୍),
			},
		},
		'FKP' => {
			display_name => {
				'currency' => q(ଫକଲ୍ୟାଣ୍ଡ୍ ଦ୍ଵୀପପୁଞ୍ଜ ପାଉଣ୍ଡ୍),
			},
		},
		'GBP' => {
			display_name => {
				'currency' => q(ବ୍ରିଟିଶ୍ ପାଉଣ୍ଡ୍),
			},
		},
		'GEL' => {
			display_name => {
				'currency' => q(ଜର୍ଜିୟ ଲାରି),
			},
		},
		'GHS' => {
			display_name => {
				'currency' => q(ଘାନିୟ ସେଡି),
			},
		},
		'GIP' => {
			display_name => {
				'currency' => q(ଗିବ୍ରାଲଟର୍ ପାଉଣ୍ଡ୍),
			},
		},
		'GMD' => {
			display_name => {
				'currency' => q(ଗାମ୍ବିୟ ଡାଲାସି),
			},
		},
		'GNF' => {
			display_name => {
				'currency' => q(ଗୁଇନେୟ ଫ୍ରାଙ୍କ୍),
			},
		},
		'GTQ' => {
			display_name => {
				'currency' => q(ଗୁଏଟମାଲୀୟ କ୍ଵେତଜାଲ୍),
			},
		},
		'GYD' => {
			display_name => {
				'currency' => q(ଗାୟାନିସ୍ ଡଲାର୍),
			},
		},
		'HKD' => {
			display_name => {
				'currency' => q(ହଂ କଂ ଡଲାର୍),
			},
		},
		'HNL' => {
			display_name => {
				'currency' => q(ହୋଣ୍ଡୁରୀୟ ଲେମପିରା),
			},
		},
		'HRK' => {
			display_name => {
				'currency' => q(କ୍ରୋଏସୀୟ କୁନା),
			},
		},
		'HTG' => {
			display_name => {
				'currency' => q(ହାଇତୀୟ ଗୋରଡ୍),
			},
		},
		'HUF' => {
			display_name => {
				'currency' => q(ହଙ୍ଗେରିୟ ଫୋରିଣ୍ଟ୍),
			},
		},
		'IDR' => {
			display_name => {
				'currency' => q(ଇଣ୍ଡୋନେସିୟ ରୁପିଆ),
			},
		},
		'ILS' => {
			display_name => {
				'currency' => q(ଇସ୍ରାଇଲି ନ୍ୟୁ ଶେକେଲ୍),
			},
		},
		'INR' => {
			display_name => {
				'currency' => q(ଭାରତୀୟ ଟଙ୍କା),
			},
		},
		'IQD' => {
			display_name => {
				'currency' => q(ଇରାକି ଦିନାର୍),
			},
		},
		'IRR' => {
			display_name => {
				'currency' => q(ଇରାନୀ ରିଆଲ୍),
			},
		},
		'ISK' => {
			display_name => {
				'currency' => q(ଆଇସଲ୍ୟାଣ୍ଡିକ୍‍ କ୍ରୋନା),
			},
		},
		'JMD' => {
			display_name => {
				'currency' => q(ଜାମାଇକୀୟ ଡଲାର୍),
			},
		},
		'JOD' => {
			display_name => {
				'currency' => q(ଜର୍ଡାନିୟ ଦିନାର୍),
			},
		},
		'JPY' => {
			symbol => '¥',
			display_name => {
				'currency' => q(ଜାପାନୀ ୟେନ୍),
			},
		},
		'KES' => {
			display_name => {
				'currency' => q(କେନିୟ ଶିଲିଂ),
			},
		},
		'KGS' => {
			display_name => {
				'currency' => q(କିର୍ଗିସ୍ତାନୀ ସୋମ୍),
			},
		},
		'KHR' => {
			display_name => {
				'currency' => q(କାମ୍ଵୋଡିୟ ରିଏଲ୍),
			},
		},
		'KMF' => {
			display_name => {
				'currency' => q(କୋମୋରୀୟ ଫ୍ରାଙ୍କ୍),
			},
		},
		'KPW' => {
			display_name => {
				'currency' => q(ଉତ୍ତର କୋରିଆଇ ୱୋନ୍),
			},
		},
		'KRW' => {
			display_name => {
				'currency' => q(ଦକ୍ଷିଣ କୋରିଆଇ ୱୋନ୍),
			},
		},
		'KWD' => {
			display_name => {
				'currency' => q(କୁୱେତି ଦିନାର୍),
			},
		},
		'KYD' => {
			display_name => {
				'currency' => q(କେମେନ୍ ଦ୍ଵୀପପୁଞ୍ଜ ଡଲାର୍),
			},
		},
		'KZT' => {
			display_name => {
				'currency' => q(କାଜାକସ୍ତାନୀ ତେଙ୍ଗେ),
			},
		},
		'LAK' => {
			display_name => {
				'currency' => q(ଲାଓଟିୟ କିପ୍),
			},
		},
		'LBP' => {
			display_name => {
				'currency' => q(ଲେବାନିଜ୍ ପାଉଣ୍ଡ୍),
			},
		},
		'LKR' => {
			display_name => {
				'currency' => q(ଶ୍ରୀଲଙ୍କିୟ ରୁପି),
			},
		},
		'LRD' => {
			display_name => {
				'currency' => q(ଲିବେରୀୟ ଡଲାର୍),
			},
		},
		'LSL' => {
			display_name => {
				'currency' => q(ଲେସୋଥୋ ଲୋଟି),
				'one' => q(ଲେସୋଥୋ ଲୋଟି),
				'other' => q(ଲେସୋଥୋ ଲୋଟିସ୍),
			},
		},
		'LYD' => {
			display_name => {
				'currency' => q(ଲିବ୍ୟ ଦିନାର୍),
			},
		},
		'MAD' => {
			display_name => {
				'currency' => q(ମୋରୋକୀୟ ଦିର୍ହାମ୍),
			},
		},
		'MDL' => {
			display_name => {
				'currency' => q(ମୋଲଡୋଭାନ୍ ଲେୟୁ),
			},
		},
		'MGA' => {
			display_name => {
				'currency' => q(ମାଲାଗାସି ଏରିଆରୀ),
			},
		},
		'MKD' => {
			display_name => {
				'currency' => q(ମାସେଡୋନୀୟ ଡିନର୍),
			},
		},
		'MMK' => {
			display_name => {
				'currency' => q(ମ୍ୟାନମାର୍ କ୍ୟାତ୍‌),
			},
		},
		'MNT' => {
			display_name => {
				'currency' => q(ମଙ୍ଗୋଲିୟ ତୁଗ୍ରିକ୍),
			},
		},
		'MOP' => {
			display_name => {
				'currency' => q(ମାକାନେଜ୍ ପାଟାକା),
			},
		},
		'MRO' => {
			display_name => {
				'currency' => q(ମର୍ଟିନିୟ ଆଗୁଇଅ \(1973–2017\)),
			},
		},
		'MRU' => {
			display_name => {
				'currency' => q(ମର୍ଟିନିୟ ଆଗୁଇଅ),
			},
		},
		'MUR' => {
			display_name => {
				'currency' => q(ମୌରିସୀୟ ରୁପି),
			},
		},
		'MVR' => {
			display_name => {
				'currency' => q(ମାଲଡିଭିୟ ରୁଫିୟା),
			},
		},
		'MWK' => {
			display_name => {
				'currency' => q(ମଲାୱି କ୍ୱାଚା),
			},
		},
		'MXN' => {
			display_name => {
				'currency' => q(ମେକ୍ସିକୀୟ ପେସୋ),
			},
		},
		'MYR' => {
			display_name => {
				'currency' => q(ମାଲେସିୟ ରିଙ୍ଗିଟ୍),
			},
		},
		'MZN' => {
			display_name => {
				'currency' => q(ମୋଜାମ୍ବିକୀୟ ମେଟିକାଲ୍),
			},
		},
		'NAD' => {
			display_name => {
				'currency' => q(ନାମିବିୟ ଡଲାର୍),
			},
		},
		'NGN' => {
			display_name => {
				'currency' => q(ନାଇଜେରିଆଇ ନାଇରା),
			},
		},
		'NIO' => {
			display_name => {
				'currency' => q(ନିକାରାଗୁଆ କୋର୍ଡୋବା),
			},
		},
		'NOK' => {
			display_name => {
				'currency' => q(ନରୱେୟୀୟ କ୍ରୋନ୍),
			},
		},
		'NPR' => {
			display_name => {
				'currency' => q(ନେପାଳି ରୁପି),
			},
		},
		'NZD' => {
			display_name => {
				'currency' => q(ନ୍ୟୁଜିଲ୍ୟାଣ୍ଡ୍ ଡଲାର୍),
			},
		},
		'OMR' => {
			display_name => {
				'currency' => q(ଓମାନି ରିଆଲ୍),
			},
		},
		'PAB' => {
			display_name => {
				'currency' => q(ପାନାମାନିୟ ବାଲବୋଆ),
			},
		},
		'PEN' => {
			display_name => {
				'currency' => q(ପେରୁଭୀୟ ସୋଲ୍),
			},
		},
		'PGK' => {
			display_name => {
				'currency' => q(ପପୁଆ ନ୍ୟୁ ଗୁଇନିୟ କିନା),
			},
		},
		'PHP' => {
			symbol => 'PHP',
			display_name => {
				'currency' => q(ଫିଲିପିନି ପେସୋ),
			},
		},
		'PKR' => {
			display_name => {
				'currency' => q(ପାକିସ୍ତାନୀ ରୁପି),
			},
		},
		'PLN' => {
			display_name => {
				'currency' => q(ପୋଲିଶ୍ ଜ୍ଲଟୀ),
			},
		},
		'PYG' => {
			display_name => {
				'currency' => q(ପାରାଗୁଆୟାନ୍ ଗୁଆରାନି),
			},
		},
		'QAR' => {
			display_name => {
				'currency' => q(କ୍ଵାତାରି ରିଆଲ୍),
			},
		},
		'RON' => {
			display_name => {
				'currency' => q(ରୋମାନିୟ ଲେଉ),
			},
		},
		'RSD' => {
			display_name => {
				'currency' => q(ସର୍ବିଆଇ ଦିନାର),
			},
		},
		'RUB' => {
			display_name => {
				'currency' => q(ରୁଷି ରୁବଲ୍),
			},
		},
		'RWF' => {
			display_name => {
				'currency' => q(ରୁୱାଣ୍ଡା ଫ୍ରାଙ୍କ୍),
			},
		},
		'SAR' => {
			display_name => {
				'currency' => q(ସୌଦି ରିୟାଲ୍),
			},
		},
		'SBD' => {
			display_name => {
				'currency' => q(ସୋଲୋମୋନ୍ ଦ୍ଵୀପପୁଞ୍ଜ ଡଲାର୍),
				'one' => q(ସୋଲୋମୋନ୍ ଦ୍ଵୀପପୁଞ୍ଜ ଡଲାର୍),
				'other' => q(ସୋଲୋମୋନ ଦ୍ଵୀପପୁଞ୍ଜ ଡଲାର୍),
			},
		},
		'SCR' => {
			display_name => {
				'currency' => q(ସେୟଚେଲୋଇସ୍ ରୁପି),
			},
		},
		'SDG' => {
			display_name => {
				'currency' => q(ସୁଦାନୀଜ ପାଉଣ୍ଡ୍),
				'one' => q(ସୁଦାନୀଜ ପାଉଣ୍ଡ୍),
				'other' => q(ସୁଦାନୀୟ ପାଉଣ୍ଡ୍),
			},
		},
		'SEK' => {
			display_name => {
				'currency' => q(ସ୍ୱେଡିଶ୍ କ୍ରୋନା),
			},
		},
		'SGD' => {
			display_name => {
				'currency' => q(ସିଙ୍ଗାପୁର୍ ଡଲାର୍),
			},
		},
		'SHP' => {
			display_name => {
				'currency' => q(ସେଣ୍ଟ୍. ହେଲେନା ପାଉଣ୍ଡ୍),
			},
		},
		'SLE' => {
			display_name => {
				'currency' => q(ସିଏରା ଲିଓନୀୟ ଲେଓନ୍),
			},
		},
		'SLL' => {
			display_name => {
				'currency' => q(ସିଏରା ଲିଓନୀୟ ଲେଓନ୍ \(1964—2022\)),
			},
		},
		'SOS' => {
			display_name => {
				'currency' => q(ସୋମାଲି ସିଲିଂ),
			},
		},
		'SRD' => {
			display_name => {
				'currency' => q(ସୁରିନାମିଜ୍ ଡଲାର୍),
			},
		},
		'SSP' => {
			display_name => {
				'currency' => q(ଦକ୍ଷିଣ ସୁଡାନିଜ୍‍ ପାଉଣ୍ଡ୍),
			},
		},
		'STD' => {
			display_name => {
				'currency' => q(ସାଓ ତୋମେ & ପ୍ରିସିପ୍ ଡୋବ୍ରା \(1977–2017\)),
			},
		},
		'STN' => {
			display_name => {
				'currency' => q(ସାଓ ତୋମେ & ପ୍ରିସିପ୍ ଡୋବ୍ରା),
			},
		},
		'SYP' => {
			display_name => {
				'currency' => q(ସିରିୟ ପାଉଣ୍ଡ୍),
			},
		},
		'SZL' => {
			display_name => {
				'currency' => q(ସ୍ଵାଜି ଲିଲାଞ୍ଜେନି),
				'one' => q(ସ୍ଵାଜି ଲିଲାଞ୍ଜେନି),
				'other' => q(ସ୍ଵାଜି ଇମାଲଞ୍ଜେନି),
			},
		},
		'THB' => {
			display_name => {
				'currency' => q(ଥାଇ ଭାଟ୍),
			},
		},
		'TJS' => {
			display_name => {
				'currency' => q(ତାଜିକିସ୍ତାନୀ ସୋମୋନି),
			},
		},
		'TMT' => {
			display_name => {
				'currency' => q(ତୁର୍କମେନିସ୍ତାନୀ ମନତ୍‌),
			},
		},
		'TND' => {
			display_name => {
				'currency' => q(ଟୁନେସିଆଇ ଦିନାର୍),
			},
		},
		'TOP' => {
			display_name => {
				'currency' => q(ତୋଙ୍ଗିୟ ପାଙ୍ଗା),
			},
		},
		'TRY' => {
			display_name => {
				'currency' => q(ତୁର୍କିୟ ଲିରା),
			},
		},
		'TTD' => {
			display_name => {
				'currency' => q(ତ୍ରିନିଦାଦ୍ ଏବଂ ଟୋବାଗୋ ଡଲାର୍),
			},
		},
		'TWD' => {
			display_name => {
				'currency' => q(ନ୍ୟୁ ତାଇୱାନ୍ ଡଲାର୍),
			},
		},
		'TZS' => {
			display_name => {
				'currency' => q(ତାନଜାନୀୟ ଶିଲିଂ),
			},
		},
		'UAH' => {
			display_name => {
				'currency' => q(ୟୁକ୍ରେନୀୟ ହ୍ରାଇଭନିଆ),
			},
		},
		'UGX' => {
			display_name => {
				'currency' => q(ଉଗାଣ୍ଡିୟ ଶିଲିଂ),
			},
		},
		'USD' => {
			symbol => '$',
			display_name => {
				'currency' => q(ଯୁକ୍ତରାଷ୍ଟ୍ର ଡଲାର୍),
			},
		},
		'UYU' => {
			display_name => {
				'currency' => q(ଉରୁଗୁଇୟାନ୍ ପେସୋ),
			},
		},
		'UZS' => {
			display_name => {
				'currency' => q(ଉଜବେକିସ୍ତାନୀ ସୋମ୍),
			},
		},
		'VEF' => {
			display_name => {
				'currency' => q(ଭେନେଜୁଏଲାନ୍ ବୋଲିଭାର୍ \(2008–2018\)),
			},
		},
		'VES' => {
			display_name => {
				'currency' => q(ଭେନେଜୁଏଲାନ୍ ବୋଲିଭାର୍),
			},
		},
		'VND' => {
			display_name => {
				'currency' => q(ଭୀଏତନାମୀୟ ଡଙ୍ଗ),
			},
		},
		'VUV' => {
			display_name => {
				'currency' => q(ଭାନୁଆଟୁ ଭାଟୁ),
			},
		},
		'WST' => {
			display_name => {
				'currency' => q(ସାମୋୟିୟ ତାଲା),
			},
		},
		'XAF' => {
			display_name => {
				'currency' => q(ମଧ୍ୟ ଆଫ୍ରିକୀ CFA ଫ୍ରାଙ୍କ୍),
			},
		},
		'XCD' => {
			display_name => {
				'currency' => q(ପୂର୍ବ କାରିବୀୟ ଡଲାର୍),
			},
		},
		'XOF' => {
			display_name => {
				'currency' => q(ପଶ୍ଚିମ ଆଫ୍ରିକିୟ CFA ଫ୍ରାଙ୍କ୍),
				'one' => q(ପଶ୍ଚିମ ଆଫ୍ରିକୀୟ CFA ଫ୍ରାଙ୍କ୍),
				'other' => q(ପଶ୍ଚିମ ଆଫ୍ରିକିୟ CFA ଫ୍ରାଙ୍କ୍),
			},
		},
		'XPF' => {
			display_name => {
				'currency' => q(CFP ଫ୍ରାଙ୍କ୍),
			},
		},
		'XXX' => {
			display_name => {
				'currency' => q(ଅଜଣା ମୁଦ୍ରା),
				'one' => q(\(ମୁଦ୍ରାର ଅଜଣା ଏକକ\)),
				'other' => q(\(ଅଜଣା ମୁଦ୍ରା\)),
			},
		},
		'YER' => {
			display_name => {
				'currency' => q(ୟେମେନି ରିଆଲ୍),
			},
		},
		'ZAR' => {
			display_name => {
				'currency' => q(ଦକ୍ଷିଣ ଆଫ୍ରିକିୟ ରାଣ୍ଡ୍),
			},
		},
		'ZMW' => {
			display_name => {
				'currency' => q(ଜାମ୍ବୀୟ କ୍ୱାଚା),
			},
		},
	} },
);


has 'calendar_months' => (
	is			=> 'ro',
	isa			=> HashRef,
	init_arg	=> undef,
	default		=> sub { {
			'gregorian' => {
				'format' => {
					wide => {
						nonleap => [
							'ଜାନୁଆରୀ',
							'ଫେବୃଆରୀ',
							'ମାର୍ଚ୍ଚ',
							'ଅପ୍ରେଲ',
							'ମଇ',
							'ଜୁନ',
							'ଜୁଲାଇ',
							'ଅଗଷ୍ଟ',
							'ସେପ୍ଟେମ୍ବର',
							'ଅକ୍ଟୋବର',
							'ନଭେମ୍ବର',
							'ଡିସେମ୍ବର'
						],
						leap => [
							
						],
					},
				},
				'stand-alone' => {
					narrow => {
						nonleap => [
							'ଜା',
							'ଫେ',
							'ମା',
							'ଅ',
							'ମଇ',
							'ଜୁ',
							'ଜୁ',
							'ଅ',
							'ସେ',
							'ଅ',
							'ନ',
							'ଡି'
						],
						leap => [
							
						],
					},
				},
			},
			'indian' => {
				'format' => {
					abbreviated => {
						nonleap => [
							'ଚୈତ୍ର',
							'ବୈଶାଖ',
							'ଜ୍ୟେଷ୍ଠ',
							'ଆଷାଢ଼',
							'ଶ୍ରାବଣ',
							'ଭାଦ୍ରବ',
							'ଆଶ୍ଵିନ',
							'କାର୍ତ୍ତିକ',
							'ମାର୍ଗଶିର',
							'ପୌଷ',
							'ମାଘ',
							'ଫାଲଗୁନ'
						],
						leap => [
							
						],
					},
					wide => {
						nonleap => [
							'ଚୈତ୍ର',
							'ବୈଶାଖ',
							'ଜ୍ୟେଷ୍ଠ',
							'ଆଷାଢ଼',
							'ଶ୍ରାବଣ',
							'ଭାଦ୍ରବ',
							'ଆଶ୍ଵିନ',
							'କାର୍ତ୍ତିକ',
							'ମାର୍ଗଶିର',
							'ପୌଷ',
							'ମାଘ',
							'ଫାଲଗୁନ'
						],
						leap => [
							
						],
					},
				},
				'stand-alone' => {
					abbreviated => {
						nonleap => [
							'ଚୈତ୍ର',
							'ବୈଶାଖ',
							'ଜ୍ୟେଷ୍ଠ',
							'ଆଷାଢ଼',
							'ଶ୍ରାବଣ',
							'ଭାଦ୍ରବ',
							'ଆଶ୍ଵିନ',
							'କାର୍ତ୍ତିକ',
							'ମାର୍ଗଶିର',
							'ପୌଷ',
							'ମାଘ',
							'ଫାଲଗୁନ'
						],
						leap => [
							
						],
					},
					wide => {
						nonleap => [
							'ଚୈତ୍ର',
							'ବୈଶାଖ',
							'ଜ୍ୟେଷ୍ଠ',
							'ଆଷାଢ଼',
							'ଶ୍ରାବଣ',
							'ଭାଦ୍ରବ',
							'ଆଶ୍ଵିନ',
							'କାର୍ତ୍ତିକ',
							'ମାର୍ଗଶିର',
							'ପୌଷ',
							'ମାଘ',
							'ଫାଲଗୁନ'
						],
						leap => [
							
						],
					},
				},
			},
	} },
);

has 'calendar_days' => (
	is			=> 'ro',
	isa			=> HashRef,
	init_arg	=> undef,
	default		=> sub { {
			'gregorian' => {
				'format' => {
					abbreviated => {
						mon => 'ସୋମ',
						tue => 'ମଙ୍ଗଳ',
						wed => 'ବୁଧ',
						thu => 'ଗୁରୁ',
						fri => 'ଶୁକ୍ର',
						sat => 'ଶନି',
						sun => 'ରବି'
					},
					wide => {
						mon => 'ସୋମବାର',
						tue => 'ମଙ୍ଗଳବାର',
						wed => 'ବୁଧବାର',
						thu => 'ଗୁରୁବାର',
						fri => 'ଶୁକ୍ରବାର',
						sat => 'ଶନିବାର',
						sun => 'ରବିବାର'
					},
				},
				'stand-alone' => {
					narrow => {
						mon => 'ସୋ',
						tue => 'ମ',
						wed => 'ବୁ',
						thu => 'ଗୁ',
						fri => 'ଶୁ',
						sat => 'ଶ',
						sun => 'ର'
					},
				},
			},
	} },
);

has 'calendar_quarters' => (
	is			=> 'ro',
	isa			=> HashRef,
	init_arg	=> undef,
	default		=> sub { {
			'gregorian' => {
				'format' => {
					abbreviated => {0 => 'Q1',
						1 => 'Q2',
						2 => '3ୟ ତ୍ରୟମାସ',
						3 => '4ର୍ଥ ତ୍ରୟମାସ'
					},
					wide => {0 => '1ମ ତ୍ରୟମାସ',
						1 => '2ୟ ତ୍ରୟମାସ',
						2 => '3ୟ ତ୍ରୟମାସ',
						3 => '4ର୍ଥ ତ୍ରୟମାସ'
					},
				},
				'stand-alone' => {
					abbreviated => {0 => 'Q1',
						1 => 'Q2',
						2 => 'Q3',
						3 => 'Q4'
					},
				},
			},
	} },
);

has 'day_periods' => (
	is			=> 'ro',
	isa			=> HashRef,
	init_arg	=> undef,
	default		=> sub { {
		'gregorian' => {
			'format' => {
				'narrow' => {
					'am' => q{ପୂ},
					'pm' => q{ଅ},
				},
			},
			'stand-alone' => {
				'abbreviated' => {
					'am' => q{ପୂର୍ବାହ୍ନ},
					'pm' => q{ଅପରାହ୍ନ},
				},
				'narrow' => {
					'am' => q{AM},
					'pm' => q{PM},
				},
			},
		},
	} },
);

has 'eras' => (
	is			=> 'ro',
	isa			=> HashRef,
	init_arg	=> undef,
	default		=> sub { {
		'generic' => {
		},
		'gregorian' => {
			abbreviated => {
				'0' => 'BC',
				'1' => 'AD'
			},
			wide => {
				'0' => 'ଖ୍ରୀଷ୍ଟପୂର୍ବ',
				'1' => 'ଖ୍ରୀଷ୍ଟାବ୍ଦ'
			},
		},
		'indian' => {
			abbreviated => {
				'0' => 'ସାକା'
			},
		},
	} },
);

has 'date_formats' => (
	is			=> 'ro',
	isa			=> HashRef,
	init_arg	=> undef,
	default		=> sub { {
		'generic' => {
			'full' => q{EEEE, MMMM d, y G},
			'long' => q{MMMM d, y G},
			'medium' => q{MMM d, y G},
			'short' => q{M/d/y GGGGG},
		},
		'gregorian' => {
			'full' => q{EEEE, MMMM d, y},
			'long' => q{MMMM d, y},
			'medium' => q{MMM d, y},
			'short' => q{M/d/yy},
		},
		'indian' => {
		},
	} },
);

has 'time_formats' => (
	is			=> 'ro',
	isa			=> HashRef,
	init_arg	=> undef,
	default		=> sub { {
		'generic' => {
		},
		'gregorian' => {
			'full' => q{h:mm:ss a zzzz},
			'long' => q{h:mm:ss a z},
			'medium' => q{h:mm:ss a},
			'short' => q{h:mm a},
		},
		'indian' => {
		},
	} },
);

has 'datetime_formats' => (
	is			=> 'ro',
	isa			=> HashRef,
	init_arg	=> undef,
	default		=> sub { {
		'generic' => {
			'full' => q{{1}, {0}},
			'long' => q{{1}, {0}},
			'medium' => q{{1}, {0}},
			'short' => q{{1}, {0}},
		},
		'gregorian' => {
			'full' => q{{1}, {0}},
			'long' => q{{1}, {0}},
			'medium' => q{{1}, {0}},
			'short' => q{{1}, {0}},
		},
		'indian' => {
		},
	} },
);

has 'datetime_formats_available_formats' => (
	is			=> 'ro',
	isa			=> HashRef,
	init_arg	=> undef,
	default		=> sub { {
		'generic' => {
			Ed => q{d E},
			Gy => q{y G},
			GyMMM => q{MMM y G},
			GyMMMEd => q{E, MMM d, y G},
			GyMMMd => q{MMM d, y G},
			MEd => q{E, M/d},
			MMMEd => q{E, MMM d},
			MMdd => q{dd-MM},
			Md => q{M/d},
			y => q{y G},
			yMM => q{MM-y G},
			yMMMM => q{MMMM y G},
			yQQQ => q{QQQ y G},
			yyyy => q{y G},
			yyyyM => q{M/y GGGGG},
			yyyyMEd => q{E, M/d/y GGGGG},
			yyyyMMM => q{MMM y G},
			yyyyMMMEd => q{E, MMM d, y G},
			yyyyMMMM => q{MMMM y G},
			yyyyMMMd => q{MMM d, y G},
			yyyyMd => q{M/d/y GGGGG},
			yyyyQQQ => q{QQQ y G},
			yyyyQQQQ => q{QQQQ y G},
		},
		'gregorian' => {
			Ed => q{d E},
			Gy => q{y G},
			GyMMM => q{MMM y G},
			GyMMMEd => q{E, MMM d, y G},
			GyMMMd => q{MMM d, y G},
			GyMd => q{M/d/y G},
			MEd => q{E, M/d},
			MMMEd => q{E, MMM d},
			MMMMW => q{MMMM ର ସପ୍ତାହ W},
			MMdd => q{dd-MM},
			Md => q{M/d},
			yM => q{M/y},
			yMEd => q{E, M/d/y},
			yMM => q{MM-y},
			yMMM => q{MMM y},
			yMMMEd => q{E, MMM d, y},
			yMMMM => q{MMMM y},
			yMMMd => q{MMM d, y},
			yMd => q{M/d/y},
			yQQQ => q{QQQ y},
			yQQQQ => q{QQQQ y},
			yw => q{Y ର ସପ୍ତାହ w},
		},
	} },
);

has 'datetime_formats_append_item' => (
	is			=> 'ro',
	isa			=> HashRef,
	init_arg	=> undef,
	default		=> sub { {
	} },
);

has 'datetime_formats_interval' => (
	is			=> 'ro',
	isa			=> HashRef,
	init_arg	=> undef,
	default		=> sub { {
		'generic' => {
			GyM => {
				G => q{M/y GGGGG – M/y GGGGG},
				M => q{M/y – M/y GGGGG},
				y => q{M/y – M/y GGGGG},
			},
			GyMEd => {
				G => q{E, M/d/y GGGGG – E, M/d/y GGGGG},
				M => q{E, M/d/y – E, M/d/y GGGGG},
				d => q{E, M/d/y – E, M/d/y GGGGG},
				y => q{E, M/d/y – E, M/d/y GGGGG},
			},
			GyMMM => {
				G => q{MMM y G – MMM y G},
				M => q{MMM – MMM y G},
				y => q{MMM y – MMM y G},
			},
			GyMMMEd => {
				G => q{E, MMM d, y G – E, MMM d, y G},
				M => q{E, MMM d – E, MMM d, y G},
				d => q{E, MMM d – E, MMM d, y G},
				y => q{E, MMM d, y – E, MMM d, y G},
			},
			GyMMMd => {
				G => q{MMM d, y G – MMM d, y G},
				M => q{MMM d – MMM d, y G},
				d => q{MMM d – d, y G},
				y => q{MMM d, y – MMM d, y G},
			},
			GyMd => {
				G => q{M/d/y GGGGG – M/d/y GGGGG},
				M => q{M/d/y – M/d/y GGGGG},
				d => q{M/d/y – M/d/y GGGGG},
				y => q{M/d/y – M/d/y GGGGG},
			},
			M => {
				M => q{M – M},
			},
			MEd => {
				M => q{E, M/d – E, M/d},
				d => q{E, M/d – E, M/d},
			},
			MMM => {
				M => q{MMM – MMM},
			},
			MMMEd => {
				M => q{E, MMM d – E, MMM d},
				d => q{E, MMM d – E, MMM d},
			},
			MMMd => {
				d => q{MMM d – d},
			},
			Md => {
				d => q{M/d – M/d},
			},
			fallback => '{0} – {1}',
			y => {
				y => q{y – y G},
			},
			yM => {
				M => q{M/y – M/y GGGGG},
				y => q{M/y – M/y GGGGG},
			},
			yMEd => {
				M => q{E, M/d/y – E, M/d/y GGGGG},
				d => q{E, M/d/y – E, M/d/y GGGGG},
				y => q{E, M/d/y – E, M/d/y GGGGG},
			},
			yMMM => {
				M => q{MMM – MMM y G},
				y => q{MMM y – MMM y G},
			},
			yMMMEd => {
				M => q{E, MMM d – E, MMM d, y G},
				d => q{E, MMM d – E, MMM d, y G},
				y => q{E, MMM d, y – E, MMM d, y G},
			},
			yMMMM => {
				M => q{MMMM – MMMM y G},
				y => q{MMMM y – MMMM y G},
			},
			yMMMd => {
				M => q{MMM d – MMM d, y G},
				d => q{MMM d – d, y G},
				y => q{MMM d, y – MMM d, y G},
			},
			yMd => {
				M => q{M/d/y – M/d/y GGGGG},
				d => q{M/d/y – M/d/y GGGGG},
				y => q{M/d/y – M/d/y GGGGG},
			},
		},
		'gregorian' => {
			Gy => {
				G => q{y G – y G},
				y => q{y – y G},
			},
			GyM => {
				G => q{M/y G – M/y G},
				M => q{M/y – M/y G},
				y => q{M/y – M/y G},
			},
			GyMEd => {
				G => q{E, M/d/y G – E, M/d/y G},
				M => q{E, M/d/y – E, M/d/y G},
				d => q{E, M/d/y – E, M/d/y G},
				y => q{E, M/d/y – E, M/d/y G},
			},
			GyMMM => {
				G => q{MMM y G – MMM y G},
				M => q{MMM – MMM y G},
				y => q{MMM y – MMM y G},
			},
			GyMMMEd => {
				G => q{E, MMM d, y G – E, MMM d, y G},
				M => q{E, MMM d – E, MMM d, y G},
				d => q{E, MMM d – E, MMM d, y G},
				y => q{E, MMM d, y – E, MMM d, y G},
			},
			GyMMMd => {
				G => q{MMM d, y G – MMM d, y G},
				M => q{MMM d – MMM d, y G},
				d => q{MMM d – d, y G},
				y => q{MMM d, y – MMM d, y G},
			},
			GyMd => {
				G => q{M/d/y G – M/d/y G},
				M => q{M/d/y – M/d/y G},
				d => q{M/d/y G – M/d/y G},
				y => q{M/d/y – M/d/y G},
			},
			MEd => {
				M => q{E, M/d – E, M/d},
				d => q{E, M/d – E, M/d},
			},
			MMM => {
				M => q{MMM – MMM},
			},
			MMMEd => {
				M => q{E, MMM d – E, MMM d},
				d => q{E, MMM d – E, MMM d},
			},
			Md => {
				M => q{M/d – M/d},
				d => q{M/d – M/d},
			},
			fallback => '{0} – {1}',
			yM => {
				M => q{M/y – M/y},
				y => q{M/y – M/y},
			},
			yMEd => {
				M => q{E, M/d/y – E, M/d/y},
				d => q{E, M/d/y – E, M/d/y},
				y => q{E, M/d/y – E, M/d/y},
			},
			yMMM => {
				M => q{MMM – MMM y},
				y => q{MMM y – MMM y},
			},
			yMMMEd => {
				M => q{E, MMM d – E, MMM d, y},
				d => q{E, MMM d – E, MMM d, y},
				y => q{E, MMM d, y – E, MMM d, y},
			},
			yMMMM => {
				M => q{MMMM – MMMM y},
				y => q{MMMM y – MMMM y},
			},
			yMMMd => {
				M => q{MMM d – MMM d, y},
				d => q{MMM d – d, y},
				y => q{MMM d, y – MMM d, y},
			},
			yMd => {
				M => q{M/d/y – M/d/y},
				d => q{M/d/y – M/d/y},
				y => q{M/d/y – M/d/y},
			},
		},
	} },
);

has 'time_zone_names' => (
	is			=> 'ro',
	isa			=> HashRef,
	init_arg	=> undef,
	default	=> sub { {
		regionFormat => q({0} ସମୟ),
		regionFormat => q({0} ଦିବାଲୋକ ସମୟ),
		regionFormat => q({0} ମାନାଙ୍କ ସମୟ),
		'Acre' => {
			long => {
				'daylight' => q#ଆକା ଗ୍ରୀଷ୍ମ ସମୟ#,
				'generic' => q#ଆକା ସମୟ#,
				'standard' => q#ଆକା ମାନକ ସମୟ#,
			},
		},
		'Afghanistan' => {
			long => {
				'standard' => q#ଆଫଗାନିସ୍ତାନ ସମୟ#,
			},
		},
		'Africa/Abidjan' => {
			exemplarCity => q#ଆବିଦଜାନ#,
		},
		'Africa/Accra' => {
			exemplarCity => q#ଆକାରା#,
		},
		'Africa/Addis_Ababa' => {
			exemplarCity => q#ଆଦିସ୍‌ ଆବାବା#,
		},
		'Africa/Algiers' => {
			exemplarCity => q#ଅଲଜିୟର୍ସ#,
		},
		'Africa/Asmera' => {
			exemplarCity => q#ଅସମରା#,
		},
		'Africa/Bamako' => {
			exemplarCity => q#ବାମାକୋ#,
		},
		'Africa/Bangui' => {
			exemplarCity => q#ବାଙ୍ଗୁଇ#,
		},
		'Africa/Banjul' => {
			exemplarCity => q#ବାଞ୍ଜୁଲ#,
		},
		'Africa/Bissau' => {
			exemplarCity => q#ବିସାଉ#,
		},
		'Africa/Blantyre' => {
			exemplarCity => q#ବ୍ଲାଣ୍ଟାୟାର୍‌#,
		},
		'Africa/Brazzaville' => {
			exemplarCity => q#ବ୍ରାଜାଭିଲ୍ଲେ#,
		},
		'Africa/Bujumbura' => {
			exemplarCity => q#ବୁଜୁମ୍ବୁରା#,
		},
		'Africa/Cairo' => {
			exemplarCity => q#କାଇରୋ#,
		},
		'Africa/Casablanca' => {
			exemplarCity => q#କାସାବ୍ଲାଙ୍କା#,
		},
		'Africa/Ceuta' => {
			exemplarCity => q#ସେଉଟା#,
		},
		'Africa/Conakry' => {
			exemplarCity => q#କୋନାକ୍ରି#,
		},
		'Africa/Dakar' => {
			exemplarCity => q#ଡକାର#,
		},
		'Africa/Dar_es_Salaam' => {
			exemplarCity => q#ଡର୍‌ ଇସ୍‌ ସାଲାମ#,
		},
		'Africa/Djibouti' => {
			exemplarCity => q#ଜିବୋଟି#,
		},
		'Africa/Douala' => {
			exemplarCity => q#ଡଉଲା#,
		},
		'Africa/El_Aaiun' => {
			exemplarCity => q#ଏଲ୍‌ ଏୟନ୍#,
		},
		'Africa/Freetown' => {
			exemplarCity => q#ଫ୍ରିଟାଉନ୍‌#,
		},
		'Africa/Gaborone' => {
			exemplarCity => q#ଗାବୋର୍ଣ୍ଣ#,
		},
		'Africa/Harare' => {
			exemplarCity => q#ହରାରେ#,
		},
		'Africa/Johannesburg' => {
			exemplarCity => q#ଜୋହାନ୍ସବର୍ଗ#,
		},
		'Africa/Juba' => {
			exemplarCity => q#ଜୁବା#,
		},
		'Africa/Kampala' => {
			exemplarCity => q#କାମ୍ପାଲା#,
		},
		'Africa/Khartoum' => {
			exemplarCity => q#ଖରଟୌମ୍‌#,
		},
		'Africa/Kigali' => {
			exemplarCity => q#କିଗାଲି#,
		},
		'Africa/Kinshasa' => {
			exemplarCity => q#କିନସାସ୍‌#,
		},
		'Africa/Lagos' => {
			exemplarCity => q#ଲାଗୋସ୍‌#,
		},
		'Africa/Libreville' => {
			exemplarCity => q#ଲିବ୍ରେଭିଲ୍ଲେ#,
		},
		'Africa/Lome' => {
			exemplarCity => q#ଲୋମ୍‌#,
		},
		'Africa/Luanda' => {
			exemplarCity => q#ଲୁଆଣ୍ଡା#,
		},
		'Africa/Lubumbashi' => {
			exemplarCity => q#ଲୁବୁମ୍ବାଶି#,
		},
		'Africa/Lusaka' => {
			exemplarCity => q#ଲୁସାକା#,
		},
		'Africa/Malabo' => {
			exemplarCity => q#ମାଲାବୋ#,
		},
		'Africa/Maputo' => {
			exemplarCity => q#ମାପୁତୋ#,
		},
		'Africa/Maseru' => {
			exemplarCity => q#ମେସେରୁ#,
		},
		'Africa/Mbabane' => {
			exemplarCity => q#ବାବେନ୍‌#,
		},
		'Africa/Mogadishu' => {
			exemplarCity => q#ମୋଗାଦିଶୁ#,
		},
		'Africa/Monrovia' => {
			exemplarCity => q#ମନରୋଭିଆ#,
		},
		'Africa/Nairobi' => {
			exemplarCity => q#ନାଇରୋବି#,
		},
		'Africa/Ndjamena' => {
			exemplarCity => q#ଜାମେନା#,
		},
		'Africa/Niamey' => {
			exemplarCity => q#ନିଆମି#,
		},
		'Africa/Nouakchott' => {
			exemplarCity => q#ନୌକାଚୋଟ#,
		},
		'Africa/Ouagadougou' => {
			exemplarCity => q#ଅଉଗାଡଉଗଉ#,
		},
		'Africa/Porto-Novo' => {
			exemplarCity => q#ପୋର୍ଟୋ-ନୋଭୋ#,
		},
		'Africa/Sao_Tome' => {
			exemplarCity => q#ସାଓ ଟୋମେ#,
		},
		'Africa/Tripoli' => {
			exemplarCity => q#ତ୍ରିପୋଲି#,
		},
		'Africa/Tunis' => {
			exemplarCity => q#ଟୁନିସ୍‌#,
		},
		'Africa/Windhoek' => {
			exemplarCity => q#ୱିଣ୍ଡହୋଏକ୍#,
		},
		'Africa_Central' => {
			long => {
				'standard' => q#ମଧ୍ୟ ଆଫ୍ରିକା ସମୟ#,
			},
		},
		'Africa_Eastern' => {
			long => {
				'standard' => q#ପୂର୍ବ ଆଫ୍ରିକା ସମୟ#,
			},
		},
		'Africa_Southern' => {
			long => {
				'standard' => q#ଦକ୍ଷିଣ ଆଫ୍ରିକା ମାନାଙ୍କ ସମୟ#,
			},
		},
		'Africa_Western' => {
			long => {
				'daylight' => q#ପଶ୍ଚିମ ଆଫ୍ରିକା ଖରାଦିନ ସମୟ#,
				'generic' => q#ପଶ୍ଚିମ ଆଫ୍ରିକା ସମୟ#,
				'standard' => q#ପଶ୍ଚିମ ଆଫ୍ରିକା ମାନାଙ୍କ ସମୟ#,
			},
		},
		'Alaska' => {
			long => {
				'daylight' => q#ଆଲାସ୍କା ଦିବାଲୋକ ସମୟ#,
				'generic' => q#ଆଲାସ୍କା ସମୟ#,
				'standard' => q#ଆଲାସ୍କା ମାନାଙ୍କ ସମୟ#,
			},
		},
		'Almaty' => {
			long => {
				'daylight' => q#ଅଲମାଟୀ ଗ୍ରୀଷ୍ମ ସମୟ#,
				'generic' => q#ଅଲମାଟୀ ସମୟ#,
				'standard' => q#ଅଲମାଟୀ ମାନକ ସମୟ#,
			},
		},
		'Amazon' => {
			long => {
				'daylight' => q#ଆମାଜନ୍ ଗ୍ରୀଷ୍ମକାଳୀନ ସମୟ#,
				'generic' => q#ଆମାଜନ୍ ସମୟ#,
				'standard' => q#ଆମାଜନ୍ ମାନାଙ୍କ ସମୟ#,
			},
		},
		'America/Adak' => {
			exemplarCity => q#ଆଡାକ୍#,
		},
		'America/Anchorage' => {
			exemplarCity => q#ଆଙ୍କରେଜ୍#,
		},
		'America/Anguilla' => {
			exemplarCity => q#ଆଙ୍ଗୁଇଲା#,
		},
		'America/Antigua' => {
			exemplarCity => q#ଆଣ୍ଟିଗୁଆ#,
		},
		'America/Araguaina' => {
			exemplarCity => q#ଆରାଗୁଆନା#,
		},
		'America/Argentina/La_Rioja' => {
			exemplarCity => q#ଲା ରିଓଜା#,
		},
		'America/Argentina/Rio_Gallegos' => {
			exemplarCity => q#ରିଓ ଗାଲ୍ଲେଗସ୍‌#,
		},
		'America/Argentina/Salta' => {
			exemplarCity => q#ସଲ୍ଟା#,
		},
		'America/Argentina/San_Juan' => {
			exemplarCity => q#ସାନ୍‌ ଜୁଆନ#,
		},
		'America/Argentina/San_Luis' => {
			exemplarCity => q#ସାନ୍‌ ଲୁଇସ୍‌#,
		},
		'America/Argentina/Tucuman' => {
			exemplarCity => q#ଟୁକୁମାନ୍‌#,
		},
		'America/Argentina/Ushuaia' => {
			exemplarCity => q#ଉଶୁୟା#,
		},
		'America/Aruba' => {
			exemplarCity => q#ଆରୁବା#,
		},
		'America/Asuncion' => {
			exemplarCity => q#ଆସନସିଅନ୍‌#,
		},
		'America/Bahia' => {
			exemplarCity => q#ବାହିଆ#,
		},
		'America/Bahia_Banderas' => {
			exemplarCity => q#ବାହିଆ ବ୍ୟାଣ୍ଡେରାସ୍#,
		},
		'America/Barbados' => {
			exemplarCity => q#ବାର୍ବାଡୋସ୍#,
		},
		'America/Belem' => {
			exemplarCity => q#ବେଲେମ#,
		},
		'America/Belize' => {
			exemplarCity => q#ବେଲିଜେ#,
		},
		'America/Blanc-Sablon' => {
			exemplarCity => q#ବ୍ଲାଙ୍କ-ସାବଲୋନ୍#,
		},
		'America/Boa_Vista' => {
			exemplarCity => q#ବୋଆ ଭିଷ୍ଟା#,
		},
		'America/Bogota' => {
			exemplarCity => q#ବୋଗୋଟା#,
		},
		'America/Boise' => {
			exemplarCity => q#ବୋଇସେ#,
		},
		'America/Buenos_Aires' => {
			exemplarCity => q#ବୁଏନସ୍‌ ଏରିସ୍‌#,
		},
		'America/Cambridge_Bay' => {
			exemplarCity => q#କେମ୍ଵ୍ରିଜ୍ ବେ#,
		},
		'America/Campo_Grande' => {
			exemplarCity => q#କାମ୍ପୋ ଗ୍ରାଣ୍ଡେ#,
		},
		'America/Cancun' => {
			exemplarCity => q#କାନକୁନ୍#,
		},
		'America/Caracas' => {
			exemplarCity => q#କାରକାସ୍‌#,
		},
		'America/Catamarca' => {
			exemplarCity => q#କାଟାମାର୍କା#,
		},
		'America/Cayenne' => {
			exemplarCity => q#କେୟେନ୍ନି#,
		},
		'America/Cayman' => {
			exemplarCity => q#କାୟମ୍ୟାନ୍#,
		},
		'America/Chicago' => {
			exemplarCity => q#ଚିକାଗୋ#,
		},
		'America/Chihuahua' => {
			exemplarCity => q#ଚିହୁଆହୁଆ#,
		},
		'America/Ciudad_Juarez' => {
			exemplarCity => q#ସିଉଡାଡ୍ ଜୁଆରେଜ୍#,
		},
		'America/Coral_Harbour' => {
			exemplarCity => q#ଆଟିକୋକାନ୍#,
		},
		'America/Cordoba' => {
			exemplarCity => q#କୋର୍ଡୋବା#,
		},
		'America/Costa_Rica' => {
			exemplarCity => q#କୋଷ୍ଟା ରିକା#,
		},
		'America/Creston' => {
			exemplarCity => q#କ୍ରେଷ୍ଟୋନ୍#,
		},
		'America/Cuiaba' => {
			exemplarCity => q#କୁଇବା#,
		},
		'America/Curacao' => {
			exemplarCity => q#କୁରାକୋ#,
		},
		'America/Danmarkshavn' => {
			exemplarCity => q#ଡାନମାର୍କସାଭନ୍#,
		},
		'America/Dawson' => {
			exemplarCity => q#ଡସନ୍‌#,
		},
		'America/Dawson_Creek' => {
			exemplarCity => q#ଡୱସନ୍ କ୍ରିକ୍#,
		},
		'America/Denver' => {
			exemplarCity => q#ଡେନଭିର୍#,
		},
		'America/Detroit' => {
			exemplarCity => q#ଡେଟ୍ରୋଇଟ୍#,
		},
		'America/Dominica' => {
			exemplarCity => q#ଡୋମିନିକା#,
		},
		'America/Edmonton' => {
			exemplarCity => q#ଏଡମୋନଟୋନ୍#,
		},
		'America/Eirunepe' => {
			exemplarCity => q#ଇରୁନେପେ#,
		},
		'America/El_Salvador' => {
			exemplarCity => q#ଏଲ୍ ସାଲଭାଡୋର୍#,
		},
		'America/Fort_Nelson' => {
			exemplarCity => q#ଫୋର୍ଟ୍ ନେଲସନ୍#,
		},
		'America/Fortaleza' => {
			exemplarCity => q#ଫୋର୍ଟେଲେଜା#,
		},
		'America/Glace_Bay' => {
			exemplarCity => q#ଗ୍ଲାସେ ବେ#,
		},
		'America/Godthab' => {
			exemplarCity => q#ନୁଉକ୍#,
		},
		'America/Goose_Bay' => {
			exemplarCity => q#ଗୁସ୍ ବେ#,
		},
		'America/Grand_Turk' => {
			exemplarCity => q#ଗ୍ରାଣ୍ଡ୍ ଟର୍କ୍#,
		},
		'America/Grenada' => {
			exemplarCity => q#ଗ୍ରେନାଡା#,
		},
		'America/Guadeloupe' => {
			exemplarCity => q#ଗୁଆଡେଲୋପ୍‌#,
		},
		'America/Guatemala' => {
			exemplarCity => q#ଗୁଆଟେମାଲା#,
		},
		'America/Guayaquil' => {
			exemplarCity => q#ଗୁୟାକ୍ୱିଲ#,
		},
		'America/Guyana' => {
			exemplarCity => q#ଗୁଏନା#,
		},
		'America/Halifax' => {
			exemplarCity => q#ହାଲିଫ୍ୟାକ୍ସ୍#,
		},
		'America/Havana' => {
			exemplarCity => q#ହାଭାନା#,
		},
		'America/Hermosillo' => {
			exemplarCity => q#ହେରମୋସିଲୋ#,
		},
		'America/Indiana/Knox' => {
			exemplarCity => q#କ୍ନୋକ୍ସ, ଇଣ୍ଡିଆନା#,
		},
		'America/Indiana/Marengo' => {
			exemplarCity => q#ମାରେନଗୋ, ଇଣ୍ଡିଆନା#,
		},
		'America/Indiana/Petersburg' => {
			exemplarCity => q#ପେଟେର୍ସବର୍ଗ୍, ଇଣ୍ଡିଆନା#,
		},
		'America/Indiana/Tell_City' => {
			exemplarCity => q#ଟେଲ୍ ସିଟି, ଇଣ୍ଡିଆନା#,
		},
		'America/Indiana/Vevay' => {
			exemplarCity => q#ଭେଭାୟ, ଇଣ୍ଡିଆନା#,
		},
		'America/Indiana/Vincennes' => {
			exemplarCity => q#ଭିନସେନ୍ନେସ୍, ଇଣ୍ଡିଆନା#,
		},
		'America/Indiana/Winamac' => {
			exemplarCity => q#ୱିନାମାକ୍, ଇଣ୍ଡିଆନା#,
		},
		'America/Indianapolis' => {
			exemplarCity => q#ଇଣ୍ଡିଆନାପୋଲିସ୍#,
		},
		'America/Inuvik' => {
			exemplarCity => q#ଇନୁଭିକ୍#,
		},
		'America/Iqaluit' => {
			exemplarCity => q#ଇକ୍ଵାଲୁଇଟ୍#,
		},
		'America/Jamaica' => {
			exemplarCity => q#ଜାମାଇକା#,
		},
		'America/Jujuy' => {
			exemplarCity => q#ଜୁଜୁଇ#,
		},
		'America/Juneau' => {
			exemplarCity => q#ଜୁନେଆଉ#,
		},
		'America/Kentucky/Monticello' => {
			exemplarCity => q#ମୋଣ୍ଟିସେଲୋ, କେଣ୍ଟଉକିକେ#,
		},
		'America/Kralendijk' => {
			exemplarCity => q#କ୍ରାଲେଣ୍ଡଜିକ#,
		},
		'America/La_Paz' => {
			exemplarCity => q#ଲା ପାଜ୍‌#,
		},
		'America/Lima' => {
			exemplarCity => q#ଲିମା#,
		},
		'America/Los_Angeles' => {
			exemplarCity => q#ଲସ୍ ଏଞ୍ଜେଲେସ୍#,
		},
		'America/Louisville' => {
			exemplarCity => q#ଲୁଇଭିଲ୍ଲେ#,
		},
		'America/Lower_Princes' => {
			exemplarCity => q#ନିମ୍ନ ପ୍ରିନ୍ସ’ର କ୍ଵାଟର୍#,
		},
		'America/Maceio' => {
			exemplarCity => q#ମାସିଓ#,
		},
		'America/Managua' => {
			exemplarCity => q#ମାନାଗୁଆ#,
		},
		'America/Manaus' => {
			exemplarCity => q#ମାନାଉସ୍‌#,
		},
		'America/Marigot' => {
			exemplarCity => q#ମାରିଗୋଟ୍#,
		},
		'America/Martinique' => {
			exemplarCity => q#ମାର୍ଟିନିକ୍ୟୁ#,
		},
		'America/Matamoros' => {
			exemplarCity => q#ମାଟାମୋରୋସ୍#,
		},
		'America/Mazatlan' => {
			exemplarCity => q#ମାନାଟଲାନ୍#,
		},
		'America/Mendoza' => {
			exemplarCity => q#ମେଣ୍ଡୋଜା#,
		},
		'America/Menominee' => {
			exemplarCity => q#ମେନୋମିନି#,
		},
		'America/Merida' => {
			exemplarCity => q#ମେରିଡା#,
		},
		'America/Metlakatla' => {
			exemplarCity => q#ମାଟଲାକାଟଲା#,
		},
		'America/Mexico_City' => {
			exemplarCity => q#ମେକ୍ସିକୋ ସିଟି#,
		},
		'America/Miquelon' => {
			exemplarCity => q#ମିକ୍ଵେଲୋନ୍#,
		},
		'America/Moncton' => {
			exemplarCity => q#ମାନକଟୋନ୍#,
		},
		'America/Monterrey' => {
			exemplarCity => q#ମୋନଟେରିଏ#,
		},
		'America/Montevideo' => {
			exemplarCity => q#ମଣ୍ଟେଭିଡିଓ#,
		},
		'America/Montserrat' => {
			exemplarCity => q#ମୋନଟସେରରାଟ୍#,
		},
		'America/Nassau' => {
			exemplarCity => q#ନାସାଉ#,
		},
		'America/New_York' => {
			exemplarCity => q#ନ୍ୟୁ ୟୋର୍କ୍#,
		},
		'America/Nome' => {
			exemplarCity => q#ନୋମେ#,
		},
		'America/Noronha' => {
			exemplarCity => q#ନୋରୋନ୍ନା#,
		},
		'America/North_Dakota/Beulah' => {
			exemplarCity => q#ବେଉଲାହ, ଉତ୍ତର ଡାକୋଟା#,
		},
		'America/North_Dakota/Center' => {
			exemplarCity => q#କେନ୍ଦ୍ର, ଉତ୍ତର ଡାକୋଟା#,
		},
		'America/North_Dakota/New_Salem' => {
			exemplarCity => q#ନ୍ୟୁ ସାଲେମ୍, ଉତ୍ତର ଡାକୋଟା#,
		},
		'America/Ojinaga' => {
			exemplarCity => q#ଓଜିନାଗା#,
		},
		'America/Panama' => {
			exemplarCity => q#ପାନାମା#,
		},
		'America/Paramaribo' => {
			exemplarCity => q#ପାରାମାରିବୋ#,
		},
		'America/Phoenix' => {
			exemplarCity => q#ଫୋଇନିକ୍ସ#,
		},
		'America/Port-au-Prince' => {
			exemplarCity => q#ପୋର୍ଟ୍-ଏୟୁ-ପ୍ରିନ୍ସ#,
		},
		'America/Port_of_Spain' => {
			exemplarCity => q#ପୋର୍ଟ୍ ଅଫ୍ ସ୍ପେନ୍#,
		},
		'America/Porto_Velho' => {
			exemplarCity => q#ପୋର୍ଟୋ ଭେଲୋ#,
		},
		'America/Puerto_Rico' => {
			exemplarCity => q#ପୁଏର୍ତୋ ରିକୋ#,
		},
		'America/Punta_Arenas' => {
			exemplarCity => q#ପୁଣ୍ଟା ଏରିନାସ୍‌#,
		},
		'America/Rankin_Inlet' => {
			exemplarCity => q#ରାନକିନ୍ ଇନଲେଟ୍#,
		},
		'America/Recife' => {
			exemplarCity => q#ରେସିଫି#,
		},
		'America/Regina' => {
			exemplarCity => q#ରେଗିନା#,
		},
		'America/Resolute' => {
			exemplarCity => q#ରିସୋଲୁଟେ#,
		},
		'America/Rio_Branco' => {
			exemplarCity => q#ରିଓ ବ୍ରାଙ୍କୋ#,
		},
		'America/Santarem' => {
			exemplarCity => q#ସାଣ୍ଟାରେମ୍‌#,
		},
		'America/Santiago' => {
			exemplarCity => q#ସାଣ୍ଟିଆଗୋ#,
		},
		'America/Santo_Domingo' => {
			exemplarCity => q#ସାଣ୍ଟୋ ଡୋମିଙ୍ଗୋ#,
		},
		'America/Sao_Paulo' => {
			exemplarCity => q#ସାଓ ପାଓଲୋ#,
		},
		'America/Scoresbysund' => {
			exemplarCity => q#ଇଟ୍ଟୋକ୍ଵୋରଟୋରମିଟ୍#,
		},
		'America/Sitka' => {
			exemplarCity => q#ସିଟକା#,
		},
		'America/St_Barthelemy' => {
			exemplarCity => q#ସେଣ୍ଟ୍. ବାର୍ଥେଲେମି#,
		},
		'America/St_Johns' => {
			exemplarCity => q#ସେଣ୍ଟ୍. ଜନସ୍#,
		},
		'America/St_Kitts' => {
			exemplarCity => q#ସେଣ୍ଟ୍ କିଟ୍ସ୍#,
		},
		'America/St_Lucia' => {
			exemplarCity => q#ସେଣ୍ଟ୍. ଲୁସିଆ#,
		},
		'America/St_Thomas' => {
			exemplarCity => q#ସେଣ୍ଟ୍. ଥୋମାସ୍#,
		},
		'America/St_Vincent' => {
			exemplarCity => q#ସେଣ୍ଟ୍. ଭିନସେଣ୍ଟ୍#,
		},
		'America/Swift_Current' => {
			exemplarCity => q#ସୁଇଫ୍ଟ୍ କରେଣ୍ଟ୍#,
		},
		'America/Tegucigalpa' => {
			exemplarCity => q#ଟେଗୁସିଗାଲପା#,
		},
		'America/Thule' => {
			exemplarCity => q#ଥୁଲେ#,
		},
		'America/Tijuana' => {
			exemplarCity => q#ତିଜୁଆନା#,
		},
		'America/Toronto' => {
			exemplarCity => q#ଟୋରୋଣ୍ଟୋ#,
		},
		'America/Tortola' => {
			exemplarCity => q#ଟୋରଟୋଲା#,
		},
		'America/Vancouver' => {
			exemplarCity => q#ଭାଙ୍କୁଭର୍#,
		},
		'America/Whitehorse' => {
			exemplarCity => q#ହ୍ଵାଇଟହର୍ସ୍#,
		},
		'America/Winnipeg' => {
			exemplarCity => q#ୱିନିପେଗ୍#,
		},
		'America/Yakutat' => {
			exemplarCity => q#ୟାକୁଟାଟ୍#,
		},
		'America_Central' => {
			long => {
				'daylight' => q#କେନ୍ଦ୍ରୀୟ ଦିବାଲୋକ ସମୟ#,
				'generic' => q#କେନ୍ଦ୍ରୀୟ ସମୟ#,
				'standard' => q#କେନ୍ଦ୍ରୀୟ ମାନାଙ୍କ ସମୟ#,
			},
		},
		'America_Eastern' => {
			long => {
				'daylight' => q#ପୂର୍ବାଞ୍ଚଳ ଦିବାଲୋକ ସମୟ#,
				'generic' => q#ପୂର୍ବାଞ୍ଚଳ ସମୟ#,
				'standard' => q#ପୂର୍ବାଞ୍ଚଳ ମାନାଙ୍କ ସମୟ#,
			},
		},
		'America_Mountain' => {
			long => {
				'daylight' => q#ପାର୍ବତ୍ୟ ଦିବାଲୋକ ସମୟ#,
				'generic' => q#ପାର୍ବତ୍ୟ ସମୟ#,
				'standard' => q#ପାର୍ବତ୍ୟ ମାନାଙ୍କ ସମୟ#,
			},
		},
		'America_Pacific' => {
			long => {
				'daylight' => q#ପାସିଫିକ୍ ଦିବାଲୋକ ସମୟ#,
				'generic' => q#ପାସିଫିକ୍ ସମୟ#,
				'standard' => q#ପାସିଫିକ୍ ମାନାଙ୍କ ସମୟ#,
			},
		},
		'Anadyr' => {
			long => {
				'daylight' => q#ଅନାଡିର୍ ଗ୍ରୀଷ୍ମ ସମୟ#,
				'generic' => q#ଅନାଡିର୍ ସମୟ#,
				'standard' => q#ଅନାଡିର୍ ମାନକ ସମୟ#,
			},
		},
		'Antarctica/Casey' => {
			exemplarCity => q#କାସେ#,
		},
		'Antarctica/Davis' => {
			exemplarCity => q#ଡେଭିସ୍‌#,
		},
		'Antarctica/DumontDUrville' => {
			exemplarCity => q#ଡୁମୋଣ୍ଟ ଡି‘ଉରଭିଲ୍ଲେ#,
		},
		'Antarctica/Macquarie' => {
			exemplarCity => q#ମାକ୍ୱେରୀ#,
		},
		'Antarctica/Mawson' => {
			exemplarCity => q#ମାୱସନ୍#,
		},
		'Antarctica/McMurdo' => {
			exemplarCity => q#ମ୍ୟାକ୍‌ମୁର୍ଡୋ#,
		},
		'Antarctica/Palmer' => {
			exemplarCity => q#ପାଲମର୍‌#,
		},
		'Antarctica/Rothera' => {
			exemplarCity => q#ରୋଥେରା#,
		},
		'Antarctica/Syowa' => {
			exemplarCity => q#ସୋୱା#,
		},
		'Antarctica/Troll' => {
			exemplarCity => q#ଟ୍ରୋଲ୍#,
		},
		'Antarctica/Vostok' => {
			exemplarCity => q#ଭୋଷ୍ଟୋକ୍‌#,
		},
		'Apia' => {
			long => {
				'daylight' => q#ଆପିଆ ଦିବାଲୋକ ସମୟ#,
				'generic' => q#ଆପିଆ ସମୟ#,
				'standard' => q#ଆପିଆ ମାନାଙ୍କ ସମୟ#,
			},
		},
		'Aqtau' => {
			long => {
				'daylight' => q#ଅକତୌ ଗ୍ରୀଷ୍ମ ସମୟ#,
				'generic' => q#ଅକତୌ ସମୟ#,
				'standard' => q#ଅକତୌ ମାନକ ସମୟ#,
			},
		},
		'Aqtobe' => {
			long => {
				'daylight' => q#ଅକ୍ତୋବ ଗ୍ରୀଷ୍ମ ସମୟ#,
				'generic' => q#ଅକ୍ତୋବ ସମୟ#,
				'standard' => q#ଅକ୍ତୋବ ମାନକ ସମୟ#,
			},
		},
		'Arabian' => {
			long => {
				'daylight' => q#ଆରବୀୟ ଦିବାଲୋକ ସମୟ#,
				'generic' => q#ଆରବୀୟ ସମୟ#,
				'standard' => q#ଆରବୀୟ ମାନାଙ୍କ ସମୟ#,
			},
		},
		'Arctic/Longyearbyen' => {
			exemplarCity => q#ଲଙ୍ଗୟେଆରବୟେନ୍#,
		},
		'Argentina' => {
			long => {
				'daylight' => q#ଆର୍ଜେଣ୍ଟିନା ଗ୍ରୀଷ୍ମକାଳ ସମୟ#,
				'generic' => q#ଆର୍ଜେଣ୍ଟିନା ସମୟ#,
				'standard' => q#ଆର୍ଜେଣ୍ଟିନା ମାନାଙ୍କ ସମୟ#,
			},
		},
		'Argentina_Western' => {
			long => {
				'daylight' => q#ପଶ୍ଚିମ ଆର୍ଜେଣ୍ଟିନା ଗ୍ରୀଷ୍ମକାଳ ସମୟ#,
				'generic' => q#ପଶ୍ଚିମ ଆର୍ଜେଣ୍ଟିନା ସମୟ#,
				'standard' => q#ପଶ୍ଚିମ ଆର୍ଜେଣ୍ଟିନା ମାନାଙ୍କ ସମୟ#,
			},
		},
		'Armenia' => {
			long => {
				'daylight' => q#ଆର୍ମେନିଆ ଗ୍ରୀଷ୍ମକାଳ ସମୟ#,
				'generic' => q#ଆର୍ମେନିଆ ସମୟ#,
				'standard' => q#ଆର୍ମେନିଆ ମାନାଙ୍କ ସମୟ#,
			},
		},
		'Asia/Aden' => {
			exemplarCity => q#ଏଡେନ୍‌#,
		},
		'Asia/Almaty' => {
			exemplarCity => q#ଅଲମାଟି#,
		},
		'Asia/Amman' => {
			exemplarCity => q#ଅମ୍ମାନ#,
		},
		'Asia/Anadyr' => {
			exemplarCity => q#ଆନାଡୟାର୍#,
		},
		'Asia/Aqtau' => {
			exemplarCity => q#ଆକଟାଉ#,
		},
		'Asia/Aqtobe' => {
			exemplarCity => q#ଆକଟୋବ୍‌#,
		},
		'Asia/Ashgabat' => {
			exemplarCity => q#ଆଶ୍‌ଗାବୋଟ୍‌#,
		},
		'Asia/Atyrau' => {
			exemplarCity => q#ଅତିରାଉ#,
		},
		'Asia/Baghdad' => {
			exemplarCity => q#ବାଗଦାଦ୍‌#,
		},
		'Asia/Bahrain' => {
			exemplarCity => q#ବାହାରିନ୍#,
		},
		'Asia/Baku' => {
			exemplarCity => q#ବାକୁ#,
		},
		'Asia/Bangkok' => {
			exemplarCity => q#ବ୍ୟାଙ୍ଗକକ୍‌#,
		},
		'Asia/Barnaul' => {
			exemplarCity => q#ବାରନାଉଲ୍#,
		},
		'Asia/Beirut' => {
			exemplarCity => q#ବୀରୁଟ୍‌#,
		},
		'Asia/Bishkek' => {
			exemplarCity => q#ବିଶକେକ୍‌#,
		},
		'Asia/Brunei' => {
			exemplarCity => q#ବ୍ରୁନେଇ#,
		},
		'Asia/Calcutta' => {
			exemplarCity => q#କୋଲକାତା#,
		},
		'Asia/Chita' => {
			exemplarCity => q#ଚିଟା#,
		},
		'Asia/Colombo' => {
			exemplarCity => q#କଲମ୍ବୋ#,
		},
		'Asia/Damascus' => {
			exemplarCity => q#ଡାମାସକସ୍‌#,
		},
		'Asia/Dhaka' => {
			exemplarCity => q#ଢାକା#,
		},
		'Asia/Dili' => {
			exemplarCity => q#ଦିଲ୍ଲୀ#,
		},
		'Asia/Dubai' => {
			exemplarCity => q#ଦୁବାଇ#,
		},
		'Asia/Dushanbe' => {
			exemplarCity => q#ଦୁଶାନବେ#,
		},
		'Asia/Famagusta' => {
			exemplarCity => q#ଫାମାଗୁଷ୍ଟା#,
		},
		'Asia/Gaza' => {
			exemplarCity => q#ଗାଜା#,
		},
		'Asia/Hebron' => {
			exemplarCity => q#ହେବ୍ରନ୍‌#,
		},
		'Asia/Hong_Kong' => {
			exemplarCity => q#ହଂ କଂ#,
		},
		'Asia/Hovd' => {
			exemplarCity => q#ହୋଭଡ୍‌#,
		},
		'Asia/Irkutsk' => {
			exemplarCity => q#ଇରକୁଟସ୍କ#,
		},
		'Asia/Jakarta' => {
			exemplarCity => q#ଜାକର୍ତ୍ତା#,
		},
		'Asia/Jayapura' => {
			exemplarCity => q#ଜୟପୁରା#,
		},
		'Asia/Jerusalem' => {
			exemplarCity => q#ଜେରୁଜେଲମ#,
		},
		'Asia/Kabul' => {
			exemplarCity => q#କାବୁଲ#,
		},
		'Asia/Kamchatka' => {
			exemplarCity => q#କାମଚାଟକା#,
		},
		'Asia/Karachi' => {
			exemplarCity => q#କରାଚି#,
		},
		'Asia/Katmandu' => {
			exemplarCity => q#କାଠମାଣ୍ଡୁ#,
		},
		'Asia/Khandyga' => {
			exemplarCity => q#ଖାନଡ୍ୟାଗା#,
		},
		'Asia/Krasnoyarsk' => {
			exemplarCity => q#କ୍ରାସନୋୟାରସ୍କ#,
		},
		'Asia/Kuala_Lumpur' => {
			exemplarCity => q#କ୍ୱାଲାଲମ୍ପୁର#,
		},
		'Asia/Kuching' => {
			exemplarCity => q#କୁଚିଂ#,
		},
		'Asia/Kuwait' => {
			exemplarCity => q#କୁଏତ#,
		},
		'Asia/Macau' => {
			exemplarCity => q#ମାକାଉ#,
		},
		'Asia/Magadan' => {
			exemplarCity => q#ମାଗାଡାନ୍#,
		},
		'Asia/Makassar' => {
			exemplarCity => q#ମାକାସାର୍‌#,
		},
		'Asia/Manila' => {
			exemplarCity => q#ମାନିଲା#,
		},
		'Asia/Muscat' => {
			exemplarCity => q#ମସ୍କାଟ୍‌#,
		},
		'Asia/Nicosia' => {
			exemplarCity => q#ନିକୋସିଆ#,
		},
		'Asia/Novokuznetsk' => {
			exemplarCity => q#ନୋଭୋକୁଜନେଟସ୍କ#,
		},
		'Asia/Novosibirsk' => {
			exemplarCity => q#ନୋଭୋସିବିରସ୍କ#,
		},
		'Asia/Omsk' => {
			exemplarCity => q#ଓମସ୍କ#,
		},
		'Asia/Oral' => {
			exemplarCity => q#ଓରାଲ୍‌#,
		},
		'Asia/Phnom_Penh' => {
			exemplarCity => q#ଫନୋମ୍‌ ପେନହ#,
		},
		'Asia/Pontianak' => {
			exemplarCity => q#ପୋଣ୍ଟିଆନାକ୍‌#,
		},
		'Asia/Pyongyang' => {
			exemplarCity => q#ପୋୟଙ୍ଗୟାଙ୍ଗ#,
		},
		'Asia/Qatar' => {
			exemplarCity => q#କତାର୍#,
		},
		'Asia/Qostanay' => {
			exemplarCity => q#କୋଷ୍ଟନେ#,
		},
		'Asia/Qyzylorda' => {
			exemplarCity => q#କୀଜିଲୋର୍ଡା#,
		},
		'Asia/Rangoon' => {
			exemplarCity => q#ୟାଙ୍ଗୁନ୍‌#,
		},
		'Asia/Riyadh' => {
			exemplarCity => q#ରିଆଦ#,
		},
		'Asia/Saigon' => {
			exemplarCity => q#ହୋ ଚି ମିନ୍‌ ସିଟି#,
		},
		'Asia/Sakhalin' => {
			exemplarCity => q#ସଖାଲିନ୍#,
		},
		'Asia/Samarkand' => {
			exemplarCity => q#ସମରକନ୍ଦ#,
		},
		'Asia/Seoul' => {
			exemplarCity => q#ସିଓଲ#,
		},
		'Asia/Shanghai' => {
			exemplarCity => q#ସାଂଘାଇ#,
		},
		'Asia/Singapore' => {
			exemplarCity => q#ସିଙ୍ଗାପୁର୍‌#,
		},
		'Asia/Srednekolymsk' => {
			exemplarCity => q#ସ୍ରେଡନେକୋଲୟମସ୍କ#,
		},
		'Asia/Taipei' => {
			exemplarCity => q#ତାଇପେଇ#,
		},
		'Asia/Tashkent' => {
			exemplarCity => q#ତାଶକେଣ୍ଟ#,
		},
		'Asia/Tbilisi' => {
			exemplarCity => q#ଟିବିଲିସି#,
		},
		'Asia/Tehran' => {
			exemplarCity => q#ତେହେରାନ୍#,
		},
		'Asia/Thimphu' => {
			exemplarCity => q#ଥିମ୍ପୁ#,
		},
		'Asia/Tokyo' => {
			exemplarCity => q#ଟୋକିଓ#,
		},
		'Asia/Tomsk' => {
			exemplarCity => q#ଟୋମସ୍କ#,
		},
		'Asia/Ulaanbaatar' => {
			exemplarCity => q#ଉଲାନ୍‌ବାଟର୍‌#,
		},
		'Asia/Urumqi' => {
			exemplarCity => q#ଉରୁମକି#,
		},
		'Asia/Ust-Nera' => {
			exemplarCity => q#ୟୁଷ୍ଟ-ନେରା#,
		},
		'Asia/Vientiane' => {
			exemplarCity => q#ଭିଏଣ୍ଟିଏନ୍‌#,
		},
		'Asia/Vladivostok' => {
			exemplarCity => q#ଭ୍ଲାଡିଭୋଷ୍ଟୋକ୍#,
		},
		'Asia/Yakutsk' => {
			exemplarCity => q#ୟାକୁଟସ୍କ#,
		},
		'Asia/Yekaterinburg' => {
			exemplarCity => q#ୟେକାଟେରିନବର୍ଗ୍#,
		},
		'Asia/Yerevan' => {
			exemplarCity => q#ୟେରେଭାନ୍#,
		},
		'Atlantic' => {
			long => {
				'daylight' => q#ଆଟଲାଣ୍ଟିକ୍ ଦିବାଲୋକ ସମୟ#,
				'generic' => q#ଆଟଲାଣ୍ଟିକ୍ ସମୟ#,
				'standard' => q#ଆଟଲାଣ୍ଟିକ୍ ମାନାଙ୍କ ସମୟ#,
			},
		},
		'Atlantic/Azores' => {
			exemplarCity => q#ଆଜୋରେସ୍#,
		},
		'Atlantic/Bermuda' => {
			exemplarCity => q#ବର୍ମୁଡା#,
		},
		'Atlantic/Canary' => {
			exemplarCity => q#କାନାରେ#,
		},
		'Atlantic/Cape_Verde' => {
			exemplarCity => q#କେପ୍‌ ଭର୍ଦେ#,
		},
		'Atlantic/Faeroe' => {
			exemplarCity => q#ଫାରୋଏ#,
		},
		'Atlantic/Madeira' => {
			exemplarCity => q#ମାଡେଇରା#,
		},
		'Atlantic/Reykjavik' => {
			exemplarCity => q#ରେୟକଜାଭିକ୍#,
		},
		'Atlantic/South_Georgia' => {
			exemplarCity => q#ଦକ୍ଷିଣ ଜର୍ଜିଆ#,
		},
		'Atlantic/St_Helena' => {
			exemplarCity => q#ସେଣ୍ଟ୍‌ ହେଲିନା#,
		},
		'Atlantic/Stanley' => {
			exemplarCity => q#ଷ୍ଟାନଲି#,
		},
		'Australia/Adelaide' => {
			exemplarCity => q#ଆଡିଲେଡ୍‌#,
		},
		'Australia/Brisbane' => {
			exemplarCity => q#ବ୍ରିସବେନ୍‌#,
		},
		'Australia/Broken_Hill' => {
			exemplarCity => q#ବ୍ରୋକେନ୍‌ ହିଲ୍‌#,
		},
		'Australia/Darwin' => {
			exemplarCity => q#ଡାରୱିନ୍‌#,
		},
		'Australia/Eucla' => {
			exemplarCity => q#ୟୁକଲା#,
		},
		'Australia/Hobart' => {
			exemplarCity => q#ହୋବାର୍ଟ୍‌#,
		},
		'Australia/Lindeman' => {
			exemplarCity => q#ଲିଣ୍ଡେମ୍ୟାନ୍‌#,
		},
		'Australia/Lord_Howe' => {
			exemplarCity => q#ଲର୍ଡ ହୋୱେ#,
		},
		'Australia/Melbourne' => {
			exemplarCity => q#ମେଲବୋର୍ଣ୍ଣ#,
		},
		'Australia/Perth' => {
			exemplarCity => q#ପର୍ଥ୍‌#,
		},
		'Australia/Sydney' => {
			exemplarCity => q#ସିଡନୀ#,
		},
		'Australia_Central' => {
			long => {
				'daylight' => q#ଅଷ୍ଟ୍ରେଲିୟ ମଧ୍ୟ ଦିବାଲୋକ ସମୟ#,
				'generic' => q#ମଧ୍ୟ ଅଷ୍ଟ୍ରେଲିଆ ସମୟ#,
				'standard' => q#ଅଷ୍ଟ୍ରେଲିୟ ମଧ୍ୟ ମାନାଙ୍କ ସମୟ#,
			},
		},
		'Australia_CentralWestern' => {
			long => {
				'daylight' => q#ଅଷ୍ଟ୍ରେଲିୟ ମଧ୍ୟ ପଶ୍ଚିମ ଦିବାଲୋକ ସମୟ#,
				'generic' => q#ଅଷ୍ଟ୍ରେଲିୟ ମଧ୍ୟ ପଶ୍ଚିମ ସମୟ#,
				'standard' => q#ଅଷ୍ଟ୍ରେଲିୟ ମଧ୍ୟ ପଶ୍ଚିମ ମାନାଙ୍କ ସମୟ#,
			},
		},
		'Australia_Eastern' => {
			long => {
				'daylight' => q#ଅଷ୍ଟ୍ରେଲିୟ ପୂର୍ବ ଦିବାଲୋକ ସମୟ#,
				'generic' => q#ପୂର୍ବ ଅଷ୍ଟ୍ରେଲିଆ ସମୟ#,
				'standard' => q#ଅଷ୍ଟ୍ରେଲିୟ ପୂର୍ବ ମାନାଙ୍କ ସମୟ#,
			},
		},
		'Australia_Western' => {
			long => {
				'daylight' => q#ଅଷ୍ଟ୍ରେଲିୟ ପଶ୍ଚିମ ଦିବାଲୋକ ସମୟ#,
				'generic' => q#ପଶ୍ଚିମ ଅଷ୍ଟ୍ରେଲିଆ ସମୟ#,
				'standard' => q#ଅଷ୍ଟ୍ରେଲିୟ ପଶ୍ଚିମ ମାନାଙ୍କ ସମୟ#,
			},
		},
		'Azerbaijan' => {
			long => {
				'daylight' => q#ଆଜେରବାଇଜାନ ଖରାଦିନ ସମୟ#,
				'generic' => q#ଆଜେରବାଇଜାନ ସମୟ#,
				'standard' => q#ଆଜେରବାଇଜାନ ମାନଙ୍କ ସମୟ#,
			},
		},
		'Azores' => {
			long => {
				'daylight' => q#ଆଜୋରେସ୍ ଗ୍ରୀଷ୍ମକାଳ ସମୟ#,
				'generic' => q#ଆଜୋରେସ୍ ସମୟ#,
				'standard' => q#ଆଜୋରେସ୍ ମାନକ ସମୟ#,
			},
		},
		'Bangladesh' => {
			long => {
				'daylight' => q#ବାଂଲାଦେଶ ଗ୍ରୀଷ୍ମକାଳୀନ ସମୟ#,
				'generic' => q#ବାଂଲାଦେଶ ସମୟ#,
				'standard' => q#ବାଂଲାଦେଶ ମାନାଙ୍କ ସମୟ#,
			},
		},
		'Bhutan' => {
			long => {
				'standard' => q#ଭୁଟାନ ସମୟ#,
			},
		},
		'Bolivia' => {
			long => {
				'standard' => q#ବଲିଭିଆ ସମୟ#,
			},
		},
		'Brasilia' => {
			long => {
				'daylight' => q#ବ୍ରାସିଲିଆ ଗ୍ରୀଷ୍ମକାଳ ସମୟ#,
				'generic' => q#ବ୍ରାସିଲିଆ ସମୟ#,
				'standard' => q#ବ୍ରାସିଲିଆ ମାନାଙ୍କ ସମୟ#,
			},
		},
		'Brunei' => {
			long => {
				'standard' => q#ବ୍ରୁନେଇ ଡାରୁସାଲାମ ସମୟ#,
			},
		},
		'Cape_Verde' => {
			long => {
				'daylight' => q#କେପ୍‌ ଭର୍ଦେ ଗ୍ରୀଷ୍ମକାଳୀନ ସମୟ#,
				'generic' => q#କେପ୍‌ ଭର୍ଦେ ସମୟ#,
				'standard' => q#କେପ୍‌ ଭର୍ଦେ ମାନାଙ୍କ ସମୟ#,
			},
		},
		'Chamorro' => {
			long => {
				'standard' => q#ଚାମୋରୋ ମାନକ ସମୟ#,
			},
		},
		'Chatham' => {
			long => {
				'daylight' => q#ଚାଥାମ୍‌ ଦିବାଲୋକ ସମୟ#,
				'generic' => q#ଚାଥାମ୍‌ ସମୟ#,
				'standard' => q#ଚାଥାମ୍‌ ମାନାଙ୍କ ସମୟ#,
			},
		},
		'Chile' => {
			long => {
				'daylight' => q#ଚିଲି ଗ୍ରୀଷ୍ମକାଳ ସମୟ#,
				'generic' => q#ଚିଲି ସମୟ#,
				'standard' => q#ଚିଲି ମାନାଙ୍କ ସମୟ#,
			},
		},
		'China' => {
			long => {
				'daylight' => q#ଚୀନ ଦିବାଲୋକ ସମୟ#,
				'generic' => q#ଚୀନ ସମୟ#,
				'standard' => q#ଚୀନ ମାନକ ସମୟ#,
			},
		},
		'Christmas' => {
			long => {
				'standard' => q#ଖ୍ରୀଷ୍ଟମାସ ଦ୍ୱୀପ ସମୟ#,
			},
		},
		'Cocos' => {
			long => {
				'standard' => q#କୋକୋସ୍‌ ଦ୍ୱୀପପୁଞ୍ଜ ସମୟ#,
			},
		},
		'Colombia' => {
			long => {
				'daylight' => q#କଲମ୍ବିଆ ଗ୍ରୀଷ୍ମକାଳ ସମୟ#,
				'generic' => q#କଲମ୍ବିଆ ସମୟ#,
				'standard' => q#କଲମ୍ବିଆ ମାନକ ସମୟ#,
			},
		},
		'Cook' => {
			long => {
				'daylight' => q#କୁକ୍‌ ଦ୍ୱୀପପୁଞ୍ଜ ଅର୍ଦ୍ଧ ଗୀଷ୍ମକାଳୀନ ସମୟ#,
				'generic' => q#କୁକ୍‌ ଦ୍ୱୀପପୁଞ୍ଜ ସମୟ#,
				'standard' => q#କୁକ୍‌ ଦ୍ୱୀପପୁଞ୍ଜ ମାନକ ସମୟ#,
			},
		},
		'Cuba' => {
			long => {
				'daylight' => q#କ୍ୟୁବା ଦିବାଲୋକ ସମୟ#,
				'generic' => q#କ୍ୟୁବା ସମୟ#,
				'standard' => q#କ୍ୟୁବା ମାନାଙ୍କ ସମୟ#,
			},
		},
		'Davis' => {
			long => {
				'standard' => q#ଡେଭିସ୍‌ ସମୟ#,
			},
		},
		'DumontDUrville' => {
			long => {
				'standard' => q#ଡୁମୋଣ୍ଟ-ଡି‘ଉରଭିଲ୍ଲେ ସମୟ#,
			},
		},
		'East_Timor' => {
			long => {
				'standard' => q#ପୂର୍ବ ତିମୋର୍‌ ସମୟ#,
			},
		},
		'Easter' => {
			long => {
				'daylight' => q#ଇଷ୍ଟର୍‌ ଆଇଲ୍ୟାଣ୍ଡ ଗ୍ରୀଷ୍ମକାଳ ସମୟ#,
				'generic' => q#ଇଷ୍ଟର୍‌ ଆଇଲ୍ୟାଣ୍ଡ ସମୟ#,
				'standard' => q#ଇଷ୍ଟର୍‌ ଆଇଲ୍ୟାଣ୍ଡ ମାନାଙ୍କ ସମୟ#,
			},
		},
		'Ecuador' => {
			long => {
				'standard' => q#ଇକ୍ୱେଡର ସମୟ#,
			},
		},
		'Etc/UTC' => {
			long => {
				'standard' => q#ସମନ୍ୱିତ ସାର୍ବଜନୀନ ସମୟ#,
			},
		},
		'Etc/Unknown' => {
			exemplarCity => q#ଅଜଣା ସହର#,
		},
		'Europe/Amsterdam' => {
			exemplarCity => q#ଆମଷ୍ଟରଡାମ୍#,
		},
		'Europe/Andorra' => {
			exemplarCity => q#ଆନଡୋରା#,
		},
		'Europe/Astrakhan' => {
			exemplarCity => q#ଆଷ୍ଟ୍ରାଖାନ୍#,
		},
		'Europe/Athens' => {
			exemplarCity => q#ଏଥେନ୍ସ#,
		},
		'Europe/Belgrade' => {
			exemplarCity => q#ବେଲଗ୍ରେଡ୍‌#,
		},
		'Europe/Berlin' => {
			exemplarCity => q#ବର୍ଲିନ୍#,
		},
		'Europe/Bratislava' => {
			exemplarCity => q#ବ୍ରାଟିସଲାଭା#,
		},
		'Europe/Brussels' => {
			exemplarCity => q#ବ୍ରସଲ୍ସ୍#,
		},
		'Europe/Bucharest' => {
			exemplarCity => q#ବୁଚାରେଷ୍ଟ୍#,
		},
		'Europe/Budapest' => {
			exemplarCity => q#ବୁଡାପେଷ୍ଟ୍#,
		},
		'Europe/Busingen' => {
			exemplarCity => q#ବୁସିନଗେନ୍#,
		},
		'Europe/Chisinau' => {
			exemplarCity => q#ଚିସିନୌ#,
		},
		'Europe/Copenhagen' => {
			exemplarCity => q#କୋପେନହାଗେନ୍#,
		},
		'Europe/Dublin' => {
			exemplarCity => q#ଡବଲିନ୍#,
			long => {
				'daylight' => q#ଆଇରିଶ୍‌ ମାନକ ସମୟ#,
			},
		},
		'Europe/Gibraltar' => {
			exemplarCity => q#ଜିବ୍ରାଲଟର୍‌#,
		},
		'Europe/Guernsey' => {
			exemplarCity => q#ଗୁଏରନସେ#,
		},
		'Europe/Helsinki' => {
			exemplarCity => q#ହେଲସିନକି#,
		},
		'Europe/Isle_of_Man' => {
			exemplarCity => q#ଇସଲେ ଅଫ୍ ମେନ୍#,
		},
		'Europe/Istanbul' => {
			exemplarCity => q#ଇସ୍ତାନବୁଲ#,
		},
		'Europe/Jersey' => {
			exemplarCity => q#ଜର୍ସି#,
		},
		'Europe/Kaliningrad' => {
			exemplarCity => q#କାଲିନିନଗ୍ରାଡ୍#,
		},
		'Europe/Kiev' => {
			exemplarCity => q#କିଏଭ୍#,
		},
		'Europe/Kirov' => {
			exemplarCity => q#କିରୋଭ#,
		},
		'Europe/Lisbon' => {
			exemplarCity => q#ଲିସବୋନ୍#,
		},
		'Europe/Ljubljana' => {
			exemplarCity => q#ଲଜୁବ୍ଲଜାନ୍#,
		},
		'Europe/London' => {
			exemplarCity => q#ଲଣ୍ଡନ୍#,
			long => {
				'daylight' => q#ବ୍ରିଟିଶ୍‌ ଗ୍ରୀଷ୍ମକାଳୀନ ସମୟ#,
			},
		},
		'Europe/Luxembourg' => {
			exemplarCity => q#ଲକ୍ସମବର୍ଗ#,
		},
		'Europe/Madrid' => {
			exemplarCity => q#ମାଡ୍ରିଡ୍#,
		},
		'Europe/Malta' => {
			exemplarCity => q#ମାଲଟା#,
		},
		'Europe/Mariehamn' => {
			exemplarCity => q#ମାରିଏହାମନ୍#,
		},
		'Europe/Minsk' => {
			exemplarCity => q#ମିନସ୍କ#,
		},
		'Europe/Monaco' => {
			exemplarCity => q#ମୋନାକୋ#,
		},
		'Europe/Moscow' => {
			exemplarCity => q#ମସ୍କୋ#,
		},
		'Europe/Oslo' => {
			exemplarCity => q#ଓସଲୋ#,
		},
		'Europe/Paris' => {
			exemplarCity => q#ପେରିସ୍#,
		},
		'Europe/Podgorica' => {
			exemplarCity => q#ପୋଡଗୋରିକା#,
		},
		'Europe/Prague' => {
			exemplarCity => q#ପ୍ରାଗ୍#,
		},
		'Europe/Riga' => {
			exemplarCity => q#ରିଗା#,
		},
		'Europe/Rome' => {
			exemplarCity => q#ରୋମ୍#,
		},
		'Europe/Samara' => {
			exemplarCity => q#ସାମାରା#,
		},
		'Europe/San_Marino' => {
			exemplarCity => q#ସାନ୍ ମାରିନୋ#,
		},
		'Europe/Sarajevo' => {
			exemplarCity => q#ସାରାଜେଭୋ#,
		},
		'Europe/Saratov' => {
			exemplarCity => q#ସାରାଟୋଭ୍#,
		},
		'Europe/Simferopol' => {
			exemplarCity => q#ସିମଫେରୋପୋଲ୍#,
		},
		'Europe/Skopje' => {
			exemplarCity => q#ସ୍କୋପଜେ#,
		},
		'Europe/Sofia' => {
			exemplarCity => q#ସୋଫିଆ#,
		},
		'Europe/Stockholm' => {
			exemplarCity => q#ଷ୍ଟକହୋମ୍‌#,
		},
		'Europe/Tallinn' => {
			exemplarCity => q#ଟାଲିନ୍ନ#,
		},
		'Europe/Tirane' => {
			exemplarCity => q#ଟିରାନେ#,
		},
		'Europe/Ulyanovsk' => {
			exemplarCity => q#ୟୁଲୟାନୋଭସ୍କ#,
		},
		'Europe/Vaduz' => {
			exemplarCity => q#ଭାଡୁଜ#,
		},
		'Europe/Vatican' => {
			exemplarCity => q#ଭାଟିକାନ୍#,
		},
		'Europe/Vienna' => {
			exemplarCity => q#ଭିଏନା#,
		},
		'Europe/Vilnius' => {
			exemplarCity => q#ଭିଲନିଉସ୍#,
		},
		'Europe/Volgograd' => {
			exemplarCity => q#ଭୋଲଗୋଗ୍ରାଡ୍#,
		},
		'Europe/Warsaw' => {
			exemplarCity => q#ୱାରସୱା#,
		},
		'Europe/Zagreb' => {
			exemplarCity => q#ଜାଗ୍ରେବ୍#,
		},
		'Europe/Zurich' => {
			exemplarCity => q#ଜୁରିକ୍#,
		},
		'Europe_Central' => {
			long => {
				'daylight' => q#କେନ୍ଦ୍ରୀୟ ୟୁରୋପୀୟ ଗ୍ରୀଷ୍ମକାଳ ସମୟ#,
				'generic' => q#କେନ୍ଦ୍ରୀୟ ୟୁରୋପୀୟ ସମୟ#,
				'standard' => q#କେନ୍ଦ୍ର ୟୁରୋପୀୟ ମାନକ ସମୟ#,
			},
		},
		'Europe_Eastern' => {
			long => {
				'daylight' => q#ପୂର୍ବାଞ୍ଚଳ ୟୁରୋପୀୟ ଗ୍ରୀଷ୍ମକାଳ ସମୟ#,
				'generic' => q#ପୂର୍ବାଞ୍ଚଳ ୟୁରୋପୀୟ ସମୟ#,
				'standard' => q#ପୂର୍ବାଞ୍ଚଳ ୟୁରୋପୀୟ ମାନାଙ୍କ ସମୟ#,
			},
		},
		'Europe_Further_Eastern' => {
			long => {
				'standard' => q#ପରବର୍ତ୍ତୀ-ପୂର୍ବାଞ୍ଚଳ ୟୁରୋପୀୟ ସମୟ#,
			},
		},
		'Europe_Western' => {
			long => {
				'daylight' => q#ପଶ୍ଚିମାଞ୍ଚଳ ୟୁରୋପୀୟ ଗ୍ରୀଷ୍ମକାଳ ସମୟ#,
				'generic' => q#ପଶ୍ଚିମାଞ୍ଚଳ ୟୁରୋପୀୟ ସମୟ#,
				'standard' => q#ପଶ୍ଚିମାଞ୍ଚଳ ୟୁରୋପୀୟ ମାନାଙ୍କ ସମୟ#,
			},
		},
		'Falkland' => {
			long => {
				'daylight' => q#ଫକଲ୍ୟାଣ୍ଡ ଦ୍ୱୀପପୁଞ୍ଜ ଗ୍ରୀଷ୍ମକାଳ ସମୟ#,
				'generic' => q#ଫକଲ୍ୟାଣ୍ଡ ଦ୍ୱୀପପୁଞ୍ଜ ସମୟ#,
				'standard' => q#ଫକଲ୍ୟାଣ୍ଡ ଦ୍ୱୀପପୁଞ୍ଜ ମାନକ ସମୟ#,
			},
		},
		'Fiji' => {
			long => {
				'daylight' => q#ଫିଜି ଗ୍ରୀଷ୍ମକାଳୀନ ସମୟ#,
				'generic' => q#ଫିଜି ସମୟ#,
				'standard' => q#ଫିଜି ମାନକ ସମୟ#,
			},
		},
		'French_Guiana' => {
			long => {
				'standard' => q#ଫ୍ରେଞ୍ଚ ଗୁଆନା ସମୟ#,
			},
		},
		'French_Southern' => {
			long => {
				'standard' => q#ଫ୍ରେଞ୍ଚ ଦକ୍ଷିଣ ଏବଂ ଆଣ୍ଟାର୍କାଟିକ୍‌ ସମୟ#,
			},
		},
		'GMT' => {
			long => {
				'standard' => q#ଗ୍ରୀନୱିଚ୍ ମିନ୍ ସମୟ#,
			},
			short => {
				'standard' => q#GMT#,
			},
		},
		'Galapagos' => {
			long => {
				'standard' => q#ଗାଲାପାଗୋସ୍ ସମୟ#,
			},
		},
		'Gambier' => {
			long => {
				'standard' => q#ଗାମ୍ବିୟର୍ ସମୟ#,
			},
		},
		'Georgia' => {
			long => {
				'daylight' => q#ଜର୍ଜିଆ ଖରାଦିନ ସମୟ#,
				'generic' => q#ଜର୍ଜିଆ ସମୟ#,
				'standard' => q#ଜର୍ଜିଆ ମାନାଙ୍କ ସମୟ#,
			},
		},
		'Gilbert_Islands' => {
			long => {
				'standard' => q#ଗିଲବର୍ଟ୍‌ ଦ୍ୱୀପପୁଞ୍ଜ ସମୟ#,
			},
		},
		'Greenland_Eastern' => {
			long => {
				'daylight' => q#ପୂର୍ବ ଗ୍ରୀନଲ୍ୟାଣ୍ଡ୍ ଗ୍ରୀଷ୍ମକାଳ ସମୟ#,
				'generic' => q#ପୂର୍ବ ଗ୍ରୀନଲ୍ୟାଣ୍ଡ୍ ସମୟ#,
				'standard' => q#ପୂର୍ବ ଗ୍ରୀନଲ୍ୟାଣ୍ଡ୍ ମାନାଙ୍କ ସମୟ#,
			},
		},
		'Greenland_Western' => {
			long => {
				'daylight' => q#ପଶ୍ଚିମ ଗ୍ରୀନଲ୍ୟାଣ୍ଡ୍ ଗ୍ରୀଷ୍ମ ସମୟ#,
				'generic' => q#ପଶ୍ଚିମ ଗ୍ରୀନଲ୍ୟାଣ୍ଡ୍ ସମୟ#,
				'standard' => q#ପଶ୍ଚିମ ଗ୍ରୀନଲ୍ୟାଣ୍ଡ୍ ମାନାଙ୍କ ସମୟ#,
			},
		},
		'Gulf' => {
			long => {
				'standard' => q#ଗଲ୍ଫ ମାନାଙ୍କ ସମୟ#,
			},
		},
		'Guyana' => {
			long => {
				'standard' => q#ଗୁଏନା ସମୟ#,
			},
		},
		'Hawaii_Aleutian' => {
			long => {
				'daylight' => q#ହୱାଇ-ଆଲେଉଟିୟ ଦିବାଲୋକ ସମୟ#,
				'generic' => q#ହୱାଇ-ଆଲେଉଟିୟ ସମୟ#,
				'standard' => q#ହୱାଇ-ଆଲେଉଟିୟ ମାନାଙ୍କ ସମୟ#,
			},
		},
		'Hong_Kong' => {
			long => {
				'daylight' => q#ହଂ କଂ ଗ୍ରୀଷ୍ମକାଳ ସମୟ#,
				'generic' => q#ହଂ କଂ ସମୟ#,
				'standard' => q#ହଂ କଂ ମାନକ ସମୟ#,
			},
		},
		'Hovd' => {
			long => {
				'daylight' => q#ହୋଭଡ୍‌ ଗ୍ରୀଷ୍ମକାଳ ସମୟ#,
				'generic' => q#ହୋଭଡ୍‌ ସମୟ#,
				'standard' => q#ହୋଭଡ୍‌ ମାନକ ସମୟ#,
			},
		},
		'India' => {
			long => {
				'standard' => q#ଭାରତୀୟ ମାନକ ସମୟ#,
			},
			short => {
				'standard' => q#IST#,
			},
		},
		'Indian/Antananarivo' => {
			exemplarCity => q#ଆଣ୍ଟାନାନାରିଭୋ#,
		},
		'Indian/Chagos' => {
			exemplarCity => q#ଚାଗୋସ୍‌#,
		},
		'Indian/Christmas' => {
			exemplarCity => q#ଖ୍ରୀଷ୍ଟମାସ#,
		},
		'Indian/Cocos' => {
			exemplarCity => q#କୋକୋସ୍‌#,
		},
		'Indian/Comoro' => {
			exemplarCity => q#କୋମୋରୋ#,
		},
		'Indian/Kerguelen' => {
			exemplarCity => q#କେରୁଗେଲେନ#,
		},
		'Indian/Mahe' => {
			exemplarCity => q#ମାହେ#,
		},
		'Indian/Maldives' => {
			exemplarCity => q#ମାଳଦ୍ୱୀପ#,
		},
		'Indian/Mauritius' => {
			exemplarCity => q#ମୌରିସସ୍#,
		},
		'Indian/Mayotte' => {
			exemplarCity => q#ମାୟୋଟେ#,
		},
		'Indian/Reunion' => {
			exemplarCity => q#ରିୟୁନିଅନ୍‌#,
		},
		'Indian_Ocean' => {
			long => {
				'standard' => q#ଭାରତ ମାହାସାଗର ସମୟ#,
			},
		},
		'Indochina' => {
			long => {
				'standard' => q#ଇଣ୍ଡୋଚାଇନା ସମୟ#,
			},
		},
		'Indonesia_Central' => {
			long => {
				'standard' => q#ମଧ୍ୟ ଇଣ୍ଡୋନେସିଆ ସମୟ#,
			},
		},
		'Indonesia_Eastern' => {
			long => {
				'standard' => q#ପୂର୍ବ ଇଣ୍ଡୋନେସିଆ ସମୟ#,
			},
		},
		'Indonesia_Western' => {
			long => {
				'standard' => q#ପଶ୍ଚିମ ଇଣ୍ଡୋନେସିଆ ସମୟ#,
			},
		},
		'Iran' => {
			long => {
				'daylight' => q#ଇରାନ ଦିବାଲୋକ ସମୟ#,
				'generic' => q#ଇରାନ ସମୟ#,
				'standard' => q#ଇରାନ ମାନକ ସମୟ#,
			},
		},
		'Irkutsk' => {
			long => {
				'daylight' => q#ଇର୍କୁଟସ୍କ୍ ଗ୍ରୀଷ୍ମକାଳୀନ ସମୟ#,
				'generic' => q#ଇଅରକୁଟସ୍କ ସମୟ#,
				'standard' => q#ଇର୍କୁଟସ୍କ୍ ମାନକ ସମୟ#,
			},
		},
		'Israel' => {
			long => {
				'daylight' => q#ଇସ୍ରାଏଲ ଦିବାଲୋକ ସମୟ#,
				'generic' => q#ଇସ୍ରାଏଲ ସମୟ#,
				'standard' => q#ଇସ୍ରାଏଲ ମାନାଙ୍କ ସମୟ#,
			},
		},
		'Japan' => {
			long => {
				'daylight' => q#ଜାପାନ ଦିବାଲୋକ ସମୟ#,
				'generic' => q#ଜାପାନ ସମୟ#,
				'standard' => q#ଜାପାନ ମାନକ ସମୟ#,
			},
		},
		'Kamchatka' => {
			long => {
				'daylight' => q#ପେଟ୍ରୋପାଭଲୋଭ୍ସକ-କମଚଟସ୍କି ଗ୍ରୀଷ୍ମ ସମୟ#,
				'generic' => q#ପେଟ୍ରୋପାଭଲୋଭ୍ସକ-କମଚଟସ୍କି ସମୟ#,
				'standard' => q#ପେଟ୍ରୋପାଭଲୋଭ୍ସକ-କମଚଟସ୍କି ମାନକ ସମୟ#,
			},
		},
		'Kazakhstan' => {
			long => {
				'standard' => q#କାଜାକସ୍ତାନ୍ ସମୟ#,
			},
		},
		'Kazakhstan_Eastern' => {
			long => {
				'standard' => q#ପୂର୍ବ କାଜାକସ୍ତାନ୍ ସମୟ#,
			},
		},
		'Kazakhstan_Western' => {
			long => {
				'standard' => q#ପଶ୍ଚିମ କାଜାକସ୍ତାନ ସମୟ#,
			},
		},
		'Korea' => {
			long => {
				'daylight' => q#କୋରିୟ ଦିବାଲୋକ ସମୟ#,
				'generic' => q#କୋରିୟ ସମୟ#,
				'standard' => q#କୋରିୟ ମାନକ ସମୟ#,
			},
		},
		'Kosrae' => {
			long => {
				'standard' => q#କୋସରେଇ ସମୟ#,
			},
		},
		'Krasnoyarsk' => {
			long => {
				'daylight' => q#କ୍ରାସନୋୟାରସ୍କ ଗ୍ରୀଷ୍ମକାଳ ସମୟ#,
				'generic' => q#କ୍ରାସନୋୟାରସ୍କ ସମୟ#,
				'standard' => q#କ୍ରାସନୋୟାରସ୍କ ମାନାଙ୍କ ସମୟ#,
			},
		},
		'Kyrgystan' => {
			long => {
				'standard' => q#କିର୍ଗିସ୍ତାନ ସମୟ#,
			},
		},
		'Lanka' => {
			long => {
				'standard' => q#ଲଙ୍କା ସମୟ#,
			},
		},
		'Line_Islands' => {
			long => {
				'standard' => q#ଲାଇନ୍‌ ଦ୍ୱୀପପୁଞ୍ଜ ସମୟ#,
			},
		},
		'Lord_Howe' => {
			long => {
				'daylight' => q#ଲର୍ଡ ହୋୱେ ଦିବାଲୋକ ସମୟ#,
				'generic' => q#ଲର୍ଡ ହୋୱେ ସମୟ#,
				'standard' => q#ଲର୍ଡ ହୋୱେ ମାନାଙ୍କ ସମୟ#,
			},
		},
		'Macau' => {
			long => {
				'daylight' => q#ମକାଓ ଗ୍ରୀଷ୍ମ ସମୟ#,
				'generic' => q#ମାକାଓ ସମୟ#,
				'standard' => q#ମକାଓ ମାନକ ସମୟ#,
			},
		},
		'Magadan' => {
			long => {
				'daylight' => q#ମାଗାଡାନ୍ ଗ୍ରୀଷ୍ମକାଳ ସମୟ#,
				'generic' => q#ମାଗାଡାନ୍ ସମୟ#,
				'standard' => q#ମାଗାଡାନ୍ ମାନାଙ୍କ ସମୟ#,
			},
		},
		'Malaysia' => {
			long => {
				'standard' => q#ମାଲେସିଆ ସମୟ#,
			},
		},
		'Maldives' => {
			long => {
				'standard' => q#ମାଳଦ୍ୱୀପ ସମୟ#,
			},
		},
		'Marquesas' => {
			long => {
				'standard' => q#ମାର୍କ୍ୱେସାସ୍‌ ସମୟ#,
			},
		},
		'Marshall_Islands' => {
			long => {
				'standard' => q#ମାର୍ଶାଲ୍‌ ଦ୍ୱୀପପୁଞ୍ଜ ସମୟ#,
			},
		},
		'Mauritius' => {
			long => {
				'daylight' => q#ମୌରିସସ୍‌ ଖରାଦିନ ସମୟ#,
				'generic' => q#ମୌରିସସ୍‌ ସମୟ#,
				'standard' => q#ମୌରିସସ୍‌ ମାନାଙ୍କ ସମୟ#,
			},
		},
		'Mawson' => {
			long => {
				'standard' => q#ମାୱସନ୍‌ ସମୟ#,
			},
		},
		'Mexico_Pacific' => {
			long => {
				'daylight' => q#ମେକ୍ସିକାନ୍ ପାସିଫିକ୍ ଦିବାଲୋକ ସମୟ#,
				'generic' => q#ମେକ୍ସିକାନ୍ ପାସିଫିକ୍ ସମୟ#,
				'standard' => q#ମେକ୍ସିକାନ୍ ପାସିଫିକ୍ ମାନାଙ୍କ ସମୟ#,
			},
		},
		'Mongolia' => {
			long => {
				'daylight' => q#ଉଲାନ୍‌ବାଟର୍‌ ଗ୍ରୀଷ୍ମକାଳୀନ ସମୟ#,
				'generic' => q#ଉଲାନ୍‌ବାଟର୍‌ ସମୟ#,
				'standard' => q#ଉଲାନ୍‌ବାଟର୍‌ ମାନକ ସମୟ#,
			},
		},
		'Moscow' => {
			long => {
				'daylight' => q#ମସ୍କୋ ଗ୍ରୀଷ୍ମକାଳ ସମୟ#,
				'generic' => q#ମସ୍କୋ ସମୟ#,
				'standard' => q#ମସ୍କୋ ମାନାଙ୍କ ସମୟ#,
			},
		},
		'Myanmar' => {
			long => {
				'standard' => q#ମିଆଁମାର୍‌ ସମୟ#,
			},
		},
		'Nauru' => {
			long => {
				'standard' => q#ନାଉରୁ ସମୟ#,
			},
		},
		'Nepal' => {
			long => {
				'standard' => q#ନେପାଳ ସମୟ#,
			},
		},
		'New_Caledonia' => {
			long => {
				'daylight' => q#ନ୍ୟୁ କାଲେଡୋନିଆ ଗ୍ରୀଷ୍ମକାଳ ସମୟ#,
				'generic' => q#ନ୍ୟୁ କାଲେଡୋନିଆ ସମୟ#,
				'standard' => q#ନ୍ୟୁ କାଲେଡୋନିଆ ମାନାଙ୍କ ସମୟ#,
			},
		},
		'New_Zealand' => {
			long => {
				'daylight' => q#ନ୍ୟୁଜିଲାଣ୍ଡ ଦିବାଲୋକ ସମୟ#,
				'generic' => q#ନ୍ୟୁଜିଲାଣ୍ଡ ସମୟ#,
				'standard' => q#ନ୍ୟୁଜିଲାଣ୍ଡ ମାନାଙ୍କ ସମୟ#,
			},
		},
		'Newfoundland' => {
			long => {
				'daylight' => q#ନ୍ୟୁଫାଉଣ୍ଡଲ୍ୟାଣ୍ଡ୍ ଦିବାଲୋକ ସମୟ#,
				'generic' => q#ନ୍ୟୁଫାଉଣ୍ଡଲ୍ୟାଣ୍ଡ୍ ସମୟ#,
				'standard' => q#ନ୍ୟୁଫାଉଣ୍ଡଲ୍ୟାଣ୍ଡ୍ ମାନାଙ୍କ ସମୟ#,
			},
		},
		'Niue' => {
			long => {
				'standard' => q#ନିୟୁ ସମୟ#,
			},
		},
		'Norfolk' => {
			long => {
				'daylight' => q#ନରଫୋକ୍‌ ଦ୍ୱୀପ ଗ୍ରୀଷ୍ମକାଳ ସମୟ#,
				'generic' => q#ନରଫୋକ୍‌ ଦ୍ୱୀପ ସମୟ#,
				'standard' => q#ନରଫୋକ୍‌ ଦ୍ୱୀପ ମାନାଙ୍କ ସମୟ#,
			},
		},
		'Noronha' => {
			long => {
				'daylight' => q#ଫର୍ଣ୍ଣାଣ୍ଡୋ ଡି ନୋରୋନ୍ନା ଗ୍ରୀଷ୍ମକାଳ ସମୟ#,
				'generic' => q#ଫର୍ଣ୍ଣାଣ୍ଡୋ ଡି ନୋରୋନ୍ନା ସମୟ#,
				'standard' => q#ଫର୍ଣ୍ଣାଣ୍ଡୋ ଡି ନୋରୋନ୍ନା ମାନାଙ୍କ ସମୟ#,
			},
		},
		'North_Mariana' => {
			long => {
				'standard' => q#ଉତ୍ତର ମେରିଆନା ଆଇଲ୍ୟାଣ୍ଡ ସମୟ#,
			},
		},
		'Novosibirsk' => {
			long => {
				'daylight' => q#ନୋଭୋସିବିରସ୍କ ଗ୍ରୀଷ୍ମକାଳ ସମୟ#,
				'generic' => q#ନୋଭୋସିବିରସ୍କ ସମୟ#,
				'standard' => q#ନୋଭୋସିବିରସ୍କ ମାନାଙ୍କ ସମୟ#,
			},
		},
		'Omsk' => {
			long => {
				'daylight' => q#ଓମସ୍କ ଗ୍ରୀଷ୍ମକାଳ ସମୟ#,
				'generic' => q#ଓମସ୍କ ସମୟ#,
				'standard' => q#ଓମସ୍କ ମାନାଙ୍କ ସମୟ#,
			},
		},
		'Pacific/Apia' => {
			exemplarCity => q#ଆପିଆ#,
		},
		'Pacific/Auckland' => {
			exemplarCity => q#ଅକଲାଣ୍ଡ#,
		},
		'Pacific/Bougainville' => {
			exemplarCity => q#ବୌଗେନ୍‌ଭିଲ୍ଲେ#,
		},
		'Pacific/Chatham' => {
			exemplarCity => q#ଚାଥାମ୍‌#,
		},
		'Pacific/Easter' => {
			exemplarCity => q#ଇଷ୍ଟର୍‌#,
		},
		'Pacific/Efate' => {
			exemplarCity => q#ଇଫେଟ୍‌#,
		},
		'Pacific/Enderbury' => {
			exemplarCity => q#ଏଣ୍ଡେରବୁରି#,
		},
		'Pacific/Fakaofo' => {
			exemplarCity => q#ଫାକାଓଫୋ#,
		},
		'Pacific/Fiji' => {
			exemplarCity => q#ଫିଜି#,
		},
		'Pacific/Funafuti' => {
			exemplarCity => q#ଫୁନାଫୁଟି#,
		},
		'Pacific/Galapagos' => {
			exemplarCity => q#ଗାଲାପାଗୋସ#,
		},
		'Pacific/Gambier' => {
			exemplarCity => q#ଗାମ୍ବିୟର୍‌#,
		},
		'Pacific/Guadalcanal' => {
			exemplarCity => q#ଗୁଆଡାଲକାନାଲ#,
		},
		'Pacific/Guam' => {
			exemplarCity => q#ଗୁଆମ#,
		},
		'Pacific/Honolulu' => {
			exemplarCity => q#ହୋନୋଲୁଲୁ#,
		},
		'Pacific/Kanton' => {
			exemplarCity => q#କ୍ୟାଣ୍ଟନ#,
		},
		'Pacific/Kiritimati' => {
			exemplarCity => q#କିରିତିମାଟି#,
		},
		'Pacific/Kosrae' => {
			exemplarCity => q#କୋସରେଇ#,
		},
		'Pacific/Kwajalein' => {
			exemplarCity => q#କ୍ୱାଜାଲେଇନ୍#,
		},
		'Pacific/Majuro' => {
			exemplarCity => q#ମାଜୁରୋ#,
		},
		'Pacific/Marquesas' => {
			exemplarCity => q#ମାର୍କ୍ୱେସାସ୍‌#,
		},
		'Pacific/Midway' => {
			exemplarCity => q#ମିଡ୍‌ୱେ#,
		},
		'Pacific/Nauru' => {
			exemplarCity => q#ନାଉରୁ#,
		},
		'Pacific/Niue' => {
			exemplarCity => q#ନିୟୂ#,
		},
		'Pacific/Norfolk' => {
			exemplarCity => q#ନରଫୋକ୍‌#,
		},
		'Pacific/Noumea' => {
			exemplarCity => q#ନୌମିୟ#,
		},
		'Pacific/Pago_Pago' => {
			exemplarCity => q#ପାଗୋ ପାଗୋ#,
		},
		'Pacific/Palau' => {
			exemplarCity => q#ପାଲାଉ#,
		},
		'Pacific/Pitcairn' => {
			exemplarCity => q#ପିଟକାରିନ୍‌#,
		},
		'Pacific/Ponape' => {
			exemplarCity => q#ପୋହନପେଇ#,
		},
		'Pacific/Port_Moresby' => {
			exemplarCity => q#ପୋର୍ଟ୍‌ ମୋରେସବି#,
		},
		'Pacific/Rarotonga' => {
			exemplarCity => q#ରାରୋଟୋଙ୍ଗା#,
		},
		'Pacific/Saipan' => {
			exemplarCity => q#ସାଇପାନ୍#,
		},
		'Pacific/Tahiti' => {
			exemplarCity => q#ତାହିତି#,
		},
		'Pacific/Tarawa' => {
			exemplarCity => q#ତାରୱା#,
		},
		'Pacific/Tongatapu' => {
			exemplarCity => q#ଟୋଙ୍ଗାଟାପୁ#,
		},
		'Pacific/Truk' => {
			exemplarCity => q#ଚୂକ୍‌#,
		},
		'Pacific/Wake' => {
			exemplarCity => q#ୱେକ୍#,
		},
		'Pacific/Wallis' => {
			exemplarCity => q#ୱାଲିସ୍‌#,
		},
		'Pakistan' => {
			long => {
				'daylight' => q#ପାକିସ୍ତାନ ଗ୍ରୀଷ୍ମକାଳ ସମୟ#,
				'generic' => q#ପାକିସ୍ତାନ ସମୟ#,
				'standard' => q#ପାକିସ୍ତାନ ମାନକ ସମୟ#,
			},
		},
		'Palau' => {
			long => {
				'standard' => q#ପାଲାଉ ସମୟ#,
			},
		},
		'Papua_New_Guinea' => {
			long => {
				'standard' => q#ପପୁଆ ନ୍ୟୁ ଗିନି ସମୟ#,
			},
		},
		'Paraguay' => {
			long => {
				'daylight' => q#ପାରାଗୁଏ ଗ୍ରୀଷ୍ମକାଳ ସମୟ#,
				'generic' => q#ପାରାଗୁଏ ସମୟ#,
				'standard' => q#ପାରାଗୁଏ ମାନାଙ୍କ ସମୟ#,
			},
		},
		'Peru' => {
			long => {
				'daylight' => q#ପେରୁ ଗ୍ରୀଷ୍ମକାଳ ସମୟ#,
				'generic' => q#ପେରୁ ସମୟ#,
				'standard' => q#ପେରୁ ମାନାଙ୍କ ସମୟ#,
			},
		},
		'Philippines' => {
			long => {
				'daylight' => q#ଫିଲିପାଇନ୍‌ ଗ୍ରୀଷ୍ମକାଳ ସମୟ#,
				'generic' => q#ଫିଲିପାଇନ୍‌ ସମୟ#,
				'standard' => q#ଫିଲିପାଇନ୍‌ ମାନାଙ୍କ ସମୟ#,
			},
		},
		'Phoenix_Islands' => {
			long => {
				'standard' => q#ଫିନିକ୍ସ ଦ୍ୱୀପପୁଞ୍ଜ ସମୟ#,
			},
		},
		'Pierre_Miquelon' => {
			long => {
				'daylight' => q#ସେଣ୍ଟ. ପିଏରେ ଏବଂ ମିକ୍ୟୁଲୋନ୍ ଦିବାଲୋକ ସମୟ#,
				'generic' => q#ସେଣ୍ଟ. ପିଏରେ ଏବଂ ମିକ୍ୟୁଲୋନ୍ ସମୟ#,
				'standard' => q#ସେଣ୍ଟ. ପିଏରେ ଏବଂ ମିକ୍ୟୁଲୋନ୍ ମାନାଙ୍କ ସମୟ#,
			},
		},
		'Pitcairn' => {
			long => {
				'standard' => q#ପିଟକେର୍ନ୍‌ ସମୟ#,
			},
		},
		'Ponape' => {
			long => {
				'standard' => q#ପୋନାପେ ସମୟ#,
			},
		},
		'Pyongyang' => {
			long => {
				'standard' => q#ପୋୟଙ୍ଗୟାଙ୍ଗ ସମୟ#,
			},
		},
		'Qyzylorda' => {
			long => {
				'daylight' => q#କାଜିଲୋର୍ଡା ଗ୍ରୀଷ୍ମ ସମୟ#,
				'generic' => q#କାଜିଲୋର୍ଡା ସମୟ#,
				'standard' => q#କାଜିଲୋର୍ଡା ମାନକ ସମୟ#,
			},
		},
		'Reunion' => {
			long => {
				'standard' => q#ରିୟୁନିଅନ୍‌ ସମୟ#,
			},
		},
		'Rothera' => {
			long => {
				'standard' => q#ରୋଥେରା ସମୟ#,
			},
		},
		'Sakhalin' => {
			long => {
				'daylight' => q#ସଖାଲିନ୍ ଗ୍ରୀଷ୍ମକାଳ ସମୟ#,
				'generic' => q#ସଖାଲିନ୍ ସମୟ#,
				'standard' => q#ସଖାଲିନ୍ ମାନାଙ୍କ ସମୟ#,
			},
		},
		'Samara' => {
			long => {
				'daylight' => q#ସମାରା ଗ୍ରୀଷ୍ମ ସମୟ#,
				'generic' => q#ସମାରା ସମୟ#,
				'standard' => q#ସମାରା ମାନକ ସମୟ#,
			},
		},
		'Samoa' => {
			long => {
				'daylight' => q#ସାମୋଆ ଦିବାଲୋକ ସମୟ#,
				'generic' => q#ସାମୋଆ ସମୟ#,
				'standard' => q#ସାମୋଆ ମାନକ ସମୟ#,
			},
		},
		'Seychelles' => {
			long => {
				'standard' => q#ସେଚେଲ୍ଲେସ୍‌ ସମୟ#,
			},
		},
		'Singapore' => {
			long => {
				'standard' => q#ସିଙ୍ଗାପୁର୍‌ ମାନକ ସମୟ#,
			},
		},
		'Solomon' => {
			long => {
				'standard' => q#ସୋଲୋମନ ଦ୍ୱୀପପୁଞ୍ଜ ସମୟ#,
			},
		},
		'South_Georgia' => {
			long => {
				'standard' => q#ଦକ୍ଷିଣ ଜର୍ଜିଆ ସମୟ#,
			},
		},
		'Suriname' => {
			long => {
				'standard' => q#ସୁରିନେମ୍‌ ସମୟ#,
			},
		},
		'Syowa' => {
			long => {
				'standard' => q#ସୋୱା ସମୟ#,
			},
		},
		'Tahiti' => {
			long => {
				'standard' => q#ତାହିତି ସମୟ#,
			},
		},
		'Taipei' => {
			long => {
				'daylight' => q#ତାଇପେଇ ଦିବାଲୋକ ସମୟ#,
				'generic' => q#ତାଇପେଇ ସମୟ#,
				'standard' => q#ତାଇପେଇ ମାନକ ସମୟ#,
			},
		},
		'Tajikistan' => {
			long => {
				'standard' => q#ତାଜିକିସ୍ତାନ ସମୟ#,
			},
		},
		'Tokelau' => {
			long => {
				'standard' => q#ଟୋକେଲାଉ ସମୟ#,
			},
		},
		'Tonga' => {
			long => {
				'daylight' => q#ଟୋଙ୍ଗା ଗ୍ରୀଷ୍ମକାଳୀନ ସମୟ#,
				'generic' => q#ଟୋଙ୍ଗା ସମୟ#,
				'standard' => q#ଟୋଙ୍ଗା ମାନକ ସମୟ#,
			},
		},
		'Truk' => {
			long => {
				'standard' => q#ଚୂକ୍‌ ସମୟ#,
			},
		},
		'Turkmenistan' => {
			long => {
				'daylight' => q#ତୁର୍କମେନିସ୍ତାନ ଖରାଦିନ ସମୟ#,
				'generic' => q#ତୁର୍କମେନିସ୍ତାନ ସମୟ#,
				'standard' => q#ତୁର୍କମେନିସ୍ତାନ ମାନାଙ୍କ ସମୟ#,
			},
		},
		'Tuvalu' => {
			long => {
				'standard' => q#ତୁଭାଲୁ ସମୟ#,
			},
		},
		'Uruguay' => {
			long => {
				'daylight' => q#ଉରୁଗୁଏ ଗ୍ରୀଷ୍ମକାଳ ସମୟ#,
				'generic' => q#ଉରୁଗୁଏ ସମୟ#,
				'standard' => q#ଉରୁଗୁଏ ମାନାଙ୍କ ସମୟ#,
			},
		},
		'Uzbekistan' => {
			long => {
				'daylight' => q#ଉଜବେକିସ୍ତାନ ଗ୍ରୀଷ୍ମକାଳୀନ ସମୟ#,
				'generic' => q#ଉଜବେକିସ୍ତାନ ସମୟ#,
				'standard' => q#ଉଜବେକିସ୍ତାନ ମାନକ ସମୟ#,
			},
		},
		'Vanuatu' => {
			long => {
				'daylight' => q#ଭାନୁଆଟୁ ଗ୍ରୀଷ୍ମକାଳୀନ ସମୟ#,
				'generic' => q#ଭାନୁଆଟୁ ସମୟ#,
				'standard' => q#ଭାନୁଆଟୁ ମାନକ ସମୟ#,
			},
		},
		'Venezuela' => {
			long => {
				'standard' => q#ଭେନିଜୁଏଲା ସମୟ#,
			},
		},
		'Vladivostok' => {
			long => {
				'daylight' => q#ଭ୍ଲାଡିଭୋଷ୍ଟୋକ୍ ଗ୍ରୀଷ୍ମକାଳ ସମୟ#,
				'generic' => q#ଭ୍ଲାଡିଭୋଷ୍ଟୋକ୍ ସମୟ#,
				'standard' => q#ଭ୍ଲାଡିଭୋଷ୍ଟୋକ୍ ମାନାଙ୍କ ସମୟ#,
			},
		},
		'Volgograd' => {
			long => {
				'daylight' => q#ଭୋଲଗୋଗ୍ରାଡ୍ ଗ୍ରୀଷ୍ମକାଳ ସମୟ#,
				'generic' => q#ଭୋଲଗୋଗ୍ରାଡ୍ ସମୟ#,
				'standard' => q#ଭୋଲଗୋଗ୍ରାଡ୍ ମାନାଙ୍କ ସମୟ#,
			},
		},
		'Vostok' => {
			long => {
				'standard' => q#ଭୋଷ୍ଟୋକ୍‌ ସମୟ#,
			},
		},
		'Wake' => {
			long => {
				'standard' => q#ୱେକ୍‌ ଦ୍ୱୀପ ସମୟ#,
			},
		},
		'Wallis' => {
			long => {
				'standard' => q#ୱାଲିସ୍‌ ଏବଂ ଫୁଟୁନା ସମୟ#,
			},
		},
		'Yakutsk' => {
			long => {
				'daylight' => q#ୟାକୁଟସ୍କ ଗ୍ରୀଷ୍ମକାଳ ସମୟ#,
				'generic' => q#ୟାକୁଟସ୍କ ସମୟ#,
				'standard' => q#ୟାକୁଟସ୍କ ମାନାଙ୍କ ସମୟ#,
			},
		},
		'Yekaterinburg' => {
			long => {
				'daylight' => q#ୟେକାଟେରିନବର୍ଗ୍ ଗ୍ରୀଷ୍ମକାଳ ସମୟ#,
				'generic' => q#ୟେକାଟେରିନବର୍ଗ୍ ସମୟ#,
				'standard' => q#ୟେକାଟେରିନବର୍ଗ୍ ମାନାଙ୍କ ସମୟ#,
			},
		},
		'Yukon' => {
			long => {
				'standard' => q#ୟୁକୋନ୍ ସମୟ#,
			},
		},
	 } }
);
no Moo;

1;

# vim: tabstop=4
